/****************************************************************************/
/*                                                                          */
/*                               ARCHIVE.H                                  */
/*                                                                          */
/*  Header file for ReadArchive() functions                                 */
/*                                                                          */
/*  File Revision Record:                                                   */
/*  	04/24/98	Created from CLKPLT.H                                   */
/*                                                                          */
/*	(c) 1998 W. Riley  Hamilton Technical Services   All Rights Reserved    */
/*                                                                          */
/****************************************************************************/

/* INCLUDE FILES */
#include <stdio.h>
#include <conio.h>
#include <math.h>
#include <string.h>
#include <dos.h>
#include <process.h>
#include <setjmp.h>
#include <fcntl.h>
#include <sys\stat.h>
#include <io.h>
#include <stdlib.h>

/* MACROS */
#define TRACE_I(flag) printf(#flag "=%d\n", flag)           /* trace an int */
#define TRACE_F(flag) printf(#flag "=%e\n", flag)          /* trace a float */
#define TRACE_L(flag) printf(#flag "=%ld\n",flag)           /* trace a long */
#define SQR( a)  ((a) * (a))                             /* square a number */

/* DEFINES */

/* data and display */
#define DATASIZE 8000                           /* # clock freq data points */
#define ORGNAMESIZE 19              /* organization and address string size */
#define FIELDWIDTH 18         /* width of field to scan for config argument */

/* display colors */
#define TITLE_COLOR      (WHITE     + ((CYAN) <<4))
#define RECORD_COLOR     (WHITE     + ((CYAN) <<4))
#define FRAME_COLOR      (YELLOW    + ((CYAN) <<4))
#define HEADING_COLOR    (YELLOW    + ((CYAN) <<4))
#define INSTALLED_COLOR  (BLUE      + ((CYAN) <<4))
#define REMOVED_COLOR    (RED       + ((CYAN) <<4))
#define GAP_COLOR        (RED       + ((CYAN) <<4))
#define BACKGROUND_COLOR (CYAN      + ((CYAN) <<4))
#define ERROR_COLOR      (WHITE     + ((RED)  <<4))
#define MESSAGE_COLOR    (BLACK     + ((CYAN) <<4))
#define ID_COLOR         (BLACK     + ((CYAN) <<4))
#define WARNING_COLOR    (YELLOW    + ((BLACK)<<4))

/* data types and status codes */
#define PHASE 0                                      /* phase data type = 0 */
#define FREQ 1                                   /* frequency data type = 1 */
#define CONFIG 2                             /* configuration data type = 2 */

/* Boolean definitions */
#define BOOL int
#define TRUE 1
#define FALSE 0

/* configuration defaults */
#define MAXOUTS 5                      /* max # outliers that can be stored */
#define OUTLIM 5.0                          /* outlier std dev limit factor */
#define JMPLIM 3.0                               /* jump sigma limit factor */
#define JMPAVG 10                                  /* jump averaging factor */
#define SCATAVG 100                             /* scatter averaging factor */
#define YSCALE 1e12                            /* default freq scale factor */
#define XSCALE 1e6                            /* default phase scale factor */
#define TAU 900                                     /* measurement interval */
#define MAXCHAN 24                                     /* largest channel # */

/* constants */
#define SEC_PER_DAY 86400.                               /* seconds per day */
#if(1) // NEW CODE 04/23/95
#define MEAS_IN_LINE 5      /* screen line # for measurement MJD in display */
#define REF_IN_LINE 9        /* screen line #  for reference MJD in display */
#define MEAS_OUT_LINE 6    /* screen line # for measurement MJD out display */
#define REF_OUT_LINE 10     /* screen line #  for reference MJD out display */
#endif

/* STRUCTURE TEMPLATES */

struct plot_data
{
	char id[31];                                         /* clock id string */
	BOOL active;                                             /* active flag */
	BOOL rev;                                     /* ref chan reversal flag */
	// BOOL sign will control reversal of sign of phase or frequency data
	// Added to take care of case where TS-3020 offset LO is high
	// and beat note is reversed giving wrong sign in result
	// Normal operation for sign==FALSE
	// Reversed sign for sign==TRUE
	BOOL sign;
	int chan;                                                  /* channel # */
	int start_time;                            /* time measurements started */
	int start_doy;                              /* DOY measurements started */
	int numdat;                                       /* # y1[] data points */
	int numpoints;                              /* # unaveraged data points */
	int numgap;                                                   /* # gaps */
	int numout;                                               /* # outliers */
	int numplot;                                      /* # y2[] data points */
	int avgfactor;                                      /* averaging factor */
	int *n;                                              /* outlier # array */
	int datype;                     /* phase or frequency data for plotting */
	int record_number;                    /* record # of data being plotted */
	long start_mjd;                             /* MJD measurements started */
	realtype avg;                                      /* average frequency */
	realtype x_offset;                                    /* x scale offset */
	realtype *y_scale_min;                       /* freq plot scale minimum */
	realtype *y_scale_max;                       /* freq plot scale maximum */
	realtype *y_tickspacing;                /* freq plot scale tick spacing */
	realtype *x;                                              /* time array */
	realtype *x1;                                     /* phase data array 1 */
	realtype *x2;                                     /* phase data array 2 */
	realtype *y1;                                      /* freq data array 1 */
	realtype *y2;                                      /* freq data array 2 */
	realtype *xx;                                       /* lin fit x points */
	realtype *yy;                                       /* lin fit y points */
	realtype *o;                                     /* outlier value array */
};

struct config_data
{
	char filenam[FILENAME_MAX];                            /* data filename */
	char org[ORGNAMESIZE];                           /* organization string */
	char adr[ORGNAMESIZE];                                /* address string */
	BOOL norm;                     /* flag to normalize freq for phase plot */
	BOOL first;                                          /* first plot flag */
	BOOL noplot;                                /* flag to inhibit plotting */
	BOOL epdata;             /* flag to cause writing of EasyPlot data file */
	int jmpavg;                                    /* jump averaging factor */
	int scatavg;                                /* scatter averaging factor */
	int maxchan;                                          /* last channel # */
	int refchan;                                       /* reference channel */
	int day;   /* day flag: 0=points, 1=days, 2=DOY, 3=MJD for x-axis scale */
	float nomfreq;                                     /* nominal frequency */
	float xscale;                                     /* phase scale factor */
	float yscale;                                      /* freq scale factor */
	float tau;                                      /* measurement interval */
	float outlim;                                   /* outlier limit factor */
	float jmplim;                                      /* jump limit factor */
};

/* STABLE_Z.C  FUNCTIONS */
void usage_info(void);                                 /* usage information */
void allocate(void);           /* allocate memory for arrays and structures */
void parse_config(void);              /* parse 1 line of configuration file */
void gett_time(void);                    /* get time & date from MJD string */
void display_in(int line);                      /* display mjd in on screen */
void display_out(int line);                    /* display mjd out on screen */
void store_start(void);    /* store start mjd & time in plot_data structure */
void date_to_doy(void);                      /* convert date to day of year */
void chan_check(int argc);               /* check for invalid channel entry */
void gap_process(void);                              /* process gap in data */
void final_check(void);                     /* check that OK data was found */

/* GLOBAL VARIABLES */
extern struct plot_data *pdat;            /* pointer to plot data structure */
extern struct config_data cdat;             /* configuration data structure */

/****************************************************************************/

