/***************************************************************************\

   (c) 1992-1995, ProtoView Development Co., All rights reserved
\***************************************************************************/

/***************************************************\
*   Data Table Custom Control Constants and Types   *
\***************************************************/

#ifndef DATATBL_INCLUDED
#define DATATBL_INCLUDED

#ifdef __cplusplus
extern "C" {
#endif

#ifndef RC_INVOKED

#define MAXFMTLEN    120   // max allowable column format string length
#define MAXCELLLEN   1000  // max allowable column data length
#define MAXHEADLEN   200   // max allowable column heading length
#define MAXNAMELEN   100   // max allowable column name length

//***** Typedefs *****
typedef unsigned long ROWNUM;
typedef unsigned short COLNUM;
typedef unsigned short ROWSTAT;
typedef unsigned short ROWLEN;
typedef unsigned short COLSTAT;
typedef unsigned short COLTYPE;
typedef unsigned short COLSTYLE;
typedef unsigned short COLLEN;
typedef unsigned short ACCMODE;
typedef unsigned short CELLSTYLE;
typedef unsigned short ROWSTYLE;

#endif   /* ifndef RC_INVOKED */

#define ROWLABELTOP_PANE        0           // Row label column, Top Pane
#define LOCKEDTOP_PANE          1           // Locked column pane, Top Pane
#define LEFTTOP_PANE            2           // Left Pane, Top Pane
#define RIGHTTOP_PANE           3           // Right Pane, Top Pane

#define ROWLABELBOT_PANE        4           // Row label column, Bottom Pane
#define LOCKEDBOT_PANE          5           // Locked column pane, Bottom Pane
#define LEFTBOT_PANE            6           // Left Pane, Bottom Pane
#define RIGHTBOT_PANE           7           // Right Pane, Bottom Pane

#define DEFAULTCOLOR   6777217UL            // use default colors
#define MAXPANESIZE     32000               // pane is max size

//***** Window Styles *****
#define DTS_VIRTUALMEM  0x0001
#define DTS_AUTODROPDN  0x8002l
#define DTS_EDIT        0x0004
#define DTS_RESIZE      0x0008
#define DTS_NONE        0x0000
#define DTS_NUMBERS     0x0010
#define DTS_LETTERS     0x0020
#define DTS_OWNERDEF    0x0030
#define DTS_HGRID       0x0040
#define DTS_VGRID       0x0080
#define DTS_ROWSELECT   0x0100
#define DTS_MULTIROW    0x0200
#define DTS_COLSELECT   0x0400
#define DTS_MULTICOL    0x0800
#define DTS_SMALLDATA   0x0000
#define DTS_LARGEDATA   0x1000
#define DTS_ROWBUTTONS  0x2000
#define DTS_ROWNUMBERS  0x4000
#define DTS_DROPDOWN    0x8000l

/*****   Extended Style bits ****/
#define DTES_USETAB      0x00000001      // Use tab between cells
#define DTES_EETAB       0x00000002     // End Edit with Tab Key
#define DTES_EELRARROWS  0x00000004     // End Edit with LF, RT Arrow Keys
#define DTES_EEUDARROWS  0x00000008     // End Edit with UP, DN Arrow Keys
#define DTES_EECTLTAB    0x00000010     // End Edit with Ctl Tab
#define DTES_EECLICK     0x00000020     // End Edit With Mouse Click
#define DTES_COLMAJOR    0x00000040     // next cell via rows w/in cols
#define DTES_OWNERDRAW   0x00000080     // notiy parent when painting cells
#define DTES_AUTOINSERT  0x00000100     // auto insert New row at bottom
#define DTES_ROWRESIZE   0x00000200     // rows are resizable
#define DTES_INSKEY      0x00000400
#define DTES_DELKEY      0x00000800
#define DTES_SHOWHSCRL   0x00010000        // Disable No horizontal scroll
#define DTES_SHOWVSCRL   0x00020000        // Disable No vertical scroll
#define DTES_BLOCKSELECT 0x00040000
#define DTES_SPLITHORZ   0x00100000
#define DTES_SPLITVERT   0x00200000
#define DTES_USEBUBBLESORT 0x0040000

/*******  3d Effects    **********/
#define DT3D_NONE          0x0000
#define DT3D_HEAVYINDENT   0x0001   // Heavily Indented effect
#define DT3D_SHADOW        0x0002   // Shadow effect
#define DT3D_OUTDENT       0x0003   // Outdented effect
#define DT3D_INDENTFRAME   0x0004   // Indented frame
#define DT3D_LIGHTINDENT   0x0005   // Lightly indented

/****** Column Styles ******/
#define DTCS_RESIZE     0x0001
#define DTCS_FIXED      0x0002
#define DTCS_EDIT       0x0004
#define DTCS_PROTECT    0x0008
#define DTCS_OVERWRITE  0x0010
#define DTCS_HIDDEN     0x0020
#define DTCS_LEFT       0x0000
#define DTCS_CENTER     0x0040
#define DTCS_RIGHT      0x0080
#define DTCS_HEADLEFT   0x0000
#define DTCS_HEADCENTER 0x0100
#define DTCS_HEADRIGHT  0x0200
#define DTCS_LOCKED     0x2000
#define DTCS_SORTKEY1   0x4000
#define DTCS_SORTKEY2   0x1000
#define DTCS_SORTKEY3   0x5000
#define DTCS_SORTCASEI  0x0400          // Sort Case Insensitive
#define DTCS_SORTDES    0x8000          // Sort Desending
#define DTCS_BOUNDCOL   0x0800

#define DTCS_SORTASC    0x4000          // Pre 2.5 Ver

/****** Row Styles ******/
#define DTRS_RESIZE     0x0001
#define DTRS_FIXED      0x0002
#define DTRS_EDIT       0x0004
#define DTRS_PROTECT    0x0008
#define DTRS_HIDDEN     0x0020

/****** Cell Styles     *******/
#define DTCELLS_NULLVALUE 0x0001

/****** Column Data Types ******/
#define DTT_INT1           0x81
#define DTT_INT2           0x82
#define DTT_INT4           0x83
#define DTT_REAL4          0x84
#define DTT_REAL8          0x85
#define DTT_CHAR           0x86
#define DTT_ZSTRING        0x87
#define DTT_FILEDATE       0x88
#define DTT_FILETIME       0x89
#define DTT_CDATETIME      0x8A
#define DTT_UINT1          0x91
#define DTT_UINT2          0x92
#define DTT_UINT4          0x93
#define DTT_CHECKBOX       0x94
#define DTT_BITMAP         0x95
#define DTT_UNKNOWN        0x96
#define DTT_VWSQLBITMAP    0x97
#define DTT_VWSQLMEMO      0x98
#define DTT_STDCHECKBOX    0x99

#define DTT_SQLINT1        0x30
#define DTT_SQLINT2        0x34
#define DTT_SQLINT4        0x38
#define DTT_SQLBIT         0x32
#define DTT_SQLFLT8        0x3E
#define DTT_SQLMONEY       0x3C
#define DTT_SQLDATETIME    0x3D
#define DTT_SQLCHAR        0x2F
#define DTT_SQLVARCHAR     0x27

/****** Messages ******/
#define DTM_RESETALL       (WM_USER+0)
#define DTM_RESETDATA      (WM_USER+1)
#define DTM_GETWNDSTYLE    (WM_USER+2)
#define DTM_SETWNDSTYLE    (WM_USER+3)
#define DTM_GETCONFIGSIZE  (WM_USER+4)
#define DTM_GETCONFIG      (WM_USER+5)
#define DTM_SETCONFIG      (WM_USER+6)
#define DTM_GETCOLCOUNT    (WM_USER+7)
#define DTM_SETCOLCOUNT    (WM_USER+8)
#define DTM_GETCOLSTYLE    (WM_USER+9)
#define DTM_SETCOLSTYLE    (WM_USER+10)
#define DTM_GETCOLTYPE     (WM_USER+11)
#define DTM_SETCOLTYPE     (WM_USER+12)
#define DTM_GETCOLDATALEN  (WM_USER+13)
#define DTM_SETCOLDATALEN  (WM_USER+14)
#define DTM_GETCOLWIDTH    (WM_USER+15)
#define DTM_SETCOLWIDTH    (WM_USER+16)
#define DTM_GETCOLFORMAT   (WM_USER+17)
#define DTM_SETCOLFORMAT   (WM_USER+18)
#define DTM_GETCOLHEAD     (WM_USER+19)
#define DTM_SETCOLHEAD     (WM_USER+20)
#define DTM_GETCOLNAME     (WM_USER+21)
#define DTM_SETCOLNAME     (WM_USER+22)
#define DTM_GETCOLEXTRA1   (WM_USER+23)
#define DTM_SETCOLEXTRA1   (WM_USER+24)
#define DTM_GETCOLEXTRA2   (WM_USER+25)
#define DTM_SETCOLEXTRA2   (WM_USER+26)
#define DTM_GETCOLNUMBER   (WM_USER+27)
#define DTM_SHOWDROPDOWN   (WM_USER+28)
#define DTM_ISDROPDOWN     (WM_USER+29)
#define DTM_GETROWCOUNT    (WM_USER+30)
#define DTM_GETTOPINDEX    (WM_USER+32)
#define DTM_SETTOPINDEX    (WM_USER+33)
#define DTM_GETLEFTINDEX   (WM_USER+34)
#define DTM_SETLEFTINDEX   (WM_USER+35)
#define DTM_GETCURROW      (WM_USER+36)
#define DTM_GETCURCOL      (WM_USER+37)
#define DTM_SETCURCELL     (WM_USER+38)
#define DTM_GETACCESSROW   (WM_USER+39)
#define DTM_GETACCESSCOL   (WM_USER+40)
#define DTM_SETACCESSPOS   (WM_USER+41)
#define DTM_READROW        (WM_USER+42)
#define DTM_UPDATEROW      (WM_USER+43)
#define DTM_INSERTROW      (WM_USER+44)
#define DTM_DELETEROW      (WM_USER+45)
#define DTM_MOVEROWTO      (WM_USER+46)
#define DTM_REPLICATEROWTO (WM_USER+47)
#define DTM_READCOL        (WM_USER+48)
#define DTM_UPDATECOL      (WM_USER+49)
#define DTM_INSERTCOL      (WM_USER+90)
#define DTM_DELETECOL      (WM_USER+50)
#define DTM_MOVECOLTO      (WM_USER+51)
#define DTM_REPLICATECOLTO (WM_USER+52)
#define DTM_READCELL       (WM_USER+53)
#define DTM_UPDATECELL     (WM_USER+54)
#define DTM_READCELLRECT   (WM_USER+55)

#define DTM_GETROWSTATUS   (WM_USER+58)
#define DTM_GETCURROWSEL   (WM_USER+91)
#define DTM_SELROW         (WM_USER+59)
#define DTM_SELROWRANGE    (WM_USER+60)
#define DTM_SELALLROWS     (WM_USER+61)
#define DTM_GETROWSELCOUNT (WM_USER+62)
#define DTM_GETROWSELLIST  (WM_USER+63)
#define DTM_GETROWSELFIRST (WM_USER+64)
#define DTM_GETROWSELNEXT  (WM_USER+65)
#define DTM_GETCOLSTATUS   (WM_USER+66)
#define DTM_GETCURCOLSEL   (WM_USER+92)
#define DTM_SELCOL         (WM_USER+67)
#define DTM_SELCOLRANGE    (WM_USER+68)
#define DTM_SELALLCOLS     (WM_USER+69)
#define DTM_GETCOLSELCOUNT (WM_USER+70)
#define DTM_GETCOLSELLIST  (WM_USER+71)
#define DTM_GETCOLSELFIRST (WM_USER+72)
#define DTM_GETCOLSELNEXT  (WM_USER+73)
#define DTM_GETCHARSEL     (WM_USER+74)
#define DTM_SETCHARSEL     (WM_USER+75)
#define DTM_GETVISROWS     (WM_USER+81)
#define DTM_GETVISCOLS     (WM_USER+82)
#define DTM_GETNOTIFYROW   (WM_USER+83)
#define DTM_GETNOTIFYCOL   (WM_USER+84)
#define DTM_GETCLICKPOS    (WM_USER+85)
#define DTM_GETCOLCFGSIZE  (WM_USER+87)
#define DTM_GETCOLCFG      (WM_USER+88)
#define DTM_SETCOLCFG      (WM_USER+89)
#define DTM_GETEDITKEY     (WM_USER+93)
#define DTM_SETEDITKEY     (WM_USER+94)
#define DTM_EDITCURRCELL   (WM_USER+95)
#define DTM_GETDTMETRICS   (WM_USER+96)

#define DTM_SETDTCOLOR         (WM_USER+97)
#define DTM_SETROWCOLOR        (WM_USER+98)
#define DTM_SETCOLCOLOR        (WM_USER+99)
#define DTM_SETCELLCOLOR       (WM_USER+100)
#define DTM_RESETDTCOLOR       (WM_USER+101)
#define DTM_RESETALLCOLOR      (WM_USER+102)
#define DTM_RESETROWCOLOR      (WM_USER+103)
#define DTM_RESETCOLCOLOR      (WM_USER+104)
#define DTM_RESETCELLCOLOR     (WM_USER+105)

#define DTM_VM_INITIALIZE      (WM_USER+106)
#define DTM_VM_GETROWDATA      (WM_USER+107)
#define DTM_VM_GETFIRST        (WM_USER+108)
#define DTM_VM_GETLAST         (WM_USER+109)
#define DTM_VM_GETPREV         (WM_USER+110)
#define DTM_VM_GETNEXT         (WM_USER+111)
#define DTM_VM_GETPERCENT      (WM_USER+112)

#define DTM_SETSORTCOL         (WM_USER+113)
#define DTM_SETROWFONT         (WM_USER+114)
#define DTM_SETCOLFONT         (WM_USER+115)
#define DTM_SETCELLFONT        (WM_USER+116)
#define DTM_RESETALLFONT       (WM_USER+117)
#define DTM_RESETROWFONT       (WM_USER+118)
#define DTM_RESETCOLFONT       (WM_USER+119)
#define DTM_RESETCELLFONT      (WM_USER+120)
#define DTM_SETDTFONT          (WM_USER+121)
#define DTM_RESETDTFONT        (WM_USER+122)

#define DTM_GETSORTCOL         (WM_USER+123)
#define DTM_GETSORTASC         (WM_USER+124)
#define DTM_SETCFENDEDIT       (WM_USER+125)
#define DTM_GETCFENDEDIT       (WM_USER+57)
#define DTM_GETFIXEDHT         (WM_USER+126)
#define DTM_SETFIXEDHT         (WM_USER+127)
#define DTM_GETVERTALIGN       (WM_USER+128)
#define DTM_SETVERTALIGN       (WM_USER+129)

#define DTM_GETKEY             (WM_USER+130)
#define DTM_SETKEY             (WM_USER+131)

#define DTM_GETFLAGSTR         (WM_USER+132)
#define DTM_SETFLAGSTR         (WM_USER+133)
#define DTM_GETCELLSTYLE       (WM_USER+134)
#define DTM_SETCELLSTYLE       (WM_USER+135)

#define DTM_SETCURCELLCOLOR    (WM_USER+136)
#define DTM_SETCURCELLFONT     (WM_USER+137)
#define DTM_GETROWLABEL        (WM_USER+138)
#define DTM_SETROWLABEL        (WM_USER+139)
#define DTM_GETROWHEIGHT       (WM_USER+140)
#define DTM_SETROWHEIGHT       (WM_USER+141)
#define DTM_INVALIDATEROW      (WM_USER+142)
#define DTM_INVALIDATECOL      (WM_USER+143)
#define DTM_INVALIDATECELL     (WM_USER+144)
#define DTM_MOVETONEXTCELL     (WM_USER+145)
#define DTM_MOVETOPREVCELL     (WM_USER+146)
#define DTM_MAKECELLVIS        (WM_USER+147)
#define DTM_GETCOLEDITSTYLE    (WM_USER+148)
#define DTM_SETCOLEDITSTYLE    (WM_USER+149)
#define DTM_SETGRIDCOLOR       (WM_USER+150)
#define DTM_GETEXTWNDSTYLE     (WM_USER+151)
#define DTM_SETEXTWNDSTYLE     (WM_USER+152)
#define DTM_GETCOLLIST         (WM_USER+153)
#define DTM_SETCOLLIST         (WM_USER+154)
#define DTM_GETCONFIGEXT        (WM_USER+155)
#define DTM_SETCONFIGEXT        (WM_USER+156)
#define DTM_GETCOLCFGEXT        (WM_USER+157)
#define DTM_SETCOLCFGEXT        (WM_USER+158)
#define DTM_SETSORTKEY          (WM_USER+159)
#define DTM_GETSORTKEY          (WM_USER+160)
#define DTM_SORTTABLE           (WM_USER+161)
#define DTM_VMSETCELLSTYLE      (WM_USER+162)
#define DTM_GETEDITHWND         (WM_USER+163)

#define DTM_GETDTCOLOR         (WM_USER+164)
#define DTM_GETROWCOLOR        (WM_USER+165)
#define DTM_GETCOLCOLOR        (WM_USER+166)
#define DTM_GETCELLCOLOR       (WM_USER+167)
#define DTM_GETCURCELLCOLOR    (WM_USER+168)
#define DTM_GETROWSTYLE         (WM_USER+169)
#define DTM_SETROWSTYLE         (WM_USER+170)
#define DTM_NOTIFYRESULTS       (WM_USER+171)
#define DTM_GETGRIDCOLOR        (WM_USER+172)
#define DTM_INSERTCOLEXT        (WM_USER+173)
#define DTM_SETSORTASC          (WM_USER+174)
#define DTM_GETSORTCASEI        (WM_USER+175)
#define DTM_SETSORTCASEI        (WM_USER+176)
#define DTM_GETLISTBOXHWND      (WM_USER+177)
#define DTM_TOTALCOL            (WM_USER+178)
#define DTM_SETSELMODE          (WM_USER+179)
#define DTM_GETSELMODE          (WM_USER+180)
#define DTM_READCELLDOUBLE      (WM_USER+181)
#define DTM_ADDMENUITEM         (WM_USER+182)
#define DTM_GETNOTIFYMENUITEM   (WM_USER+183)
#define DTM_GETACCESSPANE       (WM_USER+186)
#define DTM_SETACCESSPANE       (WM_USER+187)
#define DTM_GETLEFTPANEWIDTH    (WM_USER+188)
#define DTM_GETTOPPANEHT        (WM_USER+189)
#define DTM_GETNOTIFYPANE       (WM_USER+190)
#define DTM_GETCURPANE          (WM_USER+191)
#define DTM_GETLISTNUMITEMS     (WM_USER+192)
#define DTM_SETLISTNUMITEMS     (WM_USER+193)
#define DTM_GETDEFAULTCURSOR    (WM_USER+194)
#define DTM_SETDEFAULTCURSOR    (WM_USER+195)
#define DTM_SETFOCUSPEN         (WM_USER+196)
#define DTM_SQLCOMMIT           (WM_USER+197)
#define DTM_SQLADDROW           (WM_USER+198)
#define DTM_SQLDELROW           (WM_USER+199)
#define DTM_GETCELLSTATUS       (WM_USER+200)
#define DTM_GETCURBLOCKSEL      (WM_USER+201)
#define DTM_SELBLOCK            (WM_USER+202)
#define DTM_READEDITCELL        (WM_USER+203)
#define DTM_SETROWCOUNT         (WM_USER+204)
#define DTM_GETNOTIFYBLOCK      (WM_USER+205)
#define DTM_SEARCHCOL           (WM_USER+206)
#define DTM_SEARCHCOLFROM       (WM_USER+207)
#define DTM_GETCOLLISTSIZE      (WM_USER+208)
#define DTM_SET3DEFFECT         (WM_USER+209)
#define DTM_GET3DEFFECT         (WM_USER+210)
#define DTM_SETCOLDEFVAL          (WM_USER+211)
#define DTM_GETCOLDEFVAL          (WM_USER+212)
#define DTM_SETLEFTPANEWIDTH    (WM_USER+213)
#define DTM_SETTOPPANEHT        (WM_USER+214)
#define DTM_SETCURPANE          (WM_USER+215)
#define DTM_UPDATEEDITCELL      (WM_USER+216)
#define DTM_DLGTOSCRX           (WM_USER+217)
#define DTM_SCRTODLGX           (WM_USER+218)


#define DTM_FIRSTMSG            (WM_USER+0)
#define DTM_LASTMSG             (WM_USER+218)


#define DTM_GETSORTDIR         (WM_USER+124)    // incl. for pre 2.5

/****** Notification Codes ******/
#define DTN_CREATE         1
#define DTN_DESTROY        2
#define DTN_ERRSPACE       3
#define DTN_SETFOCUS       4
#define DTN_KILLFOCUS      5
#define DTN_HSCROLL        6
#define DTN_VSCROLL        7
#define DTN_CELLFULL       8
#define DTN_SELCHANGE      9
#define DTN_LFDBLCLK       11       // rt mouse double click
#define DTN_CHANGE         12
#define DTN_UPDATE         13
// #define DTN_DROPDOWN       14    Removed to avoid redefinition WJR 06/02/98
#define DTN_POSCHANGE      15
#define DTN_BEGINEDIT      16
#define DTN_ABORTEDIT      17
#define DTN_LFCLICK        18       // left mouse click
#define DTN_COLSIZE        20
#define DTN_COLADDED       21
#define DTN_COLDELETED     22
#define DTN_COLMOVED       23
#define DTN_COLNAMECHANGED 24
#define DTN_GOTKEY         25
#define DTN_RTCLICK        26
#define DTN_RTDBLCLK       27
#define DTN_ROWCHANGE      28
#define DTN_COLCHANGE      29
#define DTN_PAINTCELL      30
#define DTN_DELETEDROW     31
#define DTN_INSERTEDROW    32
#define DTN_BEFOREDELETEROW     33
#define DTN_BEFOREINSERTROW    34
#define DTN_DTKEYDN         35
#define DTN_VMBEGINFETCH    36
#define DTN_KEYDN           37
#define DTN_COMBODROPDN     38
#define DTN_COMBOCLOSEUP    39
#define DTN_MENUSELECTED    40
#define DTN_ROWSIZE         41
#define DTN_BEFOREBEGINEDIT 42
#define DTN_BEFOREENDEDIT   43
#define DTN_BEFOREABORTEDIT 44
#define DTN_BEFORECUT       45
#define DTN_BEFORECOPY      46
#define DTN_BEFOREPASTE     47
#define DTN_ROWSEL          48
#define DTN_COLSEL          49
#define DTN_BLOCKSEL        50
#define DTN_ROWUNSEL        51
#define DTN_COLUNSEL        52
#define DTN_BLOCKUNSEL      53
#define DTN_BEFOREROWSEL    54
#define DTN_BEFORECOLSEL    55
#define DTN_BEFOREBLOCKSEL  56
#define DTN_NOTAVAILABLE   99

// the following notifications are defined for pre ver 2.5
#define DTN_DBLCLK         11       // lf dbl click, now use DTN_LFDBLCLK
#define DTN_CLICKED        18       // left mouse click, now use DTN_LFCLICK

#define DTSORTKEY1          1
#define DTSORTKEY2          2
#define DTSORTKEY3          3


#ifndef RC_INVOKED
typedef enum {NOWHERE, ONHEADING, ONGRIDLINE, ONCELL, ONLABEL,
    ONROWGRIDLINE, ONVERTPANELINE, ONHORZPANELINE} TABLEPOS;
#define SORTASC                1
#define SORTDES                0
#endif   /* ifndef RC_INVOKED */

//*****  special locations  *****
#define DTPOS_LAST      -1              /* last row or column */
#define DTPOS_AFTERLAST -2              /* after the last (insert & move only) */
#define DTPOS_INVALID   -3              /* invalid pos (ie read past last row) */
#define DTPOS_HEADINGS  (ROWNUM)(-4)    /* "row number" of heading row */
#define DTPOS_LABELS    (COLNUM)(-5)    /* "column number" of label column */
#define DTPOS_NOWHERE   -6              /* empty area in data table */

//***** Row/Column Access Modes *****
#define DTA_ACCESS    0x0000  /* start with position passed in SetAccessPos */
#define DTA_CURRENT   0x0001  /* start with current object */
#define DTA_SELFIRST  0x0002  /* start with first selected row or column */
#define DTA_SELNEXT   0x0003  /* start with next selected row or column */
#define DTA_AUTOINC   0x0004  /* increment after access */
#define DTA_AUTODEC   0x0008  /* decrement after access */
#define DTA_COLMAJOR  0x0010  /* row # changes before column # */

//***** EditCurrCell parameter values *****
#define DT_EDITSTATE 0
#define DT_BEGINEDIT 1
#define DT_ENDEDIT   2
#define DT_ABORTEDIT 3

//***** GetDTMetrics parameter values *****
#define DT_ROWHEIGHT  1
#define DT_ROWWIDTH   2
#define DT_HEADINGHT  3
#define DT_LABELWIDTH 4

#define DSF_READONLY            1
#define DSF_RECONFFIGCOLS       2

//***** Data Table Error Codes *****
#define DTE_OKAY          (DWORD) 0     /* NO ERROR */
#define DTE_CELLFLAGGED   (DWORD) 1     /* cell is flagged */
#define DTE_NOTALLOWED    (DWORD) -1    /* operation not allowed */
#define DTE_MESSAGENUM    (DWORD) -2    /* invalid message */
#define DTE_CELLADDR      (DWORD) -3    /* invalid cell address */
#define DTE_COLNUM        (DWORD) -4    /* invalid column number */
#define DTE_ROWNUM        (DWORD) -5    /* invalid row number */
#define DTE_NUMCOLS       (DWORD) -6    /* invalid number of columns */
#define DTE_NUMROWS       (DWORD) -7    /* invalid number of rows */
#define DTE_COLWIDTH      (DWORD) -8    /* invalid column width */
#define DTE_COLTYPE       (DWORD) -9    /* invalid column data type */
#define DTE_FIXEDLENGTH   (DWORD) -10   /* column data type has fixed length */
#define DTE_TRUNCATED     (DWORD) -11   /* data buffer was truncated */
#define DTE_NULLPOINTER   (DWORD) -12   /* null pointer passed to function*/
#define DTE_NULLVALUE     (DWORD) -13   /* null parameter passed to function */
#define DTE_NOMEMORY      (DWORD) -21   /* insufficient memory */
#define DTE_NOMEMLOCK     (DWORD) -22   /* cant lock memory */
#define DTE_STRINGTABLE   (DWORD) -23   /* fatal string table size error */
#define DTE_OVERFLOW      (DWORD) -24   /* exceeded max allowable length */
#define DTE_NORESLOAD     (DWORD) -25   /* cant load resource */
#define DTE_NORESLOCK     (DWORD) -26   /* cant lock resource */
#define DTE_ROWNOTINVIEW  (DWORD) -27   /* row not in view (VM Managed Only) */
#define DTE_ROWOUTOFRANGE (DWORD) -28   /* row out of range (VM Managed Only) */
/************** Data Table Configuration Structures ************************
 Ver.   Date   Changes
 ---- -------- -----------------------------------------------------------
 1.0  10/16/91 New structures (did not contain version stamp)
 1.1  11/05/91 Added structure lengths & version stamp
 1.2  11/14/91 Added private window style bits
 1.3  12/03/91 Column widths are now in dialog coords, was screen coords
 2.5           Row Label width saved
***************************************************************************/

#define CFGSTRUCTVERSION 31   /* current version (3.0) */
#define MINCFGSTRUCTVER  11   /* earliest supported version (1.1) */
#define MINEXTCFGSTRUCTVER  25   /* earliest supported version (2.5) */

#ifndef RC_INVOKED

#ifdef WIN32
    #pragma pack(push)
    #pragma pack(4)
#else
    #pragma pack(1)
#endif

typedef struct tagCOLUMNCFGEXTSTRUCT
{
   short            nVersion;
   COLSTYLE         ColStyle;   // column style
   COLTYPE          ColType;    // internal data type
   COLLEN           DataLen;    // bytes of storage required for this type
   short            wColWidth;  // column width in window
   DWORD            dwExtra1;   // extra space for user-defined info
   DWORD            dwExtra2;   // extra space for user-defined info
   DWORD            dwEditStyle;
   LPSTR            lpFormat;   //  null-terminated format string
   LPSTR            lpHeading;  // null-terminated column heading
   LPSTR            lpName;     //  null-terminated column name
   LPSTR            lpList;     // null-terminated List Items
   LPSTR            lpDefVal;   // null-terminated default value
} COLUMNCFGEXTSTRUCT;
typedef COLUMNCFGEXTSTRUCT *PCOLUMNCFGEXTSTRUCT;
typedef COLUMNCFGEXTSTRUCT far *LPCOLUMNCFGEXTSTRUCT;

typedef struct tagCOLUMNCFGSTRUCT
{
   short            wStructLen; // length of this structure, including the strings
   COLSTYLE         ColStyle;   // column style
   COLTYPE          ColType;    // internal data type
   COLLEN           DataLen;    // bytes of storage required for this type
   short              wColWidth;  // column width in window
   DWORD            dwExtra1;   // extra space for user-defined info
   DWORD            dwExtra2;   // extra space for user-defined info
   //               szFormat;      null-terminated format string
   //               szHeading;     null-terminated column heading
   //               szName;        null-terminated column name
} COLUMNCFGSTRUCT;
typedef COLUMNCFGSTRUCT *PCOLUMNCFGSTRUCT;
typedef COLUMNCFGSTRUCT far *LPCOLUMNCFGSTRUCT;

typedef struct tablecfg
{
    short           wStructLen;      // length of this structure
    short           nVersion;        // version num of structures, in tenths
    COLNUM          NumCols;         // total # columns
    WORD            wWndStyle;       // private window style bits
} TABLECFGSTRUCT;
typedef TABLECFGSTRUCT *PTABLECFGSTRUCT;
typedef TABLECFGSTRUCT far *LPTABLECFGSTRUCT;

typedef struct tagTABLECFGEXTSTRUCT
{
    short           wStructLen;      // length of this structure
    short           nVersion;        // version num of structures, in tenths
    COLNUM          NumCols;         // total # columns
    WORD            wWndStyle;       // private window style bits
    short           wLabelWid;       // row label width
    DWORD           dwExtWndStyle;   // extended window style
    WORD            wLabelStyle;     // row label style
    WORD            wHeadingStyle;   // heading style
    LPCOLUMNCFGEXTSTRUCT lpColCfg;
} TABLECFGEXTSTRUCT;
typedef TABLECFGEXTSTRUCT *PTABLECFGEXTSTRUCT;
typedef TABLECFGEXTSTRUCT far *LPTABLECFGEXTSTRUCT;

typedef struct tagDTCOLORSTRUCT
{
    COLORREF        BkgrdColor;         // bkgrd color
    COLORREF        TextColor;          // text color
    COLORREF        SelBkgrdColor;      // selected bkgrd color
    COLORREF        SelTextColor;       // selected text color
} DTCOLORSTRUCT;
typedef DTCOLORSTRUCT *PDTCOLORSTRUCT;
typedef DTCOLORSTRUCT far *LPDTCOLORSTRUCT;


typedef struct tagVMSTRUCT
{
    short           nStatus;        // error code status
    DWORD           dwKey;          // data key value, (index or owner defined)
    LPVOID          lpData;         // data
} VMSTRUCT;
typedef VMSTRUCT *PVMSTRUCT;
typedef VMSTRUCT far *LPVMSTRUCT;

typedef struct tagPENSTRUCT
{
    int         fPenStyle;
    int         nWidth;
    COLORREF    clr;
} PENSTRUCT;
typedef PENSTRUCT far *LPPENSTRUCT;

typedef struct tagBLOCKSTRUCT
{
    ROWNUM  TopRow;
    COLNUM  LeftCol;
    ROWNUM  BottomRow;
    COLNUM  RightCol;
} BLOCKSTRUCT;
typedef BLOCKSTRUCT far *LPBLOCKSTRUCT;

#ifdef WIN32
    #pragma pack(pop)
#else
    #pragma pack()
#endif

//***************************************************************************
// Functions avaialable to applications for setting up data tables

WORD WINAPI  DataTblLoadLib (void);
DWORD WINAPI  SetupDataTbl (HANDLE hInst, LPSTR szResName, HWND hCtl);
DWORD WINAPI  SetupDlgDataTbl (HANDLE hInst, HWND hDlg, int nID, LPSTR szResName, LPSTR szDlgName);
DWORD WINAPI  SetupMultiDataTbl (HANDLE hInst, HWND hDlg, LPSTR szDlgName);

#endif   /* ifndef RC_INVOKED */

#ifdef __cplusplus
   }
#endif

#endif   /* ifndef DATATBL_INCLUDED */
