/***************************************************************************/
/*                                                                         */
/*							    HAMMER.H                                   */
/*                                                                         */
/*     Function Prototypes for Hammer Library Functions used by WJR        */
/*                                                                         */
/*	   W. Riley     1600    12/08/90   (c) Hamilton Technical Services     */
/*	   Revised      1933    07/30/91   More functions added                */
/*					0835	10/31/91   Ditto                               */
/*					1700	05/13/92   Added datadump() and dataload()     */
/*					1830	10/07/92   Added getsytim()                    */
/*					1830	12/26/92   Added atputsha() and beepon()       */
/*					1730	02/06/93   Added strpack()                     */
/*					1930	09/12/93   Added vapush() and vapop()          */
/*					2030    10/14/93   Added vputsa()                      */
/*                                                                         */
/***************************************************************************/

void atputf(int row, int col, int width, char *s, char fillchar);
									 /* display string with fill character */

void atputfa(int row, int col, int width, char *s, char fillchar,
			 UCHAR attr);
					 /* display string with fill character using attritute */

void atputfha(int row, int col, int width, char *s, char fillchar);
			  /* display string with fill character using Hammer attritute */

void atputs(int row, int col, char *s);        /* put string at (row, col) */

void atputsa(int row, int col, char *s, UCHAR attr);
								/* put string at (row, col) with attribute */

void atputsha(int row, int col, char *s);
											   /* put string at (row, col) */
void beep(void);                                           /* sound a beep */

void beepon(void);                                         /* enable beeps */

void beepoff(void);                                       /* disable beeps */

void brkdate(long int gdate, int *mo, int *da, int *yr);
							/* break Gregorian date into month, day & year */

void clrblk(int trow, int tcol, int brow, int bcol); /* clear screen block */

void clrblka(int trow, int tcol, int brow, int bcol, UCHAR attr);
									  /* clear screen block with attribute */

void clreos(void);                   /* clear from cursor to end of screen */

void clrflda(int row, int col, int len, UCHAR attr);
			   /* clear field of length len from (row, col) with attribute */

void clrlin(int row);                                  /* clear line (row) */

void clrscn(void);                                  /* clear entire screen */

											 /* data storage and retreival */
int datadump(char *filnam, char *begdptr, int elemlen, int nelems);
int dataload(char *filnam, char *begdptr, int elemlen, int maxnel);

int dayofwk(long int gdate);       /* find day of week from Gregorian date */
												/* 0=Sunday ... 6=Saturday */

void delchr(void);                         /* delete character from string */
													   /* used by getstr() */

BOOL dfendscn(int inmode);               /* check if data field entry done */

void dochar(char *valset);                            /* process character */
													   /* used by getstr() */

int domenu(struct menu_str menu[], int menusize, int choice);
											 /* display menu & get command */

long int datjul(long int gdate);    /* conv Gregorian date to Julian day # */

char *dattos(long int gdate, char *s);    /* conv Gregorian date to string */

void errmsg(char *s);                             /* display error message */

int findcol(void);                           /* get cursor column position */

int findrow(void);                              /* get cursor row position */

int getifix(int row, int col, int width, int ndecs, int imin, int imax,
			int no, int inmode);                      /* get integer input */

long int getlfix(int row, int col, int width, int ndecs, long int lmin,
				 long int lmax, long int lno, int inmode); /* get long int */

int getopt(int row, int col, int width, int defsel, int cursel,
		   char *options[], int noptions, int inmode); /* get option input */

void getstr(int row, int col, int maxlen, char *s, char *validset,
			BOOL shiftlok, int inmode);                /* get string input */

void getsydat(int *mo, int *da, int *yr, int *daofwk);  /* get system date */

void initmenu(int toprow, int btmrow, BOOL barfig, UCHAR barc,
			  UCHAR bara, UCHAR menva, UCHAR menhva);   /* set menu layout */

int inkeyi(void);                    /* input next character from keyboard */

BOOL istermc(int c);                    /* is character a field terminator */
													   /* used by getstr() */

long int juldat(long int jdate);    /* conv Julian day # to Gregorian date */

#if(0)    /* to avoid conflict WJR 8/8/92 */
BOOL kbhit(void);            /* check if character available from keyboard */
#endif

void locate(int row, int col);             /* position cursor at (row,col) */

long int makdate(int mo, int da, int yr);           /* make Gregorian date */

void movecsr(int directn, int steps);   /* move cursor in directn by steps */

void scrbox(int toprow, int leftcol, int btmrow, int rightcol,
			int borderid, UCHAR attrib);             /* draw box on screen */

void scrtable(int top, int left, int btm, int right, int borderid,
			  UCHAR attrib, int headrow, int labelrow, int totalrow,
			  int ncols, int colarray[]);          /* draw table on screen */

void setnxtdf(void);                    /* determine next data entry field */
													   /* used by getstr() */

void setupws(char *initstr);          /* set up work string for data entry */
													   /* used by getstr() */

BOOL stodat(char *s, long int *gdate, long int defdat, BOOL blankdate);
								  /* convert date string to Gregorian date */

char *strdel(char *s, int pos, int len);   /* delete character from string */

char *strinc(char *s, int pos, char c, int maxlen);
										   /* insert character into string */

char *strpack(char *s);                /* eliminate whitespace from string */

char *swcases(char *s);         /* switch case of all characters in string */

void vapop(void);                               /* restore hamva attribute */

void vapush(void);                                 /* save hamva attribute */

void vputc(char c);                /* display character at cursor position */

void vputs(char *s);          /* write string to screen at cursor position */

void vputsa(char *s, UCHAR attr);
			   /* write string to screen at cursor position with attribute */

void v_gcsrpo(int *row, int *col, int vpage);       /* get cursor position */

int v_getc(void);                               /* get character at cursor */

void v_putc(char c, int len, int vpage);   /* write character(s) at cursor */

void v_putca(char c, char attr, int len, int vpage);
							/* write character(s) at cursor with attribute */

void v_scsrpo(int row, int col, int vpage);         /* set cursor position */

void getsytim(int *hr, int *min, int *sec, int *hundredthsec); /* get time */