/*****************************************************************************/
/*                                                                           */
/*                             LOCATION.H                                    */
/*                                                                           */
/*		Stable32 header file to define status bar control locations          */
/*                                                                           */
/*		Revision record:                                                     */
/*			01/20/98	Created                                              */
/*                                                                           */
/*      (c) 1998  W. Riley Hamilton Technical Services All Rights Reserved   */
/*                                                                           */
/*****************************************************************************/

// STATUS BAR DIMENSION MACROS
// These macros defined before their use in dimension & position macros below
// Bar height
#define SW_BAR_H ((int)(3.25*cyChar))
// Vertical position of top of status bar (message bar is cyChar+4 higher)
#define SW_BAR_Y ((int)((cyClient)-(SW_BAR_H)))
// Horizontal center of screen
#define SW_CENTER ((int)(cxClient/2))

// STATUS BAR WINDOW DIMENSION MACROS
// These macros defined before their use in position macros below
// SW=STATUS WINDOW
// EDIT=EDIT CONTROL
// X=X POSITION, Y=Y POSITION, W=WIDTH, H=HEIGHT

// HEIGHT DIMENSIONS
// Height of data type select buttons
#define SW_BUT_H ((int)((SW_FILE_Y)-(SW_BUT_Y)))
// Height of edit & label text controls 
#define SW_EDIT_H ((int)(cyChar))
// Height of plot text control
#define SW_PLOT_H ((int)((SW_BAR_H)-(2)))

// WIDTH DIMENSIONS
// Width of data type select buttons
#define SW_BUT_W ((int)(12*cxChar))
// Width of Tau edit controls
#define SW_TAU_W ((int)(12*cxChar))
// Width of number edit controls (# points & analysis start & end points)
// Note: For 1M+ points would like this to be 7*cxChar
// But that cramps the plot
// Fractional values can be used as a compromise, but results depend on
// particular digits of # - not really any better than 6*cxChar
// So use that and require user to scroll # to see it all for 1M+ points
#define SW_NUM_W ((int)((6*cxChar)+(1)))

// Width of labels
#define SW_LABEL_W ((int)(4.5*cxChar))
// Width of plot text controls
#define SW_PLOT_W ((int)((SW_CENTER)-(SW_PLOT_X)-(1*cxChar)))
// Width of Filename edit controls
#define SW_FILE_W ((int)((SW_TAU_W)+(SW_LABEL_W)+(SW_NUM_W)))

// HORIZONTAL LOCATIONS
// Distance from left edge to button control and file & tau labels
// Distance from left edge to data type select button
#define SW_BUT_X ((int)(5))
// Distance from left edge to file & tau edit controls
#define SW_FILE_X ((int)(SW_LABEL_W))
// Distance from left edge to start edit controls
#define SW_START_X ((int)((SW_STARTLABEL_X)+(SW_LABEL_W)))
// Distance from left edge to end edit & # text controls
#define SW_END_X ((int)((SW_ENDLABEL_X)+(SW_LABEL_W)))
// Distance from left edge to plot text controls
#define SW_PLOT_X ((int)((SW_END_X)+(SW_NUM_W)+(1*cxChar)))
// Distance from left edge to start label
#define SW_STARTLABEL_X ((int)((SW_FILE_X)+(SW_TAU_W)))
// Distance from left edge to end label
#define SW_ENDLABEL_X ((int)((SW_START_X)+(SW_NUM_W)))


// VERTICAL LOCATIONS
// Vertical location of the data type buttons
#define SW_BUT_Y ((int)(SW_BAR_Y))
// Vertical location of file edit & # text controls
#define SW_FILE_Y ((int)((SW_BAR_Y)+(1.25*cyChar)-(2)))
// Vertical location of tau, start & end edit controls
#define SW_TAU_Y ((int)((cyClient)-(cyChar)))
// Vertical location of plot text control
#define SW_PLOT_Y ((int)((SW_BAR_Y)+(2)))

// STATUS BAR WINDOW POSITION MACROS
// SW_[P,F][S,F,T,S,E,N,P][B,L,E,T]_[X,Y]
// SW=STATUS WINDOW
// P=PHASE, F=FREQ
// S=SELECT, F=FILE, T=TAU, S=START, E=END, N=NUM, P=PLOT
// B=BUTTON, L=LABEL, E=EDIT, T=TEXT
// X=X POSITION, Y=Y POSITION, W=WIDTH, H=HEIGHT

// PHASE STATUS WINDOW
// Phase Select Button
#define SW_PSB_X SW_BUT_X 
#define SW_PSB_Y SW_BUT_Y
#define SW_PSB_W SW_BUT_W
#define SW_PSB_H SW_BUT_H
// Phase File Label
#define SW_PFL_X 0
#define SW_PFL_Y SW_FILE_Y
#define SW_PFL_W SW_LABEL_W
#define SW_PFL_H SW_EDIT_H
// Phase Tau Label
#define SW_PTL_X 0
#define SW_PTL_Y SW_TAU_Y
#define SW_PTL_W SW_LABEL_W
#define SW_PTL_H SW_EDIT_H 
// Phase Start Label
#define SW_PSL_X SW_STARTLABEL_X 
#define SW_PSL_Y SW_TAU_Y
#define SW_PSL_W SW_LABEL_W
#define SW_PSL_H SW_EDIT_H
 // Phase End Label
#define SW_PEL_X SW_ENDLABEL_X
#define SW_PEL_Y SW_TAU_Y
#define SW_PEL_W SW_LABEL_W
#define SW_PEL_H SW_EDIT_H
// Phase Num Label
#define SW_PNL_X ((int)((SW_ENDLABEL_X)-(2*cxChar))) 
#define SW_PNL_Y ((int)((SW_BUT_Y)+(3)))
#define SW_PNL_W ((int)((SW_LABEL_W)+(2*cxChar)))
#define SW_PNL_H SW_EDIT_H
// Phase Lim Label
#define SW_PLL_X SW_ENDLABEL_X
#define SW_PLL_Y SW_FILE_Y
#define SW_PLL_W SW_LABEL_W
#define SW_PLL_H SW_EDIT_H
// Phase File Edit
#define SW_PFE_X SW_FILE_X
#define SW_PFE_Y SW_FILE_Y
#define SW_PFE_W SW_FILE_W
#define SW_PFE_H SW_EDIT_H
// Phase Tau Edit
#define SW_PTE_X SW_FILE_X
#define SW_PTE_Y SW_TAU_Y
#define SW_PTE_W SW_TAU_W
#define SW_PTE_H SW_EDIT_H 
// Phase Start Edit
#define SW_PSE_X SW_START_X
#define SW_PSE_Y SW_TAU_Y
#define SW_PSE_W SW_NUM_W
#define SW_PSE_H SW_EDIT_H
 // Phase End Edit
#define SW_PEE_X SW_END_X 
#define SW_PEE_Y SW_TAU_Y
#define SW_PEE_W SW_NUM_W
#define SW_PEE_H SW_EDIT_H
// Phase Num Text
#define SW_PNT_X ((int)(SW_END_X))
#define SW_PNT_Y ((int)((SW_BUT_Y)+(3)))
#define SW_PNT_W SW_NUM_W
#define SW_PNT_H SW_EDIT_H
// Phase Limit Text
#define SW_PLT_X SW_END_X
#define SW_PLT_Y SW_FILE_Y
#define SW_PLT_W SW_NUM_W
#define SW_PLT_H SW_EDIT_H
// Phase Plot Text
#define SW_PPT_X ((int)(SW_PLOT_X))
#define SW_PPT_Y ((int)(SW_PLOT_Y))
#define SW_PPT_W ((int)(SW_PLOT_W))
#define SW_PPT_H ((int)(SW_PLOT_H))

// FREQUENCY STATUS WINDOW
// Freq Select Button
#define SW_FSB_X ((int)((SW_CENTER)+(SW_BUT_X)))
#define SW_FSB_Y SW_BUT_Y
#define SW_FSB_W SW_BUT_W
#define SW_FSB_H SW_BUT_H
// Freq File Label
#define SW_FFL_X SW_CENTER
#define SW_FFL_Y SW_FILE_Y
#define SW_FFL_W SW_LABEL_W
#define SW_FFL_H SW_EDIT_H
// Freq Tau Label
#define SW_FTL_X SW_CENTER
#define SW_FTL_Y SW_TAU_Y
#define SW_FTL_W SW_LABEL_W
#define SW_FTL_H SW_EDIT_H 
// Freq Start Label
#define SW_FSL_X ((int)((SW_CENTER)+(SW_STARTLABEL_X)))
#define SW_FSL_Y SW_TAU_Y
#define SW_FSL_W SW_LABEL_W
#define SW_FSL_H SW_EDIT_H
 // Freq End Label
#define SW_FEL_X ((int)((SW_CENTER)+(SW_ENDLABEL_X)))
#define SW_FEL_Y SW_TAU_Y
#define SW_FEL_W SW_LABEL_W
#define SW_FEL_H SW_EDIT_H
// Freq Num Label
#define SW_FNL_X ((int)((SW_CENTER)+(SW_ENDLABEL_X)-(2*cxChar))) 
#define SW_FNL_Y ((int)((SW_BUT_Y)+(3)))
#define SW_FNL_W ((int)((SW_LABEL_W)+(2*cxChar)))
#define SW_FNL_H SW_EDIT_H
// Freq Lim Label
#define SW_FLL_X ((int)((SW_CENTER)+(SW_ENDLABEL_X))) 
#define SW_FLL_Y SW_FILE_Y
#define SW_FLL_W SW_LABEL_W
#define SW_FLL_H SW_EDIT_H
// Freq File Edit
#define SW_FFE_X ((int)((SW_CENTER)+(SW_FILE_X)))
#define SW_FFE_Y SW_FILE_Y
#define SW_FFE_W SW_FILE_W
#define SW_FFE_H SW_EDIT_H
// Freq Tau Edit
#define SW_FTE_X ((int)((SW_CENTER)+(SW_FILE_X)))
#define SW_FTE_Y SW_TAU_Y
#define SW_FTE_W SW_TAU_W
#define SW_FTE_H SW_EDIT_H 
// Freq Start Edit
#define SW_FSE_X ((int)((SW_CENTER)+(SW_START_X)))
#define SW_FSE_Y SW_TAU_Y
#define SW_FSE_W SW_NUM_W
#define SW_FSE_H SW_EDIT_H
 // Freq End Edit
#define SW_FEE_X ((int)((SW_CENTER)+(SW_END_X)))
#define SW_FEE_Y SW_TAU_Y
#define SW_FEE_W SW_NUM_W
#define SW_FEE_H SW_EDIT_H
// Freq Num Text
#define SW_FNT_X ((int)((SW_CENTER)+(SW_END_X)))
#define SW_FNT_Y ((int)((SW_BUT_Y)+(3)))
#define SW_FNT_W SW_NUM_W
#define SW_FNT_H SW_EDIT_H
// Freq Lim Text
#define SW_FLT_X ((int)((SW_CENTER)+(SW_END_X)))
#define SW_FLT_Y SW_FILE_Y
#define SW_FLT_W SW_NUM_W
#define SW_FLT_H SW_EDIT_H
// Freq Plot Text
#define SW_FPT_X ((int)((SW_CENTER)+(SW_PLOT_X)))
#define SW_FPT_Y ((int)(SW_PLOT_Y))
#define SW_FPT_W ((int)(SW_PLOT_W))
#define SW_FPT_H ((int)(SW_PLOT_H))
