#include <stdio.h>

int MJD2DOY(long lnMJD);
void MJDToDate(long mjd, int *day, int *month, int *year);

void main(void)
{
	long lnMJD;
	int nDOY;
	
	printf("MJD=");
	scanf("%ld", &lnMJD);
	nDOY=MJD2DOY(lnMJD);
	printf("DOY=%d\n", nDOY);
}


/*****************************************************************************/
/*                                                                           */
/*								MJD2DOY()                                    */
/*                                                                           */
/* 		Function to convert long integer MJD to DOY                          */
/*                                                                           */
/*		Parameters:                                                          */
/*					long	nMJD	MJD value                                */
/*                                                                           */
/*		Return:		int		nDOY	Day of year	                             */
/*                                                                           */
/*      Dependencies:                                                        */
/*					MJDToDate()                                              */
/*                                                                           */
/*		Revision record:  												     */
/*			03/20/02	Created from GetRowData()                            */
/*                                                                           */
/*****************************************************************************/

int MJD2DOY(long lnMJD)
{
	// Local variables
	// Ints
	int nYear;
	int nDOY;
	int nMonth;
	int nDay;
	static int nSum[] = { 0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304,
		334, 365 };

	// Start of code
	// Convert integer MJD to date
	MJDToDate(lnMJD, &nDay, &nMonth, &nYear);

	// Convert data to DOY
	nDOY=nSum[nMonth-1]+nDay;
	if(nYear%4==0 && nYear%100!=0 || nYear%400==0)
	{
		if(nMonth>2)
		{
			nDOY++;
		}
	}

	// Return DOY
	return nDOY;
}

/****************************************************************************/
/*                                                                          */
/*                             MJDToDate()                                  */
/*                                                                          */
/*		Function for MJD to date conversion                                 */
/*                                                                          */
/*      Parameters:                                                         */
/*          long mjd     modified Julian day # to be converted into date    */
/*			int	*day	 pointer to day of date to be found from MJD        */
/*		    int *month   pointer to month of date to be found from MJD      */
/*          int *year    pointer to year of date to be found from MJD       */
/*                                                                          */
/*      Return: 														    */
/*			none (void)                                                     */
/*                                                                          */
/*		Function revision record:                                           */
/*			11/11/92	Created                                             */
/*                                                                          */
/*  (c) 1992	W. Riley  Hamilton Technical Services  All Rights Reserved  */
/*                                                                          */
/****************************************************************************/

void MJDToDate(long mjd, int *day, int *month, int *year)
{
	mjd+=679019;
	*year=(int)((mjd-122.1)/365.25);
	*month=(int)((mjd-(long)(365.25**year))/30.6001);
	*day=mjd-(int)(365.25**year)-(int)(30.6001**month);

	if(*month<14)
	{
		*month-=1;
	}                                                             /* end if */
	else
	{
		*month-=13;
	}                                                           /* end else */

	if(*month<3)
	{
		*year+=1;
	}                                                             /* end if */

}                                                        /* end MjdToDate() */

/****************************************************************************/

