/*****************************************************************************/
/*                                                                           */
/* 						   RemoveQuadraticDrift()                            */
/*															    		     */
/*		Function to remove frequency drift from phase data                   */
/*		by removing quadratic fit x(t) = a + bt + ct                        */
/*                                                                           */
/*		Parameters:		F_TYPE x[] = phase data                              */
/*                                   x[0] = # phase data points              */
/*			                         x[1] = analysis start                   */
/*                                   x[2] = analysis end                     */
/*                      F_TYPE a  =  offset term                             */
/*                      F_TYPE b  =  linear term                             */
/*                      F_TYPE c  =  drift term                              */
/*                                                                           */
/*      Return:         int       = # data points processed                  */
/*                                                                           */
/*    	Notes:          Embedded zeros treated as gaps in phase data.        */
/*		                Use quadratic() to calculate quadratic fit           */
/*						parameters a, b and c.                               */
/*                                                                           */
/*		Revision record:                                                     */
/*			02/24/97	Adapted from RemoveQuadraticDrift()                  */
/*						Corrected error in gap recognition                   */
/*                                                                           */
/*                                                                           */
/*****************************************************************************/

#include "frequenc.h"

int FAR PASCAL _export RemoveQuadraticDrift(F_TYPE x[], F_TYPE a, F_TYPE b,
	F_TYPE c)

{
	int i;                                                          /* index */
	int num=0;                                         /* # points processed */

	for( i = *(x+1)+2; i <= *(x+2)+2; i++)           /* remove quadratic fit */
	{
		if( *(x+i) || i==*(x+1)+2 || i==*(x+2)+2 )                   /* gap? */                                      /* check for gap */
		{
			*(x+i) -=  a + (b * i) + (c * i * i);       /* remove quad terms */
			num++;                                        /* increment count */
		}
	}
	return(num);
}

/*****************************************************************************/
