/*****************************************************************************/
/*                                                                           */
/*                              STABLE_B.C                                   */
/*                                                                           */
/*      Automation thread functions for Stable32                             */
/*                                                                           */
/*      Programmer:                 W. Riley                                 */
/*      Organization:               Hamilton Technical Services              */
/*      Date:                       04/22/01                                 */
/*                                                                           */
/*      Functions:                                                           */
/*      AutoThread()                                                         */
/*      AutoDlgProc()                                                        */
/*                                                                           */
/*      Revision record:                                                     */
/*          07/22/07    Changed to safe string functions                     */
/*                                                                           */
/*   (c) 2001-7  W. Riley Hamilton Technical Services  All Rights Reserved   */
/*                                                                           */
/*****************************************************************************/

// Include the Stable_w header file
#include "stable_w.h"

// File macros
#define NUM_PROCESSES		9	// Total # display IDs
#define NUM_PLOTTYPES      7	// # display IDs of type PLOT_

// Display ID #s
// These are points where auto run displays results
// that may close or remain visible
#define PLOT_ORIGINAL		0
#define PLOT_CONVERTED		1
#define PLOT_CORRECTED		2
#define PLOT_SELECTED		3 
#define PLOT_AVERAGED		4
#define PLOT_NORMALIZED	5
#define PLOT_RESIDUAL		6
#define PLOT_RUN		    7
#define TABULATE_RUN		8

// Variables with file scope
// Chars
static char szAutoPhaseVariance[BUFFER_SIZE+1];	// Phase var type as string
static char szAutoFreqVariance[BUFFER_SIZE+1];	// Freq variance type as string
static char szAutoFilename[FILE_NAME_SIZE+1];	// Filename
static char szAutoPhaseDriftType[BUFFER_SIZE+1];// Phase drift type as string
static char szAutoFreqDriftType[BUFFER_SIZE+1];	// Freq drift type as string
static char szAutoAvgFactor[BUFFER_SIZE+1];		// Avg factor as string
static char szAutoSigmaFactor[BUFFER_SIZE+1];	// Sigma factor as string
static char szAutoStart[BUFFER_SIZE+1];			// Start point string
static char szAutoEnd[BUFFER_SIZE+1];			// End point string
static char szAutoDelayTime[BUFFER_SIZE+1];		// Delay time string
// Ints
static int nAutoPhaseVarianceType=0;		// Phase numeric variance type
static int nAutoFreqVarianceType=0;			// Freq numeric variance type
static int nAutoPhaseDriftType=0;			// Phase numeric drift type
static int nAutoFreqDriftType=0;			// Freq numeric drift type
static int nAutoDelay=5000;					// Delay in msec
static int nAutoStart=1;					// Starting point
static int nAutoEnd=0;						// Ending point
static int nAutoAvgFactor=1;				// Averaging factor
// BOOLs
static BOOL bAutoDataType=PHASE_DATA;		// Equivalent to
											// main bDataType for file
static BOOL bAutoAnalysisType=PHASE_DATA;	// Equivalent to
											// main bDataType for analysis
// Flags:
static BOOL bAutoFileOpen=FALSE;		// Flag for auto file opening
static BOOL bAutoConvert=FALSE;			// Flag for auto data conversion
static BOOL bAutoRegularize=FALSE;		// Flag for auto data regularization
static BOOL bAutoOutliers=FALSE;		// Flag for auto outlier removal
static BOOL bAutoDrift=FALSE;			// Flag: for auto drift removal
static BOOL bAutoDataPlot=FALSE;		// Flag for auto data plot
static BOOL bAutoDataPrint=FALSE;		// Flag for auto data print
static BOOL bAutoPhaseDataPlot=FALSE;	// Flag for auto phase data plot
static BOOL bAutoFreqDataPlot=FALSE;	// Flag for auto freq data plot
static BOOL bAutoBothDataPlot=FALSE;	// Flag for auto both data plot
static BOOL bAutoRun=FALSE;				// Flag for auto stability run
static BOOL bAutoRunPlot=FALSE;			// Flag for auto stability plot
static BOOL bAutoStabPlot=FALSE;		// Flag for auto stab plot printout
static BOOL bAutoStabTable=FALSE;		// Flag for auto stab table printout
static BOOL bAutoClose=FALSE;			// Flag to close last automated object
static BOOL bAutoAverage=FALSE;			// Flag for automatic data avergaing
static BOOL bAutoPart=FALSE;			// Flag for using part of data
static BOOL bAutoAddDelay=FALSE;		// Flag to add extra delays
static BOOL	bAutoPrintOriginal=FALSE;	// Flag to print original data
static BOOL	bAutoPrintConverted=FALSE;	// Flag to print converted data
static BOOL bAutoPrintCorrected=FALSE;	// Flag to print corrected data
static BOOL bAutoPrintSelected=FALSE;	// Flag to print selected data
static BOOL bAutoPrintAveraged=FALSE;	// Flag to print averaged data
static BOOL bAutoPrintNormalized=FALSE;	// Flag to print normalized data
static BOOL	bAutoPrintResidual=FALSE;	// Flag to print residual data
static BOOL bAutoNormalize=FALSE;		// Flag to normalize data
static BOOL bProcess[NUM_PROCESSES];	// Array of process flags
static F_TYPE fAutoSigmaFactor=5.0;		// Sigma multiplier factor

/****************************************************************************/
/*                                                                          */
/*                          AutoThread()                                    */
/*                                                                          */
/*      Function to automate program operation by sending keystrokes        */
/*                                                                          */
/*      Parameters:                                                         */
/*                                                                          */
/*      Returns nothing (void)                                              */
/*                                                                          */
/*		Implementation notes:                                               */
/*		Microsoft recommends using SendInput() instead of keybd_event()     */
/*      for simulating keystrokes.  SendInput() seems more complicated,     */
/*      isn't implemented in Windows95, and isn't supported by my current   */
/*		development tools.  I was unable to get it to link, probably        */
/*		because of an old version of Winuser.lib.  See Keyboard.h for       */
/*		more information.                                                   */
/*                                                                          */
/*      Revision record:                                                    */
/*          04/22/01    Created                                             */
/*			04/28/01	Pretty much working                                 */
/*			04/29/01	User interface good, processing not bad             */
/*			05/03/01	Done                                                */
/*			05/04/01	Improved plot closing logic                         */
/*			10/02/01	Added normalize option                              */
/*			08/28/02	Added regularize option                             */
/*                                                                          */
/****************************************************************************/

DWORD WINAPI AutoThread(LPVOID lpDummy)
{
	// Local variables
	static char szBuffer[BUFFER_SIZE+1];	// General text buffer
	int i;								// General index
	static int nMaxProcess;				// ID # of last active process
	short sVKey;						// Virtual keycode byte
	short sShift;						// Shift state byte
	static HMENU hMenu;					// Handle to GraphiC plot menu
	static HMENU hSubMenu;				// Handle to its File submenu
	static UINT uState;					// State of the Print submenu item
	static HWND hPrint;					// Handle to GraphiC print dialog box
	static HWND hForeground;			// Handle to foreground window
	static BOOL bAutoCalcSave;			// Save org autocalc flag state
	static BOOL bAutoPlotSave;			// Save org autoplot flag state
	static BOOL bAutoSkipSave;			// Save orgiginal skip flag state
	static BOOL bWarnZeroFreqSave;		// Save original warn zero freq flag
	// Start of code

	// Wait for Auto dialog box to close
	Sleep(100);

	// Make sure have data
	if(!bAutoFileOpen &&
		((bAutoDataType && !bFreqData) ||(!bAutoDataType && !bPhaseData)))
	{
		sprintf(szBuffer, "Auto%d", nAuto);
		if(bAutoDataType)
		{
			MessageBox(hwndMain,
				"No Frequency Data\nAborting Script Execution",
				szBuffer, MB_ICONEXCLAMATION);
		}
		else
		{
			MessageBox(hwndMain, "No Phase Data\nAborting Script Execution",
				szBuffer, MB_ICONEXCLAMATION);
		}
		return(0);
	}

	// Set bAuto flag
	// Note: Not used for anything
	bAuto=TRUE;

	// Save original skip flag state
	bAutoSkipSave=bSkip;

	// Set skip flag
	bSkip=TRUE;

	// Save original autocalc state
	bAutoCalcSave=bAutoCalc;

	// Make sure autocalc is off
	bAutoCalc=FALSE;

	// Save original autoplot state
	bAutoPlotSave=bAutoPlot;

	// Make sure autoplot is off
	bAutoPlot=FALSE;

	// Save original zero frequency warning flag state
	bWarnZeroFreqSave=bWarnZeroFreq;
	
	// Turn zero frequency warning off
	bWarnZeroFreq=FALSE;

	// Give input focus to main window
	SetFocus(hwndMain);

	// Select data type
	if(bAutoDataType)
	{
		bDataType=FREQ_DATA;
	}
	else
	{
		bDataType=PHASE_DATA;
	}

	// Find ID # of last process that is requested
	nMaxProcess=-1;
	for(i=0; i<NUM_PROCESSES; i++)
	{
		if(bProcess[i])
		{
			nMaxProcess=i;
		}
	}

	// Open data file
	if(bAutoFileOpen)
	{
		// Go to file menu
		keybd_event(VK_MENU, 0, VK_PRESS, 0);	
		keybd_event(VK_F, 0, VK_PRESS, 0);
		keybd_event(VK_F, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);

		// Open the open dialog box
		keybd_event(VK_O, 0, VK_PRESS, 0);
		keybd_event(VK_O, 0, VK_RELEASE, 0);

		// Go to the filename edit control
		keybd_event(VK_MENU, 0, VK_PRESS, 0);	
		keybd_event(VK_N, 0, VK_PRESS, 0);
		keybd_event(VK_N, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);

		// Clear the filename field
		keybd_event(VK_DELETE, 0, VK_PRESS, 0);
		keybd_event(VK_DELETE, 0, VK_RELEASE, 0);

		// Put in a space
		// This seems to fix a problem that causes
		// the first letter of the filename
		// to be missed simetimes
		keybd_event(VK_SPACE, 0, VK_PRESS, 0);
		keybd_event(VK_SPACE, 0, VK_RELEASE, 0);

		// Process entry
		Sleep(10);
		YieldControl();
		
		// Load the filename character-by-character
		for(i=0; i<(int)strlen(szAutoFilename); i++)
		{
			// Get the virtual keycode and shift state for a filename character
			// Note: The HIBYTE can't be a CTRL or ALT for a filename
			// so if it is not 0 it must be a SHIFT
			sVKey=LOBYTE(VkKeyScan(szAutoFilename[i]));
			sShift=HIBYTE(VkKeyScan(szAutoFilename[i]));

			// Send the character as equivalent keystroke(s)
			if(sShift)
			{
				keybd_event(VK_SHIFT, 0, VK_PRESS, 0);	
				keybd_event((char)sVKey, 0, VK_PRESS, 0);
				keybd_event((char)sVKey, 0, VK_RELEASE, 0);
				keybd_event(VK_SHIFT, 0, VK_RELEASE, 0);
			}
			else // Unshifted
			{
				keybd_event((char)sVKey, 0, VK_PRESS, 0);
				keybd_event((char)sVKey, 0, VK_RELEASE, 0);
			}

			// Process the keystroke
			Sleep(10);
			YieldControl();
		}

		// Preset the busy flag to insure wait loop takes effect
		bBusy=TRUE;
		
		// Open the file
		keybd_event(VK_MENU, 0, VK_PRESS, 0);	
		keybd_event(VK_O, 0, VK_PRESS, 0);
		keybd_event(VK_O, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);
		
		// Wait for process done
		while(bBusy)
		{
			Sleep(10);
		}

		// Is the file opened dialog box shown?
		if(bShowFileOpened)
		{
			// Close file opened box
			keybd_event(VK_MENU, 0, VK_PRESS, 0);	
			keybd_event(VK_O, 0, VK_PRESS, 0);
			keybd_event(VK_O, 0, VK_RELEASE, 0);
			keybd_event(VK_MENU, 0, VK_RELEASE, 0);
		}

		// Wait to make sure message is seen
		Sleep(100);

		// Write message to show what's happening
		WriteMessage("Data file opened");
		
		// Add extra delay to show data in status bar
		if(bAutoAddDelay)
		{
			Sleep(nAutoDelay);
		}
	}
	
	// Interprocess delay
	Sleep(100);
	
	// Original data plot
	if(bAutoDataPlot && bAutoPrintOriginal)
	{
		// Open plot menu
		keybd_event(VK_MENU, 0, VK_PRESS, 0);	
		keybd_event(VK_P, 0, VK_PRESS, 0);
		keybd_event(VK_P, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);

		// Select data type
		if(bAutoDataType==FREQ_DATA)
		{
			keybd_event(VK_F, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_RELEASE, 0);
		}
		else // Phase data
		{
			keybd_event(VK_P, 0, VK_PRESS, 0);
			keybd_event(VK_P, 0, VK_RELEASE, 0);
		}

		// Preset hPlot to null
		hPlot=0;

		// Draw plot
		keybd_event(VK_P, 0, VK_PRESS, 0);
		keybd_event(VK_P, 0, VK_RELEASE, 0);

		// Added 11/28/05 to (hopefully) fix hang-up problem
		// Note:  I suspect that it isn't so much the delay as that the Sleep()
		// causes this thread to yield so plot can start
		Sleep(10);

		// Wait for GraphiC plot to launch
		// by checking if its menu handle is valid
		while((GetMenu(hPlot))==0)
		{
				// 11/28/05 This wasn't working right anymore
				// Was OK in Ver 1.43, but NG after that
				// Data plotting goes into loop - can't break out of it
				// Better w/o this normalize test - but rest of script still NG
				// Trouble was probably that hPlot was 0 because
				// local version of it in GPCWndProc() overrode it.

				// Check for "Must Normalize" error
				// Get handle of foreground window
				hForeground=GetForegroundWindow();

				// Get the caption of that window
				GetWindowText(hForeground, szBuffer, BUFFER_SIZE);

				// Compare it with the Stable32 "Must Normalize" dialog caption
				if((strcmp(szBuffer, "Stable32"))==0)
				{
					// Close "Must Normalize" box
					keybd_event(VK_RETURN, 0, VK_PRESS, 0);
					keybd_event(VK_RETURN, 0, VK_RELEASE, 0);

					// Open edit menu
					keybd_event(VK_MENU, 0, VK_PRESS, 0);	
					keybd_event(VK_E, 0, VK_PRESS, 0);
					keybd_event(VK_E, 0, VK_RELEASE, 0);
					keybd_event(VK_MENU, 0, VK_RELEASE, 0);

					// Select normalize function
					keybd_event(VK_N, 0, VK_PRESS, 0);
					keybd_event(VK_N, 0, VK_RELEASE, 0);

					// Normalize (OK)
					keybd_event(VK_MENU, 0, VK_PRESS, 0);	
					keybd_event(VK_O, 0, VK_PRESS, 0);
					keybd_event(VK_O, 0, VK_RELEASE, 0);
					keybd_event(VK_MENU, 0, VK_RELEASE, 0);

					// Interprocess delay
					Sleep(100);

					// Try again: open plot menu
					keybd_event(VK_MENU, 0, VK_PRESS, 0);	
					keybd_event(VK_P, 0, VK_PRESS, 0);
					keybd_event(VK_P, 0, VK_RELEASE, 0);
					keybd_event(VK_MENU, 0, VK_RELEASE, 0);

					// Select data type
					if(bAutoDataType==FREQ_DATA)
					{
						keybd_event(VK_F, 0, VK_PRESS, 0);
						keybd_event(VK_F, 0, VK_RELEASE, 0);
					}
					else // Phase data
					{
						keybd_event(VK_P, 0, VK_PRESS, 0);
						keybd_event(VK_P, 0, VK_RELEASE, 0);
					}

					// Try again to draw plot
					keybd_event(VK_P, 0, VK_PRESS, 0);
					keybd_event(VK_P, 0, VK_RELEASE, 0);
				}

				Sleep(10);
		}

		// Find out whether plot is finished drawing
		// by observing the state of the Print item in the File submenu
		// of the GraphiC menu -it is grayed during drawing
		// The handle of the GraphiC plot window is in the global hPlot
		// The GraphiC File menu is in position 0
		// The GraphiC Print item is in position 1
		// When uState=1=MF_GRAYED, the plot is still being drawn
		// When uState=0, the plot is done
		// Best approach is to mask off all except LSB and test it
		// This thread stays in wait loop until GraphiC plot is drawn
		hMenu=GetMenu(hPlot);

		hSubMenu=GetSubMenu(hMenu, 0);
		do 
		{
			Sleep(100);
			uState=GetMenuState(hSubMenu, 1, MF_BYPOSITION);
		}   while((uState&0x00000001)==TRUE);

		// At this point the data plot is drawn on screen
		// Do we want to print it?
		if(bAutoDataPrint)
		{
				// Print data plot
			keybd_event(VK_MENU, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_RELEASE, 0);
			keybd_event(VK_MENU, 0, VK_RELEASE, 0);
			keybd_event(VK_P, 0, VK_PRESS, 0);
			keybd_event(VK_P, 0, VK_RELEASE, 0);

			// Allow time for the print dialog to open
			while(1)
			{
				// Wait for the print page dialog box to open
				// Get the handle of the foreground window
				hPrint=GetForegroundWindow();

				// Get the caption of that window
				GetWindowText(hPrint, szBuffer, BUFFER_SIZE);

				// Compare it with the GraphiC print dialog caption
				if((strcmp(szBuffer, "GraphiC/Win Print Page"))==0)
				{
					break;
				}

				// Loop delay
				Sleep(10);
			}

			// Wait for the printing to take place
			while(1)
			{
				// Wait for the print page dialog box to close
				// Get the handle of the foreground window
				hPrint=GetForegroundWindow();

				// Get the caption of that window
				GetWindowText(hPrint, szBuffer, BUFFER_SIZE);

				// Compare it with the GraphiC print dialog caption
				if((strcmp(szBuffer, "GraphiC/Win Print Page"))!=0)
				{
					break;
				}

				// Loop delay
				Sleep(100);
			}

			// Now the plot has to redraw before it can be closed
			// Find out whether plot is finished drawing
			// by observing the state of the Print item in the File submenu
			// of the GraphiC menu -it is grayed during drawing
			// The handle of the GraphiC plot window is in the global hPlot
			// The GraphiC File menu is in position 0
			// The GraphiC Print item is in position 1
			// When uState=1=MF_GRAYED, the plot is still being drawn
			// When uState=0, the plot is done
			// Best approach is to mask off all except LSB and test it
			// This thread stays in wait loop until GraphiC plot is drawn
			hMenu=GetMenu(hPlot);
			hSubMenu=GetSubMenu(hMenu, 0);
			do 
			{
				Sleep(100);
				uState=GetMenuState(hSubMenu, 1, MF_BYPOSITION);
			}   while((uState&0x00000001)==TRUE);
		}

		// Wait to make sure message is seen
		Sleep(100);

		// Write message to show what's happening
		WriteMessage("Original data file plot");
		
		// Add extra delay to show original data plot
		if(bAutoAddDelay)
		{
			Sleep(nAutoDelay);
		}
	
		// Close plot if there are more processes that follow
		// or if bAutoClose flag is set
		if( (nMaxProcess>PLOT_ORIGINAL) || bAutoClose)
		{
			keybd_event(VK_MENU, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_RELEASE, 0);
			keybd_event(VK_MENU, 0, VK_RELEASE, 0);
			keybd_event(VK_X, 0, VK_PRESS, 0);
			keybd_event(VK_X, 0, VK_RELEASE, 0);

			// Close plot dialog box
			keybd_event(VK_ESCAPE, 0, VK_PRESS, 0);
			keybd_event(VK_ESCAPE, 0, VK_RELEASE, 0);
		}
	}

	// Interprocess delay
	Sleep(100);
	
	// Convert data
	if(bAutoConvert)
	{
		// Go to edit menu
		keybd_event(VK_MENU, 0, VK_PRESS, 0);	
		keybd_event(VK_E, 0, VK_PRESS, 0);
		keybd_event(VK_E, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);

		// Select convert function
		keybd_event(VK_C, 0, VK_PRESS, 0);		
		keybd_event(VK_C, 0, VK_RELEASE, 0);

		// If regulalization is called for in the script
		// for the converted data then the Transfer Timetags option
		// should be set - do this by setting the global flag bForceTagTransfer
		if(bAutoRegularize)
		{
			// Set global flag to force timetag transfer
			bForceTagTransfer=TRUE;
		}

		// Preset the busy flag to insure wait loop takes effect
		bBusy=TRUE;

		// Press ok button
		keybd_event(VK_MENU, 0, VK_PRESS, 0);
		keybd_event(VK_O, 0, VK_PRESS, 0);
		keybd_event(VK_O, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);

		// Wait for process done
		while(bBusy)
		{
			Sleep(10);
		}

		// Wait to make sure message is seen
		Sleep(100);

		// Write message to show what's happening
		WriteMessage("Data converted");
		
		// Add extra delay to show converted data in status bar
		if(bAutoAddDelay)
		{
			Sleep(nAutoDelay);
		}
	}
	
	// Interprocess delay
	Sleep(100);
	
	// Regularize data
	if(bAutoRegularize)
	{
		// Regularize only if there are timetags
		if( ((bAutoAnalysisType==FREQ_DATA) && bFreqTimetags) ||
		    ((bAutoAnalysisType==PHASE_DATA) && bPhaseTimetags) )
		{
			// Open edit menu
			keybd_event(VK_MENU, 0, VK_PRESS, 0);	
			keybd_event(VK_E, 0, VK_PRESS, 0);
			keybd_event(VK_E, 0, VK_RELEASE, 0);
			keybd_event(VK_MENU, 0, VK_RELEASE, 0);

			// Select regularize function
			keybd_event(VK_R, 0, VK_PRESS, 0);
			keybd_event(VK_R, 0, VK_RELEASE, 0);

			// Preset the busy flag to insure wait loop takes effect
			bBusy=TRUE;

			// Press ok button
			keybd_event(VK_MENU, 0, VK_PRESS, 0);
			keybd_event(VK_O, 0, VK_PRESS, 0);
			keybd_event(VK_O, 0, VK_RELEASE, 0);
			keybd_event(VK_MENU, 0, VK_RELEASE, 0);

			// Wait for process done
			while(bBusy)
			{
				Sleep(10);
			}

			// Wait to make sure message is seen
			Sleep(100);

			// Write message to show what's happening
			WriteMessage("Data regularized");
		}
	
		// Interprocess delay
		Sleep(100);
	}

	// Converted data plot
	if(bAutoDataPlot && bAutoPrintConverted)
	{
		// Open plot menu
		keybd_event(VK_MENU, 0, VK_PRESS, 0);	
		keybd_event(VK_P, 0, VK_PRESS, 0);
		keybd_event(VK_P, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);

		// Select data type
		if(bAutoAnalysisType==FREQ_DATA)
		{
			keybd_event(VK_F, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_RELEASE, 0);
		}
		else // Phase data
		{
			keybd_event(VK_P, 0, VK_PRESS, 0);
			keybd_event(VK_P, 0, VK_RELEASE, 0);
		}

		// Preset hPlot to null
		hPlot=0;

		// Draw plot
		keybd_event(VK_P, 0, VK_PRESS, 0);
		keybd_event(VK_P, 0, VK_RELEASE, 0);

		// 07/21/06 Hang-up problem here again with faster 2.8 GHz computer
		// Discovered that the Sleep(10) call that was added 11/28/05
		// for phase plot was not also put here for freq plot
		// Adding it seems to fix problem
		Sleep(10);
		
		// Wait for GraphiC plot to launch
		// by checking if its menu handle is valid
		while((GetMenu(hPlot))==0)
		{
				// Check for "Must Normalize" error
				// Get handle of foreground window
				hForeground=GetForegroundWindow();

				// Get the caption of that window
				GetWindowText(hForeground, szBuffer, BUFFER_SIZE);

				// Compare it with the Stable32 "Must Normalize" dialog caption
				if((strcmp(szBuffer, "Stable32"))==0)
				{
					// Close "Must Normalize" box
					keybd_event(VK_RETURN, 0, VK_PRESS, 0);
					keybd_event(VK_RETURN, 0, VK_RELEASE, 0);

					// Open edit menu
					keybd_event(VK_MENU, 0, VK_PRESS, 0);	
					keybd_event(VK_E, 0, VK_PRESS, 0);
					keybd_event(VK_E, 0, VK_RELEASE, 0);
					keybd_event(VK_MENU, 0, VK_RELEASE, 0);

					// Select normalize function
					keybd_event(VK_N, 0, VK_PRESS, 0);
					keybd_event(VK_N, 0, VK_RELEASE, 0);

					// Normalize (OK)
					keybd_event(VK_MENU, 0, VK_PRESS, 0);	
					keybd_event(VK_O, 0, VK_PRESS, 0);
					keybd_event(VK_O, 0, VK_RELEASE, 0);
					keybd_event(VK_MENU, 0, VK_RELEASE, 0);

					// Interprocess delay
					Sleep(100);

					// Try again: open plot menu
					keybd_event(VK_MENU, 0, VK_PRESS, 0);	
					keybd_event(VK_P, 0, VK_PRESS, 0);
					keybd_event(VK_P, 0, VK_RELEASE, 0);
					keybd_event(VK_MENU, 0, VK_RELEASE, 0);

					// Select data type
					if(bAutoDataType==FREQ_DATA)
					{
						keybd_event(VK_F, 0, VK_PRESS, 0);
						keybd_event(VK_F, 0, VK_RELEASE, 0);
					}
					else // Phase data
					{
						keybd_event(VK_P, 0, VK_PRESS, 0);
						keybd_event(VK_P, 0, VK_RELEASE, 0);
					}

					// Try again to draw plot
					keybd_event(VK_P, 0, VK_PRESS, 0);
					keybd_event(VK_P, 0, VK_RELEASE, 0);
				}
				
				Sleep(10);
		}

		// Find out whether plot is finished drawing
		// by observing the state of the Print item in the File submenu
		// of the GraphiC menu -it is grayed during drawing
		// The handle of the GraphiC plot window is in the global hPlot
		// The GraphiC File menu is in position 0
		// The GraphiC Print item is in position 1
		// When uState=1=MF_GRAYED, the plot is still being drawn
		// When uState=0, the plot is done
		// Best approach is to mask off all except LSB and test it
		// This thread stays in wait loop until GraphiC plot is drawn
		hMenu=GetMenu(hPlot);
		hSubMenu=GetSubMenu(hMenu, 0);
		do 
		{
			Sleep(100);
			uState=GetMenuState(hSubMenu, 1, MF_BYPOSITION);
		}   while((uState&0x00000001)==TRUE);

		// At this point the data plot is drawn on screen
		// Do we want to print it?
		if(bAutoDataPrint)
		{
			// Print data plot
			keybd_event(VK_MENU, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_RELEASE, 0);
			keybd_event(VK_MENU, 0, VK_RELEASE, 0);
			keybd_event(VK_P, 0, VK_PRESS, 0);
			keybd_event(VK_P, 0, VK_RELEASE, 0);

			// Allow time for the print dialog to open
			while(1)
			{
				// Wait for the print page dialog box to open
				// Get the handle of the foreground window
				hPrint=GetForegroundWindow();

				// Get the caption of that window
				GetWindowText(hPrint, szBuffer, BUFFER_SIZE);

				// Compare it with the GraphiC print dialog caption
				if((strcmp(szBuffer, "GraphiC/Win Print Page"))==0)
				{
					break;
				}

				// Loop delay
				Sleep(10);
			}

			// Wait for the printing to take place
			while(1)
			{
				// Wait for the print page dialog box to close
				// Get the handle of the foreground window
				hPrint=GetForegroundWindow();

				// Get the caption of that window
				GetWindowText(hPrint, szBuffer, BUFFER_SIZE);

				// Compare it with the GraphiC print dialog caption
				if((strcmp(szBuffer, "GraphiC/Win Print Page"))!=0)
				{
					break;
				}

				// Loop delay
				Sleep(100);
			}

			// Now the plot has to redraw before it can be closed
			// Find out whether plot is finished drawing
			// by observing the state of the Print item in the File submenu
			// of the GraphiC menu -it is grayed during drawing
			// The handle of the GraphiC plot window is in the global hPlot
			// The GraphiC File menu is in position 0
			// The GraphiC Print item is in position 1
			// When uState=1=MF_GRAYED, the plot is still being drawn
			// When uState=0, the plot is done
			// Best approach is to mask off all except LSB and test it
			// This thread stays in wait loop until GraphiC plot is drawn
			hMenu=GetMenu(hPlot);
			hSubMenu=GetSubMenu(hMenu, 0);
			do 
			{
				Sleep(100);
				uState=GetMenuState(hSubMenu, 1, MF_BYPOSITION);
			}   while((uState&0x00000001)==TRUE);
		}

		// Wait to make sure message is seen
		Sleep(100);

		// Write message to show what's happening
		WriteMessage("Converted data plot");
		
		// Add extra delay to show converted data plot
		if(bAutoAddDelay)
		{
			Sleep(nAutoDelay);
		}

		// Close plot if there are more processes that follow
		// or if bAutoClose flag is set
		if( (nMaxProcess>PLOT_CONVERTED) || bAutoClose)
		{
			keybd_event(VK_MENU, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_RELEASE, 0);
			keybd_event(VK_MENU, 0, VK_RELEASE, 0);
			keybd_event(VK_X, 0, VK_PRESS, 0);
			keybd_event(VK_X, 0, VK_RELEASE, 0);

			// Close plot dialog box
			keybd_event(VK_ESCAPE, 0, VK_PRESS, 0);
			keybd_event(VK_ESCAPE, 0, VK_RELEASE, 0);
		}
	}

	// Interprocess delay
	Sleep(100);
	
	// Remove outliers
	if(bAutoOutliers && bAutoAnalysisType==FREQ_DATA)
	{
		// Go to analysis menu
		keybd_event(VK_MENU, 0, VK_PRESS, 0);	
		keybd_event(VK_A, 0, VK_PRESS, 0);
		keybd_event(VK_A, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);

		// Select check function
		keybd_event(VK_C, 0, VK_PRESS, 0);		
		keybd_event(VK_C, 0, VK_RELEASE, 0);

		// Choose remove all outliers
		keybd_event(VK_MENU, 0, VK_PRESS, 0);	
		keybd_event(VK_L, 0, VK_PRESS, 0);
		keybd_event(VK_L, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);

		// Go to sigma factor edit control
		keybd_event(VK_MENU, 0, VK_PRESS, 0);	
		keybd_event(VK_F, 0, VK_PRESS, 0);
		keybd_event(VK_F, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);

		// Load the sigma factor character-by-character
		for(i=0; i<(int)strlen(szAutoSigmaFactor); i++)
		{
			keybd_event((char)VkKeyScan(szAutoSigmaFactor[i]), 0, VK_PRESS, 0);
			keybd_event((char)VkKeyScan(szAutoSigmaFactor[i]), 0,
				VK_RELEASE, 0);
		}

		// Preset the busy flag to insure wait loop takes effect
		bBusy=TRUE;

		// Press calc button
		keybd_event(VK_MENU, 0, VK_PRESS, 0);
		keybd_event(VK_A, 0, VK_PRESS, 0);
		keybd_event(VK_A, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);

		// Wait for process done
		while(bBusy)
		{
			Sleep(10);
		}

		// Press close button
		keybd_event(VK_MENU, 0, VK_PRESS, 0);
		keybd_event(VK_C, 0, VK_PRESS, 0);
		keybd_event(VK_C, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);

		// Wait to make sure message is seen
		Sleep(100);

		// Write message to show what's happening
		WriteMessage("Data corrected");
		
		// Add extra delay to show corrected data in status bar
		if(bAutoAddDelay)
		{
			Sleep(nAutoDelay);
		}
	}
	
	// Interprocess delay
	Sleep(100);
	
	// Corrected data plot
	if(bAutoDataPlot && bAutoPrintCorrected)
	{
		// Open plot menu
		keybd_event(VK_MENU, 0, VK_PRESS, 0);	
		keybd_event(VK_P, 0, VK_PRESS, 0);
		keybd_event(VK_P, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);

		// Select data type
		if(bAutoAnalysisType==FREQ_DATA)
		{
			keybd_event(VK_F, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_RELEASE, 0);
		}
		else // Phase data
		{
			keybd_event(VK_P, 0, VK_PRESS, 0);
			keybd_event(VK_P, 0, VK_RELEASE, 0);
		}

		// Preset hPlot to null
		hPlot=0;

		// Draw plot
		keybd_event(VK_P, 0, VK_PRESS, 0);
		keybd_event(VK_P, 0, VK_RELEASE, 0);

		// Wait for GraphiC plot to launch
		// by checking if its menu handle is valid
		while((GetMenu(hPlot))==0)
		{
				// Check for "Must Normalize" error
				// Get handle of foreground window
				hForeground=GetForegroundWindow();

				// Get the caption of that window
				GetWindowText(hForeground, szBuffer, BUFFER_SIZE);

				// Compare it with the Stable32 "Must Normalize" dialog caption
				if((strcmp(szBuffer, "Stable32"))==0)
				{
					// Close "Must Normalize" box
					keybd_event(VK_RETURN, 0, VK_PRESS, 0);
					keybd_event(VK_RETURN, 0, VK_RELEASE, 0);

					// Open edit menu
					keybd_event(VK_MENU, 0, VK_PRESS, 0);	
					keybd_event(VK_E, 0, VK_PRESS, 0);
					keybd_event(VK_E, 0, VK_RELEASE, 0);
					keybd_event(VK_MENU, 0, VK_RELEASE, 0);

					// Select normalize function
					keybd_event(VK_N, 0, VK_PRESS, 0);
					keybd_event(VK_N, 0, VK_RELEASE, 0);

					// Normalize (OK)
					keybd_event(VK_MENU, 0, VK_PRESS, 0);	
					keybd_event(VK_O, 0, VK_PRESS, 0);
					keybd_event(VK_O, 0, VK_RELEASE, 0);
					keybd_event(VK_MENU, 0, VK_RELEASE, 0);

					// Interprocess delay
					Sleep(100);

					// Try again: open plot menu
					keybd_event(VK_MENU, 0, VK_PRESS, 0);	
					keybd_event(VK_P, 0, VK_PRESS, 0);
					keybd_event(VK_P, 0, VK_RELEASE, 0);
					keybd_event(VK_MENU, 0, VK_RELEASE, 0);

					// Select data type
					if(bAutoDataType==FREQ_DATA)
					{
						keybd_event(VK_F, 0, VK_PRESS, 0);
						keybd_event(VK_F, 0, VK_RELEASE, 0);
					}
					else // Phase data
					{
						keybd_event(VK_P, 0, VK_PRESS, 0);
						keybd_event(VK_P, 0, VK_RELEASE, 0);
					}

					// Try again to draw plot
					keybd_event(VK_P, 0, VK_PRESS, 0);
					keybd_event(VK_P, 0, VK_RELEASE, 0);
				}

				Sleep(10);
		}

		// Find out whether plot is finished drawing
		// by observing the state of the Print item in the File submenu
		// of the GraphiC menu -it is grayed during drawing
		// The handle of the GraphiC plot window is in the global hPlot
		// The GraphiC File menu is in position 0
		// The GraphiC Print item is in position 1
		// When uState=1=MF_GRAYED, the plot is still being drawn
		// When uState=0, the plot is done
		// Best approach is to mask off all except LSB and test it
		// This thread stays in wait loop until GraphiC plot is drawn
		hMenu=GetMenu(hPlot);
		hSubMenu=GetSubMenu(hMenu, 0);
		do 
		{
			Sleep(100);
			uState=GetMenuState(hSubMenu, 1, MF_BYPOSITION);
		}   while((uState&0x00000001)==TRUE);

		// At this point the data plot is drawn on screen
		// Do we want to print it?
		if(bAutoDataPrint)
		{
			// Print data plot
			keybd_event(VK_MENU, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_RELEASE, 0);
			keybd_event(VK_MENU, 0, VK_RELEASE, 0);
			keybd_event(VK_P, 0, VK_PRESS, 0);
			keybd_event(VK_P, 0, VK_RELEASE, 0);

			// Allow time for the print dialog to open
			while(1)
			{
				// Wait for the print page dialog box to open
				// Get the handle of the foreground window
				hPrint=GetForegroundWindow();

				// Get the caption of that window
				GetWindowText(hPrint, szBuffer, BUFFER_SIZE);

				// Compare it with the GraphiC print dialog caption
				if((strcmp(szBuffer, "GraphiC/Win Print Page"))==0)
				{
					break;
				}

				// Loop delay
				Sleep(10);
			}

			// Wait for the printing to take place
			while(1)
			{
				// Wait for the print page dialog box to close
				// Get the handle of the foreground window
				hPrint=GetForegroundWindow();

				// Get the caption of that window
				GetWindowText(hPrint, szBuffer, BUFFER_SIZE);

				// Compare it with the GraphiC print dialog caption
				if((strcmp(szBuffer, "GraphiC/Win Print Page"))!=0)
				{
					break;
				}

				// Loop delay
				Sleep(100);
			}

			// Now the plot has to redraw before it can be closed
			// Find out whether plot is finished drawing
			// by observing the state of the Print item in the File submenu
			// of the GraphiC menu -it is grayed during drawing
			// The handle of the GraphiC plot window is in the global hPlot
			// The GraphiC File menu is in position 0
			// The GraphiC Print item is in position 1
			// When uState=1=MF_GRAYED, the plot is still being drawn
			// When uState=0, the plot is done
			// Best approach is to mask off all except LSB and test it
			// This thread stays in wait loop until GraphiC plot is drawn
			hMenu=GetMenu(hPlot);
			hSubMenu=GetSubMenu(hMenu, 0);
			do 
			{
				Sleep(100);
				uState=GetMenuState(hSubMenu, 1, MF_BYPOSITION);
			}   while((uState&0x00000001)==TRUE);

		}

		// Wait to make sure message is seen
		Sleep(100);

		// Write message to show what's happening
		WriteMessage("Corrected data plot");
		
		// Add extra delay to show corrected data plot
		if(bAutoAddDelay)
		{
			Sleep(nAutoDelay);
		}

		// Close plot if there are more processes that follow
		// or if bAutoClose flag is set
		if( (nMaxProcess>PLOT_CORRECTED) || bAutoClose)
		{
			keybd_event(VK_MENU, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_RELEASE, 0);
			keybd_event(VK_MENU, 0, VK_RELEASE, 0);
			keybd_event(VK_X, 0, VK_PRESS, 0);
			keybd_event(VK_X, 0, VK_RELEASE, 0);

			// Close plot dialog box
			keybd_event(VK_ESCAPE, 0, VK_PRESS, 0);
			keybd_event(VK_ESCAPE, 0, VK_RELEASE, 0);
		}
	}

	// Interprocess delay
	Sleep(100);
	
	// Select part of data
	if(bAutoPart)
	{
		// Go to edit menu
		keybd_event(VK_MENU, 0, VK_PRESS, 0);	
		keybd_event(VK_E, 0, VK_PRESS, 0);
		keybd_event(VK_E, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);

		// Select part function
		keybd_event(VK_P, 0, VK_PRESS, 0);		
		keybd_event(VK_P, 0, VK_RELEASE, 0);

		// Enter start # if it is not 1
		if(nAutoStart!=1)
		{
			// Go to start factor edit control
			keybd_event(VK_MENU, 0, VK_PRESS, 0);	
			keybd_event(VK_S, 0, VK_PRESS, 0);
			keybd_event(VK_S, 0, VK_RELEASE, 0);
			keybd_event(VK_MENU, 0, VK_RELEASE, 0);

			// Load the start point # character-by-character
			for(i=0; i<(int)strlen(szAutoStart); i++)
			{
				keybd_event((char)VkKeyScan(szAutoStart[i]), 0, VK_PRESS, 0);
				keybd_event((char)VkKeyScan(szAutoStart[i]), 0, VK_RELEASE, 0);
			}
		}

		// Enter end # if it is not 0 (the code for last point)
		if(nAutoEnd!=0)
		{
			// Go to end factor edit control
			keybd_event(VK_MENU, 0, VK_PRESS, 0);	
			keybd_event(VK_E, 0, VK_PRESS, 0);
			keybd_event(VK_E, 0, VK_RELEASE, 0);
			keybd_event(VK_MENU, 0, VK_RELEASE, 0);

			// Load the end point # character-by-character
			for(i=0; i<(int)strlen(szAutoEnd); i++)
			{
				keybd_event((char)VkKeyScan(szAutoEnd[i]), 0, VK_PRESS, 0);
				keybd_event((char)VkKeyScan(szAutoEnd[i]), 0, VK_RELEASE, 0);
			}
		}

		// Preset the busy flag to insure wait loop takes effect
		bBusy=TRUE;

		// Select part of data (OK and then Close)
		keybd_event(VK_MENU, 0, VK_PRESS, 0);	
		keybd_event(VK_O, 0, VK_PRESS, 0);
		keybd_event(VK_O, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_PRESS, 0);	
		keybd_event(VK_C, 0, VK_PRESS, 0);
		keybd_event(VK_C, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);

		// Wait for process done
		while(bBusy)
		{
			Sleep(10);
		}

		// Wait to make sure message is seen
		Sleep(100);

		// Write message to show what's happening
		WriteMessage("Data selected");
		
		// Add extra delay to show selected data in status bar
		if(bAutoAddDelay)
		{
			Sleep(nAutoDelay);
		}
	}
	
	// Interprocess delay
	Sleep(100);
	
	// Selected data plot
	if(bAutoDataPlot && bAutoPrintSelected)
	{
		// Open plot menu
		keybd_event(VK_MENU, 0, VK_PRESS, 0);	
		keybd_event(VK_P, 0, VK_PRESS, 0);
		keybd_event(VK_P, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);

		// Select data type
		if(bAutoAnalysisType==FREQ_DATA)
		{
			keybd_event(VK_F, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_RELEASE, 0);
		}
		else // Phase data
		{
			keybd_event(VK_P, 0, VK_PRESS, 0);
			keybd_event(VK_P, 0, VK_RELEASE, 0);
		}

		// Preset hPlot to null
		hPlot=0;

		// Draw plot
		keybd_event(VK_P, 0, VK_PRESS, 0);
		keybd_event(VK_P, 0, VK_RELEASE, 0);

		// Wait for GraphiC plot to launch
		// by checking if its menu handle is valid
		while((GetMenu(hPlot))==0)
		{
				// Check for "Must Normalize" error
				// Get handle of foreground window
				hForeground=GetForegroundWindow();

				// Get the caption of that window
				GetWindowText(hForeground, szBuffer, BUFFER_SIZE);

				// Compare it with the Stable32 "Must Normalize"
				// dialog caption
				if((strcmp(szBuffer, "Stable32"))==0)
				{
					// Close "Must Normalize" box
					keybd_event(VK_RETURN, 0, VK_PRESS, 0);
					keybd_event(VK_RETURN, 0, VK_RELEASE, 0);

					// Open edit menu
					keybd_event(VK_MENU, 0, VK_PRESS, 0);	
					keybd_event(VK_E, 0, VK_PRESS, 0);
					keybd_event(VK_E, 0, VK_RELEASE, 0);
					keybd_event(VK_MENU, 0, VK_RELEASE, 0);

					// Select normalize function
					keybd_event(VK_N, 0, VK_PRESS, 0);
					keybd_event(VK_N, 0, VK_RELEASE, 0);

					// Normalize (OK)
					keybd_event(VK_MENU, 0, VK_PRESS, 0);	
					keybd_event(VK_O, 0, VK_PRESS, 0);
					keybd_event(VK_O, 0, VK_RELEASE, 0);
					keybd_event(VK_MENU, 0, VK_RELEASE, 0);

					// Interprocess delay
					Sleep(100);

					// Try again: open plot menu
					keybd_event(VK_MENU, 0, VK_PRESS, 0);	
					keybd_event(VK_P, 0, VK_PRESS, 0);
					keybd_event(VK_P, 0, VK_RELEASE, 0);
					keybd_event(VK_MENU, 0, VK_RELEASE, 0);

					// Select data type
					if(bAutoDataType==FREQ_DATA)
					{
						keybd_event(VK_F, 0, VK_PRESS, 0);
						keybd_event(VK_F, 0, VK_RELEASE, 0);
					}
					else // Phase data
					{
						keybd_event(VK_P, 0, VK_PRESS, 0);
						keybd_event(VK_P, 0, VK_RELEASE, 0);
					}

					// Try again to draw plot
					keybd_event(VK_P, 0, VK_PRESS, 0);
					keybd_event(VK_P, 0, VK_RELEASE, 0);
				}

				Sleep(10);
		}

		// Find out whether plot is finished drawing
		// by observing the state of the Print item in the File submenu
		// of the GraphiC menu -it is grayed during drawing
		// The handle of the GraphiC plot window is in the global hPlot
		// The GraphiC File menu is in position 0
		// The GraphiC Print item is in position 1
		// When uState=1=MF_GRAYED, the plot is still being drawn
		// When uState=0, the plot is done
		// Best approach is to mask off all except LSB and test it
		// This thread stays in wait loop until GraphiC plot is drawn
		hMenu=GetMenu(hPlot);
		hSubMenu=GetSubMenu(hMenu, 0);
		do 
		{
			Sleep(100);
			uState=GetMenuState(hSubMenu, 1, MF_BYPOSITION);
		}   while((uState&0x00000001)==TRUE);

		// At this point the data plot is drawn on screen
		// Do we want to print it?
		if(bAutoDataPrint)
		{
			// Print data plot
			keybd_event(VK_MENU, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_RELEASE, 0);
			keybd_event(VK_MENU, 0, VK_RELEASE, 0);
			keybd_event(VK_P, 0, VK_PRESS, 0);
			keybd_event(VK_P, 0, VK_RELEASE, 0);

			// Allow time for the print dialog to open
			while(1)
			{
				// Wait for the print page dialog box to open
				// Get the handle of the foreground window
				hPrint=GetForegroundWindow();

				// Get the caption of that window
				GetWindowText(hPrint, szBuffer, BUFFER_SIZE);

				// Compare it with the GraphiC print dialog caption
				if((strcmp(szBuffer, "GraphiC/Win Print Page"))==0)
				{
					break;
				}

				// Loop delay
				Sleep(10);
			}

			// Wait for the printing to take place
			while(1)
			{
				// Wait for the print page dialog box to close
				// Get the handle of the foreground window
				hPrint=GetForegroundWindow();

				// Get the caption of that window
				GetWindowText(hPrint, szBuffer, BUFFER_SIZE);

				// Compare it with the GraphiC print dialog caption
				if((strcmp(szBuffer, "GraphiC/Win Print Page"))!=0)
				{
					break;
				}

				// Loop delay
				Sleep(100);
			}

			// Now the plot has to redraw before it can be closed
			// Find out whether plot is finished drawing
			// by observing the state of the Print item in the File submenu
			// of the GraphiC menu -it is grayed during drawing
			// The handle of the GraphiC plot window is in the global hPlot
			// The GraphiC File menu is in position 0
			// The GraphiC Print item is in position 1
			// When uState=1=MF_GRAYED, the plot is still being drawn
			// When uState=0, the plot is done
			// Best approach is to mask off all except LSB and test it
			// This thread stays in wait loop until GraphiC plot is drawn
			hMenu=GetMenu(hPlot);
			hSubMenu=GetSubMenu(hMenu, 0);
			do 
			{
				Sleep(100);
				uState=GetMenuState(hSubMenu, 1, MF_BYPOSITION);
			}   while((uState&0x00000001)==TRUE);
		}

		// Wait to make sure message is seen
		Sleep(100);

		// Write message to show what's happening
		WriteMessage("Selected data plot");
		
		// Add extra delay to show averaged data plot
		if(bAutoAddDelay)
		{
			Sleep(nAutoDelay);
		}

		// Close plot if there are more processes that follow
		// or if bAutoClose flag is set
		if( (nMaxProcess>PLOT_SELECTED) || bAutoClose)
		{
			keybd_event(VK_MENU, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_RELEASE, 0);
			keybd_event(VK_MENU, 0, VK_RELEASE, 0);
			keybd_event(VK_X, 0, VK_PRESS, 0);
			keybd_event(VK_X, 0, VK_RELEASE, 0);

			// Close plot dialog box
			keybd_event(VK_ESCAPE, 0, VK_PRESS, 0);
			keybd_event(VK_ESCAPE, 0, VK_RELEASE, 0);
		}
	}

	// Interprocess delay
	Sleep(100);
	
	// Average data
	if(bAutoAverage)
	{
		// Go to edit menu
		keybd_event(VK_MENU, 0, VK_PRESS, 0);	
		keybd_event(VK_E, 0, VK_PRESS, 0);
		keybd_event(VK_E, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);

		// Select average function
		keybd_event(VK_A, 0, VK_PRESS, 0);		
		keybd_event(VK_A, 0, VK_RELEASE, 0);

		// Go to avg factor edit control
		keybd_event(VK_MENU, 0, VK_PRESS, 0);	
		keybd_event(VK_A, 0, VK_PRESS, 0);
		keybd_event(VK_A, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);

		// Load the averaging factor character-by-character
		for(i=0; i<(int)strlen(szAutoAvgFactor); i++)
		{
			keybd_event((char)VkKeyScan(szAutoAvgFactor[i]), 0, VK_PRESS, 0);
			keybd_event((char)VkKeyScan(szAutoAvgFactor[i]), 0, VK_RELEASE, 0);
		}

		// Preset the busy flag to insure wait loop takes effect
		bBusy=TRUE;

		// Do averaging
		keybd_event(VK_MENU, 0, VK_PRESS, 0);	
		keybd_event(VK_O, 0, VK_PRESS, 0);
		keybd_event(VK_O, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);

		// Wait for process done
		while(bBusy)
		{
			Sleep(10);
		}

		// Wait to make sure message is seen
		Sleep(100);

		// Write message to show what's happening
		WriteMessage("Data averaged");
		
		// Add extra delay to show averaged data in status bar
		if(bAutoAddDelay)
		{
			Sleep(nAutoDelay);
		}
	}
	
	// Interprocess delay
	Sleep(100);
	
	// Averaged data plot
	if(bAutoDataPlot && bAutoPrintAveraged)
	{
		// Open plot menu
		keybd_event(VK_MENU, 0, VK_PRESS, 0);	
		keybd_event(VK_P, 0, VK_PRESS, 0);
		keybd_event(VK_P, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);

		// Select data type
		if(bAutoAnalysisType==FREQ_DATA)
		{
			keybd_event(VK_F, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_RELEASE, 0);
		}
		else // Phase data
		{
			keybd_event(VK_P, 0, VK_PRESS, 0);
			keybd_event(VK_P, 0, VK_RELEASE, 0);
		}

		// Preset hPlot to null
		hPlot=0;

		// Draw plot
		keybd_event(VK_P, 0, VK_PRESS, 0);
		keybd_event(VK_P, 0, VK_RELEASE, 0);

		// Wait for GraphiC plot to launch
		// by checking if its menu handle is valid
		while((GetMenu(hPlot))==0)
		{
				// Check for "Must Normalize" error
				// Get handle of foreground window
				hForeground=GetForegroundWindow();

				// Get the caption of that window
				GetWindowText(hForeground, szBuffer, BUFFER_SIZE);

				// Compare it with the Stable32 "Must Normalize" dialog caption
				if((strcmp(szBuffer, "Stable32"))==0)
				{
					// Close "Must Normalize" box
					keybd_event(VK_RETURN, 0, VK_PRESS, 0);
					keybd_event(VK_RETURN, 0, VK_RELEASE, 0);

					// Open edit menu
					keybd_event(VK_MENU, 0, VK_PRESS, 0);	
					keybd_event(VK_E, 0, VK_PRESS, 0);
					keybd_event(VK_E, 0, VK_RELEASE, 0);
					keybd_event(VK_MENU, 0, VK_RELEASE, 0);

					// Select normalize function
					keybd_event(VK_N, 0, VK_PRESS, 0);
					keybd_event(VK_N, 0, VK_RELEASE, 0);

					// Normalize (OK)
					keybd_event(VK_MENU, 0, VK_PRESS, 0);	
					keybd_event(VK_O, 0, VK_PRESS, 0);
					keybd_event(VK_O, 0, VK_RELEASE, 0);
					keybd_event(VK_MENU, 0, VK_RELEASE, 0);

					// Interprocess delay
					Sleep(100);

					// Try again: open plot menu
					keybd_event(VK_MENU, 0, VK_PRESS, 0);	
					keybd_event(VK_P, 0, VK_PRESS, 0);
					keybd_event(VK_P, 0, VK_RELEASE, 0);
					keybd_event(VK_MENU, 0, VK_RELEASE, 0);

					// Select data type
					if(bAutoDataType==FREQ_DATA)
					{
						keybd_event(VK_F, 0, VK_PRESS, 0);
						keybd_event(VK_F, 0, VK_RELEASE, 0);
					}
					else // Phase data
					{
						keybd_event(VK_P, 0, VK_PRESS, 0);
						keybd_event(VK_P, 0, VK_RELEASE, 0);
					}

					// Try again to draw plot
					keybd_event(VK_P, 0, VK_PRESS, 0);
					keybd_event(VK_P, 0, VK_RELEASE, 0);
				}

				Sleep(10);
		}

		// Find out whether plot is finished drawing
		// by observing the state of the Print item in the File submenu
		// of the GraphiC menu -it is grayed during drawing
		// The handle of the GraphiC plot window is in the global hPlot
		// The GraphiC File menu is in position 0
		// The GraphiC Print item is in position 1
		// When uState=1=MF_GRAYED, the plot is still being drawn
		// When uState=0, the plot is done
		// Best approach is to mask off all except LSB and test it
		// This thread stays in wait loop until GraphiC plot is drawn
		hMenu=GetMenu(hPlot);
		hSubMenu=GetSubMenu(hMenu, 0);
		do 
		{
			Sleep(100);
			uState=GetMenuState(hSubMenu, 1, MF_BYPOSITION);
		}   while((uState&0x00000001)==TRUE);

		// At this point the data plot is drawn on screen
		// Do we want to print it?
		if(bAutoDataPrint)
		{
			// Print data plot
			keybd_event(VK_MENU, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_RELEASE, 0);
			keybd_event(VK_MENU, 0, VK_RELEASE, 0);
			keybd_event(VK_P, 0, VK_PRESS, 0);
			keybd_event(VK_P, 0, VK_RELEASE, 0);

			// Allow time for the print dialog to open
			while(1)
			{
				// Wait for the print page dialog box to open
				// Get the handle of the foreground window
				hPrint=GetForegroundWindow();

				// Get the caption of that window
				GetWindowText(hPrint, szBuffer, BUFFER_SIZE);

				// Compare it with the GraphiC print dialog caption
				if((strcmp(szBuffer, "GraphiC/Win Print Page"))==0)
				{
					break;
				}

				// Loop delay
				Sleep(10);
			}

			// Wait for the printing to take place
			while(1)
			{
				// Wait for the print page dialog box to close
				// Get the handle of the foreground window
				hPrint=GetForegroundWindow();

				// Get the caption of that window
				GetWindowText(hPrint, szBuffer, BUFFER_SIZE);

				// Compare it with the GraphiC print dialog caption
				if((strcmp(szBuffer, "GraphiC/Win Print Page"))!=0)
				{
					break;
				}

				// Loop delay
				Sleep(100);
			}

			// Now the plot has to redraw before it can be closed
			// Find out whether plot is finished drawing
			// by observing the state of the Print item in the File submenu
			// of the GraphiC menu -it is grayed during drawing
			// The handle of the GraphiC plot window is in the global hPlot
			// The GraphiC File menu is in position 0
			// The GraphiC Print item is in position 1
			// When uState=1=MF_GRAYED, the plot is still being drawn
			// When uState=0, the plot is done
			// Best approach is to mask off all except LSB and test it
			// This thread stays in wait loop until GraphiC plot is drawn
			hMenu=GetMenu(hPlot);
			hSubMenu=GetSubMenu(hMenu, 0);
			do 
			{
				Sleep(100);
				uState=GetMenuState(hSubMenu, 1, MF_BYPOSITION);
			}   while((uState&0x00000001)==TRUE);
		}

		// Wait to make sure message is seen
		Sleep(100);

		// Write message to show what's happening
		WriteMessage("Averaged data plot");
		
		// Add extra delay to show averaged data plot
		if(bAutoAddDelay)
		{
			Sleep(nAutoDelay);
		}

		// Close plot if there are more processes that follow
		// or if bAutoClose flag is set
		if( (nMaxProcess>PLOT_AVERAGED) || bAutoClose)
		{
			keybd_event(VK_MENU, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_RELEASE, 0);
			keybd_event(VK_MENU, 0, VK_RELEASE, 0);
			keybd_event(VK_X, 0, VK_PRESS, 0);
			keybd_event(VK_X, 0, VK_RELEASE, 0);

			// Close plot dialog box
			keybd_event(VK_ESCAPE, 0, VK_PRESS, 0);
			keybd_event(VK_ESCAPE, 0, VK_RELEASE, 0);
		}
	}

	// Interprocess delay
	Sleep(100);
	
	// Normalize data
	if(bAutoNormalize)
	{
		// Go to edit menu
		keybd_event(VK_MENU, 0, VK_PRESS, 0);	
		keybd_event(VK_E, 0, VK_PRESS, 0);
		keybd_event(VK_E, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);

		// Select normalize function
		keybd_event(VK_N, 0, VK_PRESS, 0);		
		keybd_event(VK_N, 0, VK_RELEASE, 0);

		// Preset the busy flag to insure wait loop takes effect
		bBusy=TRUE;

		// Do normalization
		keybd_event(VK_MENU, 0, VK_PRESS, 0);	
		keybd_event(VK_O, 0, VK_PRESS, 0);
		keybd_event(VK_O, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);

		// Wait for process done
		while(bBusy)
		{
			Sleep(10);
		}

		// Wait to make sure message is seen
		Sleep(100);

		// Write message to show what's happening
		WriteMessage("Data normalized");

		// Add extra delay to show normalized data in status bar
		if(bAutoAddDelay)
		{
			Sleep(nAutoDelay);
		}
	}
	
	// Interprocess delay
	Sleep(100);

	// Normalized data plot
	if(bAutoDataPlot && bAutoPrintNormalized)
	{
		// Open plot menu
		keybd_event(VK_MENU, 0, VK_PRESS, 0);	
		keybd_event(VK_P, 0, VK_PRESS, 0);
		keybd_event(VK_P, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);

		// Select data type
		if(bAutoAnalysisType==FREQ_DATA)
		{
			keybd_event(VK_F, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_RELEASE, 0);
		}
		else // Phase data
		{
			keybd_event(VK_P, 0, VK_PRESS, 0);
			keybd_event(VK_P, 0, VK_RELEASE, 0);
		}

		// Preset hPlot to null
		hPlot=0;

		// Draw plot
		keybd_event(VK_P, 0, VK_PRESS, 0);
		keybd_event(VK_P, 0, VK_RELEASE, 0);

		// Wait for GraphiC plot to launch
		// by checking if its menu handle is valid
		while((GetMenu(hPlot))==0)
		{
				// Check for "Must Normalize" error
				// Get handle of foreground window
				hForeground=GetForegroundWindow();

				// Get the caption of that window
				GetWindowText(hForeground, szBuffer, BUFFER_SIZE);

				// Compare it with the Stable32 "Must Normalize" dialog caption
				if((strcmp(szBuffer, "Stable32"))==0)
				{
					// Close "Must Normalize" box
					keybd_event(VK_RETURN, 0, VK_PRESS, 0);
					keybd_event(VK_RETURN, 0, VK_RELEASE, 0);

					// Open edit menu
					keybd_event(VK_MENU, 0, VK_PRESS, 0);	
					keybd_event(VK_E, 0, VK_PRESS, 0);
					keybd_event(VK_E, 0, VK_RELEASE, 0);
					keybd_event(VK_MENU, 0, VK_RELEASE, 0);

					// Select normalize function
					keybd_event(VK_N, 0, VK_PRESS, 0);
					keybd_event(VK_N, 0, VK_RELEASE, 0);

					// Normalize (OK)
					keybd_event(VK_MENU, 0, VK_PRESS, 0);	
					keybd_event(VK_O, 0, VK_PRESS, 0);
					keybd_event(VK_O, 0, VK_RELEASE, 0);
					keybd_event(VK_MENU, 0, VK_RELEASE, 0);

					// Interprocess delay
					Sleep(100);

					// Try again: open plot menu
					keybd_event(VK_MENU, 0, VK_PRESS, 0);	
					keybd_event(VK_P, 0, VK_PRESS, 0);
					keybd_event(VK_P, 0, VK_RELEASE, 0);
					keybd_event(VK_MENU, 0, VK_RELEASE, 0);

					// Select data type
					if(bAutoDataType==FREQ_DATA)
					{
						keybd_event(VK_F, 0, VK_PRESS, 0);
						keybd_event(VK_F, 0, VK_RELEASE, 0);
					}
					else // Phase data
					{
						keybd_event(VK_P, 0, VK_PRESS, 0);
						keybd_event(VK_P, 0, VK_RELEASE, 0);
					}

					// Try again to draw plot
					keybd_event(VK_P, 0, VK_PRESS, 0);
					keybd_event(VK_P, 0, VK_RELEASE, 0);
				}

				Sleep(10);
		}

		// Find out whether plot is finished drawing
		// by observing the state of the Print item in the File submenu
		// of the GraphiC menu -it is grayed during drawing
		// The handle of the GraphiC plot window is in the global hPlot
		// The GraphiC File menu is in position 0
		// The GraphiC Print item is in position 1
		// When uState=1=MF_GRAYED, the plot is still being drawn
		// When uState=0, the plot is done
		// Best approach is to mask off all except LSB and test it
		// This thread stays in wait loop until GraphiC plot is drawn
		hMenu=GetMenu(hPlot);
		hSubMenu=GetSubMenu(hMenu, 0);
		do 
		{
			Sleep(100);
			uState=GetMenuState(hSubMenu, 1, MF_BYPOSITION);
		}   while((uState&0x00000001)==TRUE);

		// At this point the data plot is drawn on screen
		// Do we want to print it?
		if(bAutoDataPrint)
		{
			// Print data plot
			keybd_event(VK_MENU, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_RELEASE, 0);
			keybd_event(VK_MENU, 0, VK_RELEASE, 0);
			keybd_event(VK_P, 0, VK_PRESS, 0);
			keybd_event(VK_P, 0, VK_RELEASE, 0);

			// Allow time for the print dialog to open
			while(1)
			{
				// Wait for the print page dialog box to open
				// Get the handle of the foreground window
				hPrint=GetForegroundWindow();

				// Get the caption of that window
				GetWindowText(hPrint, szBuffer, BUFFER_SIZE);

				// Compare it with the GraphiC print dialog caption
				if((strcmp(szBuffer, "GraphiC/Win Print Page"))==0)
				{
					break;
				}

				// Loop delay
				Sleep(10);
			}

			// Wait for the printing to take place
			while(1)
			{
				// Wait for the print page dialog box to close
				// Get the handle of the foreground window
				hPrint=GetForegroundWindow();

				// Get the caption of that window
				GetWindowText(hPrint, szBuffer, BUFFER_SIZE);

				// Compare it with the GraphiC print dialog caption
				if((strcmp(szBuffer, "GraphiC/Win Print Page"))!=0)
				{
					break;
				}

				// Loop delay
				Sleep(100);
			}

			// Now the plot has to redraw before it can be closed
			// Find out whether plot is finished drawing
			// by observing the state of the Print item in the File submenu
			// of the GraphiC menu -it is grayed during drawing
			// The handle of the GraphiC plot window is in the global hPlot
			// The GraphiC File menu is in position 0
			// The GraphiC Print item is in position 1
			// When uState=1=MF_GRAYED, the plot is still being drawn
			// When uState=0, the plot is done
			// Best approach is to mask off all except LSB and test it
			// This thread stays in wait loop until GraphiC plot is drawn
			hMenu=GetMenu(hPlot);
			hSubMenu=GetSubMenu(hMenu, 0);
			do 
			{
				Sleep(100);
				uState=GetMenuState(hSubMenu, 1, MF_BYPOSITION);
			}   while((uState&0x00000001)==TRUE);
		}

		// Wait to make sure message is seen
		Sleep(100);

		// Write message to show what's happening
		WriteMessage("Normalized data plot");
		
		// Add extra delay to show normalized data plot
		if(bAutoAddDelay)
		{
			Sleep(nAutoDelay);
		}

		// Close plot if there are more processes that follow
		// or if bAutoClose flag is set
		if( (nMaxProcess>PLOT_NORMALIZED) || bAutoClose)
		{
			keybd_event(VK_MENU, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_RELEASE, 0);
			keybd_event(VK_MENU, 0, VK_RELEASE, 0);
			keybd_event(VK_X, 0, VK_PRESS, 0);
			keybd_event(VK_X, 0, VK_RELEASE, 0);

			// Close plot dialog box
			keybd_event(VK_ESCAPE, 0, VK_PRESS, 0);
			keybd_event(VK_ESCAPE, 0, VK_RELEASE, 0);
		}
	}

	// Interprocess delay
	Sleep(100);

	// Remove drift
	if(bAutoDrift)
	{
		// Go to analysis menu
		keybd_event(VK_MENU, 0, VK_PRESS, 0);	
		keybd_event(VK_A, 0, VK_PRESS, 0);
		keybd_event(VK_A, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);

		// Select drift function
		keybd_event(VK_D, 0, VK_PRESS, 0);		
		keybd_event(VK_D, 0, VK_RELEASE, 0);

		// Go to drift type list box
		keybd_event(VK_MENU, 0, VK_PRESS, 0);	
		keybd_event(VK_T, 0, VK_PRESS, 0);
		keybd_event(VK_T, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);

		// Select drift type
		// Note: Can't select item in list box by typing the name of the item
		// Selections are made as each letter is entered
		// on basis of initial letters
		// Initial letters are not necessarily unique
		// So we will use the numeric position of the item to select it

		// First move to top of list with Page Up key
		keybd_event(VK_PRIOR, 0, VK_PRESS, 0);
		keybd_event(VK_PRIOR, 0, VK_RELEASE, 0);

		// Then send a number of Down Arrows equal to its index
		if(bAutoAnalysisType==FREQ_DATA)
		{
			for(i=0; i<nAutoFreqDriftType; i++)
			{
				keybd_event(VK_DOWN, 0, VK_PRESS, 0);
				keybd_event(VK_DOWN, 0, VK_RELEASE, 0);
			}
		}
		else // Phase data
		{
			for(i=0; i<nAutoPhaseDriftType; i++)
			{
				keybd_event(VK_DOWN, 0, VK_PRESS, 0);
				keybd_event(VK_DOWN, 0, VK_RELEASE, 0);
			}
		}

		// Choose remove drift
		// Note:  The drift dialog always opens with drift removal unselected 
		keybd_event(VK_MENU, 0, VK_PRESS, 0);	
		keybd_event(VK_R, 0, VK_PRESS, 0);
		keybd_event(VK_R, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);

		// Preset the busy flag to insure wait loop takes effect
		bBusy=TRUE;

		// Press calc button
		keybd_event(VK_MENU, 0, VK_PRESS, 0);
		keybd_event(VK_A, 0, VK_PRESS, 0);
		keybd_event(VK_A, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);
		
		// Wait for process done
		while(bBusy)
		{
			Sleep(10);
		}

		// Press close button
		keybd_event(VK_MENU, 0, VK_PRESS, 0);
		keybd_event(VK_C, 0, VK_PRESS, 0);
		keybd_event(VK_C, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);

		// Wait to make sure message is seen
		Sleep(100);

		// Write message to show what's happening
		WriteMessage("Drift removed");
		
		// Add extra delay to show residual data in status bar
		if(bAutoAddDelay)
		{
			Sleep(nAutoDelay);
		}
	}
	
	// Interprocess delay
	Sleep(100);
	
	// Residual data plot
	if(bAutoDataPlot && bAutoPrintResidual)
	{
		// Open plot menu
		keybd_event(VK_MENU, 0, VK_PRESS, 0);	
		keybd_event(VK_P, 0, VK_PRESS, 0);
		keybd_event(VK_P, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);

		// Select data type
		if(bAutoAnalysisType==FREQ_DATA)
		{
			keybd_event(VK_F, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_RELEASE, 0);
		}
		else // Phase data
		{
			keybd_event(VK_P, 0, VK_PRESS, 0);
			keybd_event(VK_P, 0, VK_RELEASE, 0);
		}

		// Preset hPlot to null
		hPlot=0;

		// Draw plot
		keybd_event(VK_P, 0, VK_PRESS, 0);
		keybd_event(VK_P, 0, VK_RELEASE, 0);

		// Wait for GraphiC plot to launch
		// by checking if its menu handle is valid
		while((GetMenu(hPlot))==0)
		{
				// Check for "Must Normalize" error
				// Get handle of foreground window
				hForeground=GetForegroundWindow();

				// Get the caption of that window
				GetWindowText(hForeground, szBuffer, BUFFER_SIZE);

				// Compare it with the Stable32 "Must Normalize" dialog caption
				if((strcmp(szBuffer, "Stable32"))==0)
				{
					// Close "Must Normalize" box
					keybd_event(VK_RETURN, 0, VK_PRESS, 0);
					keybd_event(VK_RETURN, 0, VK_RELEASE, 0);

					// Open edit menu
					keybd_event(VK_MENU, 0, VK_PRESS, 0);	
					keybd_event(VK_E, 0, VK_PRESS, 0);
					keybd_event(VK_E, 0, VK_RELEASE, 0);
					keybd_event(VK_MENU, 0, VK_RELEASE, 0);

					// Select normalize function
					keybd_event(VK_N, 0, VK_PRESS, 0);
					keybd_event(VK_N, 0, VK_RELEASE, 0);

					// Normalize (OK)
					keybd_event(VK_MENU, 0, VK_PRESS, 0);	
					keybd_event(VK_O, 0, VK_PRESS, 0);
					keybd_event(VK_O, 0, VK_RELEASE, 0);
					keybd_event(VK_MENU, 0, VK_RELEASE, 0);

					// Interprocess delay
					Sleep(100);

					// Try again: open plot menu
					keybd_event(VK_MENU, 0, VK_PRESS, 0);	
					keybd_event(VK_P, 0, VK_PRESS, 0);
					keybd_event(VK_P, 0, VK_RELEASE, 0);
					keybd_event(VK_MENU, 0, VK_RELEASE, 0);

					// Select data type
					if(bAutoDataType==FREQ_DATA)
					{
						keybd_event(VK_F, 0, VK_PRESS, 0);
						keybd_event(VK_F, 0, VK_RELEASE, 0);
					}
					else // Phase data
					{
						keybd_event(VK_P, 0, VK_PRESS, 0);
						keybd_event(VK_P, 0, VK_RELEASE, 0);
					}

					// Try again to draw plot
					keybd_event(VK_P, 0, VK_PRESS, 0);
					keybd_event(VK_P, 0, VK_RELEASE, 0);
				}

				Sleep(10);
		}

		// Find out whether plot is finished drawing
		// by observing the state of the Print item in the File submenu
		// of the GraphiC menu -it is grayed during drawing
		// The handle of the GraphiC plot window is in the global hPlot
		// The GraphiC File menu is in position 0
		// The GraphiC Print item is in position 1
		// When uState=1=MF_GRAYED, the plot is still being drawn
		// When uState=0, the plot is done
		// Best approach is to mask off all except LSB and test it
		// This thread stays in wait loop until GraphiC plot is drawn
		hMenu=GetMenu(hPlot);
		hSubMenu=GetSubMenu(hMenu, 0);
		do 
		{
			Sleep(100);
			uState=GetMenuState(hSubMenu, 1, MF_BYPOSITION);
		}   while((uState&0x00000001)==TRUE);

		// At this point the data plot is drawn on screen
		// Do we want to print it?
		if(bAutoDataPrint)
		{
			// Print data plot
			keybd_event(VK_MENU, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_RELEASE, 0);
			keybd_event(VK_MENU, 0, VK_RELEASE, 0);
			keybd_event(VK_P, 0, VK_PRESS, 0);
			keybd_event(VK_P, 0, VK_RELEASE, 0);

			// Allow time for the print dialog to open
			while(1)
			{
				// Wait for the print page dialog box to open
				// Get the handle of the foreground window
				hPrint=GetForegroundWindow();

				// Get the caption of that window
				GetWindowText(hPrint, szBuffer, BUFFER_SIZE);

				// Compare it with the GraphiC print dialog caption
				if((strcmp(szBuffer, "GraphiC/Win Print Page"))==0)
				{
					break;
				}

				// Loop delay
				Sleep(10);
			}

			// Wait for the printing to take place
			while(1)
			{
				// Wait for the print page dialog box to close
				// Get the handle of the foreground window
				hPrint=GetForegroundWindow();

				// Get the caption of that window
				GetWindowText(hPrint, szBuffer, BUFFER_SIZE);

				// Compare it with the GraphiC print dialog caption
				if((strcmp(szBuffer, "GraphiC/Win Print Page"))!=0)
				{
					break;
				}

				// Loop delay
				Sleep(100);
			}

			// Now the plot has to redraw before it can be closed
			// Find out whether plot is finished drawing
			// by observing the state of the Print item in the File submenu
			// of the GraphiC menu -it is grayed during drawing
			// The handle of the GraphiC plot window is in the global hPlot
			// The GraphiC File menu is in position 0
			// The GraphiC Print item is in position 1
			// When uState=1=MF_GRAYED, the plot is still being drawn
			// When uState=0, the plot is done
			// Best approach is to mask off all except LSB and test it
			// This thread stays in wait loop until GraphiC plot is drawn
			hMenu=GetMenu(hPlot);
			hSubMenu=GetSubMenu(hMenu, 0);
			do 
			{
				Sleep(100);
				uState=GetMenuState(hSubMenu, 1, MF_BYPOSITION);
			}   while((uState&0x00000001)==TRUE);
		}

		// Wait to make sure message is seen
		Sleep(100);

		// Write message to show what's happening
		WriteMessage("Residual data plot");
		
		// Add extra delay to show residual data plot
		if(bAutoAddDelay)
		{
			Sleep(nAutoDelay);
		}

		// Close plot if there are more processes that follow
		// or if bAutoClose flag is set
		if( (nMaxProcess>PLOT_RESIDUAL) || bAutoClose)
		{
			keybd_event(VK_MENU, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_RELEASE, 0);
			keybd_event(VK_MENU, 0, VK_RELEASE, 0);
			keybd_event(VK_X, 0, VK_PRESS, 0);
			keybd_event(VK_X, 0, VK_RELEASE, 0);

			// Close plot dialog box
			keybd_event(VK_ESCAPE, 0, VK_PRESS, 0);
			keybd_event(VK_ESCAPE, 0, VK_RELEASE, 0);
		}
	}

	// Interprocess delay
	Sleep(100);
	
	// Stability analysis run
	if(bAutoRun)
	{
		// Go to analysis menu
		keybd_event(VK_MENU, 0, VK_PRESS, 0);	
		keybd_event(VK_A, 0, VK_PRESS, 0);
		keybd_event(VK_A, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);

		// Select run function
		keybd_event(VK_R, 0, VK_PRESS, 0);		
		keybd_event(VK_R, 0, VK_RELEASE, 0);

		// Go to variance list box
		keybd_event(VK_MENU, 0, VK_PRESS, 0);	
		keybd_event(VK_V, 0, VK_PRESS, 0);
		keybd_event(VK_V, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);

		// Select variance type
		// Note: Can't select item in list box by typing the name of the item
		// Selections are made as each letter is entered
		// on basis of initial letters
		// Initial letters are not necessarily unique
		// So we will use the numeric position of the item to select it

		// First move to top of list with Page Up key
		keybd_event(VK_PRIOR, 0, VK_PRESS, 0);
		keybd_event(VK_PRIOR, 0, VK_RELEASE, 0);

		// Then send a number of Down Arrows equal to its index
		if(bAutoAnalysisType==FREQ_DATA)
		{
			for(i=0; i<nAutoFreqVarianceType; i++)
			{
				keybd_event(VK_DOWN, 0, VK_PRESS, 0);
				keybd_event(VK_DOWN, 0, VK_RELEASE, 0);
			}
		}
		else // Phase data
		{
			for(i=0; i<nAutoPhaseVarianceType; i++)
			{
				keybd_event(VK_DOWN, 0, VK_PRESS, 0);
				keybd_event(VK_DOWN, 0, VK_RELEASE, 0);
			}
		}

		// Preset the busy flag to insure wait loop takes effect
		bBusy=TRUE;

		// Press calculate button
		keybd_event(VK_MENU, 0, VK_PRESS, 0);
		keybd_event(VK_A, 0, VK_PRESS, 0);
		keybd_event(VK_A, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);

		// Wait for process done
		while(bBusy)
		{
			Sleep(10);
		}

		// Wait to make sure message is seen
		Sleep(100);

		// Write message to show what's happening
		WriteMessage("Stability analysis");
		
		// Add extra delay to show stability analysis results
		if(bAutoAddDelay)
		{
			Sleep(nAutoDelay);
		}
	}

	// Interprocess delay
	Sleep(100);
	
	// Draw stability plot
	if(bAutoRunPlot && bAutoRun)
	{
		// Press plot button
		keybd_event(VK_MENU, 0, VK_PRESS, 0);
		keybd_event(VK_P, 0, VK_PRESS, 0);
		keybd_event(VK_P, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);

		// Wait for GraphiC plot to launch
		// by checking if its menu handle is valid
		while((GetMenu(hPlot))==0)
		{
			Sleep(10);
		}

		// Find out whether plot is finished drawing
		// by observing the state of the Print item in the File submenu
		// of the GraphiC menu -it is grayed during drawing
		// The handle of the GraphiC plot window is in the global hPlot
		// The GraphiC File menu is in position 0
		// The GraphiC Print item is in position 1
		// When uState=1=MF_GRAYED, the plot is still being drawn
		// When uState=0, the plot is done
		// Best approach is to mask off all except LSB and test it
		// This thread stays in wait loop until GraphiC plot is drawn
		hMenu=GetMenu(hPlot);
		hSubMenu=GetSubMenu(hMenu, 0);
		do 
		{
			Sleep(100);
			uState=GetMenuState(hSubMenu, 1, MF_BYPOSITION);
		}   while((uState&0x00000001)==TRUE);

		// Print stability plot
		if(bAutoStabPlot)
		{
			// Print stability plot
			keybd_event(VK_MENU, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_RELEASE, 0);
			keybd_event(VK_MENU, 0, VK_RELEASE, 0);
			keybd_event(VK_P, 0, VK_PRESS, 0);
			keybd_event(VK_P, 0, VK_RELEASE, 0);

			// Allow time for the print dialog to open
			while(1)
			{
				// Wait for the print page dialog box to open
				// Get the handle of the foreground window
				hPrint=GetForegroundWindow();

				// Get the caption of that window
				GetWindowText(hPrint, szBuffer, BUFFER_SIZE);

				// Compare it with the GraphiC print dialog caption
				if((strcmp(szBuffer, "GraphiC/Win Print Page"))==0)
				{
					break;
				}

				// Loop delay
				Sleep(10);
			}

			// Wait for the printing to take place
			while(1)
			{
				// Wait for the print page dialog box to close
				// Get the handle of the foreground window
				hPrint=GetForegroundWindow();

				// Get the caption of that window
				GetWindowText(hPrint, szBuffer, BUFFER_SIZE);

				// Compare it with the GraphiC print dialog caption
				if((strcmp(szBuffer, "GraphiC/Win Print Page"))!=0)
				{
					break;
				}

				// Loop delay
				Sleep(100);
			}

			// Now the plot has to redraw before it can be closed
			// Find out whether plot is finished drawing
			// by observing the state of the Print item in the File submenu
			// of the GraphiC menu -it is grayed during drawing
			// The handle of the GraphiC plot window is in the global hPlot
			// The GraphiC File menu is in position 0
			// The GraphiC Print item is in position 1
			// When uState=1=MF_GRAYED, the plot is still being drawn
			// When uState=0, the plot is done
			// Best approach is to mask off all except LSB and test it
			// This thread stays in wait loop until GraphiC plot is drawn
			hMenu=GetMenu(hPlot);
			hSubMenu=GetSubMenu(hMenu, 0);
			do 
			{
				Sleep(100);
				uState=GetMenuState(hSubMenu, 1, MF_BYPOSITION);
			}   while((uState&0x00000001)==TRUE);
		}

		// Wait to make sure message is seen
		Sleep(100);

		// Write message to show what's happening
		WriteMessage("Stability plot");
		
		// Add extra delay to show stability plot
		if(bAutoAddDelay)
		{
			Sleep(nAutoDelay);
		}

		// Close plot if there are more processes that follow
		// or if bAutoClose flag is set
		if( (nMaxProcess>TABULATE_RUN) || bAutoClose)
		{
			keybd_event(VK_MENU, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_PRESS, 0);
			keybd_event(VK_F, 0, VK_RELEASE, 0);
			keybd_event(VK_MENU, 0, VK_RELEASE, 0);
			keybd_event(VK_X, 0, VK_PRESS, 0);
			keybd_event(VK_X, 0, VK_RELEASE, 0);

			// Allow time for the plot to close
			Sleep(100);
		}
	
		// Print stability table
		if(bAutoStabTable)
		{
			// Press plot button
			keybd_event(VK_MENU, 0, VK_PRESS, 0);
			keybd_event(VK_R, 0, VK_PRESS, 0);
			keybd_event(VK_R, 0, VK_RELEASE, 0);
			keybd_event(VK_MENU, 0, VK_RELEASE, 0);
			keybd_event(VK_RETURN, 0, VK_PRESS, 0);
			keybd_event(VK_RETURN, 0, VK_RELEASE, 0);
		}
	}

	// Interprocess delay
	Sleep(100);
	
	// Close run dialog box
	if(bAutoClose)
	{
		// Close run box
		keybd_event(VK_MENU, 0, VK_PRESS, 0);
		keybd_event(VK_C, 0, VK_PRESS, 0);
		keybd_event(VK_C, 0, VK_RELEASE, 0);
		keybd_event(VK_MENU, 0, VK_RELEASE, 0);
	}

	// Clear bAuto flag
	bAuto=FALSE;

	// Wait to make sure message is seen
	Sleep(100);

	// Write message to show what's happening
	// sprintf(szBuffer, "Script done - Last process ID=%d", nMaxProcess);
	WriteMessage("Script done");
	WriteMessage(szBuffer);
		
	// Restore original skip flag state
	bSkip=bAutoSkipSave;

	// Restore original autocalc state
	bAutoCalc=bAutoCalcSave;

	// Restore original autoplot state
	bAutoPlot=bAutoPlotSave;

	// Restore original zero frequency warning state
	bWarnZeroFreq=bWarnZeroFreqSave;

	// Done
	return 0;
}

/*****************************************************************************/
/*                                                                           */
/*                        Auto Dialog Procedure                              */
/*                                                                           */
/*  Revision record:                                                         */
/*      04/22/01    Created                                                  */
/*		04/28/01	Pretty much working                                      */
/*		05/03/01	Done                                                     */
/*		05/04/01	Improved cmd line usage                                  */
/*		08/28/02	Added regularize function                                */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK AutoDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local macros
	#define NUM_PRINT_SELS	5				// # options to print
	#define SIZE_PRINT_SELS 10				// Size of max option text +1

	// Local variables
	// Handles
	HICON hAutoIcon;						// Dialog icon
	// Chars
	static char szBuffer[BUFFER_SIZE+1];	// General text buffer
	static char szSection[BUFFER_SIZE+1];	// Ini file section name
	static char szSel[NUM_PRINT_SELS][SIZE_PRINT_SELS];
											// Array of selection text
	// Ints
	int i;									// General index
	static int nPrev;					    // Previous value of int entry
	static int nEntry;					    // New value of int entry
	static int nSel[NUM_PRINT_SELS];		// Array of selection flags
	// F_TYPES
	static F_TYPE fPrev;					// Previous value of F_TYPE entry
	static F_TYPE fEntry;					// New value of F_TYPE entry
	// BOOLs	
	static BOOL bErrorTrap=FALSE;			// Flag for entry error

	// Start of code
	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Write prompt message
			WritePromptMessage(TB_AUTO1+nAuto-1);

			// Get handle to application icon
			sprintf(szBuffer, "FlatAuto%dIcon", nAuto);
			hAutoIcon=LoadIcon(hInst, szBuffer);

			// Load icon
			Static_SetIcon(GETHCTL(IDC_AUTO_ICON), hAutoIcon);
			
			// Initializations
			// Set script # displays
			sprintf(szBuffer, "Auto %d", nAuto);
			SetWindowText(hDlg, szBuffer);
			sprintf(szBuffer, "Script #%d Name", nAuto);
			SetWindowText(GETHCTL(IDC_AUTO_SCRIPTNUM), szBuffer);

			// Read ini file
			// Note: No need to save initial state because it is in ini file
			// To cancel, simply don't write changes
			SendMessage(hDlg, WM_COMMAND,
				GET_WM_COMMAND_MPS(IDC_AUTO_READINI, NULL, 0));

			// Set controls
			SendMessage(hDlg, WM_COMMAND,
				GET_WM_COMMAND_MPS(IDC_AUTO_SETCONTROLS, NULL, 0));

			// Do we want to skip the auto dialog box?
			if(bAutoCmd)
			{
				// Go when dialog box opens
				PostMessage(hDlg, WM_COMMAND,
				GET_WM_COMMAND_MPS(IDC_AUTO_GO, NULL, 0));

				// Reset flag
				bAutoCmd=FALSE;
			}
		}
		return TRUE;

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				// Respond to help button message
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::AUTO_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::AUTO_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "AUTO_FUNCTION");
					#endif
				}
				break;

				// Respond to checkboxes
				case IDC_AUTO_FILEOPEN:
				{
					// Get file open flag
					bAutoFileOpen=Button_GetCheck(GETHCTL(IDC_AUTO_FILEOPEN));

					// Reset controls
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_AUTO_SETCONTROLS, NULL, 0));
				}
				break;

				case IDC_AUTO_CONVERT:
				{
					// Get convert flag
					bAutoConvert=Button_GetCheck(GETHCTL(IDC_AUTO_CONVERT));

					// Reset controls
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_AUTO_SETCONTROLS, NULL, 0));
				}
				break;

				case IDC_AUTO_REG:
				{
					// Get regularize flag
					bAutoRegularize=Button_GetCheck(GETHCTL(IDC_AUTO_REG));

					// Reset controls
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_AUTO_SETCONTROLS, NULL, 0));
				}
				break;

				case IDC_AUTO_PART:
				{
					// Get part flag
					bAutoPart=Button_GetCheck(GETHCTL(IDC_AUTO_PART));

					// Reset controls
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_AUTO_SETCONTROLS, NULL, 0));
				}
				break;

				case IDC_AUTO_AVERAGE:
				{
					// Get average flag
					bAutoAverage=Button_GetCheck(GETHCTL(IDC_AUTO_AVERAGE));

					// Reset controls
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_AUTO_SETCONTROLS, NULL, 0));
				}
				break;

				case IDC_AUTO_NORM:
				{
					// Get normalize flag
					bAutoNormalize=Button_GetCheck(GETHCTL(IDC_AUTO_NORM));

					// Reset controls
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_AUTO_SETCONTROLS, NULL, 0));
				}
				break;

				case IDC_AUTO_OUTLIERS:
				{
					// Get outlier flag
					bAutoOutliers=Button_GetCheck(GETHCTL(IDC_AUTO_OUTLIERS));

					// Reset controls
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_AUTO_SETCONTROLS, NULL, 0));
				}
				break;

				case IDC_AUTO_DRIFT:
				{
					// Get drift flag
					bAutoDrift=Button_GetCheck(GETHCTL(IDC_AUTO_DRIFT));

					// Reset controls
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_AUTO_SETCONTROLS, NULL, 0));
				}
				break;

				case IDC_AUTO_DATAPLOT:
				{
					// Get data plot flag
					bAutoDataPlot=
						Button_GetCheck(GETHCTL(IDC_AUTO_DATAPLOT));
						
					// Reset controls
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_AUTO_SETCONTROLS, NULL, 0));
				}
				break;

				case IDC_AUTO_RUN:
				{
					// Get run flag
					bAutoRun=Button_GetCheck(GETHCTL(IDC_AUTO_RUN));

					// Reset controls
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_AUTO_SETCONTROLS, NULL, 0));
				}
				break;

				case IDC_AUTO_RUNPLOT:
				{
					// Get run plot flag
					bAutoRunPlot=Button_GetCheck(GETHCTL(IDC_AUTO_RUNPLOT));

					// Reset controls
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_AUTO_SETCONTROLS, NULL, 0));
				}
				break;

				case IDC_AUTO_STABPLOT:
				{
					// Get stability plot flag
					bAutoStabPlot=Button_GetCheck(GETHCTL(IDC_AUTO_STABPLOT));

					// Reset controls
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_AUTO_SETCONTROLS, NULL, 0));
				}
				break;

				case IDC_AUTO_STABTABLE:
				{
					// Get stability table flag
					bAutoStabTable=
						Button_GetCheck(GETHCTL(IDC_AUTO_STABTABLE));

					// Reset controls
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_AUTO_SETCONTROLS, NULL, 0));
				}
				break;

				case IDC_AUTO_CLOSE:
				{
					// Get close flag
					bAutoClose=Button_GetCheck(GETHCTL(IDC_AUTO_CLOSE));

					// Reset controls
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_AUTO_SETCONTROLS, NULL, 0));
				}
				break;

				case IDC_AUTO_ADDDELAY:
				{
					// Get add delay flag
					bAutoAddDelay=Button_GetCheck(GETHCTL(IDC_AUTO_ADDDELAY));

					// Reset controls
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_AUTO_SETCONTROLS, NULL, 0));
				}
				break;

				case IDC_AUTO_DATAPRINT:
				{
					// Get data print flag
					bAutoDataPrint=
						Button_GetCheck(GETHCTL(IDC_AUTO_DATAPRINT));

					// Reset controls
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_AUTO_SETCONTROLS, NULL, 0));
				}
				break;

				// Respond to radio buttons
				case IDC_AUTO_PHASEDATA:
				case IDC_AUTO_FREQDATA:
				{
					// Get freq data state
					bAutoDataType=Button_GetCheck(GETHCTL(IDC_AUTO_FREQDATA));

					// Reset controls
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_AUTO_SETCONTROLS, NULL, 0));
				}
				
				// Respond to list boxes
				case IDC_AUTO_DATAPLOTTYPE:
				{
					// This multiple-selection listbox can have from 1 to
					// NUM_PLOTTYPES items depending on what processing options
					// are chosen
					// The job here is to set flags corresponding to the state
					// of those 5 items
					// First we'll poll the list box 5 times asking whether
					// there is a selected item at each (0 based) index
					// A selected item returns 1 (unselected=0, error=-1)
					for(i=0; i<NUM_PLOTTYPES; i++)
					{
						nSel[i]=ListBox_GetSel(GETHCTL(IDC_AUTO_DATAPLOTTYPE),
							i);
					}

					// Now we'll read the text of the selected items
					for(i=0; i<NUM_PLOTTYPES; i++)
					{
						if(nSel[i]==1)
						{
							nDummy=
								ListBox_GetText(GETHCTL(IDC_AUTO_DATAPLOTTYPE),
								i, szSel[i]);
						}
						else // Empty text
						{
							strlcpy(szSel[i], "", sizeof(szSel[i]));
						}
					}

					// Initialize all the NUM_PLOTTYPES flags to FALSE
					bAutoPrintOriginal=FALSE;
					bAutoPrintConverted=FALSE;
					bAutoPrintCorrected=FALSE;
					bAutoPrintSelected=FALSE;
					bAutoPrintAveraged=FALSE;
					bAutoPrintNormalized=FALSE;
					bAutoPrintResidual=FALSE;

					// Finally we'll set our flags according to the selections
					for(i=0; i<NUM_PLOTTYPES; i++)
					{
						if(strcmp(szSel[i], "Original")==0)
						{
							bAutoPrintOriginal=TRUE;
						}
						if(strcmp(szSel[i], "Converted")==0)
						{
							bAutoPrintConverted=TRUE;
						}
						if(strcmp(szSel[i], "Corrected")==0)
						{
							bAutoPrintCorrected=TRUE;
						}
						if(strcmp(szSel[i], "Selected")==0)
						{
							bAutoPrintSelected=TRUE;
						}
						if(strcmp(szSel[i], "Averaged")==0)
						{
							bAutoPrintAveraged=TRUE;
						}
						if(strcmp(szSel[i], "Normalized")==0)
						{
							bAutoPrintNormalized=TRUE;
						}
						if(strcmp(szSel[i], "Residual")==0)
						{
							bAutoPrintResidual=TRUE;
						}
					}
				}
				break;
				
				// Respond to edit control messages
				case IDC_AUTO_SIGMAFACTOR:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) && (GetFocus()!=GETHCTL(IDC_AVG_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Save previous value
						fPrev=fAutoSigmaFactor;

                        // Get sigma factor
						GetWindowText(GETHCTL(IDC_AUTO_SIGMAFACTOR), szBuffer,
							BUFFER_SIZE-1);
                        fEntry=fabs(atof(szBuffer)); // must be +

						// Use new value w/o validation
						fAutoSigmaFactor=fEntry;
                        sprintf(szAutoSigmaFactor, "%5.3f", fAutoSigmaFactor);
						SetWindowText(GETHCTL(IDC_AUTO_SIGMAFACTOR),
							szAutoSigmaFactor);
                    }
                    else
                    {
                        // Reset error flag
                        bErrorTrap=FALSE;
                    }
                }
                break;

				case IDC_AUTO_AVGFACTOR:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) && (GetFocus()!=GETHCTL(IDC_AVG_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Save previous value
						nPrev=nAutoAvgFactor;

                        // Get averaging factor
						GetWindowText(GETHCTL(IDC_AUTO_AVGFACTOR), szBuffer,
							BUFFER_SIZE-1);
                        nEntry=abs(atoi(szBuffer)); // must be +

						// Use new value w/o validation
						nAutoAvgFactor=nEntry;
                        sprintf(szAutoAvgFactor, "%d", nAutoAvgFactor);
						SetWindowText(GETHCTL(IDC_AUTO_AVGFACTOR),
							szAutoAvgFactor);
                    }
                    else
                    {
                        // Reset error flag
                        bErrorTrap=FALSE;
                    }
                }
                break;

				case IDC_AUTO_START:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) && (GetFocus()!=GETHCTL(IDC_AVG_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Save previous value
						nPrev=nAutoStart;

                        // Get start point
						GetWindowText(GETHCTL(IDC_AUTO_START), szBuffer,
							BUFFER_SIZE-1);
                        nEntry=abs(atoi(szBuffer)); // must be +

						// Use new value w/o validation
						nAutoStart=nEntry;
                        sprintf(szAutoStart, "%d", nAutoStart);
						SetWindowText(GETHCTL(IDC_AUTO_START), szAutoStart);
                    }
                    else
                    {
                        // Reset error flag
                        bErrorTrap=FALSE;
                    }
                }
                break;

				case IDC_AUTO_END:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) && (GetFocus()!=GETHCTL(IDC_AVG_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Save previous value
						nPrev=nAutoEnd;

                        // Get end point
						GetWindowText(GETHCTL(IDC_AUTO_END), szBuffer,
							BUFFER_SIZE-1);
                        nEntry=abs(atoi(szBuffer)); // must be +

						// Use new value w/o validation
						nAutoEnd=nEntry;
                        sprintf(szAutoEnd, "%d", nAutoEnd);
						SetWindowText(GETHCTL(IDC_AUTO_END), szAutoEnd);
                   }
                    else
                    {
                        // Reset error flag
                        bErrorTrap=FALSE;
                    }
                }
                break;

				case IDC_AUTO_DELAYTIME:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) && (GetFocus()!=GETHCTL(IDC_AVG_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Save previous value
						nPrev=nAutoDelay;

                        // Get delay time
						GetWindowText(GETHCTL(IDC_AUTO_DELAYTIME), szBuffer,
							BUFFER_SIZE-1);
                        nEntry=abs(atoi(szBuffer)); // must be +

						// Use new value w/o validation
						nAutoDelay=nEntry;
                        sprintf(szAutoDelayTime, "%d", nAutoDelay);
						SetWindowText(GETHCTL(IDC_AUTO_DELAYTIME),
							szAutoDelayTime);
                    }
                    else
                    {
                        // Reset error flag
                        bErrorTrap=FALSE;
                    }
				}
                break;

				case IDC_AUTO_SCRIPTNAME:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) && (GetFocus()!=GETHCTL(IDC_AVG_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get script name
						GetWindowText(GETHCTL(IDC_AUTO_SCRIPTNAME),
							szScriptname,
							BUFFER_SIZE);

						// Redisplay the script name (to give user feedback)
						SetWindowText(GETHCTL(IDC_AUTO_SCRIPTNAME),
							szScriptname);
					}
                    else
                    {
                        // Reset error flag
                        bErrorTrap=FALSE;
                    }
                }
                break;

				case IDC_AUTO_FILENAME:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) && (GetFocus()!=GETHCTL(IDC_AVG_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get filename
						GetWindowText(GETHCTL(IDC_AUTO_FILENAME),
							szAutoFilename,	FILE_NAME_SIZE);

						// Redisplay the filename (to give user feedback)
						SetWindowText(GETHCTL(IDC_AUTO_FILENAME),
							szAutoFilename);
					}
                    else
                    {
                        // Reset error flag
                        bErrorTrap=FALSE;
                    }
                }
                break;

				// Respond to combo box messages
				case IDC_AUTO_VARIANCE:
				{
					// Get variance type as a string and numeric value
					if(bAutoAnalysisType==FREQ_DATA)
					{
						GetWindowText(GETHCTL(IDC_AUTO_VARIANCE),
							szAutoFreqVariance,	BUFFER_SIZE);
						nAutoFreqVarianceType=
							ComboBox_GetCurSel(GETHCTL(IDC_AUTO_VARIANCE));
					}
					else // Phase data
					{
						GetWindowText(GETHCTL(IDC_AUTO_VARIANCE),
							szAutoPhaseVariance, BUFFER_SIZE);
						nAutoPhaseVarianceType=
							ComboBox_GetCurSel(GETHCTL(IDC_AUTO_VARIANCE));
					}
				}
				break;

				case IDC_AUTO_DRIFTTYPE:
				{
					// Get drift type as a string and numeric value
					if(bAutoAnalysisType==FREQ_DATA)
					{
						GetWindowText(GETHCTL(IDC_AUTO_DRIFTTYPE),
							szAutoFreqDriftType, BUFFER_SIZE);
						nAutoFreqDriftType=
							ComboBox_GetCurSel(GETHCTL(IDC_AUTO_DRIFTTYPE));
					}
					else // Phase data
					{
						GetWindowText(GETHCTL(IDC_AUTO_DRIFTTYPE),
							szAutoPhaseDriftType, BUFFER_SIZE);
						nAutoPhaseDriftType=
							ComboBox_GetCurSel(GETHCTL(IDC_AUTO_DRIFTTYPE));
					}
				}
				break;

                // Internal Subroutines
				// Set all dialog box controls
				case IDC_AUTO_SETCONTROLS:
				{
					// Show the script name
					SetWindowText(GETHCTL(IDC_AUTO_SCRIPTNAME), szScriptname);

					// Show the filenamename
					SetWindowText(GETHCTL(IDC_AUTO_FILENAME), szAutoFilename);

					// Show the start point #
					SetWindowText(GETHCTL(IDC_AUTO_START), szAutoStart);

					// Show the end point #
					SetWindowText(GETHCTL(IDC_AUTO_END), szAutoEnd);

					// Show the averaging factor
					SetWindowText(GETHCTL(IDC_AUTO_AVGFACTOR),
						szAutoAvgFactor);

					// Show the sigma factor
					SetWindowText(GETHCTL(IDC_AUTO_SIGMAFACTOR),
						szAutoSigmaFactor);

					// Show the delay time
					SetWindowText(GETHCTL(IDC_AUTO_DELAYTIME),
						szAutoDelayTime);

                    // Get numeric delay time
                    nAutoDelay=abs(atoi(szAutoDelayTime)); // must be +

					// Set the numeric part start and end points
					nAutoStart=atoi(szAutoStart);
					nAutoEnd=atoi(szAutoEnd);

					// Set checkbox states
					Button_SetCheck(GETHCTL(IDC_AUTO_FILEOPEN), bAutoFileOpen);
					Button_SetCheck(GETHCTL(IDC_AUTO_CONVERT), bAutoConvert);
					Button_SetCheck(GETHCTL(IDC_AUTO_REG), bAutoRegularize);
					Button_SetCheck(GETHCTL(IDC_AUTO_OUTLIERS), bAutoOutliers);
					Button_SetCheck(GETHCTL(IDC_AUTO_DRIFT), bAutoDrift);
					Button_SetCheck(GETHCTL(IDC_AUTO_RUN), bAutoRun);
					Button_SetCheck(GETHCTL(IDC_AUTO_RUNPLOT), bAutoRunPlot);
					Button_SetCheck(GETHCTL(IDC_AUTO_STABPLOT), bAutoStabPlot);
					Button_SetCheck(GETHCTL(IDC_AUTO_STABTABLE),
						bAutoStabTable);
					Button_SetCheck(GETHCTL(IDC_AUTO_CLOSE), bAutoClose);
					Button_SetCheck(GETHCTL(IDC_AUTO_PART), bAutoPart);
					Button_SetCheck(GETHCTL(IDC_AUTO_AVERAGE), bAutoAverage);
					Button_SetCheck(GETHCTL(IDC_AUTO_DATAPLOT),	bAutoDataPlot);
					Button_SetCheck(GETHCTL(IDC_AUTO_ADDDELAY),	bAutoAddDelay);
					Button_SetCheck(GETHCTL(IDC_AUTO_DATAPRINT),
						bAutoDataPrint);
					Button_SetCheck(GETHCTL(IDC_AUTO_NORM), bAutoNormalize);

					// Set data file radio button states
					Button_SetCheck(GETHCTL(IDC_AUTO_PHASEDATA),
						!bAutoDataType);
					Button_SetCheck(GETHCTL(IDC_AUTO_FREQDATA), bAutoDataType);
 					
					// Set edit box activations
					EnableWindow(GETHCTL(IDC_AUTO_FILENAME), bAutoFileOpen);
					EnableWindow(GETHCTL(IDC_AUTO_AVGFACTOR), bAutoAverage);
					EnableWindow(GETHCTL(IDC_AUTO_DELAYTIME), bAutoAddDelay);
					EnableWindow(GETHCTL(IDC_AUTO_START), bAutoPart);
					EnableWindow(GETHCTL(IDC_AUTO_END), bAutoPart);

					// Set combo box activations
					EnableWindow(GETHCTL(IDC_AUTO_DRIFTTYPE), bAutoDrift);
					EnableWindow(GETHCTL(IDC_AUTO_VARIANCE), bAutoRun);

					// Set list box activations
					EnableWindow(GETHCTL(IDC_AUTO_DATAPLOTTYPE),
						bAutoDataPlot);
					
					// Set checkbox activations
					EnableWindow(GETHCTL(IDC_AUTO_STABPLOT), bAutoRunPlot);
					EnableWindow(GETHCTL(IDC_AUTO_STABTABLE), bAutoRunPlot);
					EnableWindow(GETHCTL(IDC_AUTO_DATAPRINT), bAutoDataPlot);
					EnableWindow(GETHCTL(IDC_AUTO_RUNPLOT), bAutoRun);
					EnableWindow(GETHCTL(IDC_AUTO_STABPLOT),
						bAutoRun && bAutoRunPlot);
					EnableWindow(GETHCTL(IDC_AUTO_STABTABLE), 
						bAutoRun && bAutoRunPlot);

					// Set pushbutton activations
					EnableWindow(GETHCTL(IDC_AUTO_BROWSE), bAutoFileOpen);

					// Fill up the drift type list box
					nDummy=ComboBox_ResetContent(GETHCTL(IDC_AUTO_DRIFTTYPE));

					if( (bAutoDataType && !bAutoConvert) ||
						(!bAutoDataType && bAutoConvert) )
					{
						// Set analysis type
						bAutoAnalysisType=FREQ_DATA;

						// Show analysis data type
						SetWindowText(GETHCTL(IDC_AUTO_DATATYPE), 
							"(Analysis of Freq Data)");

						// Load drift types
						for(i=0; i<4; i++)
						{
							LoadString(hInst, IDS_FDRIFT_TYPE_0+i, szBuffer,
								BUFFER_SIZE);
							nDummy=
								ComboBox_InsertString(
								GETHCTL(IDC_AUTO_DRIFTTYPE), i,	szBuffer);
						}
					}
					else
					{
						// Set data type
						bAutoAnalysisType=PHASE_DATA;

						// Show analysis data type
						SetWindowText(GETHCTL(IDC_AUTO_DATATYPE), 
							"(Analysis of Phase Data)");

						// Load drift types
						for(i=0; i<6; i++)
						{
							LoadString(hInst, IDS_PDRIFT_TYPE_0+i, szBuffer,
								BUFFER_SIZE);
							nDummy=
								ComboBox_InsertString(
								GETHCTL(IDC_AUTO_DRIFTTYPE), i,	szBuffer);
						}
					}

					// Select the current drift type
					if(bAutoAnalysisType==FREQ_DATA)
					{
						ComboBox_SelectString(GETHCTL(IDC_AUTO_DRIFTTYPE), 0,
							szAutoFreqDriftType);
					}
					else // Phase data
					{
						ComboBox_SelectString(GETHCTL(IDC_AUTO_DRIFTTYPE), 0,
							szAutoPhaseDriftType);
					}

					// Find numeric drift type
					if(bAutoAnalysisType==FREQ_DATA)
					{
						nAutoFreqDriftType=
							ComboBox_GetCurSel(GETHCTL(IDC_AUTO_DRIFTTYPE));
					}
					else // Phase data
					{
						nAutoPhaseDriftType=
							ComboBox_GetCurSel(GETHCTL(IDC_AUTO_DRIFTTYPE));
					}

					// Set the outliers check box enable state
					EnableWindow(GETHCTL(IDC_AUTO_OUTLIERS),
						bAutoAnalysisType);

					// Set the sigma factor edit box enable state
					EnableWindow(GETHCTL(IDC_AUTO_SIGMAFACTOR),
						(bAutoOutliers && bAutoAnalysisType));

					// Fill up the sigma type list box
					nDummy=ComboBox_ResetContent(GETHCTL(IDC_AUTO_VARIANCE));

					// Note: The index is equal to the macro value
					// TIE rms and MTIE apply to phase data only
					for(i=0; i<NUM_RUN_TYPES-2*bAutoAnalysisType; i++)
					{
						LoadString(hInst, IDS_RUN_TYPE_0+i, szBuffer,
							BUFFER_SIZE);
						nDummy=
							ComboBox_InsertString(GETHCTL(IDC_AUTO_VARIANCE),
							i, szBuffer);
					}
					
					// Select the current sigma type
					if(bAutoAnalysisType==FREQ_DATA)
					{
						ComboBox_SelectString(GETHCTL(IDC_AUTO_VARIANCE), 0,
							szAutoFreqVariance);
					}
					else // Phase data
					{
						ComboBox_SelectString(GETHCTL(IDC_AUTO_VARIANCE), 0,
							szAutoPhaseVariance);
					}

					// Find numeric variance type
					if(bAutoAnalysisType==FREQ_DATA)
					{
						nAutoFreqVarianceType=
							ComboBox_GetCurSel(GETHCTL(IDC_AUTO_VARIANCE));
					}
					else // Phase data
					{
						nAutoPhaseVarianceType=
							ComboBox_GetCurSel(GETHCTL(IDC_AUTO_VARIANCE));
					}

					// Fill up the data plot type list box
					nDummy=
						ListBox_ResetContent(GETHCTL(IDC_AUTO_DATAPLOTTYPE));
					nDummy=ListBox_InsertString(GETHCTL(IDC_AUTO_DATAPLOTTYPE), -1,
						"Original");
					if(bAutoConvert)
					{
						nDummy=	ListBox_InsertString(
							GETHCTL(IDC_AUTO_DATAPLOTTYPE), -1,	"Converted");
					}
					if(bAutoOutliers && bAutoAnalysisType==FREQ_DATA)
					{
						nDummy=ListBox_InsertString(
							GETHCTL(IDC_AUTO_DATAPLOTTYPE),	-1,	"Corrected");
					}
					if(bAutoPart)
					{
						nDummy=ListBox_InsertString(
							GETHCTL(IDC_AUTO_DATAPLOTTYPE), -1,	"Selected");
					}
					if(bAutoAverage)
					{
						nDummy=ListBox_InsertString(
							GETHCTL(IDC_AUTO_DATAPLOTTYPE), -1,	"Averaged");
					}
					if(bAutoNormalize)
					{
						nDummy=ListBox_InsertString(
							GETHCTL(IDC_AUTO_DATAPLOTTYPE),	-1,	"Normalized");
					}
					if(bAutoDrift)
					{
						nDummy=ListBox_InsertString(
							GETHCTL(IDC_AUTO_DATAPLOTTYPE),	-1, "Residual");
					}

					// Make data plot list box selections
					if(bAutoPrintOriginal)
					{
						// The index of "Original" is always 0
						// and it is always present
						nDummy=ListBox_SetSel(GETHCTL(IDC_AUTO_DATAPLOTTYPE),
							TRUE, 0);
					}
					if(bAutoPrintConverted)
					{
						// The index of "Converted" (if present) is always 1
						nDummy=ListBox_SetSel(GETHCTL(IDC_AUTO_DATAPLOTTYPE),
							TRUE, 1);
					}
					if(bAutoPrintCorrected)
					{
						// The index of "Corrected" (if present) is 1 or 2
						// depending on whether "Converted is present
						nDummy=ListBox_SetSel(GETHCTL(IDC_AUTO_DATAPLOTTYPE),
							TRUE, 1+bAutoConvert);
					}
					if(bAutoPart && bAutoPrintSelected)
					{
						// The index of "Selected" (if present) is 1, 2 or 3
						// depending on whether "Converted" and/or "Corrected"
						// are present
						nDummy=ListBox_SetSel(GETHCTL(IDC_AUTO_DATAPLOTTYPE),
							TRUE, 1+bAutoConvert+bAutoOutliers);
					}
					if(bAutoAverage && bAutoPrintAveraged)
					{
						// The index of "Averaged" (if present) is 1, 2, 3 or 4
						// depending on whether "Converted" and/or "Corrected"
						// and/or "Selected" are present
						nDummy=ListBox_SetSel(GETHCTL(IDC_AUTO_DATAPLOTTYPE),
							TRUE, 1+bAutoConvert+bAutoOutliers+bAutoPart);
					}
					if(bAutoNormalize && bAutoPrintNormalized)
					{
						// The index of "Normalized" (if present) is
						// 1, 2, 3, 4 or 5
						// depending on whether "Converted" and/or "Corrected"
						// and/or "Selected" and/or "Averaged" are present
						nDummy=ListBox_SetSel(GETHCTL(IDC_AUTO_DATAPLOTTYPE),
							TRUE, 1+bAutoConvert+bAutoOutliers+bAutoPart+
							bAutoAverage);
					}
					if(bAutoDrift && bAutoPrintResidual)
					{
						// Etc
						nDummy=ListBox_SetSel(GETHCTL(IDC_AUTO_DATAPLOTTYPE),
							TRUE, 1+bAutoConvert+bAutoOutliers+bAutoPart+
							bAutoAverage+bAutoNormalize);
					}

					// Set up process flags to control closing of windows
					bProcess[PLOT_ORIGINAL]=
						bAutoDataPlot && bAutoPrintOriginal;
					bProcess[PLOT_CONVERTED]=
						bAutoDataPlot && bAutoPrintConverted;
					bProcess[PLOT_CORRECTED]=
						bAutoDataPlot && bAutoPrintCorrected;
					bProcess[PLOT_SELECTED]=
						bAutoDataPlot && bAutoPrintSelected;
					bProcess[PLOT_AVERAGED]=
						bAutoDataPlot && bAutoPrintAveraged;
					bProcess[PLOT_NORMALIZED]=
						bAutoDataPlot && bAutoPrintNormalized;
					bProcess[PLOT_RESIDUAL]=
						bAutoDataPlot && bAutoPrintResidual;
					bProcess[PLOT_RUN]=bAutoRun && bAutoRunPlot;
					bProcess[TABULATE_RUN]=bAutoRun;
				}
				break;

				// Read configuration file
				case IDC_AUTO_READINI:
				{
					// Setup section name
					sprintf(szSection, "Auto%d", nAuto);

					// Strings
					sprintf(szBuffer, "Script_%d", nAuto);
					GetPrivateProfileString(szSection, "Script", szBuffer,
						szScriptname, BUFFER_SIZE, szIniFile);
					GetPrivateProfileString(szSection, "PhaseVariance",
						"Normal", szAutoPhaseVariance, BUFFER_SIZE,
						szIniFile);
					GetPrivateProfileString(szSection, "FreqVariance",
						"Normal", szAutoFreqVariance, BUFFER_SIZE, szIniFile);
					GetPrivateProfileString(szSection, "Filename", "",
						szAutoFilename,	FILE_NAME_SIZE, szIniFile);
					GetPrivateProfileString(szSection, "PhaseDriftType",
						"Quadratic", szAutoPhaseDriftType, BUFFER_SIZE,
						szIniFile);
					GetPrivateProfileString(szSection, "FreqDriftType",
						"Linear", szAutoFreqDriftType, BUFFER_SIZE, szIniFile);
					GetPrivateProfileString(szSection, "AvgFactor", "1",
						szAutoAvgFactor, BUFFER_SIZE, szIniFile);
					GetPrivateProfileString(szSection, "SigmaFactor", "5.000",
						szAutoSigmaFactor, BUFFER_SIZE, szIniFile);
					GetPrivateProfileString(szSection, "DelayTime", "0",
						szAutoDelayTime, BUFFER_SIZE, szIniFile);
					GetPrivateProfileString(szSection, "Start", "1",
						szAutoStart, BUFFER_SIZE, szIniFile);
					GetPrivateProfileString(szSection, "End", "0",
						szAutoEnd, BUFFER_SIZE, szIniFile);

					// BOOLS
					bAutoDataType=GetPrivateProfileInt(szSection, "DataType",
						0, szIniFile);
					bAutoAnalysisType=GetPrivateProfileInt(szSection,
						"AnalysisType",	0, szIniFile);
					bAutoFileOpen=GetPrivateProfileInt(szSection, "FileOpen",
						0, szIniFile);
					bAutoConvert=GetPrivateProfileInt(szSection, "Convert",
						0, szIniFile);
					bAutoRegularize=GetPrivateProfileInt(szSection,
						"Regularize", 0, szIniFile);
					bAutoOutliers=GetPrivateProfileInt(szSection, "Outliers",
						0, szIniFile);
					bAutoAverage=GetPrivateProfileInt(szSection, "Average",
						0, szIniFile);
					bAutoPart=GetPrivateProfileInt(szSection, "Part",
						0, szIniFile);
					bAutoDrift=GetPrivateProfileInt(szSection, "Drift",
						0, szIniFile);
					bAutoDataPlot=GetPrivateProfileInt(szSection, "DataPlot",
						0, szIniFile);
					bAutoPhaseDataPlot=GetPrivateProfileInt(szSection, "PhaseDataPlot",
						0, szIniFile);
					bAutoFreqDataPlot=GetPrivateProfileInt(szSection,
						"FreqDataPlot",	0, szIniFile);
					bAutoRun=GetPrivateProfileInt(szSection, "Run",
						0, szIniFile);
					bAutoRunPlot=GetPrivateProfileInt(szSection, "RunPlot",
						0, szIniFile);
					bAutoStabPlot=GetPrivateProfileInt(szSection, "StabPlot",
						0, szIniFile);
					bAutoStabTable=GetPrivateProfileInt(szSection, "StabTable",
						0, szIniFile);
					bAutoClose=GetPrivateProfileInt(szSection, "Close",
						0, szIniFile);
					bAutoAddDelay=GetPrivateProfileInt(szSection, "Delay",
						0, szIniFile);
					bAutoPrintOriginal=GetPrivateProfileInt(szSection,
						"PrintOriginal", 0, szIniFile);
					bAutoPrintConverted=GetPrivateProfileInt(szSection,
						"PrintConverted", 0, szIniFile);
					bAutoPrintCorrected=GetPrivateProfileInt(szSection,
						"PrintCorrected", 0, szIniFile);
					bAutoPrintSelected=GetPrivateProfileInt(szSection,
						"PrintSelected", 0, szIniFile);
					bAutoPrintAveraged=GetPrivateProfileInt(szSection,
						"PrintAveraged", 0, szIniFile);
					bAutoPrintNormalized=GetPrivateProfileInt(szSection,
						"PrintNormalized", 0, szIniFile);
					bAutoPrintResidual=GetPrivateProfileInt(szSection,
						"PrintResidual", 0, szIniFile);
					bAutoDataPrint=GetPrivateProfileInt(szSection,
						"DataPrint", 0, szIniFile);
					bAutoNormalize=GetPrivateProfileInt(szSection, "Normalize",
						0, szIniFile);
				}
				break;

				case IDC_AUTO_WRITEINI:
				{
					// Setup section name
					sprintf(szSection, "Auto%d", nAuto);

					// Strings
					WritePrivateProfileString(szSection, "Script",
						szScriptname, szIniFile);
					WritePrivateProfileString(szSection, "PhaseVariance",
						szAutoPhaseVariance,	szIniFile);
					WritePrivateProfileString(szSection, "FreqVariance",
						szAutoFreqVariance,	szIniFile);
					WritePrivateProfileString(szSection, "Filename",
						szAutoFilename,	szIniFile);
					WritePrivateProfileString(szSection, "PhaseDriftType",
						szAutoPhaseDriftType, szIniFile);
					WritePrivateProfileString(szSection, "FreqDriftType",
						szAutoFreqDriftType, szIniFile);
					WritePrivateProfileString(szSection, "AvgFactor",
						szAutoAvgFactor, szIniFile);
					WritePrivateProfileString(szSection, "SigmaFactor",
						szAutoSigmaFactor, szIniFile);
					WritePrivateProfileString(szSection, "DelayTime",
						szAutoDelayTime, szIniFile);
					WritePrivateProfileString(szSection, "Start",
						szAutoStart, szIniFile);
					WritePrivateProfileString(szSection, "End",
						szAutoEnd, szIniFile);
					
					// BOOLS
					sprintf(szBuffer, "%d", bAutoDataType);
					WritePrivateProfileString(szSection, "DataType", szBuffer,
						szIniFile);
					sprintf(szBuffer, "%d", bAutoAnalysisType);
					WritePrivateProfileString(szSection, "AnalysisType",
						szBuffer, szIniFile);
					sprintf(szBuffer, "%d", bAutoFileOpen);
					WritePrivateProfileString(szSection, "FileOpen", szBuffer,
						szIniFile);
					sprintf(szBuffer, "%d", bAutoConvert);
					WritePrivateProfileString(szSection, "Convert", szBuffer,
						szIniFile);
					sprintf(szBuffer, "%d", bAutoRegularize);
					WritePrivateProfileString(szSection, "Regularize",
						szBuffer, szIniFile);
					sprintf(szBuffer, "%d", bAutoOutliers);
					WritePrivateProfileString(szSection, "Outliers", szBuffer,
						szIniFile);
					sprintf(szBuffer, "%d", bAutoAverage);
					WritePrivateProfileString(szSection, "Average", szBuffer,
						szIniFile);
					sprintf(szBuffer, "%d", bAutoPart);
					WritePrivateProfileString(szSection, "Part", szBuffer,
						szIniFile);
					sprintf(szBuffer, "%d", bAutoDrift);
					WritePrivateProfileString(szSection, "Drift", szBuffer,
						szIniFile);
					sprintf(szBuffer, "%d", bAutoDataPlot);
					WritePrivateProfileString(szSection, "DataPlot", szBuffer,
						szIniFile);
					sprintf(szBuffer, "%d", bAutoPhaseDataPlot);
					WritePrivateProfileString(szSection, "PhaseDataPlot",
						szBuffer, szIniFile);
					sprintf(szBuffer, "%d", bAutoFreqDataPlot);
					WritePrivateProfileString(szSection, "FreqDataPlot",
						szBuffer, szIniFile);
					sprintf(szBuffer, "%d", bAutoRunPlot);
					WritePrivateProfileString(szSection, "RunPlot", szBuffer,
						szIniFile);
					sprintf(szBuffer, "%d", bAutoRun);
					WritePrivateProfileString(szSection, "Run", szBuffer,
						szIniFile);
					sprintf(szBuffer, "%d", bAutoStabPlot);
					WritePrivateProfileString(szSection, "StabPlot", szBuffer,
						szIniFile);
					sprintf(szBuffer, "%d", bAutoStabTable);
					WritePrivateProfileString(szSection, "StabTable", szBuffer,
						szIniFile);
					sprintf(szBuffer, "%d", bAutoClose);
					WritePrivateProfileString(szSection, "Close", szBuffer,
						szIniFile);
					sprintf(szBuffer, "%d", bAutoAddDelay);
					WritePrivateProfileString(szSection, "Delay", szBuffer,
						szIniFile);
					sprintf(szBuffer, "%d", bAutoPrintOriginal);
					WritePrivateProfileString(szSection, "PrintOriginal",
						szBuffer, szIniFile);
					sprintf(szBuffer, "%d", bAutoPrintConverted);
					WritePrivateProfileString(szSection, "PrintConverted",
						szBuffer, szIniFile);
					sprintf(szBuffer, "%d", bAutoPrintCorrected);
					WritePrivateProfileString(szSection, "PrintCorrected",
						szBuffer, szIniFile);
					sprintf(szBuffer, "%d", bAutoPrintSelected);
					WritePrivateProfileString(szSection, "PrintSelected",
						szBuffer, szIniFile);
					sprintf(szBuffer, "%d", bAutoPrintAveraged);
					WritePrivateProfileString(szSection, "PrintAveraged",
						szBuffer, szIniFile);
					sprintf(szBuffer, "%d", bAutoPrintNormalized);
					WritePrivateProfileString(szSection, "PrintNormalized",
						szBuffer, szIniFile);
					sprintf(szBuffer, "%d", bAutoPrintResidual);
					WritePrivateProfileString(szSection, "PrintResidual",
						szBuffer, szIniFile);
					sprintf(szBuffer, "%d", bAutoDataPrint);
					WritePrivateProfileString(szSection, "DataPrint", szBuffer,
						szIniFile);
					sprintf(szBuffer, "%d", bAutoNormalize);
					WritePrivateProfileString(szSection, "Normalize", szBuffer,
						szIniFile);
				}
				break;

				
				// Respond to CR in an edit control
                // Note: No button is a DEFPUSHBUTTON
                case IDOK:
                {
                    // Does sigma factor edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_AUTO_SIGMAFACTOR))
                    {
						// Send EN_KILLFOCUS message to sigma factor
						// edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_AUTO_SIGMAFACTOR, 0,
							EN_KILLFOCUS));
					}

                    // Does averaging factor edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_AUTO_AVGFACTOR))
                    {
						// Send EN_KILLFOCUS message to avg factor edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_AUTO_AVGFACTOR, 0,
							EN_KILLFOCUS));
					}

                    // Does delay time edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_AUTO_DELAYTIME))
                    {
						// Send EN_KILLFOCUS message to delay time edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_AUTO_DELAYTIME, 0,
							EN_KILLFOCUS));
					}

                    // Does scipt name edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_AUTO_SCRIPTNAME))
                    {
						// Send EN_KILLFOCUS message to script name
						// edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_AUTO_SCRIPTNAME, 0,
							EN_KILLFOCUS));
					}

                    // Does filename edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_AUTO_FILENAME))
                    {
						// Send EN_KILLFOCUS message to filename edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_AUTO_FILENAME, 0,
							EN_KILLFOCUS));
					}
				}
                break;

				// Respond to the browse button
				case IDC_AUTO_BROWSE:
				{
					// Initialize OPENFILENAME structure
					FileInitialize(TRUE, FALSE, hDlg, hInst, "Open Data File",
						0);

					// Invoke standard File Open Dialog
					if(FileOpenDlg(FALSE, hDlg, szFile, szFileTitle))
					{
						strlcpy(szAutoFilename, szFile,
							sizeof(szAutoFilename));
					}
					else // Error
					{
						;
					}

					// Display the filename
					SetWindowText(GETHCTL(IDC_AUTO_FILENAME),
						szAutoFilename);
				}
				break;
				
				// Respond to go button
				// This executes the script
                case IDC_AUTO_GO:
                {
					// Save new parameters in ini file
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_AUTO_WRITEINI, NULL, 0));

					// Call automatic processing thread
					hAutoThread=CreateThread(NULL, 0, AutoThread, 0, 0,
						&dwAutoThreadID);

					// Close thread handle
					// Note: Can't do this here!
					// CloseHandle(hAutoThread);
					
					// Put info into log file
					sprintf(szBuffer, "#=%d", nAuto);
					WriteLog(64, szBuffer);

					// Close dialog
					EndDialog(hDlg, 0);
                 }
				break;

				// Respond to OK buttom message
				// This just saves the script
                case IDC_AUTO_ACCEPT:
                {
					// Save new parameters in ini file
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_AUTO_WRITEINI, NULL, 0));

					// Put info into log file
					sprintf(szBuffer, "#=%d", nAuto);
					WriteLog(63, szBuffer);

					// Close dialog
					EndDialog(hDlg, 0);
                }
				break;

                // Respond to esc key or cancel button
                case IDCANCEL:
                case IDC_AUTO_CANCEL:
                {
                    // Ignore new parameters
					EndDialog(hDlg, 0);
                }
                return TRUE;
            }
        }
        break;
	 }
     return FALSE;
}

/***************************************************************************/
