/*****************************************************************************/
/*                                                                           */
/*                            STABLE_EE.C                                    */
/*                                                                           */
/*		NR Functions for Levenberg-Marquardt Nonlinear Curve Fitting         */
/*                                                                           */
/*		Functions:                                                           */
/*					mrqmin()                                                 */
/*					mrqcof()                                                 */
/*					covsrt()                                                 */
/*                  gaussj()                                                 */
/*                                                                           */
/*      Example:                                                             */
/*					xmrqmin()                                                */
/*                  fgauss()                                                 */
/*                                                                           */
/*      Reference:                                                           */
/*           W.H. Press, et al, Numerical Recipes in C, Cambridge Univ.      */
/*           Press, 1988, ISBN 0-521-35465                                   */
/*                                                                           */
/*      Notes:                                                               */
/*           1. See NR Examples Book p.195-199 for usage example             */
/*           2. Requires function derivatives                                */
/*                                                                           */
/*	    Revision record:                                                     */
/*			 12/25/07   Created                                              */
/*                      Error message implemented  with TRACE_STR macro      */
/*						Some casts added, vector() and free_vector changed   */
/*						to nrvector, matrix() and free_matrix() changed      */
/*						to nrmatrix, ivector() and free_ivector() changed    */
/*                      to nrivector, SQR macro changed to NR_SQR, several   */
/*                      #defines added to replace those in nr.h.             */
/*                      Compiles cleanly                                     */
/*                      Top-level function not yet complete - not yet used   */
/*                                                                           */
/* (c) 2007  W. Riley   Hamilton Technical Services   All Rights Reserved    */
/*                                                                           */
/*****************************************************************************/

// Stable32 header
#include "stable_w.h"           // STABLE_W header file

// Defines
#define TOL 1.0e-5
#define NR_END 1
#define FREE_ARG char*
#define SIGN(a,b) ((b) >= 0.0 ? fabs(a) : -fabs(a))
static int iminarg1,iminarg2;
#define IMIN(a,b) (iminarg1=(a),iminarg2=(b),(iminarg1) < (iminarg2) ?\
        (iminarg1) : (iminarg2))
static float maxarg1,maxarg2;
#define FMAX(a,b) (maxarg1=(a),maxarg2=(b),(maxarg1) > (maxarg2) ?\
        (maxarg1) : (maxarg2))
static float sqrarg;
#define NR_SQR(a) ((sqrarg=(a)) == 0.0 ? 0.0 : sqrarg*sqrarg)

#if(0)
/*****************************************************************************/
/*                                                                           */
/*								mrqfit()                                     */
/*                                                                           */
/*		Levenberg-Marquardt Nonlinear Fit - Top-Level Function               */
/*                                                                           */
/*	    Revision record:                                                     */
/*			 12/25/07   Created from xmrqmin() - not complete                */
/*                      Not sure how to get derivatives.  Could evaluate     */
/*                      function at x + delta a[i] for each parameter        */
/*                                                                           */
/* (c) 2007  W. Riley   Hamilton Technical Services   All Rights Reserved    */
/*                                                                           */
/*****************************************************************************/

/* Driver for routine mrqmin */

//#include <stdio.h>
//#include <math.h>
//#define NRANSI
//#define NPT 100
//#define MA 6
//#define SPREAD 0.001

int mrqfit(void)
{
	long idum=(-911);
	int i,*ia,iter,itst,j,k;
	//int mfit=MA;
	float alamda,chisq,ochisq,*x,*y,*sig,**covar,**alpha;

	#if(0)
	static float a[MA+1]=
		{0.0,5.0,2.0,3.0,2.0,5.0,3.0};
	static float gues[MA+1]=
		{0.0,4.5,2.2,2.8,2.5,4.9,2.8};
	#endif

	// MA is # parameters
	// NPT is # data points
	
	ia=inrvector(1,MA);
	x=nrvector(1,NPT);
	y=nrvector(1,NPT);
	sig=nrvector(1,NPT);
	covar=nrmatrix(1,MA,1,MA);
	alpha=nrmatrix(1,MA,1,MA);

	#if(0)
	/* First try a sum of two Gaussians */
	for (i=1;i<=NPT;i++) {
		x[i]=0.1*i;
		y[i]=0.0;
		for (j=1;j<=MA;j+=3) {
			y[i] += a[j]*exp(-NR_SQR((x[i]-a[j+1])/a[j+2]));
		}
		y[i] *= (1.0+SPREAD*gasdev(&idum));
		sig[i]=SPREAD*y[i];
	}
	for (i=1;i<=mfit;i++) ia[i]=1;
	for (i=1;i<=MA;i++) a[i]=gues[i];
	#endif

	// y[] is observed data array
	// a[] is parameter array
	// Initial parameter guesses are in a[i]
	// Top-level iteration loop
	for (iter=1;iter<=2;iter++) {
		alamda = -1;
		mrqmin(x,y,sig,NPT,a,ia,MA,covar,alpha,&chisq,fgauss,&alamda);
		k=1;
		itst=0;
		for (;;) {
			printf("\n%s %2d %17s %10.4f %10s %9.2e\n","Iteration #",k,
				"chi-squared:",chisq,"alamda:",alamda);
			printf("%8s %8s %8s %8s %8s %8s\n",
				"a[1]","a[2]","a[3]","a[4]","a[5]","a[6]");
			for (i=1;i<=6;i++) printf("%9.4f",a[i]);
			printf("\n");
			k++;
			ochisq=chisq;
			mrqmin(x,y,sig,NPT,a,ia,MA,covar,alpha,&chisq,fgauss,&alamda);
			if (chisq > ochisq)
				itst=0;
			else if (fabs(ochisq-chisq) < 0.1)
				itst++;
			if (itst < 4) continue;
			alamda=0.0;
			mrqmin(x,y,sig,NPT,a,ia,MA,covar,alpha,&chisq,fgauss,&alamda);
			printf("\nUncertainties:\n");
			for (i=1;i<=6;i++) printf("%9.4f",sqrt(covar[i][i]));
			printf("\n");
			printf("\nExpected results:\n");
			printf(" %7.2f %8.2f %8.2f %8.2f %8.2f %8.2f\n",
				5.0,2.0,3.0,2.0,5.0,3.0);
			break;
		}
		if (iter == 1) {
			printf("press return to continue with constraint\n");
			(void) getchar();
			printf("holding a[2] and a[5] constant\n");
			for (j=1;j<=MA;j++) a[j] += 0.1;
			a[2]=2.0;
			ia[2]=0;
			a[5]=5.0;
			ia[5]=0;
		}
	}
	free_nrmatrix(alpha,1,MA,1,MA);
	free_nrmatrix(covar,1,MA,1,MA);
	free_nrvector(sig,1,NPT);
	free_nrvector(y,1,NPT);
	free_nrvector(x,1,NPT);
	free_inrvector(ia,1,MA);
	return 0;
}
#undef NRANSI
#endif

/*****************************************************************************/
/*                                                                           */
/*	mrqmin()                                                                 */
/*                                                                           */
/*  Returns best-fit values for ma nonlinear fit parameters a[] and their    */
/*  chi-squared value.  Call repeatedly until convergence.                   */
/*                                                                           */
/*  x[]		1-based float array of ndata observation x values                */
/*  y[]		1-based float array of ndata observation y values                */
/*  sig[]	1-based float array of ndata observation standard deviations     */
/*  ndata   # observations                                                   */
/*  a[]     1-based float array of ma fit coefficients (initial guesses)     */
/*  ia[]    1-based integer array of coefficient fit flags (0=fixed, 1=fit)  */
/*  ma		# coefficients                                                   */
/*  covar	pointer to 1-based float covariance matrix of size ma+1, ma+1    */
/*  alpha   pointer to 1-based float working matrix of size ma+1, ma+1       */
/*  chisqr  pointer to chi-squared fit value                                 */
/*  funcs	function to evaluate fitting function (with derivatives)         */
/*          funcs(x, a, yfit, dyda, ma) where x=xvalue, a=coefficient array, */
/*          yfit=y value, dyda=1-based array of ma derivative values wrt a   */
/*          at x, ma=# coefficients                                          */
/*  alamda	pointer to float lamda value to control iteration (set <0 on 1st */
/*          call, set to 0 on last call                                      */
/*                                                                           */
/*****************************************************************************/

#define NRANSI

void mrqmin(float x[], float y[], float sig[], int ndata, float a[], int ia[],
	int ma, float **covar, float **alpha, float *chisq,
	void (*funcs)(float, float [], float *, float [], int), float *alamda)
{
	void covsrt(float **covar, int ma, int ia[], int mfit);
	void gaussj(float **a, int n, float **b, int m);
	void mrqcof(float x[], float y[], float sig[], int ndata, float a[],
		int ia[], int ma, float **alpha, float beta[], float *chisq,
		void (*funcs)(float, float [], float *, float [], int));
	int j,k,l;
	static int mfit;
	static float ochisq,*atry,*beta,*da,**oneda;

	if (*alamda < 0.0) {
		atry=nrvector(1,ma);
		beta=nrvector(1,ma);
		da=nrvector(1,ma);
		for (mfit=0,j=1;j<=ma;j++)
			if (ia[j]) mfit++;
		oneda=nrmatrix(1,mfit,1,1);
		*alamda=(float)0.001;
		mrqcof(x,y,sig,ndata,a,ia,ma,alpha,beta,chisq,funcs);
		ochisq=(*chisq);
		for (j=1;j<=ma;j++) atry[j]=a[j];
	}
	for (j=1;j<=mfit;j++) {
		for (k=1;k<=mfit;k++) covar[j][k]=alpha[j][k];
		covar[j][j]=alpha[j][j]*((float)1.0+(*alamda));
		oneda[j][1]=beta[j];
	}
	gaussj(covar,mfit,oneda,1);
	for (j=1;j<=mfit;j++) da[j]=oneda[j][1];
	if (*alamda == 0.0) {
		covsrt(covar,ma,ia,mfit);
		covsrt(alpha,ma,ia,mfit);
		free_nrmatrix(oneda,1,mfit,1,1);
		free_nrvector(da,1,ma);
		free_nrvector(beta,1,ma);
		free_nrvector(atry,1,ma);
		return;
	}
	for (j=0,l=1;l<=ma;l++)
		if (ia[l]) atry[l]=a[l]+da[++j];
	mrqcof(x,y,sig,ndata,atry,ia,ma,covar,da,chisq,funcs);
	if (*chisq < ochisq) {
		*alamda *= (float)0.1;
		ochisq=(*chisq);
		for (j=1;j<=mfit;j++) {
			for (k=1;k<=mfit;k++) alpha[j][k]=covar[j][k];
			beta[j]=da[j];
		}
		for (l=1;l<=ma;l++) a[l]=atry[l];
	} else {
		*alamda *= 10.0;
		*chisq=ochisq;
	}
}
#undef NRANSI


/*****************************************************************************/
/*                                                                           */
/*		mrqcof()                                                             */
/*                                                                           */
/*****************************************************************************/

#define NRANSI

void mrqcof(float x[], float y[], float sig[], int ndata, float a[], int ia[],
	int ma, float **alpha, float beta[], float *chisq,
	void (*funcs)(float, float [], float *, float [], int))
{
	int i,j,k,l,m,mfit=0;
	float ymod,wt,sig2i,dy,*dyda;

	dyda=nrvector(1,ma);
	for (j=1;j<=ma;j++)
		if (ia[j]) mfit++;
	for (j=1;j<=mfit;j++) {
		for (k=1;k<=j;k++) alpha[j][k]=0.0;
		beta[j]=0.0;
	}
	*chisq=0.0;
	for (i=1;i<=ndata;i++) {
		(*funcs)(x[i],a,&ymod,dyda,ma);
		sig2i=(float)1.0/(sig[i]*sig[i]);
		dy=y[i]-ymod;
		for (j=0,l=1;l<=ma;l++) {
			if (ia[l]) {
				wt=dyda[l]*sig2i;
				for (j++,k=0,m=1;m<=l;m++)
					if (ia[m]) alpha[j][++k] += wt*dyda[m];
				beta[j] += dy*wt;
			}
		}
		*chisq += dy*dy*sig2i;
	}
	for (j=2;j<=mfit;j++)
		for (k=1;k<j;k++) alpha[k][j]=alpha[j][k];
	free_nrvector(dyda,1,ma);
}
#undef NRANSI


/*****************************************************************************/
/*                                                                           */
/*		covsrt()                                                             */
/*                                                                           */
/*****************************************************************************/

#define NR_SWAP(a,b) {swap=(a);(a)=(b);(b)=swap;}

void covsrt(float **covar, int ma, int ia[], int mfit)
{
	int i,j,k;
	float swap;

	for (i=mfit+1;i<=ma;i++)
		for (j=1;j<=i;j++) covar[i][j]=covar[j][i]=0.0;
	k=mfit;
	for (j=ma;j>=1;j--) {
		if (ia[j]) {
			for (i=1;i<=ma;i++) NR_SWAP(covar[i][k],covar[i][j])
			for (i=1;i<=ma;i++) NR_SWAP(covar[k][i],covar[j][i])
			k--;
		}
	}
}
#undef NR_SWAP


/*****************************************************************************/
/*                                                                           */
/*		gaussj()                                                             */
/*                                                                           */
/*****************************************************************************/

#include <math.h>
#define NRANSI
#define NR_SWAP(a,b) {temp=(a);(a)=(b);(b)=temp;}

void gaussj(float **a, int n, float **b, int m)
{
	int *indxc,*indxr,*ipiv;
	int i,icol,irow,j,k,l,ll;
	float big,dum,pivinv,temp;

	indxc=nrivector(1,n);
	indxr=nrivector(1,n);
	ipiv=nrivector(1,n);
	for (j=1;j<=n;j++) ipiv[j]=0;
	for (i=1;i<=n;i++) {
		big=0.0;
		for (j=1;j<=n;j++)
			if (ipiv[j] != 1)
				for (k=1;k<=n;k++) {
					if (ipiv[k] == 0) {
						if (fabs(a[j][k]) >= big) {
							big=(float)fabs(a[j][k]);
							irow=j;
							icol=k;
						}
					}
				}
		++(ipiv[icol]);
		if (irow != icol) {
			for (l=1;l<=n;l++) NR_SWAP(a[irow][l],a[icol][l])
			for (l=1;l<=m;l++) NR_SWAP(b[irow][l],b[icol][l])
		}
		indxr[i]=irow;
		indxc[i]=icol;
		if (a[icol][icol] == 0.0) TRACE_STR("gaussj: Singular Matrix");
		pivinv=(float)1.0/a[icol][icol];
		a[icol][icol]=1.0;
		for (l=1;l<=n;l++) a[icol][l] *= pivinv;
		for (l=1;l<=m;l++) b[icol][l] *= pivinv;
		for (ll=1;ll<=n;ll++)
			if (ll != icol) {
				dum=a[ll][icol];
				a[ll][icol]=0.0;
				for (l=1;l<=n;l++) a[ll][l] -= a[icol][l]*dum;
				for (l=1;l<=m;l++) b[ll][l] -= b[icol][l]*dum;
			}
	}
	for (l=n;l>=1;l--) {
		if (indxr[l] != indxc[l])
			for (k=1;k<=n;k++)
				NR_SWAP(a[k][indxr[l]],a[k][indxc[l]]);
	}
	free_nrivector(ipiv,1,n);
	free_nrivector(indxr,1,n);
	free_nrivector(indxc,1,n);
}
#undef NR_SWAP
#undef NRANSI


#if(0)
/*****************************************************************************/
/*                                                                           */
/*		main() for example program                                           */
/*                                                                           */
/*****************************************************************************/

/* Driver for routine mrqmin */

#include <stdio.h>
#include <math.h>
#define NRANSI
#define NPT 100
#define MA 6
#define SPREAD 0.001

int main(void)
{
	long idum=(-911);
	int i,*ia,iter,itst,j,k,mfit=MA;
	float alamda,chisq,ochisq,*x,*y,*sig,**covar,**alpha;
	static float a[MA+1]=
		{0.0,5.0,2.0,3.0,2.0,5.0,3.0};
	static float gues[MA+1]=
		{0.0,4.5,2.2,2.8,2.5,4.9,2.8};

	ia=inrvector(1,MA);
	x=nrvector(1,NPT);
	y=nrvector(1,NPT);
	sig=nrvector(1,NPT);
	covar=nrmatrix(1,MA,1,MA);
	alpha=nrmatrix(1,MA,1,MA);
	/* First try a sum of two Gaussians */
	for (i=1;i<=NPT;i++) {
		x[i]=0.1*i;
		y[i]=0.0;
		for (j=1;j<=MA;j+=3) {
			y[i] += a[j]*exp(-NR_SQR((x[i]-a[j+1])/a[j+2]));
		}
		y[i] *= (1.0+SPREAD*gasdev(&idum));
		sig[i]=SPREAD*y[i];
	}
	for (i=1;i<=mfit;i++) ia[i]=1;
	for (i=1;i<=MA;i++) a[i]=gues[i];
	for (iter=1;iter<=2;iter++) {
		alamda = -1;
		mrqmin(x,y,sig,NPT,a,ia,MA,covar,alpha,&chisq,fgauss,&alamda);
		k=1;
		itst=0;
		for (;;) {
			printf("\n%s %2d %17s %10.4f %10s %9.2e\n","Iteration #",k,
				"chi-squared:",chisq,"alamda:",alamda);
			printf("%8s %8s %8s %8s %8s %8s\n",
				"a[1]","a[2]","a[3]","a[4]","a[5]","a[6]");
			for (i=1;i<=6;i++) printf("%9.4f",a[i]);
			printf("\n");
			k++;
			ochisq=chisq;
			mrqmin(x,y,sig,NPT,a,ia,MA,covar,alpha,&chisq,fgauss,&alamda);
			if (chisq > ochisq)
				itst=0;
			else if (fabs(ochisq-chisq) < 0.1)
				itst++;
			if (itst < 4) continue;
			alamda=0.0;
			mrqmin(x,y,sig,NPT,a,ia,MA,covar,alpha,&chisq,fgauss,&alamda);
			printf("\nUncertainties:\n");
			for (i=1;i<=6;i++) printf("%9.4f",sqrt(covar[i][i]));
			printf("\n");
			printf("\nExpected results:\n");
			printf(" %7.2f %8.2f %8.2f %8.2f %8.2f %8.2f\n",
				5.0,2.0,3.0,2.0,5.0,3.0);
			break;
		}
		if (iter == 1) {
			printf("press return to continue with constraint\n");
			(void) getchar();
			printf("holding a[2] and a[5] constant\n");
			for (j=1;j<=MA;j++) a[j] += 0.1;
			a[2]=2.0;
			ia[2]=0;
			a[5]=5.0;
			ia[5]=0;
		}
	}
	free_nrmatrix(alpha,1,MA,1,MA);
	free_nrmatrix(covar,1,MA,1,MA);
	free_nrvector(sig,1,NPT);
	free_nrvector(y,1,NPT);
	free_nrvector(x,1,NPT);
	free_inrvector(ia,1,MA);
	return 0;
}
#undef NRANSI

/*****************************************************************************/
/*                                                                           */
/*		fgauss() funcs() for example program                                 */
/*                                                                           */
/*****************************************************************************/

#include <math.h>

void fgauss(float x, float a[], float *y, float dyda[], int na)
{
	int i;
	float fac,ex,arg;

	*y=0.0;
	for (i=1;i<=na-1;i+=3) {
		arg=(x-a[i+1])/a[i+2];
		ex=exp(-arg*arg);
		fac=a[i]*ex*2.0*arg;
		*y += a[i]*ex;
		dyda[i]=ex;
		dyda[i+1]=fac/a[i+2];
		dyda[i+2]=fac*arg/a[i+2];
	}
}
#endif

/*****************************************************************************/
/*                                                                           */
/*		nrvector()                                                           */
/*                                                                           */
/*****************************************************************************/

float *nrvector(long nl, long nh)
/* allocate a float vector with subscript range v[nl..nh] */
{
	float *v;

	v=(float *)malloc((size_t) ((nh-nl+1+NR_END)*sizeof(float)));
	if (!v) TRACE_STR("Allocation failure in nrvector()");
	return v-nl+NR_END;
}

/*****************************************************************************/
/*                                                                           */
/*		free_nrvector()                                                      */
/*                                                                           */
/*****************************************************************************/

void free_nrvector(float *v, long nl, long nh)
/* free a float vector allocated with nrvector() */
{
	free((FREE_ARG) (v+nl-NR_END));
}

/*****************************************************************************/
/*                                                                           */
/*		nrmatrix()                                                           */
/*                                                                           */
/*****************************************************************************/

float **nrmatrix(long nrl, long nrh, long ncl, long nch)
/* allocate a float matrix with subscript range m[nrl..nrh][ncl..nch] */
{
	long i, nrow=nrh-nrl+1,ncol=nch-ncl+1;
	float **m;

	/* allocate pointers to rows */
	m=(float **) malloc((size_t)((nrow+NR_END)*sizeof(float*)));
	if (!m) TRACE_STR("Allocation failure 1 in nrmatrix()");
	m += NR_END;
	m -= nrl;

	/* allocate rows and set pointers to them */
	m[nrl]=(float *) malloc((size_t)((nrow*ncol+NR_END)*sizeof(float)));
	if (!m[nrl]) TRACE_STR("Allocation failure 2 in nrmatrix()");
	m[nrl] += NR_END;
	m[nrl] -= ncl;

	for(i=nrl+1;i<=nrh;i++) m[i]=m[i-1]+ncol;

	/* return pointer to array of pointers to rows */
	return m;
}

/*****************************************************************************/
/*                                                                           */
/*		free_nrmatrix()                                                      */
/*                                                                           */
/*****************************************************************************/

void free_nrmatrix(float **m, long nrl, long nrh, long ncl, long nch)
/* free a float matrix allocated by matrix() */
{
	free((FREE_ARG) (m[nrl]+ncl-NR_END));
	free((FREE_ARG) (m+nrl-NR_END));
}

/*****************************************************************************/
/*                                                                           */
/*		nrivector()                                                          */
/*                                                                           */
/*****************************************************************************/

int *nrivector(long nl, long nh)
/* allocate an int vector with subscript range v[nl..nh] */
{
	int *v;

	v=(int *)malloc((size_t) ((nh-nl+1+NR_END)*sizeof(int)));
	if (!v) TRACE_STR("allocation failure in ivector()");
	return v-nl+NR_END;
}

/*****************************************************************************/
/*                                                                           */
/*		free_nrivector()                                                     */
/*                                                                           */
/*****************************************************************************/

void free_nrivector(int *v, long nl, long nh)
/* free an int vector allocated with ivector() */
{
	free((FREE_ARG) (v+nl-NR_END));
}

/*****************************************************************************/
