/*****************************************************************************/
/*                                                                           */
/*                            STABLE_Q.C                                     */
/*                                                                           */
/*                                                                           */
/*      Miscellaneous file processing functions for Stable Windows 95/NT     */
/*                                                                           */
/*      ReadIni()                                                            */
/*      WriteIni()                                                           */
/*		ReadFileInfo()                                                       */
/*		WriteFileInfo()                                                      */
/*      UpdateFileInfo()                                                     */
/*      ReadDataFile()                                                       */
/*      TooBigDlgProc()                                                      */
/*      OpenedDlgProc()                                                      */
/*                                                                           */
/*		Revision record:                                                     */
/*                                                                           */
/*			06/29/97	Use GET_WM_COMMAND_ID, etc. WIN32 compatibility      */
/*						macros to process WM_COMMAND messages:               */
/*						wParam <- GET_WM_COMMAND_ID(wParam, lParam)          */
/*						HIWORD(lParam) <- GET_WM_COMMAND_CMD(wParam, lParam) */
/*						Replaced WORD with UINT                              */
/*			06/30/97	Replaced MoveTo() with MoveToEx()                    */
/*			07/12/97	More Win32 compatibility changes                     */
/*			12/22/97	Made changes for BC Win32 compliation w/o warnings   */
/*			01/16/98	Added ShortenExp() usage for MSC VC++                */
/*			07/26/07    Changed to safe string functions                     */
/*                                                                           */
/*  (c) 1996-2007  W. Riley Hamilton Technical Services All Rights Reserved  */
/*                                                                           */
/*****************************************************************************/

#define STRICT 					// For Win32 compatibility

// Include the stable_w header file
#include "stable_w.h"           // STABLE_W header file

/*****************************************************************************/
/*                                                                           */
/*                              ReadIni()                                    */
/*                                                                           */
/*		Function to read configuration data from STABLE32.INI                */
/*                                                                           */
/*      Revision record:                                                     */
/*      	08/24/96	Created								                 */
/*			10/14/96	Added ShowFileOpened item							 */
/*			10/27/96	Added PlotLabel items								 */
/*			11/03/96	Added IncExtension items                             */
/*			11/06/96	Added WriteSigmaFile item                            */
/*			11/27/96	Added Notepad item                                   */
/*			12/21/96	Added Path item                                      */
/*			12/31/96	Added Sigma, Spect & Histo Plot items                */
/*			01/09/97	Added nSection parameter & tests                     */
/*			03/19/97	Added bAutoCalc & bAutoPlot items                    */
/*			04/27/97	Added x-div phase & freq plot items                  */
/*			12/19/97	Added code to read plot line & note items            */
/*						Changed section & key names to use stringtable       */
/*						to save DGROUP space                                 */
/*			02/28/98	Added reading of bShowWelcome                        */
/*			03/21/98	Changed to global full ini filename                  */
/*			05/30/98	Added x & y-axis labels for stability plot           */
/*						Made toolbutton state default=1                      */
/*			06/11/98	Added bSplash                                        */
/*			07/20/98	Added box, date, table & errbar flags for            */
/*                      sigma plot                                           */
/*			01/14/99	Added global sigma, run & drift type items           */
/*			01/23/98	Added check, drift & sigma details & wide edit       */
/*						Added NormFreq & XferTags flags for convert          */
/*			02/04/99	Added NonNums for # non-numerics skipped in data     */
/*			03/06/99	Added bTest for general test control                 */
/*			12/11/99	Added bComma to handle Europeandeciaml point         */
/*			02/07/00	Added bWarnZeroFreq to warn re equal phase vals      */
/*			02/10/00	Added main window screen position vals               */
/*			02/19/00	Added bSmartScale flag                               */
/*			02/26/00	Added fTagScale input value                          */
/*			06/01/00	Added nPPlotX and NFPlotX data plot label #s         */
/*			09/08/00	Added bLastOpened=type of last data file opened      */
/*			09/09/00	Added bOpenScale flag                                */
/*			04/08/01	Added bHeader flag                                   */
/*			08/19/01	Added szCornFileA, B and C                           */
/*			11/23/01	Added bNoGreek                                       */
/*			02/02/02	Added several spectrum plot parameters               */
/*			03/24/02	Moved PPlotX & FPlotX to [PhasePlot] & [FreqPlot]    */
/*			05/10/02	Added FXDefault & PXDefault                          */
/*			06/21/02	Added sigma plot TablePos                            */
/*			12/07/02	Added timetag offsets                                */
/*			01/21/03	Added bManyTau flag                                  */
/*			01/22/03	Added nManySize value                                */
/*			04/11/03	Added fSlopeSpec                                     */
/*			08/02/03	Added bOpaque for plot notes                         */
/*			08/07/03	Added AutoPlot                                       */
/*						Added UseTags                                        */
/*			09/18/03	Added bACFNoiseID flag                               */
/*			11/16/05	Added DAVAR section                                  */
/*			11/29/05	Added Colors for DAVAR                               */
/*			12/05/05	Note: Database ini code in its own functions         */
/*			01/28/07	Added Smooth (sPSPlot.smooth)                        */
/*			01/31/07	Added PSDSmoothPPO (sPSPlot.ppo)                     */
/*			02/04/07	Moved sPSPlot.smooth & sPSPlot.ppo to [Preferences]  */
/*						sPSPlot.smooth=Smooth, sPSPlot.ppo=PSDSmoothPPO      */
/*						Added PSDAvgSize, PSDAvgMax, PSDLFSkip,              */
/*						PSDLineWeight                                        */
/*			07/28/07	Added nPointSize                                     */
/*						Added [Audio] section, nSampleRate, szAudioPlayer    */
/*			08/27/07	Added bZeroPad                                       */
/*			03/19/08	Added nFTag                                          */
/*			04/15/08	Added JumpMethod                                     */
/*			05/17/08	Added sPSPlot.limit                                  */
/*						Added sPSPlot.do_spur                                */
/*          08/14/08	Added bUnixComment                                   */
/*			11/26/09	Removed improper fabs() in reading fFreqAddendInput  */
/*                                                                           */
/*****************************************************************************/

void ReadIni(int nSection)
{
	// Local variables
	int i;						     // Index
	char szNum[BUFFER_SIZE+1];		 // Line # string
	char szKey[BUFFER_SIZE+1];		 // Key string
	char szBuffer[BUFFER_SIZE+1];	 // General text buffer
	char szSection[BUFFER_SIZE+1];   // Section name

	// [Files] section
	if(nSection==INI_FILES || nSection==INI_ALL)
	{
		LoadString(hInst, IDS_INI_SECTION_0, szSection, BUFFER_SIZE);
		LoadString(hInst, IDS_INI_KEY_0, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", szFile,
			FILE_NAME_SIZE, szIniFile);
		// Load external filename pattern (read only)
		// Format: Ext=Backup Files (*.bak)|*.bak|
		// where | is placeholder for EOS to allow string manipulations
		GetPrivateProfileString(szSection, "Ext", "", szExternalPattern,
			BUFFER_SIZE, szIniFile);
		GetPrivateProfileString(szSection, "A", "", szCornFileA, BUFFER_SIZE,
			szIniFile);
		GetPrivateProfileString(szSection, "B", "", szCornFileB, BUFFER_SIZE,
			szIniFile);
		GetPrivateProfileString(szSection, "C", "", szCornFileC, BUFFER_SIZE,
			szIniFile);
	}

	// [Preferences] section
	if(nSection==INI_PREFS || nSection==INI_ALL)
	{
		LoadString(hInst, IDS_INI_SECTION_2, szSection, BUFFER_SIZE);
		LoadString(hInst, IDS_INI_KEY_2, szKey, BUFFER_SIZE);
		bShowFileOpened=GetPrivateProfileInt(szSection, szKey, 1,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_3, szKey, BUFFER_SIZE);
		bUseFreqPlotIni=GetPrivateProfileInt(szSection, szKey, 0,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_4, szKey, BUFFER_SIZE);
		bUsePhasePlotIni=GetPrivateProfileInt(szSection, szKey,	0,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_5, szKey, BUFFER_SIZE);
		bUseSigmaPlotIni=GetPrivateProfileInt(szSection, szKey,	0,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_6, szKey, BUFFER_SIZE);
		bUseHistoPlotIni=GetPrivateProfileInt(szSection, szKey,	0,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_7, szKey, BUFFER_SIZE);
		bUseSpectPlotIni=GetPrivateProfileInt(szSection, szKey,	0,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_113, szKey, BUFFER_SIZE);
		bUseAutoPlotIni=GetPrivateProfileInt(szSection, szKey,	0,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_114, szKey, BUFFER_SIZE);
		bUseDAVARPlotIni=GetPrivateProfileInt(szSection, szKey,	0,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_87, szKey, BUFFER_SIZE);
		bOpenScale=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_108, szKey, BUFFER_SIZE);
		bACFNoiseID=GetPrivateProfileInt(szSection, szKey, 1, szIniFile);
		LoadString(hInst, IDS_INI_KEY_8, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", szBuffer,
			BUFFER_SIZE, szIniFile);
		if(strcmp(szBuffer, "Phase")==0)
		{
			bDataType=PHASE_DATA;
		}
		else
		{
			bDataType=FREQ_DATA;
		}
		LoadString(hInst, IDS_INI_KEY_86, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", szBuffer,
			BUFFER_SIZE, szIniFile);
		if(strcmp(szBuffer, "Phase")==0)
		{
			bLastOpened=PHASE_DATA;
		}
		else
		{
			bLastOpened=FREQ_DATA;
		}
		LoadString(hInst, IDS_INI_KEY_9, szKey, BUFFER_SIZE);
		bPlotLabel=GetPrivateProfileInt(szSection, szKey,	0,	szIniFile);
		LoadString(hInst, IDS_INI_KEY_10, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", szPlotLabel,
			BUFFER_SIZE, szIniFile);
		LoadString(hInst, IDS_INI_KEY_11, szKey, BUFFER_SIZE);
		bIncExtension=GetPrivateProfileInt(szSection, szKey, 0,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_12, szKey, BUFFER_SIZE);
		bWriteSigmaFile=GetPrivateProfileInt(szSection, szKey, 0,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_13, szKey, BUFFER_SIZE);
		bAutoCalc=GetPrivateProfileInt(szSection, szKey, 0,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_14, szKey, BUFFER_SIZE);
		bAutoPlot=GetPrivateProfileInt(szSection, szKey, 0,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_15, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "NOTEPAD", szNotepad,
			BUFFER_SIZE, szIniFile);
		LoadString(hInst, IDS_INI_KEY_55, szKey, BUFFER_SIZE);
		nMaxSize=GetPrivateProfileInt(szSection, szKey, MAX_DATA_FILE_SIZE,
			szIniFile);
		#ifdef STUDENT_VER
		nMaxSize=STUDENT_MAX;
		#endif
		#ifdef LITE_VER
		nMaxSize=LITE_MAX;
		#endif
		LoadString(hInst, IDS_INI_KEY_56, szKey, BUFFER_SIZE);
		bShowWelcome=GetPrivateProfileInt(szSection, szKey, 1,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_58, szKey, BUFFER_SIZE);
		bSplash=GetPrivateProfileInt(szSection, szKey,	1,	szIniFile);
		LoadString(hInst, IDS_INI_KEY_62, szKey, BUFFER_SIZE);
		nGlobalSigmaType=GetPrivateProfileInt(szSection, szKey,	0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_63, szKey, BUFFER_SIZE);
		nGlobalRunType=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_135, szKey, BUFFER_SIZE);
		nTauIncrement=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_64, szKey, BUFFER_SIZE);
		nGlobalPhaseDriftType=GetPrivateProfileInt(szSection, szKey, 0,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_65, szKey, BUFFER_SIZE);
		nGlobalFreqDriftType=GetPrivateProfileInt(szSection, szKey,	0,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_66, szKey, BUFFER_SIZE);
		bCheckDetails=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_67, szKey, BUFFER_SIZE);
		bDriftDetails=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_68, szKey, BUFFER_SIZE);
		bSigmaDetails=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_69, szKey, BUFFER_SIZE);
		bWideEdit=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_70, szKey, BUFFER_SIZE);
		bGlobalNormFreq=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_71, szKey, BUFFER_SIZE);
		bGlobalXferTags=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_72, szKey, BUFFER_SIZE);
		nSkipChar=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_73, szKey, BUFFER_SIZE);
		bTest=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_100, szKey, BUFFER_SIZE);
		bDetailedLog=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_74, szKey, BUFFER_SIZE);
		// Note: These default links changed for UFFC version of Stable32
		// szEmail becomes an ordinary URL instead of a mailto
		#if(0) // Original code
		GetPrivateProfileString(szSection, szKey,
			"http://www.wriley.com", szURL, BUFFER_SIZE,
			szIniFile);
		#endif
		#if(1) // New code 11/10/17 for Ver. 1.62 UFFC version
		GetPrivateProfileString(szSection, szKey,
			"https://ieee-uffc.org", szURL, BUFFER_SIZE,
			szIniFile);
		#endif
		LoadString(hInst, IDS_INI_KEY_75, szKey, BUFFER_SIZE);
		#if(0) // Original code
		GetPrivateProfileString(szSection, szKey, "mailto:stable32@wriley.com",
			szEMail, BUFFER_SIZE, szIniFile);
		#endif
		#if(1) // New code 11/10/17 for Ver. 1.62 UFFC version
		GetPrivateProfileString(szSection, szKey,
			"https://ieee-uffc.org/home/feedback/", szEMail, BUFFER_SIZE,
			szIniFile);
		#endif
		// Get comma preference for European decimal point usage
		LoadString(hInst, IDS_INI_KEY_76, szKey, BUFFER_SIZE);
		bComma=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		// Get zero freq warning preference
		LoadString(hInst, IDS_INI_KEY_77, szKey, BUFFER_SIZE);
		bWarnZeroFreq=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		// Get smart scale preference
		LoadString(hInst, IDS_INI_KEY_82, szKey, BUFFER_SIZE);
		bSmartScale=GetPrivateProfileInt(szSection, szKey, 1, szIniFile);
		// Get main window left position
		LoadString(hInst, IDS_INI_KEY_78, szKey, BUFFER_SIZE);
		nMainLeft=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		// Get main window top position
		LoadString(hInst, IDS_INI_KEY_79, szKey, BUFFER_SIZE);
		nMainTop=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		// Get main window right position
		LoadString(hInst, IDS_INI_KEY_80, szKey, BUFFER_SIZE);
		nMainRight=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		// Get main window bottom position
		LoadString(hInst, IDS_INI_KEY_81, szKey, BUFFER_SIZE);
		nMainBottom=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		// Get header flag
		LoadString(hInst, IDS_INI_KEY_89, szKey, BUFFER_SIZE);
		bHeader=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		// Get many tau flag
		LoadString(hInst, IDS_INI_KEY_103, szKey, BUFFER_SIZE);
		bManyTau=GetPrivateProfileInt(szSection, szKey, 1, szIniFile);
		// Get many size value
		LoadString(hInst, IDS_INI_KEY_104, szKey, BUFFER_SIZE);
		nManySize=GetPrivateProfileInt(szSection, szKey, 500, szIniFile);
		nManySize=max(nManySize, 50);
		// Get NoGreek flag
		bNoGreek=GetPrivateProfileInt(szSection, "NoGreek", 0, szIniFile);
		// Get UseTags flag
		LoadString(hInst, IDS_INI_KEY_107, szKey, BUFFER_SIZE);
		bUseTags=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		// Get PSDAvgSize
		LoadString(hInst, IDS_INI_KEY_116, szKey, BUFFER_SIZE);
		nPSDAvgSize=GetPrivateProfileInt(szSection, szKey, 64, szIniFile);
		// Get PSDAvgMax
		LoadString(hInst, IDS_INI_KEY_117, szKey, BUFFER_SIZE);
		nPSDAvgMax=GetPrivateProfileInt(szSection, szKey, 256, szIniFile);
		// Get PSDLFSkip
		LoadString(hInst, IDS_INI_KEY_118, szKey, BUFFER_SIZE);
		nPSDLFSkip=GetPrivateProfileInt(szSection, szKey, 1, szIniFile);
		// Get PointSize
		LoadString(hInst, IDS_INI_KEY_124, szKey, BUFFER_SIZE);
		nPointSize=GetPrivateProfileInt(szSection, szKey, 9, szIniFile);
		// Get ZeroPad
		LoadString(hInst, IDS_INI_KEY_129, szKey, BUFFER_SIZE);
		bZeroPad=GetPrivateProfileInt(szSection, szKey, 1, szIniFile);
		// Note:  The next three sPSPlot items are considered preferences
		// Get sPSPlot.smooth
		LoadString(hInst, IDS_INI_KEY_121, szKey, BUFFER_SIZE);
		sPSPlot.smooth=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		// Get sPSPlot.weight
		LoadString(hInst, IDS_INI_KEY_120, szKey, BUFFER_SIZE);
		sPSPlot.weight=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		// Get sPSPlot.ppo
		LoadString(hInst, IDS_INI_KEY_119, szKey, BUFFER_SIZE);
		sPSPlot.ppo=GetPrivateProfileInt(szSection, szKey, 64, szIniFile);
		// Get sPSPlot.limit
		LoadString(hInst, IDS_INI_KEY_132, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "20", szBuffer,
			BUFFER_SIZE, szIniFile);
		sPSPlot.limit=(float)atof(szBuffer);
		// Get nFTag fre timetag type code
		LoadString(hInst, IDS_INI_KEY_130, szKey, BUFFER_SIZE);
		nFTag=GetPrivateProfileInt(szSection, szKey, FTAG_FIRST, szIniFile);
		// Get bUnixComment flag (read only)
		LoadString(hInst, IDS_INI_KEY_134, szKey, BUFFER_SIZE);
		bUnixComment=GetPrivateProfileInt(szSection, szKey, 1, szIniFile);
		// Plot style
		nStyle=GetPrivateProfileInt(szSection, "Style", 0, szIniFile);
	}

	// [FreqPlot] section
	if( (nSection==INI_FREQ) || (nSection==INI_ALL && bUseFreqPlotIni) )
	{
		LoadString(hInst, IDS_INI_SECTION_3, szSection, BUFFER_SIZE);
		// Note: These have no effect unless UseFreqPlotIni=1
		LoadString(hInst, IDS_INI_KEY_16, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", sFPlot.title, TITLESIZE,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_17, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", sFPlot.subtitle,
			SUBTITLESIZE, szIniFile);
		LoadString(hInst, IDS_INI_KEY_18, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", sFPlot.message_str,
			MESSAGESIZE, szIniFile);
		LoadString(hInst, IDS_INI_KEY_19, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", sFPlot.x_label,
			XLABELSIZE, szIniFile);
		LoadString(hInst, IDS_INI_KEY_20, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", sFPlot.left_y_label,
			YLABELSIZE, szIniFile);
		LoadString(hInst, IDS_INI_KEY_21, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", sFPlot.plot_filename,
			FILENAMESIZE, szIniFile);
		// If there was no plot filename in ini file, use default
		if(strcmp(sFPlot.plot_filename, "")==0)
		{
			strlcpy(szStabFile, szDrive, FILE_NAME_SIZE);
			strlcat(szStabFile, szDirectory, FILE_NAME_SIZE);
			strlcat(szStabFile, "FREQ.TKF", FILE_NAME_SIZE);
		}
		LoadString(hInst, IDS_INI_KEY_22, szKey, BUFFER_SIZE);
		sFPlot.position=GetPrivateProfileInt(szSection, szKey, 0,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_23, szKey, BUFFER_SIZE);
		sFPlot.x_div=GetPrivateProfileInt(szSection, szKey, 5, szIniFile);
		// y_div cannot be zero
		if(!sFPlot.x_div)
		{
			sFPlot.x_div=5;
		}
		LoadString(hInst, IDS_INI_KEY_24, szKey, BUFFER_SIZE);
		sFPlot.y_div=GetPrivateProfileInt(szSection, szKey, 5, szIniFile);
		// y_div cannot be zero
		if(!sFPlot.y_div)
		{
			sFPlot.y_div=5;
		}
		LoadString(hInst, IDS_INI_KEY_25, szKey, BUFFER_SIZE);
		sFPlot.y_tic=GetPrivateProfileInt(szSection, szKey, 5, szIniFile);
		// y_tic cannot be zero
		if(!sFPlot.y_tic)
		{
			sFPlot.y_tic=5;
		}
		LoadString(hInst, IDS_INI_KEY_26, szKey, BUFFER_SIZE);
		sFPlot.do_line=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_27, szKey, BUFFER_SIZE);
		sFPlot.do_mouse=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_28, szKey, BUFFER_SIZE);
		sFPlot.do_date=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_29, szKey, BUFFER_SIZE);
		sFPlot.do_box=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_88, szKey, BUFFER_SIZE);
		sFPlot.do_wide=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_30, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "0", szBuffer,
			BUFFER_SIZE, szIniFile);
		sFPlot.x_offset=(float)atof(szBuffer);
		LoadString(hInst, IDS_INI_KEY_31, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "1", szBuffer, BUFFER_SIZE,
			szIniFile);
		sFPlot.x_mult=(float)atof(szBuffer);
		LoadString(hInst, IDS_INI_KEY_32, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "0", szBuffer,
			BUFFER_SIZE, szIniFile);
		sFPlot.y_offset=(float)atof(szBuffer);
		LoadString(hInst, IDS_INI_KEY_33, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "1", szBuffer, BUFFER_SIZE,
			szIniFile);
		sFPlot.y_mult=(float)atof(szBuffer);
		LoadString(hInst, IDS_INI_KEY_34, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "0", szBuffer, BUFFER_SIZE,
			szIniFile);
		sFPlot.y_min=(float)atof(szBuffer);
		LoadString(hInst, IDS_INI_KEY_35, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "1", szBuffer, BUFFER_SIZE,
			szIniFile);
		sFPlot.y_max=(float)atof(szBuffer);
		// Crude protection against bad scale
		if(sFPlot.y_max<=sFPlot.y_min)
		{
			sFPlot.y_max=1.0;
			sFPlot.y_min=0.0;
		}
		LoadString(hInst, IDS_INI_KEY_61, szKey, BUFFER_SIZE);
		sFPlot.do_fit=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		// Get freq data plot x-axis label #
		LoadString(hInst, IDS_INI_KEY_85, szKey, BUFFER_SIZE);
		nFPlotX=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		if(nFPlotX<0 || nFPlotX>(NUM_X_SCALES))
		{
			nFPlotX=0;
		}
		// Get freq plot x-axis scale default flag
		LoadString(hInst, IDS_INI_KEY_96, szKey, BUFFER_SIZE);
		bFXDefault=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		// Get log drift spec limit
		LoadString(hInst, IDS_INI_KEY_105, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "0", szBuffer,
			BUFFER_SIZE, szIniFile);
		fSlopeSpec=(F_TYPE)(fabs(atof(szBuffer)));
		if(fSlopeSpec==0.0)
		{
			bSlopeSpec=FALSE;
		}
		else
		{
			bSlopeSpec=TRUE;
		}
		// Frequency jump detection method
		LoadString(hInst, IDS_INI_KEY_131, szKey, BUFFER_SIZE);
		sFPlot.method=GetPrivateProfileInt(szSection, szKey, 1, szIniFile);
	}

	// [PhasePlot] section
	if( (nSection==INI_PHASE) || (nSection==INI_ALL && bUsePhasePlotIni) )
	{
		LoadString(hInst, IDS_INI_SECTION_4, szSection, BUFFER_SIZE);
		// Note: These have no effect unless UsePhasePlotIni=1
		LoadString(hInst, IDS_INI_KEY_16, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", sPPlot.title, TITLESIZE,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_17, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", sPPlot.subtitle,
			SUBTITLESIZE, szIniFile);
		LoadString(hInst, IDS_INI_KEY_18, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", sPPlot.message_str,
			MESSAGESIZE, szIniFile);
		LoadString(hInst, IDS_INI_KEY_19, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", sPPlot.x_label,
			XLABELSIZE, szIniFile);
		LoadString(hInst, IDS_INI_KEY_20, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", sPPlot.left_y_label,
			YLABELSIZE, szIniFile);
		LoadString(hInst, IDS_INI_KEY_21, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", sPPlot.plot_filename,
			FILENAMESIZE, szIniFile);
		// If there was no plot filename in ini file, use default
		if(strcmp(sPPlot.plot_filename, "")==0)
		{
			strlcpy(szStabFile, szDrive, FILE_NAME_SIZE);
			strlcat(szStabFile, szDirectory, FILE_NAME_SIZE);
			strlcat(szStabFile, "PHASE.TKF", FILE_NAME_SIZE);
		}
		LoadString(hInst, IDS_INI_KEY_22, szKey, BUFFER_SIZE);
		sPPlot.position=GetPrivateProfileInt(szSection, szKey, 0,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_23, szKey, BUFFER_SIZE);
		sPPlot.x_div=GetPrivateProfileInt(szSection, szKey, 5, szIniFile);
		// x_div cannot be zero
		if(!sPPlot.x_div)
		{
			sPPlot.x_div=5;
		}
		LoadString(hInst, IDS_INI_KEY_24, szKey, BUFFER_SIZE);
		sPPlot.y_div=GetPrivateProfileInt(szSection, szKey, 5, szIniFile);
		// y_div cannot be zero
		if(!sPPlot.y_div)
		{
			sPPlot.y_div=5;
		}
		LoadString(hInst, IDS_INI_KEY_25, szKey, BUFFER_SIZE);
		sPPlot.y_tic=GetPrivateProfileInt(szSection, szKey, 5, szIniFile);
		// y_tic cannot be zero
		if(!sPPlot.y_tic)
		{
			sPPlot.y_tic=5;
		}
		LoadString(hInst, IDS_INI_KEY_26, szKey, BUFFER_SIZE);
		sPPlot.do_line=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_27, szKey, BUFFER_SIZE);
		sPPlot.do_mouse=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_28, szKey, BUFFER_SIZE);
		sPPlot.do_date=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_29, szKey, BUFFER_SIZE);
		sPPlot.do_box=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_88, szKey, BUFFER_SIZE);
		sPPlot.do_wide=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_30, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "0", szBuffer,
			BUFFER_SIZE, szIniFile);
		sPPlot.x_offset=(float)atof(szBuffer);
		LoadString(hInst, IDS_INI_KEY_31, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "1", szBuffer, BUFFER_SIZE,
			szIniFile);
		sPPlot.x_mult=(float)atof(szBuffer);
		LoadString(hInst, IDS_INI_KEY_32, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "0", szBuffer,
			BUFFER_SIZE, szIniFile);
		sPPlot.y_offset=(float)atof(szBuffer);
		LoadString(hInst, IDS_INI_KEY_33, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "1", szBuffer, BUFFER_SIZE,
			szIniFile);
		sPPlot.y_mult=(float)atof(szBuffer);
		LoadString(hInst, IDS_INI_KEY_34, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "0", szBuffer, BUFFER_SIZE,
			szIniFile);
		sPPlot.y_min=(float)atof(szBuffer);
		LoadString(hInst, IDS_INI_KEY_35, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "1", szBuffer, BUFFER_SIZE,
			szIniFile);
		sPPlot.y_max=(float)atof(szBuffer);
		// Crude protection against bad scale
		if(sPPlot.y_max<=sPPlot.y_min)
		{
			sPPlot.y_max=1.0;
			sPPlot.y_min=0.0;
		}
		LoadString(hInst, IDS_INI_KEY_61, szKey, BUFFER_SIZE);
		sPPlot.do_fit=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		// Get phase data plot x-axis label #
		LoadString(hInst, IDS_INI_KEY_84, szKey, BUFFER_SIZE);
		nPPlotX=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		if(nPPlotX<0 || nPPlotX>(NUM_X_SCALES))
		{
			nPPlotX=0;
		}
		// Get phase plot x-axis scale default flag
		LoadString(hInst, IDS_INI_KEY_97, szKey, BUFFER_SIZE);
		bPXDefault=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
	}

	// [SigmaPlot] section
	if( (nSection==INI_SIGMA) || (nSection==INI_ALL && bUseSigmaPlotIni) )
	{
		LoadString(hInst, IDS_INI_SECTION_5, szSection, BUFFER_SIZE);
		// Note: These have no effect unless UseSigmaPlotIni=1
		LoadString(hInst, IDS_INI_KEY_16, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", sSPlot.title, TITLESIZE,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_17, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", sSPlot.subtitle,
			SUBTITLESIZE, szIniFile);
		LoadString(hInst, IDS_INI_KEY_18, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", sSPlot.message_str,
			MESSAGESIZE, szIniFile);
		LoadString(hInst, IDS_INI_KEY_19, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", sSPlot.x_label,
			XLABELSIZE, szIniFile);
		LoadString(hInst, IDS_INI_KEY_20, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", sSPlot.left_y_label,
			YLABELSIZE, szIniFile);
		LoadString(hInst, IDS_INI_KEY_21, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", sSPlot.plot_filename,
			FILENAMESIZE, szIniFile);
		// If there was no plot filename in ini file, use default
		if(strcmp(sSPlot.plot_filename, "")==0)
		{
			strlcpy(szStabFile, szDrive, FILE_NAME_SIZE);
			strlcat(szStabFile, szDirectory, FILE_NAME_SIZE);
			strlcat(szStabFile, "SIGMA.TKF", FILE_NAME_SIZE);
		}
		LoadString(hInst, IDS_INI_KEY_57, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", szStabFile,
			FILENAMESIZE, szIniFile);
		// If there was no stability filename in ini file, use default
		if(strcmp(szStabFile, "")==0)
		{
			strlcpy(szStabFile, szDrive, FILE_NAME_SIZE);
			strlcat(szStabFile, szDirectory, FILE_NAME_SIZE);
			strlcat(szStabFile, "SIGMA.TAU", FILE_NAME_SIZE);
		}
		LoadString(hInst, IDS_INI_KEY_22, szKey, BUFFER_SIZE);
		sSPlot.position=GetPrivateProfileInt(szSection, szKey, 0,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_99, szKey, BUFFER_SIZE);
		sSPlot.table_position=GetPrivateProfileInt(szSection, szKey, 1,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_36, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", szBuffer, BUFFER_SIZE,
			szIniFile);
		sSPlot.x_max=(float)atof(szBuffer);
		LoadString(hInst, IDS_INI_KEY_37, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", szBuffer, BUFFER_SIZE,
			szIniFile);
		sSPlot.x_min=(float)atof(szBuffer);
		LoadString(hInst, IDS_INI_KEY_35, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", szBuffer, BUFFER_SIZE,
			szIniFile);
		sSPlot.y_max=(float)atof(szBuffer);
		LoadString(hInst, IDS_INI_KEY_34, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", szBuffer, BUFFER_SIZE,
			szIniFile);
		sSPlot.y_min=(float)atof(szBuffer);
		LoadString(hInst, IDS_INI_KEY_28, szKey, BUFFER_SIZE);
		sSPlot.do_date=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_29, szKey, BUFFER_SIZE);
		sSPlot.do_box=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_88, szKey, BUFFER_SIZE);
		sSPlot.do_wide=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_59, szKey, BUFFER_SIZE);
		sSPlot.do_table=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_60, szKey, BUFFER_SIZE);
		sSPlot.do_errbar=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_61, szKey, BUFFER_SIZE);
		sSPlot.do_fit=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
	}

	// [SpectPlot] section
	// Note:  See also three items in [Preferences]
	if( (nSection==INI_SPECT) || (nSection==INI_ALL && bUseSpectPlotIni) )
	{
		LoadString(hInst, IDS_INI_SECTION_6, szSection, BUFFER_SIZE);
		// Note: These have no effect unless UseSpectPlotIni=1
		LoadString(hInst, IDS_INI_KEY_16, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", sPSPlot.title,
			TITLESIZE, szIniFile);
		LoadString(hInst, IDS_INI_KEY_17, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", sPSPlot.subtitle,
			SUBTITLESIZE, szIniFile);
		LoadString(hInst, IDS_INI_KEY_18, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", sPSPlot.message_str,
			MESSAGESIZE, szIniFile);
		LoadString(hInst, IDS_INI_KEY_22, szKey, BUFFER_SIZE);
		sPSPlot.position=GetPrivateProfileInt(szSection, szKey, 0,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_88, szKey, BUFFER_SIZE);
		sPSPlot.do_wide=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_25, szKey, BUFFER_SIZE);
		sPSPlot.y_tic=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_90, szKey, BUFFER_SIZE);
		sPSPlot.do_table=GetPrivateProfileInt(szSection, szKey, 1, szIniFile);
		LoadString(hInst, IDS_INI_KEY_28, szKey, BUFFER_SIZE);
		sPSPlot.do_date=GetPrivateProfileInt(szSection, szKey, 1, szIniFile);
		LoadString(hInst, IDS_INI_KEY_29, szKey, BUFFER_SIZE);
		sPSPlot.do_box=GetPrivateProfileInt(szSection, szKey, 1, szIniFile);
		LoadString(hInst, IDS_INI_KEY_61, szKey, BUFFER_SIZE);
		sPSPlot.do_line=GetPrivateProfileInt(szSection, szKey, 1, szIniFile);
		LoadString(hInst, IDS_INI_KEY_91, szKey, BUFFER_SIZE);
		sPSPlot.do_errbar=GetPrivateProfileInt(szSection, szKey, 1, szIniFile);
		LoadString(hInst, IDS_INI_KEY_93, szKey, BUFFER_SIZE);
		sPSPlot.plotype=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_94, szKey, BUFFER_SIZE);
		sPSPlot.win=GetPrivateProfileInt(szSection, szKey, 1, szIniFile);
		LoadString(hInst, IDS_INI_KEY_95, szKey, BUFFER_SIZE);
		sPSPlot.num=GetPrivateProfileInt(szSection, szKey, 1, szIniFile);
		LoadString(hInst, IDS_INI_KEY_27, szKey, BUFFER_SIZE);
		sPSPlot.do_mouse=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_133, szKey, BUFFER_SIZE);
		sPSPlot.do_spur=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_34, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", szBuffer, BUFFER_SIZE,
			szIniFile);
		sPSPlot.y_min=(float)atof(szBuffer);
		LoadString(hInst, IDS_INI_KEY_35, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", szBuffer, BUFFER_SIZE,
			szIniFile);
		sPSPlot.y_max=(float)atof(szBuffer);
		LoadString(hInst, IDS_INI_KEY_92, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", szBuffer, BUFFER_SIZE,
			szIniFile);
		sPSPlot.carrier=(float)atof(szBuffer);
	}

	// [HistoPlot] section
	if( (nSection==INI_HISTO) || (nSection==INI_ALL && bUseHistoPlotIni) )
	{
		LoadString(hInst, IDS_INI_SECTION_7, szSection, BUFFER_SIZE);
		// Note: These have no effect unless UseHistoPlotIni=1
		LoadString(hInst, IDS_INI_KEY_16, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", sHPlot.title, TITLESIZE,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_17, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", sHPlot.subtitle,
			SUBTITLESIZE, szIniFile);
		LoadString(hInst, IDS_INI_KEY_18, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", sHPlot.message_str,
			MESSAGESIZE, szIniFile);
		LoadString(hInst, IDS_INI_KEY_22, szKey, BUFFER_SIZE);
		sHPlot.position=GetPrivateProfileInt(szSection, szKey, 0,
			szIniFile);
	}

	// [AutoPlot] section
	if( (nSection==INI_AUTO) || (nSection==INI_ALL && bUseAutoPlotIni) )
	{
		LoadString(hInst, IDS_INI_SECTION_16, szSection, BUFFER_SIZE);
		// Note: These have no effect unless UseAutoPlotIni=1
		LoadString(hInst, IDS_INI_KEY_16, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", sAPlot.title,
			TITLESIZE, szIniFile);
		LoadString(hInst, IDS_INI_KEY_17, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", sAPlot.subtitle,
			SUBTITLESIZE, szIniFile);
		LoadString(hInst, IDS_INI_KEY_18, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", sAPlot.message_str,
			MESSAGESIZE, szIniFile);
		LoadString(hInst, IDS_INI_KEY_22, szKey, BUFFER_SIZE);
		sAPlot.position=GetPrivateProfileInt(szSection, szKey, 0,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_88, szKey, BUFFER_SIZE);
		sAPlot.do_wide=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_28, szKey, BUFFER_SIZE);
		sAPlot.do_date=GetPrivateProfileInt(szSection, szKey, 1, szIniFile);
		LoadString(hInst, IDS_INI_KEY_29, szKey, BUFFER_SIZE);
		sAPlot.do_box=GetPrivateProfileInt(szSection, szKey, 1, szIniFile);
		sAPlot.do_line=GetPrivateProfileInt(szSection, "Zero", 1, szIniFile);
		sAPlot.do_table=GetPrivateProfileInt(szSection, "Lag1", 1, szIniFile);
		sAPlot.win=GetPrivateProfileInt(szSection, "Lag#", 1, szIniFile);
		sAPlot.num=GetPrivateProfileInt(szSection, "Lags", 1, szIniFile);
		LoadString(hInst, IDS_INI_KEY_27, szKey, BUFFER_SIZE);
		sAPlot.do_mouse=GetPrivateProfileInt(szSection, szKey, 0, szIniFile);
		LoadString(hInst, IDS_INI_KEY_21, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", sAPlot.plot_filename,
			FILE_NAME_SIZE, szIniFile);
		GetPrivateProfileString(szSection, "AutoFile", "", szAutoFile,
			FILE_NAME_SIZE, szIniFile);
		sAPlot.af=GetPrivateProfileInt(szSection, "AF", 1, szIniFile);
	}

	// [DAVARPlot] section
	if( (nSection==INI_DAVAR) || (nSection==INI_ALL && bUseDAVARPlotIni) )
	{
		LoadString(hInst, IDS_INI_SECTION_17, szSection, BUFFER_SIZE);
		// Note: These have no effect unless UseDAVARPlotIni=1
		LoadString(hInst, IDS_INI_KEY_16, szKey, BUFFER_SIZE);

		GetPrivateProfileString(szSection, szKey, "", sDPlot.title, TITLESIZE,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_17, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", sDPlot.subtitle,
			SUBTITLESIZE, szIniFile);
		LoadString(hInst, IDS_INI_KEY_18, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", sDPlot.message_str,
			5*MESSAGESIZE, szIniFile);
		LoadString(hInst, IDS_INI_KEY_22, szKey, BUFFER_SIZE);
		sDPlot.position=GetPrivateProfileInt(szSection, szKey, 0,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_28, szKey, BUFFER_SIZE);
		sDPlot.do_date=GetPrivateProfileInt(szSection, szKey, 0,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_29, szKey, BUFFER_SIZE);
		sDPlot.do_box=GetPrivateProfileInt(szSection, szKey, 0,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_112, szKey, BUFFER_SIZE);
		sDPlot.colors=GetPrivateProfileInt(szSection, szKey, 0,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_115, szKey, BUFFER_SIZE);
		sDPlot.grid=GetPrivateProfileInt(szSection, szKey, 1,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_62, szKey, BUFFER_SIZE);
		sDPlot.vartype=GetPrivateProfileInt(szSection, szKey, 0,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_110, szKey, BUFFER_SIZE);
		sDPlot.winsize=GetPrivateProfileInt(szSection, szKey, 100,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_111, szKey, BUFFER_SIZE);
		sDPlot.stepsize=GetPrivateProfileInt(szSection, szKey, 10,
			szIniFile);
	}

	// [FreqLines] section
	if( (nSection==INI_FLINE) || (nSection==INI_ALL && bUseFreqPlotIni) )
	{
		LoadString(hInst, IDS_INI_SECTION_8, szSection, BUFFER_SIZE);

		// Loop thru all lines, getting their parameters
		for(i=0; i<FLINE_NUMLINES; i++)
		{
			// Store line # string in its buffer with a ']' after it
			itoa(i+1, szNum, 10);
			strlcat(szNum, "]", sizeof(szNum));

			// Line type
			// Defaults to 0, tested for between 0-5
			LoadString(hInst, IDS_INI_KEY_38, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szNum));
			sFLine[i].nLineType=GetPrivateProfileInt(szSection, szKey, 0,
				szIniFile);
			// nLineType must be between 0 and 5
			if( (sFLine[i].nLineType<0) || (sFLine[i].nLineType>5) )
			{
				sFLine[i].nLineType=0;
			}

			// Line coordinates
			// All default to 0, no value test
			LoadString(hInst, IDS_INI_KEY_39, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			GetPrivateProfileString(szSection, szKey, "0", szBuffer,
				BUFFER_SIZE, szIniFile);
			sFLine[i].fXStart=(F_TYPE)atof(szBuffer);
			LoadString(hInst, IDS_INI_KEY_40, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			GetPrivateProfileString(szSection, szKey, "0", szBuffer,
				BUFFER_SIZE, szIniFile);
			sFLine[i].fXEnd=(F_TYPE)atof(szBuffer);
			LoadString(hInst, IDS_INI_KEY_41, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			GetPrivateProfileString(szSection, szKey, "0", szBuffer,
				BUFFER_SIZE, szIniFile);
			sFLine[i].fYStart=(F_TYPE)atof(szBuffer);
			LoadString(hInst, IDS_INI_KEY_42, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			GetPrivateProfileString(szSection, szKey, "0", szBuffer,
				BUFFER_SIZE, szIniFile);
			sFLine[i].fYEnd=(F_TYPE)atof(szBuffer);

			// Line slope
			// Defaults to 0, tested for between 0-5
			LoadString(hInst, IDS_INI_KEY_43, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			sFLine[i].nSlope=GetPrivateProfileInt(szSection, szKey, 0,
				szIniFile);
			// Line slope must be between 0 and 5
			if( (sFLine[i].nSlope<0) || (sFLine[i].nSlope>5) )
			{
				sFLine[i].nSlope=0;
			}
		}
	}

	// [PhaseLines] section
	if( (nSection==INI_PLINE) || (nSection==INI_ALL && bUsePhasePlotIni) )
	{
		LoadString(hInst, IDS_INI_SECTION_9, szSection, BUFFER_SIZE);

		// Loop thru all lines, getting their parameters
		for(i=0; i<PLINE_NUMLINES; i++)
		{
			// Store line # string in its buffer with a ']' after it
			itoa(i+1, szNum, 10);
			strlcat(szNum, "]", sizeof(szNum));

			// Line type
			// Defaults to 0, tested for between 0-5
			LoadString(hInst, IDS_INI_KEY_38, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szNum));
			sPLine[i].nLineType=GetPrivateProfileInt(szSection, szKey, 0,
				szIniFile);
			// nLineType must be between 0 and 5
			if( (sPLine[i].nLineType<0) || (sPLine[i].nLineType>5) )
			{
				sPLine[i].nLineType=0;
			}

			// Line coordinates
			// All default to 0, no value test
			LoadString(hInst, IDS_INI_KEY_39, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			GetPrivateProfileString(szSection, szKey, "0", szBuffer,
				BUFFER_SIZE, szIniFile);
			sPLine[i].fXStart=(F_TYPE)atof(szBuffer);
			LoadString(hInst, IDS_INI_KEY_40, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			GetPrivateProfileString(szSection, szKey, "0", szBuffer,
				BUFFER_SIZE, szIniFile);
			sPLine[i].fXEnd=(F_TYPE)atof(szBuffer);
			LoadString(hInst, IDS_INI_KEY_41, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			GetPrivateProfileString(szSection, szKey, "0", szBuffer,
				BUFFER_SIZE, szIniFile);
			sPLine[i].fYStart=(F_TYPE)atof(szBuffer);
			LoadString(hInst, IDS_INI_KEY_42, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			GetPrivateProfileString(szSection, szKey, "0", szBuffer,
				BUFFER_SIZE, szIniFile);
			sPLine[i].fYEnd=(F_TYPE)atof(szBuffer);

			// Line slope
			// Defaults to 0, tested for between 0-5
			LoadString(hInst, IDS_INI_KEY_43, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			sPLine[i].nSlope=GetPrivateProfileInt(szSection, szKey, 0,
				szIniFile);
			// Line slope must be between 0 and 5
			if( (sPLine[i].nSlope<0) || (sPLine[i].nSlope>5) )
			{
				sPLine[i].nSlope=0;
			}
		}
	}

	// [SigmaLines] section
	if( (nSection==INI_SLINE) || (nSection==INI_ALL && bUseSigmaPlotIni) )
	{
		LoadString(hInst, IDS_INI_SECTION_10, szSection, BUFFER_SIZE);

		// Loop thru all lines, getting their parameters
		for(i=0; i<SLINE_NUMLINES; i++)
		{
			// Store line # string in its buffer with a ']' after it
			itoa(i+1, szNum, 10);
			strlcat(szNum, "]", sizeof(szNum));

			// Line type
			// Defaults to 0, tested for between 0-5
			LoadString(hInst, IDS_INI_KEY_38, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			sSLine[i].nLineType=GetPrivateProfileInt(szSection, szKey, 0,
				szIniFile);
			// nLineType must be between 0 and 7
			if( (sSLine[i].nLineType<0) || (sSLine[i].nLineType>7) )
			{
				sSLine[i].nLineType=0;
			}

			// Line coordinates
			// All default to 0, no value test
			LoadString(hInst, IDS_INI_KEY_39, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			GetPrivateProfileString(szSection, szKey, "0", szBuffer,
				BUFFER_SIZE, szIniFile);
			sSLine[i].fXStart=(F_TYPE)atof(szBuffer);
			LoadString(hInst, IDS_INI_KEY_40, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			GetPrivateProfileString(szSection, szKey, "0", szBuffer,
				BUFFER_SIZE, szIniFile);
			sSLine[i].fXEnd=(F_TYPE)atof(szBuffer);
			LoadString(hInst, IDS_INI_KEY_41, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			GetPrivateProfileString(szSection, szKey, "0", szBuffer,
				BUFFER_SIZE, szIniFile);
			sSLine[i].fYStart=(F_TYPE)atof(szBuffer);
			LoadString(hInst, IDS_INI_KEY_42, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			GetPrivateProfileString(szSection, szKey, "0", szBuffer,
				BUFFER_SIZE, szIniFile);
			sSLine[i].fYEnd=(F_TYPE)atof(szBuffer);

			// Line slope
			// Defaults to 0, tested for between 0-5
			LoadString(hInst, IDS_INI_KEY_43, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			sSLine[i].nSlope=GetPrivateProfileInt(szSection, szKey, 0,
				szIniFile);
			// Line slope must be between 0 and 5
			if( (sSLine[i].nSlope<0) || (sSLine[i].nSlope>5) )
			{
				sSLine[i].nSlope=0;
			}

			// Mask file
			// Defaults to blank string
			LoadString(hInst, IDS_INI_KEY_109, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			GetPrivateProfileString(szSection, szKey, "", sSLine[i].szMaskFile,
				BUFFER_SIZE, szIniFile);
		}
	}

	// [FreqNotes] section
	if( (nSection==INI_FNOTE) || (nSection==INI_ALL && bUseFreqPlotIni) )
	{
		LoadString(hInst, IDS_INI_SECTION_11, szSection, BUFFER_SIZE);

		// Loop thru all lines, getting their parameters
		for(i=0; i<FNOTE_NUMNOTES; i++)
		{
			// Store line # string in its buffer with a ']' after it
			itoa(i+1, szNum, 10);
			strlcat(szNum, "]", sizeof(szNum));

			// Size
			LoadString(hInst, IDS_INI_KEY_44, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			sFNote[i].nSize=GetPrivateProfileInt(szSection, szKey, 8,
				szIniFile);
			// nSize must be > 0
			if(sFNote[i].nSize<=0)
			{
				sFNote[i].nSize=8;
			}

			// Border flag
			LoadString(hInst, IDS_INI_KEY_45, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			sFNote[i].bBorder=(BOOL)GetPrivateProfileInt(szSection, szKey, 1,
				szIniFile);

			// Opaque flag
			LoadString(hInst, IDS_INI_KEY_106, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			sFNote[i].bOpaque=(BOOL)GetPrivateProfileInt(szSection, szKey, 1,
				szIniFile);

			// Note position
			// All default to 0, no value test
			LoadString(hInst, IDS_INI_KEY_46, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			GetPrivateProfileString(szSection, szKey, "0", szBuffer,
				BUFFER_SIZE, szIniFile);
			sFNote[i].fX=(F_TYPE)atof(szBuffer);

			LoadString(hInst, IDS_INI_KEY_47, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			GetPrivateProfileString(szSection, szKey, "0", szBuffer,
				BUFFER_SIZE, szIniFile);
			sFNote[i].fY=(F_TYPE)atof(szBuffer);

			// Text
			// Defaults to blank
			LoadString(hInst, IDS_INI_KEY_48, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			GetPrivateProfileString(szSection, szKey, "", sFNote[i].szText,
				BUFFER_SIZE, szIniFile);
		}
	}

	// [PhaseNotes] section
	if( (nSection==INI_PNOTE) || (nSection==INI_ALL && bUsePhasePlotIni) )
	{
		LoadString(hInst, IDS_INI_SECTION_12, szSection, BUFFER_SIZE);

		// Loop thru all lines, getting their parameters
		for(i=0; i<PNOTE_NUMNOTES; i++)
		{
			// Store line # string in its buffer with a ']' after it
			itoa(i+1, szNum, 10);
			strlcat(szNum, "]", sizeof(szNum));

			// Size
			LoadString(hInst, IDS_INI_KEY_44, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			sPNote[i].nSize=GetPrivateProfileInt(szSection, szKey, 8,
				szIniFile);
			// nSize must be > 0
			if(sPNote[i].nSize<=0)
			{
				sPNote[i].nSize=8;
			}

			// Border flag
			LoadString(hInst, IDS_INI_KEY_45, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			sPNote[i].bBorder=(BOOL)GetPrivateProfileInt(szSection, szKey, 1,
				szIniFile);

			// Opaque flag
			LoadString(hInst, IDS_INI_KEY_106, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			sPNote[i].bOpaque=(BOOL)GetPrivateProfileInt(szSection, szKey, 1,
				szIniFile);

			// Note position
			// All default to 0, no value test
			LoadString(hInst, IDS_INI_KEY_46, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			GetPrivateProfileString(szSection, szKey, "0", szBuffer,
				BUFFER_SIZE, szIniFile);
			sPNote[i].fX=(F_TYPE)atof(szBuffer);

			LoadString(hInst, IDS_INI_KEY_47, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			GetPrivateProfileString(szSection, szKey, "0", szBuffer,
				BUFFER_SIZE, szIniFile);
			sPNote[i].fY=(F_TYPE)atof(szBuffer);

			// Text
			// Defaults to blank
			LoadString(hInst, IDS_INI_KEY_48, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			GetPrivateProfileString(szSection, szKey, "", sPNote[i].szText,
				BUFFER_SIZE, szIniFile);
		}
	}

	// [SigmaNotes] section
	if( (nSection==INI_SNOTE) || (nSection==INI_ALL && bUseSigmaPlotIni) )
	{
		LoadString(hInst, IDS_INI_SECTION_13, szSection, BUFFER_SIZE);

		// Loop thru all lines, getting their parameters
		for(i=0; i<SNOTE_NUMNOTES; i++)
		{
			// Store line # string in its buffer with a ']' after it
			itoa(i+1, szNum, 10);
			strlcat(szNum, "]", sizeof(szNum));

			// Size
			LoadString(hInst, IDS_INI_KEY_44, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			sSNote[i].nSize=GetPrivateProfileInt(szSection, szKey, 8,
				szIniFile);
			// nSize must be > 0
			if(sSNote[i].nSize<=0)
			{
				sSNote[i].nSize=8;
			}

			// Border flag
			LoadString(hInst, IDS_INI_KEY_45, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			sSNote[i].bBorder=(BOOL)GetPrivateProfileInt(szSection, szKey, 1,
				szIniFile);

			// Opaque flag
			LoadString(hInst, IDS_INI_KEY_106, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			sSNote[i].bOpaque=(BOOL)GetPrivateProfileInt(szSection, szKey, 1,
				szIniFile);

			// Note position
			// All default to 0, no value test
			LoadString(hInst, IDS_INI_KEY_46, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			GetPrivateProfileString(szSection, szKey, "0", szBuffer,
				BUFFER_SIZE, szIniFile);
			sSNote[i].fX=(F_TYPE)atof(szBuffer);

			LoadString(hInst, IDS_INI_KEY_47, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			GetPrivateProfileString(szSection, szKey, "0", szBuffer,
				BUFFER_SIZE, szIniFile);
			sSNote[i].fY=(F_TYPE)atof(szBuffer);

			// Text
			// Defaults to blank
			LoadString(hInst, IDS_INI_KEY_48, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			GetPrivateProfileString(szSection, szKey, "", sSNote[i].szText,
				BUFFER_SIZE, szIniFile);
		}
	}

	// [Toolbuttons] section
	if(nSection==INI_TOOLS || nSection==INI_ALL)
	{
		LoadString(hInst, IDS_INI_SECTION_14, szSection, BUFFER_SIZE);
		for(i=0; i<NUM_TOOLS; i++)
		{
			tb[i].show_flag=GetPrivateProfileInt(szSection, tb[i].label, 1,
				szIniFile);
		}
	}

	// {Inputs) section (Read only)
	if(nSection==INI_INPUTS || nSection==INI_ALL)
	{
		LoadString(hInst, IDS_INI_SECTION_15, szSection, BUFFER_SIZE);

		// Phase & freq tau values
		// Both default to 1.0 and are forced to be positive
		// Flag set when default value is used

		LoadString(hInst, IDS_INI_KEY_49, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "Default", szBuffer,
			BUFFER_SIZE, szIniFile);
		if(strcmp(szBuffer, "Default")==0)
		{
			bPhaseTauDefault=TRUE;
			fPhaseTauInput=1.0;
		}
		else
		{
			bPhaseTauDefault=FALSE;
			fPhaseTauInput=(F_TYPE)fabs(atof(szBuffer));
		}
		LoadString(hInst, IDS_INI_KEY_50, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "Default", szBuffer,
			BUFFER_SIZE, szIniFile);
		if(strcmp(szBuffer, "Default")==0)
		{
			bFreqTauDefault=TRUE;
			fFreqTauInput=1.0;
		}
		else
		{
			bFreqTauDefault=FALSE;
			fFreqTauInput=(F_TYPE)fabs(atof(szBuffer));
		}

		// Phase & freq scale addend values
		// Both default to 0.0
		LoadString(hInst, IDS_INI_KEY_51, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "0.0", szBuffer,
			BUFFER_SIZE, szIniFile);
		fPhaseAddendInput=(F_TYPE)atof(szBuffer);
		LoadString(hInst, IDS_INI_KEY_52, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "0.0", szBuffer,
			BUFFER_SIZE, szIniFile);
		fFreqAddendInput=(F_TYPE)(atof(szBuffer));

		// Phase & freq scale multiplier values
		// Both default to 1.0
		LoadString(hInst, IDS_INI_KEY_53, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "1.0", szBuffer,
			BUFFER_SIZE, szIniFile);
		fPhaseMultiplierInput=(F_TYPE)atof(szBuffer);
		LoadString(hInst, IDS_INI_KEY_54, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "1.0", szBuffer,
			BUFFER_SIZE, szIniFile);
		fFreqMultiplierInput=(F_TYPE)atof(szBuffer);
		// Phase timetag scale multiplier value: TagScale
		// Defaults to 1.0
		LoadString(hInst, IDS_INI_KEY_83, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "1.0", szBuffer,
			BUFFER_SIZE, szIniFile);
		fPhaseTagScale=(F_TYPE)atof(szBuffer);
		// Freq timetag scale multiplier value: TagScale
		// Defaults to 1.0
		LoadString(hInst, IDS_INI_KEY_98, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "1.0", szBuffer,
			BUFFER_SIZE, szIniFile);
		fFreqTagScale=(F_TYPE)atof(szBuffer);
		// Phase timetag scale offset value: TagOffset
		// Defaults to 0.0
		LoadString(hInst, IDS_INI_KEY_101, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "0.0", szBuffer,
			BUFFER_SIZE, szIniFile);
		fPhaseTagOffset=(F_TYPE)atof(szBuffer);
		// Freq timetag scale offset value: TagOffset
		// Defaults to 0.0
		LoadString(hInst, IDS_INI_KEY_102, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "0.0", szBuffer,
			BUFFER_SIZE, szIniFile);
		fFreqTagOffset=(F_TYPE)atof(szBuffer);
	}

	// [Audio] section
	if(nSection==INI_AUDIO || nSection==INI_ALL)
	{
		LoadString(hInst, IDS_INI_SECTION_18, szSection, BUFFER_SIZE);

		// Get SampleRate
		LoadString(hInst, IDS_INI_KEY_125, szKey, BUFFER_SIZE);
		nSampleRate=GetPrivateProfileInt(szSection, szKey, 11025, szIniFile);

		// Get szAudioPlayer
		LoadString(hInst, IDS_INI_KEY_126, szKey, BUFFER_SIZE);
		GetPrivateProfileString(szSection, szKey, "", szAudioPlayer,
			FILE_NAME_SIZE, szIniFile);
	}
}

/*****************************************************************************/
/*                                                                           */
/*                              WriteIni()                                   */
/*                                                                           */
/*		Function to write configuration data to STABLE32.INI                 */
/*                                                                           */
/*      Revision record:                                                     */
/*      	08/24/96	Created                                              */
/*			10/14/96	Added ShowFileOpened item                            */
/*			10/27/96	Added LabelPlot item                                 */
/*			11/03/96	Added IncExtension item                              */
/*			11/06/96	Added WriteSigmaFile item                            */
/*			12/31/96	Added Sigma, Spect & Histo Plot items                */
/*			01/11/97	Added nSection parameter & tests                     */
/*			03/19/97	Added bAutoCalc & bAutoPlot items                    */
/*			04/27/97	Added x-div phase & freq plot items                  */
/*			12/19/97	Added code to write plot line & note items           */
/*						Changed section & key names to use stringtable       */
/*						to save DGROUP space                                 */
/*			12/21/97	Added writing of plot label                          */
/*			02/28/98	Added writing of bShowWelcome                        */
/*			03/21/98	Changed to global full ini filename                  */
/*			05/30/98	Added x & y-axis labels for stability plot           */
/*			07/20/98	Added box, date, table & errbar flags for            */
/*                      sigma plot                                           */
/*			01/14/99	Added global sigma, run & drift type items           */
/*			01/23/98	Added check, drift & sigma details & wide edit       */
/*						Added NormFreq & XferTags flags for convert          */
/*			02/04/99	Added NonNums for # non-numerics skipped in data     */
/*			12/11/99	Added bComma to handle Europeandeciaml point         */
/*			02/07/00	Added bWarnZeroFreq to warn re equal phase vals      */
/*			02/10/00	Added main window screen position vals               */
/*			02/19/00	Added bSmartScale flag                               */
/*			06/01/00	Added nPPlotX & nFPlotX data plot label #s           */
/*			09/08/00	Added bLastOpened=type of last data file opened      */
/*			09/09/00	Added bOpenScale flag                                */
/*			04/08/01	Added bHeader flag                                   */
/*			08/19/01	Added szCornFileA, B and C                           */
/*			02/02/02	Added several spectrum plot parameters               */
/*			03/24/02	Moved PPlotX & FPlotX to [PhasePlot] & [FreqPlot]    */
/*			05/10/02	Added FXDefault & PXDefault                          */
/*			06/21/02	Added sigma plot TablePos                            */
/*			01/21/03	Added bManyTau flag                                  */
/*			01/22/03	Added nManySize value                                */
/*			08/02/03	Added bOpaque for plot notes                         */
/*			08/07/03	Added AutoPlot                                       */
/*						Added bUseTags                                       */
/*			09/18/03	Added bACFNoiseID flag                               */
/*			11/16/05	Added DAVAR section                                  */
/*			11/29/05	Added Colors for DAVAR                               */
/*			12/05/05	Note: Database ini code in its own functions         */
/*			02/04/07	Added PSDAvgSize, PSDAvgMax, PSDLFSkip,              */
/*						PSDSmoothPPO, PSDLineWeight, Smooth                  */
/*			07/27/07	Added PointSize                                      */
/*			08/27/07	Added bZeroPad                                       */
/*			03/19/08	Added nFTag                                          */
/*			04/15/08	Added JumpMethod                                     */
/*			05/17/08	Added sPSPlot.limit                                  */
/*						Addec sPSPlot.do_spur                                */
/*                                                                           */
/*****************************************************************************/

void WriteIni(int nSection)
{
	// Local variables
	int i;						    // Index
	char szBuffer[BUFFER_SIZE+1];	// General text buffer
	char szSection[BUFFER_SIZE+1];  // Section name
	char szKey[BUFFER_SIZE+1];		// Key name
	char szNum[BUFFER_SIZE+1];		// Line number string

	// [Files] section
	if(nSection==INI_FILES || nSection==INI_ALL)
	{
		LoadString(hInst, IDS_INI_SECTION_0, szSection, BUFFER_SIZE);
		LoadString(hInst, IDS_INI_KEY_0, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szFile, szIniFile);
		WritePrivateProfileString(szSection, "A", szCornFileA, szIniFile);
		WritePrivateProfileString(szSection, "B", szCornFileB, szIniFile);
		WritePrivateProfileString(szSection, "C", szCornFileC, szIniFile);
	}

	// [Preferences] section
	if(nSection==INI_PREFS || nSection==INI_ALL)
	{
		LoadString(hInst, IDS_INI_SECTION_2, szSection, BUFFER_SIZE);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bShowFileOpened);
		LoadString(hInst, IDS_INI_KEY_2, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		if(bDataType)
		{
			strlcpy(szBuffer, "Freq", sizeof(szBuffer));
		}
		else // Phase data
		{
			strlcpy(szBuffer, "Phase", sizeof(szBuffer));
		}
		LoadString(hInst, IDS_INI_KEY_8, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		if(bLastOpened)
		{
			strlcpy(szBuffer, "Freq", sizeof(szBuffer));
		}
		else // Phase data
		{
			strlcpy(szBuffer, "Phase", sizeof(szBuffer));
		}
		LoadString(hInst, IDS_INI_KEY_86, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bUseFreqPlotIni);
		LoadString(hInst, IDS_INI_KEY_3, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer,
			szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bUsePhasePlotIni);
		LoadString(hInst, IDS_INI_KEY_4, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer,
			szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bUseSigmaPlotIni);
		LoadString(hInst, IDS_INI_KEY_5, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer,
			szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bUseHistoPlotIni);
		LoadString(hInst, IDS_INI_KEY_6, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer,
			szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bUseSpectPlotIni);
		LoadString(hInst, IDS_INI_KEY_7, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer,
			szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bUseAutoPlotIni);
		LoadString(hInst, IDS_INI_KEY_113, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer,
			szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bUseDAVARPlotIni);
		LoadString(hInst, IDS_INI_KEY_114, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer,
			szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bOpenScale);
		LoadString(hInst, IDS_INI_KEY_87, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer,
			szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bPlotLabel);
		LoadString(hInst, IDS_INI_KEY_9, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		LoadString(hInst, IDS_INI_KEY_10, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szPlotLabel, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bIncExtension);
		LoadString(hInst, IDS_INI_KEY_11, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer,
			szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bWriteSigmaFile);
		LoadString(hInst, IDS_INI_KEY_12, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer,
			szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bAutoCalc);
		LoadString(hInst, IDS_INI_KEY_13, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bAutoPlot);
		LoadString(hInst, IDS_INI_KEY_14, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", nMaxSize);
		LoadString(hInst, IDS_INI_KEY_55, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bShowWelcome);
		LoadString(hInst, IDS_INI_KEY_56, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", nGlobalSigmaType);
		LoadString(hInst, IDS_INI_KEY_62, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", nGlobalRunType);
		LoadString(hInst, IDS_INI_KEY_63, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", nTauIncrement);
		LoadString(hInst, IDS_INI_KEY_135, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", nGlobalPhaseDriftType);
		LoadString(hInst, IDS_INI_KEY_64, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", nGlobalFreqDriftType);
		LoadString(hInst, IDS_INI_KEY_65, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bCheckDetails);
		LoadString(hInst, IDS_INI_KEY_66, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bDriftDetails);
		LoadString(hInst, IDS_INI_KEY_67, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bSigmaDetails);
		LoadString(hInst, IDS_INI_KEY_68, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bWideEdit);
		LoadString(hInst, IDS_INI_KEY_69, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bGlobalNormFreq);
		LoadString(hInst, IDS_INI_KEY_70, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bGlobalXferTags);
		LoadString(hInst, IDS_INI_KEY_71, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", nSkipChar);
		LoadString(hInst, IDS_INI_KEY_72, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bTest);
		LoadString(hInst, IDS_INI_KEY_73, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bDetailedLog);
		LoadString(hInst, IDS_INI_KEY_100, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		// Save comma preference for European decimal point usage
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bComma);
		LoadString(hInst, IDS_INI_KEY_76, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		// Save zero freq warning preference
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bWarnZeroFreq);
		LoadString(hInst, IDS_INI_KEY_77, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		// Save smart scale preference
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bSmartScale);
		LoadString(hInst, IDS_INI_KEY_82, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		// Save ACD noise ID preference
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bACFNoiseID);
		LoadString(hInst, IDS_INI_KEY_108, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		// Save main window left position
		_snprintf(szBuffer, sizeof(szBuffer), "%d", nMainLeft);
		LoadString(hInst, IDS_INI_KEY_78, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		// Save main window top position
		_snprintf(szBuffer, sizeof(szBuffer), "%d", nMainTop);
		LoadString(hInst, IDS_INI_KEY_79, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		// Save main window right position
		_snprintf(szBuffer, sizeof(szBuffer), "%d", nMainRight);
		LoadString(hInst, IDS_INI_KEY_80, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		// Save main window bottom position
		_snprintf(szBuffer, sizeof(szBuffer), "%d", nMainBottom);
		LoadString(hInst, IDS_INI_KEY_81, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		// Save bHeader flag
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bHeader);
		LoadString(hInst, IDS_INI_KEY_89, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		// Save bManyTau flag
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bManyTau);
		LoadString(hInst, IDS_INI_KEY_103, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		// Save nManySize value
		_snprintf(szBuffer, sizeof(szBuffer), "%d", nManySize);
		LoadString(hInst, IDS_INI_KEY_104, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		// Save bUseTags flag
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bUseTags);
		LoadString(hInst, IDS_INI_KEY_107, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		// Save PSDAvgSize
		_snprintf(szBuffer, sizeof(szBuffer), "%d", nPSDAvgSize);
		LoadString(hInst, IDS_INI_KEY_116, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		// Save PSDAvgMax
		_snprintf(szBuffer, sizeof(szBuffer), "%d", nPSDAvgMax);
		LoadString(hInst, IDS_INI_KEY_117, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		// Save PSDLFSkip
		_snprintf(szBuffer, sizeof(szBuffer), "%d", nPSDLFSkip);
		LoadString(hInst, IDS_INI_KEY_118, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		// Save Point Size
		_snprintf(szBuffer, sizeof(szBuffer), "%d", nPointSize);
		LoadString(hInst, IDS_INI_KEY_124, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		// Save ZeroPad
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bZeroPad);
		LoadString(hInst, IDS_INI_KEY_129, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		// Note:  The next three sPSPlot items are considered preferences
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sPSPlot.smooth);
		// Save sPSPlot.smooth
		LoadString(hInst, IDS_INI_KEY_121, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		// Save sPSPlot.weight
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sPSPlot.weight);
		LoadString(hInst, IDS_INI_KEY_120, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		// Save sPSPlot.ppo
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sPSPlot.ppo);
		LoadString(hInst, IDS_INI_KEY_119, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		// Save sPSPlot.limit
		_snprintf(szBuffer, sizeof(szBuffer), "%2.0f", sPSPlot.limit);
		LoadString(hInst, IDS_INI_KEY_132, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		// Save bNoGreek flag
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bNoGreek);
		LoadString(hInst, IDS_INI_KEY_122, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		// Save bSplash flag
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bSplash);
		LoadString(hInst, IDS_INI_KEY_123, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		// Save szNotepad
		LoadString(hInst, IDS_INI_KEY_15, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szNotepad, szIniFile);
		// Save nFTag freq timetag type code
		_snprintf(szBuffer, sizeof(szBuffer), "%d", nFTag);
		LoadString(hInst, IDS_INI_KEY_130, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		// Plot style
		_snprintf(szBuffer, sizeof(szBuffer), "%d", nStyle);
		WritePrivateProfileString(szSection, "Style", szBuffer, szIniFile);
	}

	// [FreqPlot] section
	if( (nSection==INI_FREQ) || (nSection==INI_ALL && bUseFreqPlotIni) )
	{
		LoadString(hInst, IDS_INI_SECTION_3, szSection, BUFFER_SIZE);
		LoadString(hInst, IDS_INI_KEY_16, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, sFPlot.title, szIniFile);
		LoadString(hInst, IDS_INI_KEY_17, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, sFPlot.subtitle,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_18, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, sFPlot.message_str,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_19, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, sFPlot.x_label,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_20, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, sFPlot.left_y_label,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_21, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, sFPlot.plot_filename,
			szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sFPlot.position);
		LoadString(hInst, IDS_INI_KEY_22, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sFPlot.x_div);
		LoadString(hInst, IDS_INI_KEY_23, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sFPlot.y_div);
		LoadString(hInst, IDS_INI_KEY_24, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sFPlot.y_tic);
		LoadString(hInst, IDS_INI_KEY_25, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sFPlot.do_line);
		LoadString(hInst, IDS_INI_KEY_26, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sFPlot.do_mouse);
		LoadString(hInst, IDS_INI_KEY_27, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sFPlot.do_date);
		LoadString(hInst, IDS_INI_KEY_28, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sFPlot.do_box);
		LoadString(hInst, IDS_INI_KEY_29, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", sFPlot.x_offset);
		ShortenExp(szBuffer);
		LoadString(hInst, IDS_INI_KEY_30, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		if(sFPlot.x_mult)
		{
			_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", sFPlot.x_mult);
			ShortenExp(szBuffer);
		}
		else
		{
			_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", 1.0);
			ShortenExp(szBuffer);
		}
		LoadString(hInst, IDS_INI_KEY_31, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", sFPlot.y_offset);
		ShortenExp(szBuffer);
		LoadString(hInst, IDS_INI_KEY_32, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer,	szIniFile);
		if(sFPlot.y_mult)
		{
			_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", sFPlot.y_mult);
			ShortenExp(szBuffer);
		}
		else
		{
			_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", 1.0);
			ShortenExp(szBuffer);
		}
		LoadString(hInst, IDS_INI_KEY_33, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", sFPlot.y_min);
		ShortenExp(szBuffer);
		LoadString(hInst, IDS_INI_KEY_34, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", sFPlot.y_max);
		ShortenExp(szBuffer);
		LoadString(hInst, IDS_INI_KEY_35, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sFPlot.do_fit);
		LoadString(hInst, IDS_INI_KEY_61, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sFPlot.do_wide);
		LoadString(hInst, IDS_INI_KEY_88, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		// Save freq data plot x-axis label #
		if(nFPlotX<0 || nFPlotX>NUM_X_SCALES)
		{
			nFPlotX=0;
		}
		_snprintf(szBuffer, sizeof(szBuffer), "%d", nFPlotX);
		LoadString(hInst, IDS_INI_KEY_85, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bFXDefault);
		LoadString(hInst, IDS_INI_KEY_96, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		// Frequency jump detection method
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sFPlot.method);
		LoadString(hInst, IDS_INI_KEY_131, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
	}

	// [PhasePlot] section
	if( (nSection==INI_PHASE) || (nSection==INI_ALL && bUsePhasePlotIni) )
	{
		LoadString(hInst, IDS_INI_SECTION_4, szSection, BUFFER_SIZE);
		LoadString(hInst, IDS_INI_KEY_16, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, sPPlot.title,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_17, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, sPPlot.subtitle,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_18, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, sPPlot.message_str,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_19, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, sPPlot.x_label,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_20, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, sPPlot.left_y_label,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_21, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, sPPlot.plot_filename,
			szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sPPlot.position);
		LoadString(hInst, IDS_INI_KEY_22, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sPPlot.x_div);
		LoadString(hInst, IDS_INI_KEY_23, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sPPlot.y_div);
		LoadString(hInst, IDS_INI_KEY_24, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sPPlot.y_tic);
		LoadString(hInst, IDS_INI_KEY_25, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sPPlot.do_line);
		LoadString(hInst, IDS_INI_KEY_26, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sPPlot.do_mouse);
		LoadString(hInst, IDS_INI_KEY_27, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sPPlot.do_date);
		LoadString(hInst, IDS_INI_KEY_28, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sPPlot.do_box);
		LoadString(hInst, IDS_INI_KEY_29, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", sPPlot.x_offset);
		ShortenExp(szBuffer);
		LoadString(hInst, IDS_INI_KEY_30, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		if(sPPlot.x_mult)
		{
			_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", sPPlot.x_mult);
			ShortenExp(szBuffer);
		}
		else
		{
			_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", 1.0);
			ShortenExp(szBuffer);
		}
		LoadString(hInst, IDS_INI_KEY_31, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", sPPlot.y_offset);
		ShortenExp(szBuffer);
		LoadString(hInst, IDS_INI_KEY_32, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		if(sPPlot.y_mult)
		{
			_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", sPPlot.y_mult);
			ShortenExp(szBuffer);
		}
		else
		{
			_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", 1.0);
			ShortenExp(szBuffer);
		}
		LoadString(hInst, IDS_INI_KEY_33, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", sPPlot.y_min);
		ShortenExp(szBuffer);
		LoadString(hInst, IDS_INI_KEY_34, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", sPPlot.y_max);
		ShortenExp(szBuffer);
		LoadString(hInst, IDS_INI_KEY_35, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sPPlot.do_fit);
		LoadString(hInst, IDS_INI_KEY_61, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sPPlot.do_wide);
		LoadString(hInst, IDS_INI_KEY_88, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		// Save phase data plot x-axis label #
		if(nPPlotX<0 || nPPlotX>(NUM_X_SCALES-1))
		{
			nPPlotX=0;
		}
		_snprintf(szBuffer, sizeof(szBuffer), "%d", nPPlotX);
		LoadString(hInst, IDS_INI_KEY_84, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", bPXDefault);
		LoadString(hInst, IDS_INI_KEY_97, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
	}

	// [SigmaPlot] section
	if( (nSection==INI_SIGMA) || (nSection==INI_ALL && bUseSigmaPlotIni) )
	{
		LoadString(hInst, IDS_INI_SECTION_5, szSection, BUFFER_SIZE);
		LoadString(hInst, IDS_INI_KEY_16, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, sSPlot.title, szIniFile);
		LoadString(hInst, IDS_INI_KEY_17, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, sSPlot.subtitle,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_18, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, sSPlot.message_str,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_19, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, sSPlot.x_label,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_20, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, sSPlot.left_y_label,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_21, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, sSPlot.plot_filename,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_57, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szStabFile,
			szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sSPlot.position);
		LoadString(hInst, IDS_INI_KEY_22, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sSPlot.table_position);
		LoadString(hInst, IDS_INI_KEY_99, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", sSPlot.x_max);
		ShortenExp(szBuffer);
		LoadString(hInst, IDS_INI_KEY_36, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", sSPlot.x_min);
		ShortenExp(szBuffer);
		LoadString(hInst, IDS_INI_KEY_37, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", sSPlot.y_max);
		ShortenExp(szBuffer);
		LoadString(hInst, IDS_INI_KEY_35, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", sSPlot.y_min);
		ShortenExp(szBuffer);
		LoadString(hInst, IDS_INI_KEY_34, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sSPlot.do_date);
		LoadString(hInst, IDS_INI_KEY_28, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sSPlot.do_box);
		LoadString(hInst, IDS_INI_KEY_29, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sSPlot.do_table);
		LoadString(hInst, IDS_INI_KEY_59, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sSPlot.do_errbar);
		LoadString(hInst, IDS_INI_KEY_60, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sSPlot.do_fit);
		LoadString(hInst, IDS_INI_KEY_61, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sSPlot.do_wide);
		LoadString(hInst, IDS_INI_KEY_88, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
	}

	// [SpectPlot] section
	if( (nSection==INI_SPECT) || (nSection==INI_ALL && bUseSpectPlotIni) )
	{
		LoadString(hInst, IDS_INI_SECTION_6, szSection, BUFFER_SIZE);
		LoadString(hInst, IDS_INI_KEY_16, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, sPSPlot.title, szIniFile);
		LoadString(hInst, IDS_INI_KEY_17, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, sPSPlot.subtitle,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_18, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, sPSPlot.message_str,
			szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sPSPlot.position);
		LoadString(hInst, IDS_INI_KEY_22, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sPSPlot.do_wide);
		LoadString(hInst, IDS_INI_KEY_88, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sPSPlot.y_tic);
		LoadString(hInst, IDS_INI_KEY_25, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sPSPlot.do_date);
		LoadString(hInst, IDS_INI_KEY_28, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sPSPlot.do_box);
		LoadString(hInst, IDS_INI_KEY_29, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sPSPlot.do_line);
		LoadString(hInst, IDS_INI_KEY_61, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sPSPlot.do_errbar);
		LoadString(hInst, IDS_INI_KEY_91, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sPSPlot.plotype);
		LoadString(hInst, IDS_INI_KEY_93, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sPSPlot.win);
		LoadString(hInst, IDS_INI_KEY_94, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sPSPlot.num);
		LoadString(hInst, IDS_INI_KEY_95, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sPSPlot.do_mouse);
		LoadString(hInst, IDS_INI_KEY_27, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sPSPlot.do_table);
		LoadString(hInst, IDS_INI_KEY_90, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sPSPlot.do_spur);
		LoadString(hInst, IDS_INI_KEY_133, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		LoadString(hInst, IDS_INI_KEY_128, szKey, BUFFER_SIZE);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sPSPlot.smooth);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%e", sPSPlot.y_max);
		LoadString(hInst, IDS_INI_KEY_35, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%e", sPSPlot.y_min);
		LoadString(hInst, IDS_INI_KEY_34, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%e", sPSPlot.carrier);
		LoadString(hInst, IDS_INI_KEY_92, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		LoadString(hInst, IDS_INI_KEY_127, szKey, BUFFER_SIZE);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sPSPlot.af);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
	}

	// [HistoPlot] section
	if( (nSection==INI_HISTO) || (nSection==INI_ALL && bUseHistoPlotIni) )
	{
		LoadString(hInst, IDS_INI_SECTION_7, szSection, BUFFER_SIZE);
		LoadString(hInst, IDS_INI_KEY_16, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, sHPlot.title, szIniFile);
		LoadString(hInst, IDS_INI_KEY_17, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, sHPlot.subtitle,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_18, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, sHPlot.message_str,
			szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sHPlot.position);
		LoadString(hInst, IDS_INI_KEY_22, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
	}

	// [AutoPlot] section
	if( (nSection==INI_AUTO) || (nSection==INI_ALL && bUseAutoPlotIni) )
	{
		LoadString(hInst, IDS_INI_SECTION_16, szSection, BUFFER_SIZE);
		LoadString(hInst, IDS_INI_KEY_16, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, sAPlot.title, szIniFile);
		LoadString(hInst, IDS_INI_KEY_17, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, sAPlot.subtitle,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_18, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, sAPlot.message_str,
			szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sAPlot.position);
		LoadString(hInst, IDS_INI_KEY_22, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sAPlot.do_wide);
		LoadString(hInst, IDS_INI_KEY_88, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sAPlot.do_date);
		LoadString(hInst, IDS_INI_KEY_28, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sAPlot.do_box);
		LoadString(hInst, IDS_INI_KEY_29, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sAPlot.do_line);
		WritePrivateProfileString(szSection, "Zero", szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sAPlot.do_table);
		WritePrivateProfileString(szSection, "Lag1", szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sAPlot.win);
		WritePrivateProfileString(szSection, "Lag#", szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sAPlot.num);
		LoadString(hInst, IDS_INI_KEY_95, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, "Lags", szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sAPlot.do_mouse);
		LoadString(hInst, IDS_INI_KEY_27, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		WritePrivateProfileString(szSection, "AutoFile", szAutoFile,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_21, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, sAPlot.plot_filename,
			szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sAPlot.af);
		WritePrivateProfileString(szSection, "AF", szBuffer, szIniFile);
	}

	// [DAVARPlot] section
	if( (nSection==INI_DAVAR) || (nSection==INI_ALL && bUseDAVARPlotIni) )
	{
		LoadString(hInst, IDS_INI_SECTION_17, szSection, BUFFER_SIZE);
		LoadString(hInst, IDS_INI_KEY_16, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, sDPlot.title, szIniFile);
		LoadString(hInst, IDS_INI_KEY_17, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, sDPlot.subtitle,
			szIniFile);
		LoadString(hInst, IDS_INI_KEY_18, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, sDPlot.message_str,
			szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sDPlot.position);
		LoadString(hInst, IDS_INI_KEY_22, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sDPlot.do_date);
		LoadString(hInst, IDS_INI_KEY_28, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sDPlot.do_box);
		LoadString(hInst, IDS_INI_KEY_29, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sDPlot.colors);
		LoadString(hInst, IDS_INI_KEY_112, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sDPlot.grid);
		LoadString(hInst, IDS_INI_KEY_115, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sDPlot.vartype);
		LoadString(hInst, IDS_INI_KEY_62, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sDPlot.winsize);
		LoadString(hInst, IDS_INI_KEY_110, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", sDPlot.stepsize);
		LoadString(hInst, IDS_INI_KEY_111, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);
	}

	// [FreqLines] section
	if( (nSection==INI_FLINE) || (nSection==INI_ALL && bUseFreqPlotIni) )
	{
		// Assign section label
		LoadString(hInst, IDS_INI_SECTION_8, szSection, BUFFER_SIZE);

		for(i=0; i<FLINE_NUMLINES; i++)
		{
			// Store line # string in its buffer with a ']' after it
			itoa(i+1, szNum, 10);
			strlcat(szNum, "]", sizeof(szNum));

			// Write line type
			LoadString(hInst, IDS_INI_KEY_38, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			_snprintf(szBuffer, sizeof(szBuffer), "%d", sFLine[i].nLineType);
			WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);

			if(sFLine[i].nLineType==FLINE_NONE)
			{
				// Erase line parameters
				LoadString(hInst, IDS_INI_KEY_39, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey, NULL,
					szIniFile);
				LoadString(hInst, IDS_INI_KEY_40, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey, NULL,
					szIniFile);
				LoadString(hInst, IDS_INI_KEY_41, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey, NULL,
					szIniFile);
				LoadString(hInst, IDS_INI_KEY_42, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey, NULL,
					szIniFile);
				LoadString(hInst, IDS_INI_KEY_43, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey, NULL,
					szIniFile);
			}
			else
			{
				// Write line coordinates
				LoadString(hInst, IDS_INI_KEY_39, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
					sFLine[i].fXStart);
				ShortenExp(szBuffer);
				WritePrivateProfileString(szSection, szKey, szBuffer,
					szIniFile);
				LoadString(hInst, IDS_INI_KEY_40, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
					sFLine[i].fXEnd);
				ShortenExp(szBuffer);
				WritePrivateProfileString(szSection, szKey, szBuffer,
					szIniFile);
				LoadString(hInst, IDS_INI_KEY_41, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
					sFLine[i].fYStart);
				ShortenExp(szBuffer);
				WritePrivateProfileString(szSection, szKey, szBuffer,
					szIniFile);
				LoadString(hInst, IDS_INI_KEY_42, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
					sFLine[i].fYEnd);
				ShortenExp(szBuffer);
				WritePrivateProfileString(szSection, szKey, szBuffer,
					szIniFile);

				//  Write line slope
				LoadString(hInst, IDS_INI_KEY_43, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				_snprintf(szBuffer, sizeof(szBuffer), "%d", sFLine[i].nSlope);
				WritePrivateProfileString(szSection, szKey, szBuffer,
					szIniFile);
			}
		}
	}

	// [PhaseLines] section
	if( (nSection==INI_PLINE) || (nSection==INI_ALL && bUsePhasePlotIni) )
	{
		// Assign section label
		LoadString(hInst, IDS_INI_SECTION_9, szSection, BUFFER_SIZE);

		for(i=0; i<PLINE_NUMLINES; i++)
		{
			// Store line # string in its buffer with a ']' after it
			itoa(i+1, szNum, 10);
			strlcat(szNum, "]", sizeof(szNum));

			// Write line type
			LoadString(hInst, IDS_INI_KEY_38, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			_snprintf(szBuffer, sizeof(szBuffer), "%d", sPLine[i].nLineType);
			WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);

			if(sPLine[i].nLineType==PLINE_NONE)
			{
				// Erase line parameters
				LoadString(hInst, IDS_INI_KEY_39, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey, NULL,
					szIniFile);
				LoadString(hInst, IDS_INI_KEY_40, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey, NULL,
					szIniFile);
				LoadString(hInst, IDS_INI_KEY_41, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey, NULL,
					szIniFile);
				LoadString(hInst, IDS_INI_KEY_42, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey, NULL,
					szIniFile);
				LoadString(hInst, IDS_INI_KEY_43, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey, NULL,
					szIniFile);
			}
			else
			{
				// Write line coordinates
				LoadString(hInst, IDS_INI_KEY_39, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
					sPLine[i].fXStart);
				ShortenExp(szBuffer);
				WritePrivateProfileString(szSection, szKey, szBuffer,
					szIniFile);
				LoadString(hInst, IDS_INI_KEY_40, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
					sPLine[i].fXEnd);
				ShortenExp(szBuffer);
				WritePrivateProfileString(szSection, szKey, szBuffer,
					szIniFile);
				LoadString(hInst, IDS_INI_KEY_41, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
					sPLine[i].fYStart);
				ShortenExp(szBuffer);
				WritePrivateProfileString(szSection, szKey, szBuffer,
					szIniFile);
				LoadString(hInst, IDS_INI_KEY_42, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
					sPLine[i].fYEnd);
				ShortenExp(szBuffer);
				WritePrivateProfileString(szSection, szKey, szBuffer,
					szIniFile);

				//  Write line slope
				LoadString(hInst, IDS_INI_KEY_43, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				_snprintf(szBuffer, sizeof(szBuffer), "%d", sPLine[i].nSlope);
				WritePrivateProfileString(szSection, szKey, szBuffer,
					szIniFile);
			}
		}
	}

	// [SigmaLines] section
	if( (nSection==INI_SLINE) || (nSection==INI_ALL && bUseSigmaPlotIni) )
	{
		// Assign section label
		LoadString(hInst, IDS_INI_SECTION_10, szSection, BUFFER_SIZE);

		for(i=0; i<SLINE_NUMLINES; i++)
		{
			// Store line # string in its buffer with a ']' after it
			itoa(i+1, szNum, 10);
			strlcat(szNum, "]", sizeof(szNum));

			// Write line type
				LoadString(hInst, IDS_INI_KEY_38, szKey, BUFFER_SIZE);
			strlcat(szKey, szNum, sizeof(szKey));
			_snprintf(szBuffer, sizeof(szBuffer), "%d", sSLine[i].nLineType);
			WritePrivateProfileString(szSection, szKey, szBuffer, szIniFile);

			if(sSLine[i].nLineType==SLINE_NONE)
			{
				// Erase line parameters
				LoadString(hInst, IDS_INI_KEY_39, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey, NULL,
					szIniFile);
				LoadString(hInst, IDS_INI_KEY_40, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey, NULL,
					szIniFile);
				LoadString(hInst, IDS_INI_KEY_41, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey, NULL,
					szIniFile);
				LoadString(hInst, IDS_INI_KEY_42, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey, NULL,
					szIniFile);
				LoadString(hInst, IDS_INI_KEY_43, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey, NULL,
					szIniFile);
			}
			else
			{
				// Write line coordinates
				LoadString(hInst, IDS_INI_KEY_39, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
					sSLine[i].fXStart);
				ShortenExp(szBuffer);
				WritePrivateProfileString(szSection, szKey, szBuffer,
					szIniFile);
				LoadString(hInst, IDS_INI_KEY_40, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
					sSLine[i].fXEnd);
				ShortenExp(szBuffer);
				WritePrivateProfileString(szSection, szKey, szBuffer,
					szIniFile);
				LoadString(hInst, IDS_INI_KEY_41, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
					sSLine[i].fYStart);
				ShortenExp(szBuffer);
				WritePrivateProfileString(szSection, szKey, szBuffer,
					szIniFile);
				LoadString(hInst, IDS_INI_KEY_42, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
					sSLine[i].fYEnd);
				ShortenExp(szBuffer);
				WritePrivateProfileString(szSection, szKey, szBuffer,
					szIniFile);

				//  Write line slope
				LoadString(hInst, IDS_INI_KEY_43, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				_snprintf(szBuffer, sizeof(szBuffer), "%d", sSLine[i].nSlope);
				WritePrivateProfileString(szSection, szKey, szBuffer,
					szIniFile);

				// Write mask filename
				LoadString(hInst, IDS_INI_KEY_109, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey,
					sSLine[i].szMaskFile,
					szIniFile);
			}
		}
	}

	// [FreqNotes] section
	if( (nSection==INI_FNOTE) || (nSection==INI_ALL && bUseFreqPlotIni) )
	{
		// Assign section label
		LoadString(hInst, IDS_INI_SECTION_11, szSection, BUFFER_SIZE);

		for(i=0; i<FNOTE_NUMNOTES; i++)
		{
			// Store line # string in its buffer with a ']' after it
			itoa(i+1, szNum, 10);
			strlcat(szNum, "]", sizeof(szNum));

			if(strlen(sFNote[i].szText)==FNOTE_NONE)
			{
				// Erase note parameters
				LoadString(hInst, IDS_INI_KEY_44, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey, NULL, szIniFile);
				LoadString(hInst, IDS_INI_KEY_45, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey, NULL, szIniFile);
				LoadString(hInst, IDS_INI_KEY_46, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey, NULL, szIniFile);
				LoadString(hInst, IDS_INI_KEY_47, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey, NULL, szIniFile);
				LoadString(hInst, IDS_INI_KEY_48, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey, NULL, szIniFile);
			}
			else
			{
				// Write size
				LoadString(hInst, IDS_INI_KEY_44, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				_snprintf(szBuffer, sizeof(szBuffer), "%d", sFNote[i].nSize);
				WritePrivateProfileString(szSection, szKey, szBuffer,
					szIniFile);

				// Write border flag
				LoadString(hInst, IDS_INI_KEY_45, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				_snprintf(szBuffer, sizeof(szBuffer), "%d",
					(int)sFNote[i].bBorder);
				WritePrivateProfileString(szSection, szKey, szBuffer,
					szIniFile);

				// Write opaque flag
				LoadString(hInst, IDS_INI_KEY_106, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				_snprintf(szBuffer, sizeof(szBuffer), "%d",
					(int)sFNote[i].bOpaque);
				WritePrivateProfileString(szSection, szKey, szBuffer,
					szIniFile);

				// Write note position
				LoadString(hInst, IDS_INI_KEY_46, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
					sFNote[i].fX);
				ShortenExp(szBuffer);
				WritePrivateProfileString(szSection, szKey, szBuffer,
					szIniFile);
				LoadString(hInst, IDS_INI_KEY_47, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
					sFNote[i].fY);
				ShortenExp(szBuffer);
				WritePrivateProfileString(szSection, szKey, szBuffer,
					szIniFile);

				//  Write note text
				LoadString(hInst, IDS_INI_KEY_48, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey, sFNote[i].szText,
					szIniFile);
			}
		}
	}

	// [PhaseNotes] section
	if( (nSection==INI_PNOTE) || (nSection==INI_ALL && bUsePhasePlotIni) )
	{
		// Assign section label
		LoadString(hInst, IDS_INI_SECTION_12, szSection, BUFFER_SIZE);

		for(i=0; i<PNOTE_NUMNOTES; i++)
		{
			// Store line # string in its buffer with a ']' after it
			itoa(i+1, szNum, 10);
			strlcat(szNum, "]", sizeof(szNum));

			if(strlen(sPNote[i].szText)==PNOTE_NONE)
			{
				// Erase note parameters
				LoadString(hInst, IDS_INI_KEY_44, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey, NULL, szIniFile);
				LoadString(hInst, IDS_INI_KEY_45, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey, NULL, szIniFile);
				LoadString(hInst, IDS_INI_KEY_46, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey, NULL, szIniFile);
				LoadString(hInst, IDS_INI_KEY_47, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey, NULL, szIniFile);
				LoadString(hInst, IDS_INI_KEY_48, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey, NULL, szIniFile);
			}
			else
			{
				// Write size
				LoadString(hInst, IDS_INI_KEY_44, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				_snprintf(szBuffer, sizeof(szBuffer), "%d", sPNote[i].nSize);
				WritePrivateProfileString(szSection, szKey, szBuffer,
					szIniFile);

				// Write border flag
				LoadString(hInst, IDS_INI_KEY_45, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				_snprintf(szBuffer, sizeof(szBuffer), "%d",
					(int)sPNote[i].bBorder);
				WritePrivateProfileString(szSection, szKey, szBuffer,
					szIniFile);

				// Write opaque flag
				LoadString(hInst, IDS_INI_KEY_106, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				_snprintf(szBuffer, sizeof(szBuffer), "%d",
					(int)sPNote[i].bOpaque);
				WritePrivateProfileString(szSection, szKey, szBuffer,
					szIniFile);

				// Write note position
				LoadString(hInst, IDS_INI_KEY_46, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
					sPNote[i].fX);
				ShortenExp(szBuffer);
				WritePrivateProfileString(szSection, szKey, szBuffer,
					szIniFile);
				LoadString(hInst, IDS_INI_KEY_47, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
					sPNote[i].fY);
				ShortenExp(szBuffer);
				WritePrivateProfileString(szSection, szKey, szBuffer,
					szIniFile);

				//  Write note text
				LoadString(hInst, IDS_INI_KEY_48, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey, sPNote[i].szText,
					szIniFile);
			}
		}
	}

	// [SigmaNotes] section
	if( (nSection==INI_SNOTE) || (nSection==INI_ALL && bUseSigmaPlotIni) )
	{
		// Assign section label
		LoadString(hInst, IDS_INI_SECTION_13, szSection, BUFFER_SIZE);

		for(i=0; i<SNOTE_NUMNOTES; i++)
		{
			// Store line # string in its buffer with a ']' after it
			itoa(i+1, szNum, 10);
			strlcat(szNum, "]", sizeof(szNum));

			if(strlen(sSNote[i].szText)==SNOTE_NONE)
			{
				// Erase note parameters
				LoadString(hInst, IDS_INI_KEY_44, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey, NULL, szIniFile);
				LoadString(hInst, IDS_INI_KEY_45, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey, NULL, szIniFile);
				LoadString(hInst, IDS_INI_KEY_46, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey, NULL, szIniFile);
				LoadString(hInst, IDS_INI_KEY_47, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey, NULL, szIniFile);
				LoadString(hInst, IDS_INI_KEY_48, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey, NULL, szIniFile);
			}
			else
			{
				// Write size
				LoadString(hInst, IDS_INI_KEY_44, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				_snprintf(szBuffer, sizeof(szBuffer), "%d", sSNote[i].nSize);
				WritePrivateProfileString(szSection, szKey, szBuffer,
					szIniFile);

				// Write border flag
				LoadString(hInst, IDS_INI_KEY_45, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				_snprintf(szBuffer, sizeof(szBuffer), "%d",
					(int)sSNote[i].bBorder);
				WritePrivateProfileString(szSection, szKey, szBuffer,
					szIniFile);

				// Write opaque flag
				LoadString(hInst, IDS_INI_KEY_106, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				_snprintf(szBuffer, sizeof(szBuffer), "%d",
					(int)sSNote[i].bOpaque);
				WritePrivateProfileString(szSection, szKey, szBuffer,
					szIniFile);

				// Write note position
				LoadString(hInst, IDS_INI_KEY_46, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", sSNote[i].fX);
				ShortenExp(szBuffer);
				WritePrivateProfileString(szSection, szKey, szBuffer,
					szIniFile);
				LoadString(hInst, IDS_INI_KEY_47, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", sSNote[i].fY);
				ShortenExp(szBuffer);
				WritePrivateProfileString(szSection, szKey, szBuffer,
					szIniFile);

				//  Write note text
				LoadString(hInst, IDS_INI_KEY_48, szKey, BUFFER_SIZE);
				strlcat(szKey, szNum, sizeof(szKey));
				WritePrivateProfileString(szSection, szKey, sSNote[i].szText,
					szIniFile);
			}
		}
	}

	// [Toolbuttons] section
	if(nSection==INI_TOOLS || nSection==INI_ALL)
	{
		LoadString(hInst, IDS_INI_SECTION_14, szSection, BUFFER_SIZE);
		for(i=0; i<NUM_TOOLS; i++)
		{
			_snprintf(szBuffer, sizeof(szBuffer), "%d", tb[i].show_flag);
			WritePrivateProfileString(szSection, tb[i].label, szBuffer,
				szIniFile);
		}
	}

	// [Audio] section
	if(nSection==INI_AUDIO || nSection==INI_ALL)
	{
		LoadString(hInst, IDS_INI_SECTION_18, szSection, BUFFER_SIZE);

		// Save SampleRate
		LoadString(hInst, IDS_INI_KEY_125, szKey, BUFFER_SIZE);
		_snprintf(szBuffer, sizeof(szBuffer), "%d", nSampleRate);
		WritePrivateProfileString(szSection, szKey, szBuffer,
			szIniFile);

		// Save szAudioPlayer
		LoadString(hInst, IDS_INI_KEY_126, szKey, BUFFER_SIZE);
		WritePrivateProfileString(szSection, szKey, szAudioPlayer,
			szIniFile);

	}
}

/*****************************************************************************/
/*                                                                           */
/*                            ReadFileInfo()                                 */
/*                                                                           */
/*		Function to read previous filename information from STABLE32.INI.    */
/*		{Files} section of STABLE32.INI holds full filenames of last         */
/*		NUM_FILENAMES-1 phase and frequency files that were opened.          */
/*                                                                           */
/*      Parameters:		None (void)                                          */
/*                                                                           */
/*      Return:			None (void)                                          */
/*                                                                           */
/*      Revision record:                                                     */
/*      	09/10/96		Created                                          */
/*			03/21/98		Changed to global full ini filename              */
/*                                                                           */
/*****************************************************************************/

void ReadFileInfo(void)
{
	// Local variables
	int i;						// Index
	char szName[11];			// Keyname string

	for(i=0; i<NUM_FILENAMES-1; i++)
	{
		_snprintf(szName, sizeof(szName), "PhaseFile%d", i+1);
		GetPrivateProfileString("Files", szName, "",
			szPreviousPhaseFilename[i+1], FILE_NAME_SIZE, szIniFile);
		_snprintf(szName, sizeof(szName), "FreqFile%d", i+1);
		GetPrivateProfileString("Files", szName, "",
			szPreviousFreqFilename[i+1], FILE_NAME_SIZE, szIniFile);
	}
}

/*****************************************************************************/
/*                                                                           */
/*                              WriteFileInfo()                              */
/*                                                                           */
/*		Function to write previous filename information to STABLE32.INI.     */
/*		{Files} section of STABLE32.INI holds full filenames of last         */
/*		NUM_FILENAMES-1 phase and frequency files that were opened.          */
/*                                                                           */
/*      Parameters:		None (void)                                          */
/*                                                                           */
/*      Return:			None (void)                                          */
/*                                                                           */
/*      Revision record:                                                     */
/*      	09/10/96		Created                                          */
/*			03/21/98		Changed to global full ini filename              */
/*                                                                           */
/*****************************************************************************/

void WriteFileInfo(void)
{
	// Local variables
	int i;						// Index
	char szName[11];			// Keyname string

	for(i=0; i<NUM_FILENAMES-1; i++)
	{
		_snprintf(szName, sizeof(szName), "PhaseFile%d", i+1);
		WritePrivateProfileString("Files", szName,
			szPreviousPhaseFilename[i+1], szIniFile);
		_snprintf(szName, sizeof(szName), "FreqFile%d", i+1);
		WritePrivateProfileString("Files", szName,
			szPreviousFreqFilename[i+1], szIniFile);
	}
}

/*****************************************************************************/
/*                                                                           */
/*                              UpdateFileInfo()                             */
/*                                                                           */
/*		If new filename parameter is not NULL, update filenames: 0->1->2->3. */
/*		Otherwise, just put filenames into File menu.                        */
/*		There are phase & freq filename arrays each of size NUM_FILENAMES.   */
/*		Indices are as follows: 0=new, 1=most recent, 2=next most recent,    */
/*		thru NUM_FILENAMES-1=oldest.  NUM_FILENAMES is currently 4.          */
/*                                                                           */
/*      Note: The previous file opened list is displayed from STABLE32.INI   */
/*      when program opens w/o advancing their positions because the 0th     */
/*      filename is empty.  The list is updated when a new file is read      */
/*      using the Open function.  It is not updated when a file on the       */
/*      list is re-read, or as the result of an Add operation.               */
/*                                                                           */
/*      Parameters:		char *	szFilename[]	Pointer to array of strings  */
/*                                              containing full filenames    */
/*      Return:			None (void)                                          */
/*                                                                           */
/*      Revision record:                                                     */
/*      	09/10/96		Created                                          */
/*			01/23/97		Added logic to avoid listing duplicate filenames */
/*			04/11/98		Increased string sizes for long filenames        */
/*                                                                           */
/*****************************************************************************/

void UpdateFileInfo(char *szFilename[])
{
	// Local variables
	int i;						// Index
	char *ptr;					// Pointer to basic filename
	char szBasicFilename[FILENAMESIZE+1];	// Basic filename
	// Basic filename was [FILENAME.EXT + EOS] = 13 = NG for long filenames
	char szMenu[FILENAMESIZE+5];			// Menu item string
	// Menu item string was [&#. FILENAME.EXT + EOS] = 17 = ditto above
	BOOL nNewFilename=TRUE;		// Flag to indicate duplicate filename

	// Check for duplicate filename
	for(i=1; i<NUM_FILENAMES; i++)
	{
		if(strcmp(szFilename[0], szFilename[i])==0)
		{
			nNewFilename=FALSE;
		}
	}

	// Update filenames
	if( (strlen(szFilename[0])!=0) && (nNewFilename) )
	{
		for(i=NUM_FILENAMES-1; i>0; i--)
		{
			// 3<-2, 2<-1, 1<-0
			strlcpy(szFilename[i], szFilename[i-1], FILE_NAME_SIZE); 
		}
	}

	// 02/07/98
	// Debugger says there is an error in ptr=strrchr(szFilename[i+1], '\\');
	// Put filenames into file menu
	for(i=0; i<NUM_FILENAMES-1; i++)
	{
		// Parse basic filename from full filename
		ptr=strrchr(szFilename[i+1], '\\');
		// Produces "&#. " , #=1-3
		_snprintf(szMenu, sizeof(szMenu), "&%d. ", i+1);	
		if(ptr==NULL)
		{
			strlcpy(szBasicFilename, szFilename[i+1], FILE_NAME_SIZE);
		}
		else
		{
			strlcpy(szBasicFilename, ptr+1, FILE_NAME_SIZE);
		}
		strlcat(szMenu, szBasicFilename, FILE_NAME_SIZE);

		// Put string into file menu
		if(strlen(szBasicFilename))
		{
			ModifyMenu(hMenu, IDM_FILE1+i, MF_BYCOMMAND, IDM_FILE1+i, szMenu);
		}
		else // Blank filename - displayed # grayed
		{
			ModifyMenu(hMenu, IDM_FILE1+i, MF_BYCOMMAND | MF_GRAYED,
				IDM_FILE1+i, szMenu);
		}
	}
}

/*****************************************************************************/
/*                                                                           */
/*                            ReadDataFile()                                 */
/*								                                             */
/* 		Function to read data file.                                          */
/*                                                                           */
/*      Parameters:                                                          */
/*					int*	pnCols		ptr to # data file cols              */
/*                  int*	pnTagCol    ptr to tag col #                     */
/*                  int*	pnDatCol	ptr to data col #                    */
/*                                                                           */
/*      Return:	  	BOOL 0=Read NG, 1=Read OK                                */
/*                                                                           */
/*      Revision record:                                                     */
/*      	09/11/96	Created from existing in-line code                   */
/*			09/21/96	Added code for handling large data files             */
/*			11/19/96	Made changes for handling of invalid data points     */
/*			01/04/97	Added more flags & globals                           */
/*			11/25/97	Changed nDataArray Size from int to long             */
/*			10/14/03	Added BIG_DOAVG option                               */
/*			08/20/09	Note that nComments is a new global variable         */
/*                                                                           */
/*****************************************************************************/

BOOL ReadDataFile(int *pnCols, int *pnTagCol, int *pnDatCol)
{
	// Local variables
	int i;									// Index
	char szBuffer[BUFFER_SIZE+1];			// General text buffer
	long nDataArraySize;          			// Size of data array
	int nAF;								// Averaging factor
	int nRealNum;                           // Actual # of valid data points
	static int nRejects;					// # rejected data file points
	F_TYPE fD;								// 1st diff of phase


	// Start of code
	// Display wait cursor
	SetCursor(hWait);

	// Set busy flag
	bBusy=TRUE;
	
	// Get # data points, # data columns, # rejected lines & 1st line
	// Returns -1 if error
	nDataFileSize=FileInfo(szFile, pnCols, &nRejects, &nComments, szFileText);
	nDataFileRejects=nRejects;

	// Bail out here if couldn't open data file and nDataFileSize is -1
	if(nDataFileSize==-1)
	{
		// Reset busy flag
		bBusy=FALSE;

		// Display normal cursor
		SetCursor(hArrow);

		// Abort
		return 0;
	}

	nDataArraySize=min(nDataFileSize, nMaxSize);

	// Here's where we want to check the file size, and, if its too big,
	// bring up a dialog box offering to read just the first part, the last
	// part, do averaging as it is read, or abort the read operation.

	// Initialize nTooBigOption
	// Note:  nTooBigOption is passed to Multocolumn Data Read().  If it
	//        is BIG_OK, then file size is OK.  Otherwise special measures
	//        will be taken to deal with a large file size.
	// Note: nTooBigOption set to either BIG_OK or BIG_DOAVG
	// in FileOpenHookProc()
	// nTooBigOption=BIG_OK;

	// Check if file too small
	if(nDataFileSize<MIN_DATA_FILE_SIZE)
	{
		// Open message box
		MessageBox(hwndMain, "File Too Small To Process!", "Open",
			MB_ICONEXCLAMATION);

		// Reset busy flag
		bBusy=FALSE;
		
		// Display normal cursor
		SetCursor(hArrow);

		// Abort
		return 0;
	}

	// Check if file is large
	if(nDataFileSize>nMaxSize)
	{
		// Open dialog box
		InvokeDialogBox(hInst, "TooBigBox", hwndMain, (DLGPROC)TooBigDlgProc);

		if(nTooBigOption==BIG_ABORT)
		{
			// Reset busy flag
			bBusy=FALSE;
		
			// Display normal cursor
			SetCursor(hArrow);

			// Abort
			return 0;
		}
	}

	// Use all data if averaging a large file or ignoring size limit
	if(nTooBigOption==BIG_AVERAGE || nTooBigOption==BIG_DOAVG || nTooBigOption==BIG_ALL)
	{
		nDataArraySize=nDataFileSize;
	}

	//  Save filenames
	if(nDataFileSize>0) // Don't change status display if file NG
	{
		if(bDataType==FREQ_DATA)
		{
			strlcpy(szFreqFile, szFile, FILE_NAME_SIZE);
			strlcpy(szFreqFileTitle, szFileTitle, FILE_TITLE_SIZE);
		}
		else // Phase data
		{
			strlcpy(szPhaseFile, szFile, FILE_NAME_SIZE);
			strlcpy(szPhaseFileTitle, szFileTitle, FILE_TITLE_SIZE);
		}

	}
	else // File NG
	{
		// Reset busy flag
		bBusy=FALSE;
		
		// Display normal cursor
		SetCursor(hArrow);

		// Abort
		return 0;
	}

	// Insert a \n into the string at the 41th char
	// Fill in the end of the string with spaces
	for(i=strlen(szFileText); i<BUFFER_SIZE+1; i++)
	{
		szFileText[i]=' ';
	}
	// Move up the last 40 characters
	for(i=79; i>=40; i--)
	{
		szFileText[i+1]=szFileText[i];
	}
	// Set the 41th character to a newline
	szFileText[40]='\n';
	// Set the 81th character to a EOS
	szFileText[81]='\0';

	// Use multicolumn dialog box if more than 1 column
	if(*pnCols>1)
	{
		// Initialize cancel data read flag
		bCancelDataRead=FALSE;

		if(*pnCols<9) // Use radio button column selection box
		{
			// Open multicolumn dialog box
			InvokeDialogBox(hInst, "MulticolumnBox", hwndMain,
				(DLGPROC)MulticolumnDlgProc);
		}
		else // More than 8 columns - use numeric entry column selection box
		{
			// Open multi dialog box
			InvokeDialogBox(hInst, "MultiBox", hwndMain,
				(DLGPROC)MultiDlgProc);
		}

		// Bail out if data read was cancelled
		if(bCancelDataRead)
		{
			// Reset busy flag
			bBusy=FALSE;
		
			// Display normal cursor
			SetCursor(hArrow);

			// Abort
			return 0;
		}

		if(bDataType==FREQ_DATA)
		{
			bFreqTimetags=TRUE;
		}
		else
		{
			bPhaseTimetags=TRUE;
		}
	}
	else
	{
		*pnTagCol=0;
		*pnDatCol=1;
	}

	// Bound the # data points to be read
	if((nDataFileSize>nMaxSize) && (nTooBigOption==BIG_FIRST))
	{
		nDataFileSize=nMaxSize;
	}

	// The memory allocations and status displays are scaled by nAF, which is
	// set to 1 unless we are doing averaging of a large data file
	if(nTooBigOption!=BIG_AVERAGE)
	{
		nAF=1;
	}
	else
	{
		nAF=nBigAvgFactor;
	}

	// Clear data array - this resets all process flags
	// and will elim obsolete plot messages
	ClearDataArray(bDataType);
	
	// Reallocate memory
	if(bDataType)
	{
		// Realloc freq data
		if((fNew=(F_TYPE*)realloc(fFreqData,
			((nDataArraySize/nAF)+ARRAY_OFFSET+EXTRA_MEM)*
			sizeof(F_TYPE)))==NULL)
		{
			// Display error message
			AllocErrorMessage();

			// Reset busy flag
			bBusy=FALSE;
		
			// Display normal cursor
			SetCursor(hArrow);

			// Abort
			return 0;
		}
		else
		{
			fFreqData=fNew;
		}
		fData=fFreqData;
		bFreqRedraw=TRUE;

		if(*pnCols>1)
		{
			// Realloc freq timetags
			if((fNew=(F_TYPE*)realloc(fFreqTimetags,
				((nDataArraySize/nAF)+ARRAY_OFFSET+EXTRA_MEM)*
				sizeof(F_TYPE)))==NULL)
			{
				// Display error message
				AllocErrorMessage();
				// Note: Bailing out here will leave the freq data array
				// reallocated, so the safest thing to do is to clear it
				// along with the freq timetag array
				ClearDataArray(FREQ_DATA);
				ClearTimetagArray(FREQ_DATA);
		
				// Reset busy flag
				bBusy=FALSE;
		
				// Display normal cursor
				SetCursor(hArrow);
				
				// Abort
				return 0;
			}
			else
			{
				fFreqTimetags=fNew;
			}
			fTags=fFreqTimetags;
		}
	}
	else // Phase
	{
		// Realloc phase data
		if((fNew=(F_TYPE*)realloc(fPhaseData,
			((nDataArraySize/nAF)+ARRAY_OFFSET+EXTRA_MEM)
			*sizeof(F_TYPE)))==NULL)
		{
			// Display error message
			AllocErrorMessage();

			// Reset busy flag
			bBusy=FALSE;
		
			// Display normal cursor
			SetCursor(hArrow);

			// Abort
			return 0;
		}
		else
		{
			fPhaseData=fNew;
		}
		fData=fPhaseData;
		bPhaseRedraw=TRUE;

		if(*pnCols>1)
		{
			// Realloc phase timetags
			if((fNew=(F_TYPE*)realloc(fPhaseTimetags,
				((nDataArraySize/nAF)+ARRAY_OFFSET+EXTRA_MEM)
				*sizeof(F_TYPE)))==NULL)
			{
				// Display error message
				AllocErrorMessage();
				// Note: Bailing out here will leave the phase data array
				// reallocated, so the safest thing to do is to clear it
				// along with the phase timetag array
				ClearDataArray(PHASE_DATA);
				ClearTimetagArray(PHASE_DATA);
				
				// Reset busy flag
				bBusy=FALSE;
		
				// Display normal cursor
				SetCursor(hArrow);

				// Abort
				return 0;
			}
			else
			{
				fPhaseTimetags=fNew;
			}
			fTags=fPhaseTimetags;
		}
	}

	// Activate data-dependent functions
	ActivateFunctions(MF_ENABLED);

	// Read the data
	nRealNum=MulticolumnDataRead(szFile, *pnTagCol, *pnDatCol, nTooBigOption);

	// nRealNum may be < nDataArraySize/nAF if some input data file lines were
	// invalid.  This leaves extra mem allocated, which should be no problem

	// Update status display & flags
	if(bDataType==FREQ_DATA)
	{
		SetWindowText(hwndFreqFilename, szFileTitle);
		_snprintf(szBuffer, sizeof(szBuffer), "%5.0d", nRealNum);
		SetWindowText(hwndFreqNum, szBuffer);
		SetWindowText(hwndFreqEnd, szBuffer);
		_snprintf(szBuffer, sizeof(szBuffer), "%5.0d", 1);
		SetWindowText(hwndFreqStart, szBuffer);
		_snprintf(szBuffer, sizeof(szBuffer), "%11.5e", (double)nAF);
		ShortenExp(szBuffer);
		SetWindowText(hwndFreqTau, szBuffer);
		bFreqData=TRUE;
		bFreqDataChanged=TRUE;
		bFreqDataUnsaved=FALSE;
		bAutoFreqDataRead=TRUE;
		bFreqScaleChanged=TRUE;
		bOutRem=FALSE;
		bFreqGapFill=FALSE;
		bFreqNorm=FALSE;
		bLinDriftRem=FALSE;
		bLogDriftRem=FALSE;
		bDiffDriftRem=FALSE;
		nFreqGapsFilled=0;
        nOutliersRemoved=0;
	}
	else // Phase data
	{
		SetWindowText(hwndPhaseFilename, szFileTitle);
		_snprintf(szBuffer, sizeof(szBuffer), "%5.0d", nRealNum);
		SetWindowText(hwndPhaseNum, szBuffer);
		SetWindowText(hwndPhaseEnd, szBuffer);
		_snprintf(szBuffer, sizeof(szBuffer), "%5.0d", 1);
		SetWindowText(hwndPhaseStart, szBuffer);
		_snprintf(szBuffer, sizeof(szBuffer), "%11.5e", (double)nAF);
		ShortenExp(szBuffer);

		SetWindowText(hwndPhaseTau, szBuffer);
		bPhaseData=TRUE;
		// Was FALSE until 02/06/02
		// Then incorrectly changed to TRUE
		// Made FALSE again 03/30/02
		// The idea is that, when a file is read,
		// it obviously already exists on disk
		// so the not saved icon should not be displayed
		// BUT THERE'S A PROBLEM WITH NOT SETTING IT:
		// WON'T UPDATE FILENAME IN SUBTITLE BOXES
		// OF VARIOUS FUNCTIONS LIKE POWER SPECTRUM
		// This needs some attention
		// 11/22/06 Add bPhaseDataUnsaved and bFreqDataUnsaved flags
		// Now can control change and unsaved separately
		bPhaseDataChanged=TRUE;
		bFreqDataUnsaved=FALSE;
		bAutoPhaseDataRead=TRUE;
		bPhaseScaleChanged=TRUE;
		bPhaseGapFill=FALSE;
		bPhaseNorm=FALSE;
		bQuadDriftRem=FALSE;
		nPhaseGapsFilled=0;

		// Check for zero frequency (two adjacent phase data points the same)
		// As of 02/07/00 only make this check if bWarnZeroFreq is TRUE
		CalcFirstDiff(fPhaseData, &fD);
		if((fD==0.0) && bWarnZeroFreq)
		{
			LoadString(hInst, IDS_MESSAGE_ZEROFREQ, szBuffer, BUFFER_SIZE);
			MessageBox(hwndMain, szBuffer, "Warning", MB_ICONEXCLAMATION);
		}
	}

	// Reset busy flag
	bBusy=FALSE;
	
	// Update plot subtitles to new file title
	UpdatePlotSubtitles();

	// Display normal cursor
	SetCursor(hArrow);

	// OK
	return 1;
}

/*****************************************************************************/
/*                                                                           */
/*					     	TooBigDlgProc()                                  */
/*                                                                           */
/*		Dialog box procedure to handle a data file that is too big to read.  */
/*                                                                           */
/*      Offers options via global int nTooBigOption to:                      */
/*				BIG_ABORT	0	Abort data read operation                    */
/*				BIG_AVERAGE	1	Average data as it is read (default)         */
/*				BIG_FIRST	2	Read first portion of data                   */
/*				BIG_LAST	3	Read last portion of data                    */
/*                                                                           */
/*		Uses global int nDataFileSize to facilitate display of # data points */
/*      and averaging factor (based on macro MAX_DATA_FILE_SIZE and          */
/*		variable nMaxSize).                                                  */
/*                                                                           */
/*      This function simply announces that file is too big too read and     */
/*		gets option choice from user.  It does not do any file processing.   */
/*                                                                           */
/*		Revision record:                                                     */
/*      	09/20/96	Written                                              */
/*			09/21/96	Added tau entry                                      */
/*			09/22/96	Removed tau entry                                    */
/*			11/25/97	Changed # points display variable from int to long   */
/*			11/26/97	Added provisions for entering avg factor             */
/*						Made avg factor adapt to data reading method         */
/*						Note: Avg factor always = 1 for first or last method */
/*			11/27/97	Split # Points into 2 parts: label & #               */
/*			10/22/03	Added tau correction for averaging factor            */
/*			12/17/03	Fixed error in avg factor entry                      */
/*			08/23/08	Added option to read all data with AF=1              */
/*			12/31/11	Added display of max data file size limit            */
/*                                                                           */
/*****************************************************************************/

#ifndef _MSC_VER
	#pragma argsused
#endif

BOOL CALLBACK TooBigDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	char szBuffer[BUFFER_SIZE+1];	// General text buffer
	static int nAvgFactor;          // Averaging factor
	static int nMinAvgFactor;       // Min allowable avg factor
	static int nMaxAvgFactor;       // Max allowable avg factor
	int nEntry;                     // User avg factor entry to be validated
	int nPrev;                      // Previous value
	double fEntry;                  // Float to check for AF > int
	// BOOLs
	static BOOL bErrorTrap=FALSE;   // Flag for entry error

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Set the options radio buttons to their defaults
			Button_SetCheck(GETHCTL(IDC_BIG_AVG), TRUE);
			Button_SetCheck(GETHCTL(IDC_BIG_FIRST), FALSE);
			Button_SetCheck(GETHCTL(IDC_BIG_LAST), FALSE);

			// Display the # data points
			_snprintf(szBuffer, sizeof(szBuffer), "%ld", nDataFileSize);
			SetWindowText(GETHCTL(IDC_BIG_POINTS), szBuffer);

			// Display the max data file size limit
			_snprintf(szBuffer, sizeof(szBuffer), "%ld", nMaxSize);
			SetWindowText(GETHCTL(IDC_BIG_LIMIT), szBuffer);

			// Display the averaging factor
			nAvgFactor=(int)ceil((double)nDataFileSize/
				(double)nMaxSize);

			// Set the global big averaging factor value
			nBigAvgFactor=nAvgFactor;

			// The min allowable avg factor is the default
			nMinAvgFactor=nAvgFactor;

			// The max allowable avg factor is the data file size
			// If that factor used, won't have enough analysis points
			// but might want to do averaging anyway
			nMaxAvgFactor=(int)nDataFileSize;

			_snprintf(szBuffer, sizeof(szBuffer), "%d", nAvgFactor);
			SetWindowText(GETHCTL(IDC_BIG_AVGFACTOR), szBuffer);

			return TRUE;
		}

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				// Respond to help button
				case IDHELP:
				{
					// Invoke help file
					#if(0)
					HtmlHelp(hDlg, "Stable32.chm::LARGE_DATA_FILE.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::LARGE_DATA_FILE.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "LARGE_DATA_FIL");
					#endif
				}
				break;

				// Respond to average radiobutton
				case IDC_BIG_AVG:
				{
					// Set nAvgFactor to that needed for averaging
					nAvgFactor=nBigAvgFactor;
					_snprintf(szBuffer, sizeof(szBuffer), "%d", nAvgFactor);
					SetWindowText(GETHCTL(IDC_BIG_AVGFACTOR), szBuffer);
					// Activate the AF edit box
					EnableWindow(GETHCTL(IDC_BIG_AVGFACTOR), TRUE);
				}
				break;

				// Respond to first radiobutton
				case IDC_BIG_FIRST:
				{
					// Set nAvgFactor to 1
					nAvgFactor=1;
					_snprintf(szBuffer, sizeof(szBuffer), "%d", nAvgFactor);
					SetWindowText(GETHCTL(IDC_BIG_AVGFACTOR), szBuffer);

					// Grey the AF edit box
					EnableWindow(GETHCTL(IDC_BIG_AVGFACTOR), FALSE);
				}
				break;

				// Respond to last radiobutton
				case IDC_BIG_LAST:
				{
					// Set nAvgFactor to 1
					nAvgFactor=1;
					_snprintf(szBuffer, sizeof(szBuffer), "%d", nAvgFactor);
					SetWindowText(GETHCTL(IDC_BIG_AVGFACTOR), szBuffer);

					// Grey the AF edit box
					EnableWindow(GETHCTL(IDC_BIG_AVGFACTOR), FALSE);
				}
				break;

				// Respond to all radiobutton
				case IDC_BIG_ALL:
				{
					// Set nAvgFactor to 1
					nAvgFactor=1;
					_snprintf(szBuffer, sizeof(szBuffer), "%d", nAvgFactor);
					SetWindowText(GETHCTL(IDC_BIG_AVGFACTOR), szBuffer);

					// Grey the AF edit box
					EnableWindow(GETHCTL(IDC_BIG_AVGFACTOR), FALSE);
				}
				break;

				// Respond to avg factor edit control message
				case IDC_BIG_AVGFACTOR:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) && (GetFocus()!=GETHCTL(IDC_BIG_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Save previous value
						nPrev=nAvgFactor;

						// Get avg factor entry
						GetWindowText(GETHCTL(IDC_BIG_AVGFACTOR), szBuffer,
							BUFFER_SIZE);

						// Get (new) avg factor
						fEntry=fabs(atof(szBuffer));

						// Make sure entry is a valid int
						if(fEntry>2147483651.) // Out of int range
						{
							// Invalid entry - restore default value
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nPrev);
							SetWindowText(GETHCTL(IDC_BIG_AVGFACTOR),
								szBuffer);
							SetFocus(GETHCTL(IDC_BIG_AVGFACTOR));
							LoadString(hInst, IDS_MESSAGE_TOOBIGINT, szBuffer,
								BUFFER_SIZE);
							MessageBox(hDlg, szBuffer, "Invalid Entry",
								MB_ICONEXCLAMATION);
							break;
						}
						else
						{
							nEntry=abs(atoi(szBuffer));
						}

						// Check entry - must be between nMinAvgFactor and
						// nMaxAvgfactor
						if(ValidateInteger(hDlg, nEntry, nMinAvgFactor,
							nMaxAvgFactor)==TRUE)
						{
							// New value OK
							nAvgFactor=nEntry;
							_snprintf(szBuffer, sizeof(szBuffer), "%d",
								nAvgFactor);
							SetWindowText(GETHCTL(IDC_BIG_AVGFACTOR),
								szBuffer);
						}
						else
						{
							// Invalid entry - restore default value
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nPrev);
							SetWindowText(GETHCTL(IDC_BIG_AVGFACTOR),
								szBuffer);
							SetFocus(GETHCTL(IDC_BIG_AVGFACTOR));
						}
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Respond to CR in an edit control
				// Note: No button is a DEFPUSHBUTTON
				case IDOK:
				{
					// Does avg factor edit control have focus?
					if(GetFocus()==GETHCTL(IDC_BIG_AVGFACTOR))
					{
						// Send EN_KILLFOCUS message to factor edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_BIG_AVGFACTOR, 0,
							EN_KILLFOCUS));
					}
				}
				break;

				// Respond to OK button
				case IDC_BIG_OK:
				{
					// Read option
					if(Button_GetCheck(GETHCTL(IDC_BIG_AVG)))
					{
						nTooBigOption=BIG_AVERAGE;
						
						if(bCommandTau)
						{
							// Multiply tau by nAvgFactor
							fCommandTau*=nAvgFactor;
						}
					}
					if(Button_GetCheck(GETHCTL(IDC_BIG_FIRST)))
					{
						nTooBigOption=BIG_FIRST;
					}
					if(Button_GetCheck(GETHCTL(IDC_BIG_LAST)))
					{
						nTooBigOption=BIG_LAST;
					}
					if(Button_GetCheck(GETHCTL(IDC_BIG_ALL)))
					{
						nTooBigOption=BIG_ALL;
					}

					// Set the global big averaging factor value
					nBigAvgFactor=nAvgFactor;

					// Close dialog box
					EndDialog (hDlg, 0);
				}
				return TRUE;

				// Respond to cancel button
				case IDCANCEL:
				case IDC_BIG_CANCEL:
				{
					// Set nTooBigOption to BIG_ABORT
					nTooBigOption=BIG_ABORT;

					// Reset the global averaging factor to 1
					nBigAvgFactor=1;

					// Close dialog box
					EndDialog (hDlg, 0);
				}
				return TRUE;
			}
		}
		break;
	 }
	 return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*		File opened dialog box procedure                                     */
/*                                                                           */
/*		Globals:	int nTagCol		Column # of timetags                     */
/*					int nDatCol		Column # of data                         */
/*                                                                           */
/*		Revision record:                                                     */
/*			10/05/96	Written & debugged                                   */
/*			10/06/96	Plot added                                           */
/*			10/14/96	Added WM_PAINT processing to repaint plot            */
/*			01/10/97	Added error trap for 0 tau entry                     */
/*			02/19/97	Added error trap for zero plot range                 */
/*						Improved gap plotting                                */
/*			09/09/98	Added faster plotting for large # freq points        */
/*			03/06/99	Added use of timetag spacing as default tau          */
/*			02/12/00	Added log file entry                                 */
/*			02/26/00    Added fTagScale factor                               */
/*			09/09/00	Added Scale Data checkbox                            */
/*			08/09/01	Fixed some UI details                                */
/*			08/12/01	Added tau determination display                      */
/*						Added tau scale display                              */
/*			05/17/02	Made minor changes in user interface                 */
/*			12/07/02	Added tag offset value                               */
/*			09/30/03	Added trap for zero tau due to equal timetags        */
/*			10/21/03	Added fix for tau when doing data averaging          */
/*                                                                           */
/*****************************************************************************/

#ifndef _MSC_VER
	#pragma argsused
#endif

BOOL CALLBACK OpenedDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local macros
	#define POINTLIMIT 512

	// Macros for indicating how tau determined
	#define TAU_DEFAULT 0 // Lowest priority
	#define TAU_INI     1
	#define TAU_TAGS    2
	#define TAU_HEADER  3 
	#define TAU_CMDLINE 4 
	#define TAU_MANUAL  5 // Highest priority

	// Local variables
	// Misc
	static HDC hdcPlot;		  			// Handle to plot device context
	RECT rect;							// Plot rectangle
	// Chars
	char szBuffer[BUFFER_SIZE+1]; 		// General text buffer
	// Ints
	int i;								// Index
	int nGaps;							// # gaps
    int nLastY;
	static int nPoints;			 		// # data points
	static int nTauType=TAU_DEFAULT;	// Tau type
	// BOOLs
	BOOL bTags;							// Timetags flag

	static BOOL bErrorTrap=FALSE;   	// Flag for entry error
	static BOOL bDoScale=FALSE;			// Flag for scaling
	static BOOL bCheckFileHeader=TRUE;	// Local flag to control whether
										// data file is examined for
										// header entries
	// F_TYPEs
	static F_TYPE fTau;					// Tau value
	F_TYPE fRange, fXScale, fYScale;	// Plot scale factors
	static F_TYPE fMin, fMax;	  		// Minimun & maximum
	static F_TYPE fAdd;					// Addend value
    static F_TYPE fMult;				// Data multiplier value
	static F_TYPE fTauMult;				// Tau multiplier
	F_TYPE fEntry;						// File header entry value

	switch(message)
	{
		case WM_INITDIALOG:
		{

			// Initialize tau type
			nTauType=TAU_DEFAULT;

			// Was tau entered on command line?
			// This has highest precedence
			if(bCommandTau)
			{
				nTauType=TAU_CMDLINE;
				fTau=fCommandTau;
			}
			
			// Are we checking for a file header?
			// Don't want to do this if add - filename incremented
			if(!bAdd && bCheckFileHeader) 
			{
				// Check file header for tau value if tau not on cmd line
				if( (TauInfo(szFile, &fTau)) && (nTauType!=TAU_CMDLINE) )
				{
					// Set tau determination type
					// This has 2nd highest precedence
					nTauType=TAU_HEADER;

					// Set tau value from file header
					if(bDataType==FREQ_DATA)
					{
						fFreqTauInput=fTau;	
						bFreqTauDefault=FALSE;
					}
					else // Phase data
					{
						fPhaseTauInput=fTau;
						bPhaseTauDefault=FALSE;
					}
				}

				#if(1) // New code 03/22/10
				// Check file header for addend value
				if(AddendInfo(szFile, &fEntry))
				{
					// Set addend value from file header
					if(bDataType==FREQ_DATA)
					{
						fFreqAddendInput=fEntry;	
					}
					else // Phase data
					{
						fPhaseAddendInput=fEntry;
					}
				}

				// Check file header for multiplier value
				if(MultiplierInfo(szFile, &fEntry))
				{
					if(bDataType==FREQ_DATA)
					{
						fFreqMultiplierInput=fEntry;
					}
					else // Phase data
					{
						fPhaseMultiplierInput=fEntry;
					}
				}

				// Check file header for tag scale value
				if(TagScaleInfo(szFile, &fEntry))
				{
					if(bDataType==FREQ_DATA)
					{
						fFreqTagScale=fEntry;
					}
					else // Phase data
					{
						fPhaseTagScale=fEntry;
					}
				}

				// Check file header for tag offset value
				if(TagOffsetInfo(szFile, &fEntry))
				{
					if(bDataType==FREQ_DATA)
					{
						fFreqTagOffset=fEntry;
					}
					else // Phase data
					{
						fPhaseTagOffset=fEntry;
					}
				}
				#endif
			}

			// Get handle and device context to plot
			hPlot=GETHCTL(IDC_OPENED_PLOT);
			hdcPlot=GetDC(hPlot);

			// Check if this is an append operation
			if(bAdd)
			{
				// Change dialog box title
				LoadString(hInst, IDS_OPENED_ADD, szBuffer, BUFFER_SIZE);
				SetWindowText(hDlg, szBuffer);
			}

			// Display filename
			SetWindowText(GETHCTL(IDC_OPENED_FILE), szFileTitle);

			// Get addend, multiplier and tau multiplier
			if(bDataType==FREQ_DATA)
			{
				fAdd=fFreqAddendInput;
				fMult=fFreqMultiplierInput;
				fTauMult=fFreqTagScale;
			}
			else // Phase data
			{
				fAdd=fPhaseAddendInput;
				fMult=fPhaseMultiplierInput;
				fTauMult=fPhaseTagScale;
			}
			
			// Don't activate the Scale Data checkbox if addend=0
			// and multiplier=1
			if(fAdd!=0.0 || fMult!=1.0)
			{
				// Restore the Scale Data checkbox state
				Button_SetCheck(GETHCTL(IDC_OPENED_SCALE), bOpenScale);

				// Set the local scaling flag
				bDoScale=TRUE;

				// Enable the Scale Data checkbox
				EnableWindow(GETHCTL(IDC_OPENED_SCALE), TRUE);

				// Display the scaling factors
				_snprintf(szBuffer, sizeof(szBuffer), "Addend:      %e",
					fAdd);
				ShortenExp(szBuffer);
			    SetWindowText(GETHCTL(IDC_OPENED_ADD), szBuffer);
				_snprintf(szBuffer, sizeof(szBuffer), "Multiplier:     %e",
					fMult);
				ShortenExp(szBuffer);
			    SetWindowText(GETHCTL(IDC_OPENED_MULT), szBuffer);
			}
			else
			{
				// Disable the Scale Data checkbox
				EnableWindow(GETHCTL(IDC_OPENED_SCALE), FALSE);
			    
				// Clear the addend and multiplier displays
				SetWindowText(GETHCTL(IDC_OPENED_ADD), "");
			    SetWindowText(GETHCTL(IDC_OPENED_MULT), "");
			}

			// Activate the Tag Scale display if have timetags and it is not 0
			if(fTauMult!=1.0)
			{
				// Are there timetags?
				if( (bDataType==FREQ_DATA && bFreqTimetags) ||
					(bDataType==PHASE_DATA && bPhaseTimetags) )
				{
					_snprintf(szBuffer, sizeof(szBuffer), "Tag Scale: %e",
						fTauMult);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_OPENED_TAUSCALE), szBuffer);
				}
			}
			else
			{
				// Clear the tag scale display
				SetWindowText(GETHCTL(IDC_OPENED_TAUSCALE), "");
			}

			// Get data type and tau (if not determined by header)
			if(bDataType==FREQ_DATA )
			{
				// Display data type
				SetWindowText(GETHCTL(IDC_OPENED_TYPE), "Frequency");
				bTags=bFreqTimetags;

				if( (nTauType!=TAU_CMDLINE) && (nTauType!=TAU_HEADER) )
				{
					// If there is timetag data
					// then use spacing of 1st two timetags as tau value
					if(bTags)
					{
						fTau=fFreqTimetags[ARRAY_OFFSET+1]-
							fFreqTimetags[ARRAY_OFFSET];

						// Scale the tau value by ini file variable fTagScale
						// which is read from [Inputs]
						// as TagScale with default=1
						fTau*=fFreqTagScale;

						// Set tau determination type
						nTauType=TAU_TAGS;

						// Added 9/30/03
						// Trap zero tau (in case timetags were equal)
						if(fTau==0.0)
						{
							// Use default tau value
							fTau=1.0;
							nTauType=TAU_DEFAULT;
						}
					}
					else if(!bFreqTauDefault)
					{
						// Use tau from INI file multiplied by global
						// nBigAvgFactor from TooBigDlgProc()
						fTau=fFreqTauInput*nBigAvgFactor;

						// Set tau determination type
						nTauType=TAU_INI;
					}
					else
					{
						// Use default tau value
						fTau=1.0;
						nTauType=TAU_DEFAULT;
					}
				}
			}
			else // Phase data
			{
				// Display data type
				SetWindowText(GETHCTL(IDC_OPENED_TYPE), "Phase");
				bTags=bPhaseTimetags;

				if( (nTauType!=TAU_CMDLINE) && (nTauType!=TAU_HEADER) )
				{
					// If tau from INI file is default
					// and there is timetag data
					// then use spacing of 1st two timetags as tau value
					if(bTags)
					{
						fTau=fPhaseTimetags[ARRAY_OFFSET+1]-
							fPhaseTimetags[ARRAY_OFFSET];

						// Everything is fine if timetag units are seconds
						// But suppose they are something else (like MJD)
						// Then we need to scale the tau value
						// by ini file variable fTagScale
						// which is read from [Inputs] as TagScale
						// with default=1
						fTau*=fPhaseTagScale;

						// Set tau determination type
						nTauType=TAU_TAGS;

						// Added 9/30/03
						// Trap zero tau (in case timetags were equal)
						if(fTau==0.0)
						{
							// Use default tau value
							fTau=1.0;
							nTauType=TAU_DEFAULT;
						}
					}
					else if(!bPhaseTauDefault)
					{
						// Use default tau from INI file multiplied by global
						// nBigAvgFactor from TooBigDlgProc()
						fTau=fPhaseTauInput*nBigAvgFactor;

						// Set tau determination type
						nTauType=TAU_INI;
					}
					else
					{
						// Use default tau value
						fTau=1.0;
						nTauType=TAU_DEFAULT;
					}
				}
			}

			// Display # data points
			nPoints=(int)fData[0];
			_snprintf(szBuffer, sizeof(szBuffer), "%d", nPoints);
			SetWindowText(GETHCTL(IDC_OPENED_NUM), szBuffer);

			// Display # gaps
			nGaps=CountGaps(fData, bDataType);
			_snprintf(szBuffer, sizeof(szBuffer), "%d", nGaps);
			SetWindowText(GETHCTL(IDC_OPENED_GAPS), szBuffer);

			// Display min & max
			FindMinMax(fData, &fMin, &fMax, bDataType);
			_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e", fMin);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_OPENED_MIN), szBuffer);
			_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e", fMax);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_OPENED_MAX), szBuffer);

			// If data averaging was done, need to adjust tau
			// if tau value is from file header
			if(nTooBigOption==BIG_AVERAGE && nTauType==TAU_HEADER)
			{
				fTau*=nBigAvgFactor;
			}
			
			// If data averaging was done, need to adjust tau
			// if tau value is from file header, and
			// if averaging was requested in Open Data File dialog box
			// Note: Choosing data averaging forces this Data File Opened
			// dialog to be invoked
			if(nTooBigOption==BIG_DOAVG && nTauType==TAU_HEADER)
			{
				fTau*=nBigAvgFactor;
			}

			// Display tau
			_snprintf(szBuffer, sizeof(szBuffer), "%11.5e", fTau);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_OPENED_TAU), szBuffer);

			// Display tau determination type
			switch(nTauType)
			{
				case TAU_DEFAULT:
				{
					strlcpy(szBuffer, "Default Value", sizeof(szBuffer));
					break;
				}
				case TAU_INI:
				{
					strlcpy(szBuffer, "INI File [Input]", sizeof(szBuffer));
					break;
				}
				case TAU_TAGS:
				{
					strlcpy(szBuffer, "Data Timetags", sizeof(szBuffer));
					break;
				}
				case TAU_HEADER:
				{
					strlcpy(szBuffer, "Data File Header", sizeof(szBuffer));
					break;
				}
				case TAU_CMDLINE:
				{
					strlcpy(szBuffer, "Command Line", sizeof(szBuffer));
					break;
				}
				case TAU_MANUAL:
				{
					strlcpy(szBuffer, "Manual Entry", sizeof(szBuffer));
					break;
				}
			}

			SetWindowText(GETHCTL(IDC_OPENED_TAUTYPE), szBuffer);

			// Display timetag column #
			if(bTags)
			{
				_snprintf(szBuffer, sizeof(szBuffer), "%d", nTagCol);
				SetWindowText(GETHCTL(IDC_OPENED_TAGCOL), szBuffer);
			}

			// Display data column #
			_snprintf(szBuffer, sizeof(szBuffer), "%d", nDatCol);
			SetWindowText(GETHCTL(IDC_OPENED_DATCOL), szBuffer);

			// Display 1st timetag value
			if(bTags)
			{
				_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
					fTags[ARRAY_OFFSET]);
				ShortenExp(szBuffer);
				SetWindowText(GETHCTL(IDC_OPENED_TAGVAL), szBuffer);
			}
			else
			{
				SetWindowText(GETHCTL(IDC_OPENED_TAGVAL), "None");
			}

			// Display 1st data value
			_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
				fData[ARRAY_OFFSET]);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_OPENED_DATVAL), szBuffer);

			return TRUE;
		}

		// Repaint plot when necessary (such as after invoking help)
		// Ref: C. Petzold "Programming Windows 3.1", p.434
		case WM_PAINT:
		{
			InvalidateRect(hPlot, NULL, TRUE);
			UpdateWindow(hPlot);
			SendMessage(hDlg, WM_COMMAND,
				GET_WM_COMMAND_MPS(IDC_OPENED_PLOTDATA, NULL, 0));
		}
		break;

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				// Respond to tau entry
				case IDC_OPENED_TAU:
				{
					// Respond to edit control when it loses the input focus
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDCANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get tau entry
						GetWindowText(GETHCTL(IDC_OPENED_TAU), szBuffer,
							BUFFER_SIZE);

						// Use its absolute value
						fTau=fabs(atof(szBuffer));

						// Check tau entry - must be >0
						if(fTau)
						{
							// New value OK
							_snprintf(szBuffer, sizeof(szBuffer), "%11.5e",
								fTau);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_OPENED_TAU), szBuffer);

							// Set tau type
							nTauType=TAU_MANUAL;
							SetWindowText(GETHCTL(IDC_OPENED_TAUTYPE),
								"Manual Entry");
						}
						else
						{
							// Invalid entry - restore previous value
							LoadString(hInst, IDS_MESSAGE_NOZERO, szBuffer,
								BUFFER_SIZE);
							MessageBox(hDlg, szBuffer, "Invalid Entry",
								MB_ICONEXCLAMATION);
							_snprintf(szBuffer, sizeof(szBuffer), "%11.5e",
								1.0);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_OPENED_TAU), szBuffer);
							SetFocus(GETHCTL(IDC_OPENED_TAU));
						}
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Respond to CR in an edit control
				// This does not close the dialog box
				case IDOK:
				{
					// Send EN_KILLFOCUS message to TAU edit control
					if(GetFocus()==GETHCTL(IDC_OPENED_TAU))
					{
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_OPENED_TAU, NULL,
							EN_KILLFOCUS));
					}
				}
				break;

				// Display data
				case IDC_OPENED_DISPLAY:
				{
					strlcpy(szBuffer, szNotepad, sizeof(szBuffer));
					strlcat(szBuffer, " ", sizeof(szBuffer));
					strlcat(szBuffer, szFile, sizeof(szBuffer));
					WinExec(szBuffer, SW_SHOWNORMAL);
				}
				break;

				// Plot data
				case IDC_OPENED_PLOTDATA:
				{
					// Get size of plot area
					GetClientRect(hPlot, &rect);

					// Make plot background white
					FillRect(hdcPlot, &rect, GetStockObject(WHITE_BRUSH));
					
					// Calc plot scales
					fRange=fMax-fMin;

					// Check for zero range
					if(fRange)
					{
						fYScale=(F_TYPE)(rect.bottom-rect.top);
						fXScale=(F_TYPE)(rect.right-rect.left);

						// Create & select red pen
						SelectObject(hdcPlot, CreatePen(PS_SOLID, 1,
							RGB(255, 0, 0)));

						nLastY=0;
						// Plot data points
						for(i=0; i<nPoints-1; i++)
						{
							// Skip gaps
							if(fData[i+ARRAY_OFFSET] && fData[i+ARRAY_OFFSET+1])
							{
								if(bDataType==FREQ_DATA)
								{
									if(nPoints<POINTLIMIT)
									{
										// Plot freq data points as freq data
										// with horizontal lines
										// Move to current point
										MoveToEx(hdcPlot,
											(int)(((F_TYPE)i/(F_TYPE)nPoints)*
											fXScale), (int)
											(((fMax-fData[i+ARRAY_OFFSET])/
											(fRange))*(fYScale)), NULL);
										// Draw horiz line
										// from there to next point
										LineTo(hdcPlot, (int)
											(((F_TYPE)(i+1)/(F_TYPE)nPoints)*
											fXScale), (int)
											(((fMax-fData[i+ARRAY_OFFSET])/
											(fRange))*(fYScale)));
										// Draw vert line
										// from there to next point
										nLastY= (int)
											(((fMax-fData[i+ARRAY_OFFSET+1])/
											(fRange))*(fYScale));
										LineTo(hdcPlot,	(int)
											(((F_TYPE)(i+1)/(F_TYPE)nPoints)*
											fXScale), nLastY);
									}
									else
									{
										// Plot freq data as phase data
										// if # points>POINTLIMIT
										// This speeds up freq data plotting
										// by x2 & looks same
										// Move to current point
										MoveToEx(hdcPlot, (int)
											(((F_TYPE)i/(F_TYPE)(nPoints))*
											fXScale), (int)
											(((fMax-fData[i+ARRAY_OFFSET])/
											(fRange))*(fYScale)), NULL);
										// Draw line from there to next point
										LineTo(hdcPlot,	(int)
											(((F_TYPE)(i+1)/
											(F_TYPE)(nPoints))*fXScale), (int)
											(((fMax-fData[i+ARRAY_OFFSET+1])/
											(fRange))*(fYScale)));
									}
								}
								else // Phase data
								{
									// Move to current point
									MoveToEx(hdcPlot,
										(int)(((F_TYPE)i/(F_TYPE)(nPoints-1))*
										fXScale),
										(int)(((fMax-fData[i+ARRAY_OFFSET])/
										(fRange))*(fYScale)), NULL);
									// Draw line from there to next point
									LineTo(hdcPlot,
										(int)(((F_TYPE)(i+1)/
										(F_TYPE)(nPoints-1))*fXScale),
										(int)(((fMax-fData[i+ARRAY_OFFSET+1])/
										(fRange))*(fYScale)));
								}
							}
							else // Gap
							{
								nLastY=0;
                                if( (bDataType==FREQ_DATA) &&
                                    (fData[i+ARRAY_OFFSET]) &&
									(nPoints<POINTLIMIT) )
								{
									// Draw horiz line from there to next point
									LineTo(hdcPlot,
										(int)(((F_TYPE)(i+1)/(F_TYPE)nPoints)*
										fXScale),
										(int)(((fMax-fData[i+ARRAY_OFFSET])/
										(fRange))*(fYScale)));
								}
							}
						}

                        if( (bDataType==FREQ_DATA) &&(nPoints<POINTLIMIT) )
                        {
                            // Draw final horiz line - test added 09/14/98
							// Avoids trouble with zoomed gaps
							if(nLastY)
                            {
                                LineTo(hdcPlot,
                                    (int)(((F_TYPE)(i+1)/
                                    (F_TYPE)nPoints)*fXScale), nLastY);
                            }
                        }

						// Select black pen & delete red one
						// Ref: C. Petzold "Programming Windows 3.1", p.548
						DeleteObject(SelectObject(hdcPlot,
							GetStockObject(BLACK_PEN)));

						// Draw horizontal grid
						for(i=1; i<4; i++)
						{
							MoveToEx(hdcPlot, 0, (int)((i/4.0)*fYScale),
								NULL);
							LineTo(hdcPlot,	(int)fXScale,
								(int)((i/4.0)*fYScale));
						}

						// Draw vertical grid
						for(i=1; i<4; i++)
						{
							MoveToEx(hdcPlot, (int)((i/4.0)*fXScale), 0, NULL);
							LineTo(hdcPlot,	(int)((i/4.0)*fXScale),
								(int)fYScale);
						}
					}
					else
					{
						// Display error message instead of plot
						SetWindowText(GETHCTL(IDC_OPENED_PLOT),
							"\n\nZero Range");
					}
				}
				break;

				// Respond to help button
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::DATA_FILE_OPENED.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::DATA_FILE_OPENED.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "DATA_FILE_OPENED");
					#endif
				}
				break;

				// Respond to inputs button
				case IDC_OPENED_INPUTS:
				{
					// Open dialog box
					InvokeDialogBox(hInst, "InputsBox", hDlg,
						(DLGPROC)InputsDlgProc);

					if(bNewInputs)
					{
						// Reread input values
						// Get tau, addend,multiplier and tau multiplier
						if(bDataType==FREQ_DATA)
						{
							fTau=fFreqTauInput;
							fAdd=fFreqAddendInput;
							fMult=fFreqMultiplierInput;
							fTauMult=fFreqTagScale;
						}
						else // Phase data
						{
							fTau=fPhaseTauInput;
							fAdd=fPhaseAddendInput;
							fMult=fPhaseMultiplierInput;
							fTauMult=fPhaseTagScale;
						}
					}

					// Refresh user interface
					SendMessage(hDlg, WM_INITDIALOG, 0, 0);
				}
				break;

				// Respond to OK button - it has specific IDC not IDOK
				// IDOK used to kill CR response of edit controls
				// This is a PUSHBUTTON not a DEFPUSHBUTTON
				case IDC_OPENED_ACCEPT:
				{
					// Get tau value
					GetWindowText(GETHCTL(IDC_OPENED_TAU), szBuffer,
						BUFFER_SIZE);

					// Update tau in status display
					if(bDataType==FREQ_DATA)
					{
						SetWindowText(GetDlgItem(hwndMain,IDC_FREQTAU),
							szBuffer);
					}
					else // Phase data
					{
						SetWindowText(GetDlgItem(hwndMain,IDC_PHASETAU),
							szBuffer);
					}

					// Read scale data flag
					bOpenScale=
						(BOOL)Button_GetCheck(GETHCTL(IDC_OPENED_SCALE));

					// Scale data
					if(bDoScale && bOpenScale)
					{
						{
							// Display wait cursor
							SetCursor(hWait);

							// Scale data
							ScaleData(fData, fAdd, fMult, bDataType);

							// Set data changes flag
							if(bDataType==FREQ_DATA)
							{
								// Put info into log file
								_snprintf(szBuffer, sizeof(szBuffer),
									"Addend=%e, Mult=%e", fAdd, fMult);
								ShortenExp(szBuffer);
								WriteLog(17, szBuffer);
									
								// Do not want to set bPhaseDataChanged flag
								// because it causes unsaved file icon
								// to appear
								// bFreqDataChanged=TRUE;
								bFreqDataUnsaved=TRUE;
								sFPlot.new_file=TRUE;
								bFreqScaleChanged=TRUE;
								bFreqRedraw=TRUE;

								if(fAdd!=0.0) // Addend added
								{
									// Set global freq addend added flag
									bFreqAddend=TRUE;

									// Save value of freq addend
									fFreqAddend=fAdd;
								}

								if(fMult!=1.0) // Data scaled
								{
									// Set global freq scaled flag
									bFreqScaled=TRUE;

									// Save value of freq scaling factor
									fFreqScaled=fMult;
								}

								// Increment filename
								if(bIncExtension)
								{
									IncExtension(szFile, FREQ_DATA);
									IncExtension(szFileTitle, FREQ_DATA);
									IncExtension(szFreqFile, FREQ_DATA);
									IncExtension(szFreqFileTitle, FREQ_DATA);
									SetWindowText(hwndFreqFilename,
										szFileTitle);
								}
							}
							else // Phase data
							{
								// Put info into log file
								_snprintf(szBuffer, sizeof(szBuffer),
									"Addend=%e, Mult=%e", fAdd, fMult);
								ShortenExp(szBuffer);
								WriteLog(16, szBuffer);
									
								// Do not want to set bPhaseDataChanged flag
								// because it causes unsaved file icon
								// to appear
								// bPhaseDataChanged=TRUE;
								bFreqDataUnsaved=TRUE;
								bPhaseScaleChanged=TRUE;
								bPhaseRedraw=TRUE;

								if(fAdd!=0.0) // Addend added
								{
									// Set global phase addend added flag
									bPhaseAddend=TRUE;

									// Save value of phase addend
									fPhaseAddend=fAdd;
								}

								if(fMult!=1.0) // Data scaled
								{
									// Set global phase scaled flag
									bPhaseScaled=TRUE;

									// Save value of phase scaling factor
									fPhaseScaled=fMult;
								}

								// Increment filename
								if(bIncExtension)
								{
									IncExtension(szFile, PHASE_DATA);
									IncExtension(szFileTitle, PHASE_DATA);
									IncExtension(szPhaseFile, PHASE_DATA);
									IncExtension(szPhaseFileTitle, PHASE_DATA);
									SetWindowText(hwndPhaseFilename,
										szFileTitle);
								}
							}

							// Redraw status plots from new data
							UpdateStatusBar(hwndMain, NEW_DATA);

							// Reset redraw flags
							bPhaseRedraw=FALSE;
							bFreqRedraw=FALSE;

							// Clear plot lines
							ClearLines();

							// Clear synch flag
							bSynch=FALSE;

							// Display normal cursor
							SetCursor(hArrow);
						}
					}
				}

				// Fall into EndDialog()
				// Respond to esc key or cancel button
				// Just close - don't change tau

				case IDCANCEL:
				{
					// Make log entry
					_snprintf(szBuffer, sizeof(szBuffer), "Tau=%e", fTau);
					WriteLog(61, szBuffer);

					// Close dialog box
					ReleaseDC(hPlot, hdcPlot);
					EndDialog (hDlg, 0);
				}
				return TRUE;
			}
		}
		break;
	 }
	 return FALSE;
}

/*****************************************************************************/

