/*****************************************************************************/
/*                                                                           */
/*                            STABLE_T.C                                     */
/*                                                                           */
/* 		Stable Windows 95/NT Toolbar and Edit Control Subclass Functions     */
/*                                                                           */
/*      The toolbar occupies a window across the full client width of the    */
/*      main window directly below the main title or menu bar.  It is fill-  */
/*      ed with the button face system color and framed in black.  The tool  */
/*      buttons are 32x32 bit, 16-color icons drawn on the toolbar window.   */
/*      They are not separate windows.  There are NUM_TOOLS toolbuttons      */
/*		starting from the left side.  NUM_TOOLS should be limited to 19 for  */
/*		VGA displays.                                                        */
/*                                                                           */
/*		A caption is written below each toolbar, and a prompt string         */
/*		describing each toolbar function can be displayed on a status line.  */
/*      A blank full-width icon may be used to separate actual toolbuttons,  */
/*      which should have out, in and dim versions.  The toolbuttons may be  */
/*      momentary, toggling or inactive.  A BN_CLICKED command is sent to    */
/*      main window when a active toolbutton is released.  The state of the  */
/*      toolbuttons may be read with the BM_GETSTATE message, and may be     */
/*      set with the BM_SETSTATE message.                                    */
/*                                                                           */
/*      	Function                		Description                      */
/*                                                                           */
/*		ToolbarWndProc()			Toolbar Window Procedure                 */
/*		RedrawToolbar()             Redraw Toolbar Buttons                   */
/*      WritePromptMessage()        Write Prompt Message in Status Bar       */
/*		WriteAd()					(Lite only) Write Ad in Toolbar          */
/*		InitializeToolbar()         Initialize Toolbar Structures            */
/*		ActivateFunctions()         Activate/Deactivate Data Functions       */
/*      EditProc()                  Subclass Edit Control Procedure          */
/*		WriteMessage()				Write General Message in Status Bar      */
/*                                                                           */
/*		Revision record:                                                     */
/*                                                                           */
/*			06/29/97	Use GET_WM_COMMAND_ID, etc. WIN32 compatibility      */
/*						macros to process WM_COMMAND messages:               */
/*						wParam <- GET_WM_COMMAND_ID(wParam, lParam)          */
/*						Replaced WORD with UINT                              */
/*			06/30/97	Replaced FAR PASCAL _export with WINAPI              */
/*						Replaced MoveTo() with MoveToEx()                    */
/*			07/25/07    Changed to safe string functions                     */
/*                                                                           */
/* 	(c) 1996-2007  W. Riley Hamilton Technical Services All Rights Reserved  */
/*                                                                           */
/*****************************************************************************/

#define STRICT                  // For Win32 compatibility

#include "stable_w.h"           // STABLE_W header file

/*****************************************************************************/
/*                                                                           */
/*                         Toolbar Window Procedure                          */
/*                                                                           */
/*****************************************************************************/

LRESULT CALLBACK ToolbarWndProc(HWND hwnd, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	POINT point;			// Point struct
	RECT rect;				// Rect struct
	PAINTSTRUCT ps;			// Paint struct
	HBRUSH hBrush;			// Local brush
	HFONT hFont;			// Font handle
	HDC hdc;
	static LOGFONT logfont;	// Font structure - static fills it it with zeros
	int i;					// Index
	int nToolbuttonID;		// ID # of toolbutton sending message

	// Toolbar message switching procedure
	switch(message)
	{
		case WM_CREATE:
		{
			InitializeToolbar(tb);
			return 0;
		}

		case WM_MOUSEMOVE:
		{
			// Get mouse position
			point.x=LOWORD(lParam);
			point.y=HIWORD(lParam);

			for(i=0; i<NUM_TOOLS; i++) // Loop thru all toolbuttons
			{
					// Display prompt message
					// Get device context
					hdc=GetDC(hwndMain);

		// THERE WAS A GDI RESOURCE LEAK IN THIS SECTION OF CODE
		// THE LEAK WAS APPARENTLY FIXED BY DESELECTING THE CUSTOM FONT
		// BY SELECTING A STOCK FONT BEFORE DELETING THE CUSTOM ONE

					if(PtInRect(&tb[i].rect, point)&&tb[i].flag==FALSE)
					{
						// Flag to force repaint when mouse leaves toolbar
						bPaintFlag=TRUE;

						// Use smaller than system font
						// 16 seems to match size of text in dialog boxes
						logfont.lfHeight=16;

						// Specify highest quality font
						logfont.lfQuality=PROOF_QUALITY;
						// Specify font family
						logfont.lfPitchAndFamily=FF_SWISS;
						// Set the facename
						strlcpy(logfont.lfFaceName, "MS Sans Serif",
							LF_FACESIZE);

						hFont=CreateFontIndirect(&logfont); 
						SelectFont(hdc, hFont);

						// Write message in message bar above status bar
						SetRect(&rect, -1, (int)
							(cyClient-3.25*cyChar-2.5*cyChar/2.5),
							cxClient+1, (int)(cyClient-3.25*cyChar-2));
						FillRect(hdc, &rect, GetStockObject(LTGRAY_BRUSH));
						FrameRect(hdc, &rect, GetStockObject(BLACK_BRUSH));
						SetBkColor(hdc, GetSysColor(COLOR_BTNFACE));
						ExtTextOut(hdc, 0, (int)
							(cyClient-3.25*cyChar-2.5*cyChar/2.5),
							ETO_OPAQUE, &rect, tb[i].prompt,
							strlen(tb[i].prompt), NULL);

						// Deselect custom font before deleting it
						SelectFont(hdc, GetStockObject(SYSTEM_FONT));

						// Destroy font object
						DeleteFont(hFont);

						// Inhibit rewriting
						tb[i].flag=TRUE; 
					}
					else
					{
						tb[i].flag=FALSE;
					}

					// Release device context
					ReleaseDC(hwndMain, hdc);

				if(tb[i].state==TOOLBUTTON_IN) // Is this button pressed?
				{
					// Is mouse still in this toolbutton?
					if(PtInRect(&tb[i].rect, point))
					{
						return 0; // OK
					}
					else // Mouse has moved out of toolbutton
						 // so button should be brought back out
						 // without sending message or changing logic flag
					{
						tb[i].state=TOOLBUTTON_OUT;
						tb[i].abort=TRUE;
					}
				}

				if(tb[i].abort==TRUE) // Was this button pressed?
				{
					// Is mouse back to this toolbutton?
					if(PtInRect(&tb[i].rect, point))
					{
						tb[i].state=TOOLBUTTON_IN;
						tb[i].abort=FALSE;
					}
				}
			}

			RedrawToolbar(tb, FALSE);
			return 0;
		}

		case WM_PAINT:
		{
			hdc = BeginPaint(hwndToolbar, &ps);

			// Create background color brush
			hBrush=CreateSolidBrush(GetSysColor(COLOR_BTNFACE));

			// Fill toolbar
			GetClientRect(hwndToolbar, &rect);
			FillRect(hdc, &rect, hBrush);

			// Delete background color brush
			DeleteObject(hBrush);

			// Create black brush
			hBrush=GetStockObject(BLACK_BRUSH);

			// Frame toolbar
			GetClientRect(hwndToolbar, &rect);
			FrameRect(hdc, &rect, hBrush);

			// Draw toolbar
			RedrawToolbar(tb, TRUE);

			EndPaint(hwndToolbar, &ps);
			return 0;
		}

		case WM_LBUTTONDOWN:
		{
			// Capture mouse to track it everywhere
			SetCapture(hwndToolbar);

			// Get mouse position
			point.x=LOWORD(lParam);
			point.y=HIWORD(lParam);

			for(i=0; i<NUM_TOOLS; i++) // Loop thru all toolbuttons
			{
				tb[i].abort=FALSE;

				if(PtInRect(&tb[i].rect, point)) // Is mouse in toolbutton?
				{
					switch(tb[i].state) // Respond to mouse button pressed
					{
						case TOOLBUTTON_BLANK:
							break;
						case TOOLBUTTON_OUT:
							tb[i].state=TOOLBUTTON_IN;
							break;
						case TOOLBUTTON_IN:
							break;
						case TOOLBUTTON_DIM:
							MessageBeep(0);
							break;
					}
				}
			}

			RedrawToolbar(tb, FALSE);
			return 0;
		}

		case WM_LBUTTONUP:
		{
			// Release mouse
			ReleaseCapture();
			
			// Get mouse position
			point.x=LOWORD(lParam);
			point.y=HIWORD(lParam);
			nToolbuttonID=0; // Reset ID #

			for(i=0; i<NUM_TOOLS; i++) // Loop thru all toolbuttons
			{
				tb[i].abort=FALSE;

				if(PtInRect(&tb[i].rect, point)) // Is mouse in toolbutton?
				{
					switch(tb[i].state) // Respond to mouse button pressed
					{
						case TOOLBUTTON_BLANK:
							break;
						case TOOLBUTTON_OUT:
							break;
						case TOOLBUTTON_IN:
							if(tb[i].type==TOOLBUTTON_TOGGLE)
							{
								tb[i].flag=!tb[i].flag; // Toggle flag
								if(tb[i].flag) // TRUE==Button stays in
								{
									break;
								}
							}
							tb[i].state=TOOLBUTTON_OUT;
							nToolbuttonID=i+1; // ID # of toolbutton
											   // +1 so 0 can be tested for
							break;
						case TOOLBUTTON_DIM:
							break;
					}
				}
			}

			RedrawToolbar(tb, FALSE);

			// Post queued BN_CLICKED message to parent (main) window
			// if ID is >0
			if(nToolbuttonID)
			{
				PostMessage(hwndMain, WM_COMMAND,
					GET_WM_COMMAND_MPS(IDC_TOOLBUTTON, nToolbuttonID,
					BN_CLICKED));
			}
			return 0;
		}

		case BM_SETSTATE: // Message to change state of toolbutton.
        				  // Note:  Review for WIN32 compatibility
						  // wParam contains action to take:
						  //     TOOLBUTTON_BLANK = Remove toolbutton
						  //     TOOLBUTTON_DIM   = Gray toolbutton
						  //     TOOLBUTTON_OUT   = Release toolbutton
						  //     TOOLBUTTON_IN    = Depress toolbutton
						  // LOWORD of lParam contains toolbutton ID #
		{
			tb[LOWORD(lParam)].state=GET_WM_COMMAND_ID(wParam, lParam);
			return 0;
		}

		case BM_GETSTATE: // Message to get state of toolbutton.
						  // Returns toolbutton state:
						  //     TOOLBUTTON_BLANK = No toolbutton
						  //     TOOLBUTTON_DIM   = Grayed toolbutton
						  //     TOOLBUTTON_OUT   = Released toolbutton
						  //     TOOLBUTTON_IN    = Depressed toolbutton
						  // LOWORD of lParam contains toolbutton ID #
		{
			return tb[LOWORD(lParam)].state;
		}
	}	
	
	// Call DefWindowProc to process other messages
	return DefWindowProc(hwnd, message, wParam, lParam);
}

/*****************************************************************************/
/*                                                                           */
/*                   Function to redraw toolbar buttons                      */
/*                                                                           */
/*                                                                           */
/*****************************************************************************/
void WINAPI RedrawToolbar(TOOLBUTTON tb[], BOOL bDraw)
{
	// Local variables
	HFONT hFont;			// Font handle
	HDC hdc;
	RECT rect;				// Rect struct

	static LOGFONT logfont;	// Font structure - static fills it it with zeros
	int i;					// Index

	// Fill in size of font structure for toolbutton labels
	// 12 is nice with NT but is too small under 95/98
	// 13 is too big on both
	logfont.lfHeight=12; // 12 is largest that will fit

	// Specify highest quality font
	// Avoid scaling of a raster font - no effect
	logfont.lfQuality=PROOF_QUALITY;
	// Specify font family - this is good to avoid a Times Roman serif font
	logfont.lfPitchAndFamily=FF_SWISS;
	// Set the facename
	strlcpy(logfont.lfFaceName, "Small Fonts", LF_FACESIZE);

	// Get device context
	hdc=GetDC(hwndToolbar);

	// Loop thru all buttons
	for(i=0; i<NUM_TOOLS; i++)
	{
		// Redraw only if necessary or requested
		if(tb[i].state!=tb[i].prev_state || bDraw)
		{
			tb[i].prev_state=tb[i].state;

			// Get system metrics
			cxIcon=GetSystemMetrics(SM_CXICON);
			cyIcon=GetSystemMetrics(SM_CYICON);

			// Repaint background color below ocon being redrawn
			SetRect(&rect, tb[i].position*cxIcon, 0, (tb[i].position+1)*cxIcon,
				cyIcon);
			FillRect(hdc, &rect, hBrush);

			// Draw icon
			DrawIcon(hdc, tb[i].position*cxIcon, 0, tb[i].hIcon[tb[i].state]);

			// Draw separator line
			MoveToEx(hdc, (int)((tb[i].position+1)*cxIcon-0.5), cyIcon, NULL);
			LineTo(hdc, (int)((tb[i].position+1)*cxIcon-0.5),
				(int)(1.45*cyIcon));

			// Write caption
			hFont=CreateFontIndirect(&logfont);
			SelectObject(hdc, hFont);

			SetBkMode(hdc, TRANSPARENT); // Make bkgrnd color show thru text
			SetTextAlign(hdc, TA_CENTER);
			TextOut(hdc, tb[i].position*cxIcon+cxIcon/2-1, cyIcon, tb[i].label,
				strlen(tb[i].label));

			// Deselect & delete custom font
			SelectFont(hdc, GetStockObject(SYSTEM_FONT));
			DeleteObject(hFont);
		}
	}

	// Release device context
	ReleaseDC(hwndToolbar, hdc);
}

/*****************************************************************************/
/*                                                                           */
/*             Function to write prompt message in status bar                */
/*                                                                           */
/*                                                                           */
/*****************************************************************************/
void WINAPI WritePromptMessage(UINT wFunction)
{
	// Local variables
	RECT rect;
	HDC hdc;
	HFONT hFont;			// Font handle
	static LOGFONT logfont;	// Font structure - static fills it it with zeros

	// Fill in size of font structure
	logfont.lfHeight=16; // 16 seems to match size of text in dialog boxes

	// Specify highest quality font - avoid scaling of a raster font
	logfont.lfQuality=PROOF_QUALITY;
	// Specify font family
	logfont.lfPitchAndFamily=FF_SWISS;
	// Set the facename
	strlcpy(logfont.lfFaceName, "MS Sans Serif", LF_FACESIZE);

	// Create font
	hFont=CreateFontIndirect(&logfont);

	// Get device context
	hdc=GetDC(hwndMain);

	// Select font into device context
	SelectObject(hdc, hFont);
	
	// Write message in message bar above status bar
	SetRect(&rect, -1, (int)(cyClient-3.25*cyChar-2.5*cyChar/2.5),
		cxClient+1, (int)(cyClient-3.25*cyChar-2));
	FillRect(hdc, &rect, GetStockObject(LTGRAY_BRUSH));
	FrameRect(hdc, &rect, GetStockObject(BLACK_BRUSH));
	SetBkColor(hdc, GetSysColor(COLOR_BTNFACE));
	ExtTextOut(hdc, 0, (int)(cyClient-3.25*cyChar-2.5*cyChar/2.5),
		ETO_OPAQUE, &rect, tb[wFunction].prompt, strlen(tb[wFunction].prompt),
		NULL);

	// Deselect custom font before deleting it
	SelectFont(hdc, GetStockObject(SYSTEM_FONT));

	// Delete font object
	DeleteObject(hFont);
	
	// Release device context
	ReleaseDC(hwndMain, hdc);
}

#ifdef LITE_VER
/*****************************************************************************/
/*                                                                           */
/*             Function to write ad at right end of toolbar                  */
/*                                                                           */
/*                                                                           */
/*****************************************************************************/
void WINAPI WriteAd(LPSTR szLine1, LPSTR szLine2, LPSTR szLine3)
{
	// Local variables
	int cyMenu;				// Height of menu
	RECT rect;
	HDC hdc;
	HFONT hFont;			// Font handle
	static LOGFONT logfont;	// Font structure - static fills it it with zeros
	
	// Get height of menu
	cyMenu=GetSystemMetrics(SM_CYMENU);

	// Fill in size of font structure
	logfont.lfHeight=15; // A little smaller than text in dialog boxes

	// Specify highest quality font - avoid scaling of a raster font
	logfont.lfQuality=PROOF_QUALITY;
	// Specify font family
	logfont.lfPitchAndFamily=FF_SWISS;
	// Set the facename
	strlcpy(logfont.lfFaceName, "Arial", LF_FACESIZE);

	// Create font
	hFont=CreateFontIndirect(&logfont);

	// Get device context
	hdc=GetDC(hwndMain);

	// Select font into device context
	SelectObject(hdc, hFont);
	
	// Write ad at right end of toolbar
	SetRect(&rect, NUM_TOOLS*cxIcon, cyMenu, cxClient-10, cyIcon);
	FillRect(hdc, &rect, GetStockObject(LTGRAY_BRUSH));
	FrameRect(hdc, &rect, GetStockObject(BLACK_BRUSH));
	SetBkColor(hdc, GetSysColor(COLOR_BTNFACE));
	ExtTextOut(hdc, (NUM_TOOLS*cxIcon)+5, 1, ETO_OPAQUE, &rect, szLine1,
		strlen(szLine1), NULL);
	SetRect(&rect, NUM_TOOLS*cxIcon, cyIcon/2, cxClient-10, cyIcon);
	ExtTextOut(hdc, (NUM_TOOLS*cxIcon)+5, (int)(0.75*cyChar), ETO_OPAQUE,
		&rect, szLine2, strlen(szLine2), NULL);
	SetRect(&rect, NUM_TOOLS*cxIcon, cyIcon, cxClient-10, (int)(1.4*cyIcon));
	ExtTextOut(hdc, (NUM_TOOLS*cxIcon)+5, (int)(1.5*cyChar), ETO_OPAQUE,
		&rect, szLine3, strlen(szLine3), NULL);

	// Deselect & delete custom font GDI object
	SelectFont(hdc, GetStockObject(SYSTEM_FONT));
	DeleteObject(hFont);
	
	// Release device context
	ReleaseDC(hwndMain, hdc);
}
#endif

/*****************************************************************************/
/*                                                                           */
/*                   Function to initialize toolbar structures               */
/*                                                                           */
/*  Note: The following toolbar buttons are dimmed if there is no data:      */
/*     	  Save, Add, Print, Clear, Conv, Norm, Avg, Fill, Scale,             */
/*        Stats, Check, Drift, Sigma, Run, Power, Histo, Plot, Tag, Reg      */
/*                                                                           */
/*	Revision Record:                                                         */
/*  	10/02/96	Added usage of stringtable for prompt strings            */
/*  	10/24/96	Added notepad toolbutton                                 */
/*		11/19/05	Added DAVAR function                                     */
/*		01/12/07	Added tab toolbutton                                     */
/*                                                                           */
/*****************************************************************************/

void WINAPI InitializeToolbar(TOOLBUTTON tb[])
{
	// Local variables
	int i;						// Index

	// Fill out a toolbar structure for each toolbar
	// Order doesn't matter

	// Open toolbutton
	i=TB_OPEN;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimOpenIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutOpenIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InOpenIcon");
	tb[i].state     =TOOLBUTTON_OUT;
	tb[i].prev_state=TOOLBUTTON_OUT;
	tb[i].flag      =FALSE;
	tb[i].abort=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Open", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_OPEN, tb[i].prompt, TOOLPROMPTSIZE);

	#ifndef LITE_VER
	// Add toolbutton
	i=TB_ADD;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimAddIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutAddIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InAddIcon");
	tb[i].state     =TOOLBUTTON_DIM;
	tb[i].prev_state=TOOLBUTTON_DIM;
	tb[i].flag      =FALSE;
	tb[i].abort=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Add", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_ADD, tb[i].prompt, TOOLPROMPTSIZE);
	#endif

	#ifndef LITE_VER
	// Read toolbutton
	i=TB_READ;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimReadIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutReadIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InReadIcon");
	tb[i].state     =TOOLBUTTON_OUT;
	tb[i].prev_state=TOOLBUTTON_OUT;
	tb[i].flag      =FALSE;
	tb[i].abort=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Read", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_READ, tb[i].prompt, TOOLPROMPTSIZE);
	#endif

	// Save toolbutton
	i=TB_SAVE;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimSaveIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutSaveIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InSaveIcon");
	tb[i].state     =TOOLBUTTON_DIM;
	tb[i].prev_state=TOOLBUTTON_DIM;
	tb[i].flag      =FALSE;
	tb[i].abort=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Save", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_SAVE, tb[i].prompt, TOOLPROMPTSIZE);

	// Conv toolbutton
	i=TB_CONV;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimConvIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutConvIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InConvIcon");
	tb[i].state     =TOOLBUTTON_DIM;
	tb[i].prev_state=TOOLBUTTON_DIM;
	tb[i].flag      =FALSE;
	tb[i].abort=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Conv", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_CONV, tb[i].prompt, TOOLPROMPTSIZE);

	// Stat toolbutton
	i=TB_STAT;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimStatIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutStatIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InStatIcon");
	tb[i].state     =TOOLBUTTON_DIM;
	tb[i].prev_state=TOOLBUTTON_DIM;
	tb[i].flag      =FALSE;
	tb[i].abort=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Stats", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_STAT, tb[i].prompt, TOOLPROMPTSIZE);

	// Check toolbutton
	i=TB_CHECK;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimCheckIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutCheckIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InCheckIcon");
	tb[i].state     =TOOLBUTTON_DIM;
	tb[i].prev_state=TOOLBUTTON_DIM;
	tb[i].flag      =FALSE;
	tb[i].abort=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Check", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_CHECK, tb[i].prompt, TOOLPROMPTSIZE);

	// Run toolbutton
	i=TB_RUN;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimRunIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutRunIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InRunIcon");
	tb[i].state     =TOOLBUTTON_DIM;
	tb[i].prev_state=TOOLBUTTON_DIM;
	tb[i].flag      =FALSE;
	tb[i].abort=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Run", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_RUN, tb[i].prompt, TOOLPROMPTSIZE);

	// Norm toolbutton
	i=TB_NORM;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimNormIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutNormIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InNormIcon");
	tb[i].state     =TOOLBUTTON_DIM;
	tb[i].prev_state=TOOLBUTTON_DIM;
	tb[i].flag      =FALSE;
	tb[i].abort=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Norm", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_NORM, tb[i].prompt, TOOLPROMPTSIZE);

	// Plot toolbutton
	i=TB_PLOT;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimPlotIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutPlotIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InPlotIcon");
	tb[i].state     =TOOLBUTTON_DIM;
	tb[i].prev_state=TOOLBUTTON_DIM;
	tb[i].flag      =FALSE;
	tb[i].abort=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Plot", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_PLOT, tb[i].prompt, TOOLPROMPTSIZE);

	// Drift toolbutton
	i=TB_DRIFT;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimDriftIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutDriftIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InDriftIcon");
	tb[i].state     =TOOLBUTTON_DIM;
	tb[i].prev_state=TOOLBUTTON_DIM;
	tb[i].flag      =FALSE;
	tb[i].abort=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Drift", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_DRIFT, tb[i].prompt, TOOLPROMPTSIZE);

	#ifndef LITE_VER
	// Hist toolbutton
	i=TB_HIST;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimHistIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutHistIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InHistIcon");
	tb[i].state     =TOOLBUTTON_DIM;
	tb[i].prev_state=TOOLBUTTON_DIM;
	tb[i].flag      =FALSE;
	tb[i].abort=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Histo", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_HIST, tb[i].prompt, TOOLPROMPTSIZE);
	#endif

	#ifndef LITE_VER
	// Cal toolbutton
	i=TB_CAL;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimCalIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutCalIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InCalIcon");
	tb[i].state     =TOOLBUTTON_OUT;
	tb[i].prev_state=TOOLBUTTON_OUT;
	tb[i].flag      =FALSE;
	tb[i].abort=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Cal", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_CAL, tb[i].prompt, TOOLPROMPTSIZE);
	#endif

	#ifndef LITE_VER
	// Vibra toolbutton
	i=TB_VIBRA;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimVibIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutVibIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InVibIcon");
	tb[i].state     =TOOLBUTTON_OUT;
	tb[i].prev_state=TOOLBUTTON_OUT;
	tb[i].flag      =FALSE;
	tb[i].abort=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Vibra", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_VIBRA, tb[i].prompt, TOOLPROMPTSIZE);
	#endif

	#ifndef LITE_VER
	// Filter toolbutton
	i=TB_FILTER;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimFilIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutFilIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InFilIcon");
	tb[i].state     =TOOLBUTTON_DIM;
	tb[i].prev_state=TOOLBUTTON_DIM;
	tb[i].flag      =FALSE;
	tb[i].abort=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Filter", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_FILTER, tb[i].prompt, TOOLPROMPTSIZE);
	#endif

	// Avg toolbutton
	i=TB_AVG;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimAvgIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutAvgIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InAvgIcon");
	tb[i].state     =TOOLBUTTON_DIM;
	tb[i].prev_state=TOOLBUTTON_DIM;
	tb[i].flag      =FALSE;
	tb[i].abort=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Avg", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_AVG, tb[i].prompt, TOOLPROMPTSIZE);

	// Step toolbutton
	i=TB_STEP;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimStepIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutStepIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InStepIcon");
	tb[i].state     =TOOLBUTTON_DIM;
	tb[i].prev_state=TOOLBUTTON_DIM;
	tb[i].flag      =FALSE;
	tb[i].abort=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Step", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_STEP, tb[i].prompt, TOOLPROMPTSIZE);

	#ifndef LITE_VER
	// Prn toolbutton
	i=TB_PRINT;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimPrintIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutPrintIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InPrintIcon");
	tb[i].state     =TOOLBUTTON_DIM;
	tb[i].prev_state=TOOLBUTTON_DIM;
	tb[i].flag      =FALSE;
	tb[i].abort=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Print", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_PRINT, tb[i].prompt, TOOLPROMPTSIZE);
	#endif

	#ifndef LITE_VER
	// Noise toolbutton
	i=TB_NOISE;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimNoiseIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutNoiseIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InNoiseIcon");
	tb[i].state     =TOOLBUTTON_OUT;
	tb[i].prev_state=TOOLBUTTON_OUT;
	tb[i].flag      =FALSE;
	tb[i].abort=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Noise", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_NOISE, tb[i].prompt, TOOLPROMPTSIZE);
	#endif

	// Clear toolbutton
	i=TB_CLEAR;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimClearIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutClearIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InClearIcon");
	tb[i].state     =TOOLBUTTON_DIM;
	tb[i].prev_state=TOOLBUTTON_DIM;
	tb[i].flag      =FALSE;
	tb[i].abort=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Clear", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_CLEAR, tb[i].prompt, TOOLPROMPTSIZE);

	#ifndef LITE_VER
	// Power toolbutton
	i=TB_POWER;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimPowerIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutPowerIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InPowerIcon");
	tb[i].state     =TOOLBUTTON_DIM;
	tb[i].prev_state=TOOLBUTTON_DIM;
	tb[i].flag      =FALSE;
	tb[i].abort=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Power", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_POWER, tb[i].prompt, TOOLPROMPTSIZE);
	#endif

	// Edit toolbutton
	// Deactivated at start 11/14/96
	i=TB_EDIT;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimEditIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutEditIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InEditIcon");
	tb[i].state     =TOOLBUTTON_DIM;
	tb[i].prev_state=TOOLBUTTON_DIM;
	tb[i].flag      =FALSE;
	tb[i].abort=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Edit", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_EDIT, tb[i].prompt, TOOLPROMPTSIZE);

	// Sigma toolbutton
	i=TB_SIGMA;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimSigmaIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutSigmaIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InSigmaIcon");
	tb[i].state     =TOOLBUTTON_DIM;
	tb[i].prev_state=TOOLBUTTON_DIM;
	tb[i].flag      =FALSE;
	tb[i].abort=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Sigma", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_SIGMA, tb[i].prompt, TOOLPROMPTSIZE);

	#ifndef LITE_VER
	// Fill toolbutton
	i=TB_FILL;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimFillIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutFillIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InFillIcon");
	tb[i].state     =TOOLBUTTON_DIM;
	tb[i].prev_state=TOOLBUTTON_DIM;
	tb[i].flag      =FALSE;
	tb[i].abort=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Fill", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_FILL, tb[i].prompt, TOOLPROMPTSIZE);
	#endif

	// Scale toolbutton
	i=TB_SCALE;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimScaleIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutScaleIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InScaleIcon");
	tb[i].state     =TOOLBUTTON_DIM;
	tb[i].prev_state=TOOLBUTTON_DIM;
	tb[i].flag      =FALSE;
	tb[i].abort=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Scale", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_SCALE, tb[i].prompt, TOOLPROMPTSIZE);

	#ifndef LITE_VER
	#ifndef STUDENT_VER
	// Play toolbutton
	i=TB_PLAY;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimPlayIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutPlayIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InPlayIcon" );
	tb[i].state     =TOOLBUTTON_OUT;
	tb[i].prev_state=TOOLBUTTON_OUT;
	tb[i].flag      =FALSE;
	tb[i].abort=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Play", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_PLAY, tb[i].prompt, TOOLPROMPTSIZE);
	#endif
	#endif

	#ifndef LITE_VER
	//#ifndef STUDENT_VER // Removed 5/13/04
	// Autocorrelation toolbutton
	i=TB_ACS;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimACSIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutACSIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InACSIcon" );
	tb[i].state     =TOOLBUTTON_OUT;
	tb[i].prev_state=TOOLBUTTON_OUT;
	tb[i].flag      =FALSE;
	tb[i].abort=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "ACF", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_ACS, tb[i].prompt, TOOLPROMPTSIZE);
	//#endif
	#endif

	#ifndef LITE_VER
	// Timetag toolbar
	i=TB_TIMETAG;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimTagIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutTagIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InTagIcon" );
	tb[i].state     =TOOLBUTTON_DIM;
	tb[i].prev_state=TOOLBUTTON_DIM;
	tb[i].flag      =FALSE;
	tb[i].abort=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Tag", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_TIMETAG, tb[i].prompt, TOOLPROMPTSIZE);
	#endif

	#ifndef LITE_VER
	// Regularize toolbar
	i=TB_REGULARIZE;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimRegIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutRegIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InRegIcon" );
	tb[i].state     =TOOLBUTTON_DIM;
	tb[i].prev_state=TOOLBUTTON_DIM;
	tb[i].flag      =FALSE;
	tb[i].abort=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Reg", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_REGULARIZE, tb[i].prompt, TOOLPROMPTSIZE);
	#endif

	#ifndef LITE_VER
	// Domain toolbar
	i=TB_DOMAIN;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimDomainIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutDomainIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InDomainIcon" );
	tb[i].state     =TOOLBUTTON_OUT;
	tb[i].prev_state=TOOLBUTTON_OUT;
	tb[i].flag      =FALSE;
	tb[i].abort=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Dom", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_DOMAIN, tb[i].prompt, TOOLPROMPTSIZE);
	#endif

	// Part toolbar
	i=TB_PART;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimPartIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutPartIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InPartIcon" );
	tb[i].state     =TOOLBUTTON_DIM;
	tb[i].prev_state=TOOLBUTTON_DIM;
	tb[i].flag      =FALSE;
	tb[i].abort=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Part", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_PART, tb[i].prompt, TOOLPROMPTSIZE);

	#ifndef LITE_VER
	// Configure toolbar
	i=TB_CONF;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimConfIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutConfIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InConfIcon" );
	tb[i].state     =TOOLBUTTON_OUT;
	tb[i].prev_state=TOOLBUTTON_OUT;
	tb[i].flag      =FALSE;
	tb[i].abort=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Conf", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_CONF, tb[i].prompt, TOOLPROMPTSIZE);
	#endif

	#ifndef LITE_VER
	// File toolbar
	i=TB_FILE;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimFileIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutFileIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InFileIcon" );
	tb[i].state     =TOOLBUTTON_OUT;
	tb[i].prev_state=TOOLBUTTON_OUT;
	tb[i].flag      =FALSE;
	tb[i].abort=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "File", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_FILE, tb[i].prompt, TOOLPROMPTSIZE);
	#endif

	// Help toolbar
	i=TB_HELP;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "OutHlpIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutHlpIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InHlpIcon" );
	tb[i].state     =TOOLBUTTON_OUT;
	tb[i].prev_state=TOOLBUTTON_OUT;
	tb[i].flag      =FALSE;
	tb[i].abort		=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Help", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_HELP, tb[i].prompt, TOOLPROMPTSIZE);

	#ifndef SPECIAL_VERSION
	#ifndef LITE_VER
	// Notepad toolbar
	i=TB_NOTEPAD;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "OutPadIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutPadIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InPadIcon" );
	tb[i].state     =TOOLBUTTON_OUT;
	tb[i].prev_state=TOOLBUTTON_OUT;
	tb[i].flag      =FALSE;
	tb[i].abort		=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Pad", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_NOTEPAD, tb[i].prompt, TOOLPROMPTSIZE);
	#endif
	#endif

	#ifndef SPECIAL_VERSION
	#ifndef LITE_VER
	// Tab toolbar
	i=TB_TAB;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimTabIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutTabIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InTabIcon" );
	tb[i].state     =TOOLBUTTON_OUT;
	tb[i].prev_state=TOOLBUTTON_OUT;
	tb[i].flag      =FALSE;
	tb[i].abort		=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Tab", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_TAB, tb[i].prompt, TOOLPROMPTSIZE);
	#endif
	#endif

	#ifndef SPECIAL_VERSION
	#ifndef LITE_VER
	#ifndef STUDENT_VER
	// 5110Comm toolbar
	i=TB_COMM;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimCommIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutCommIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InCommIcon" );
	tb[i].state     =TOOLBUTTON_OUT;
	tb[i].prev_state=TOOLBUTTON_OUT;
	tb[i].flag      =FALSE;
	tb[i].abort		=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Comm", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_COMM, tb[i].prompt, TOOLPROMPTSIZE);
	#endif
	#endif
	#endif

	#ifndef SPECIAL_VERSION
	#ifndef LITE_VER
	//#ifndef STUDENT_VER
	// DAVAR toolbar
	i=TB_DAVAR;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimDAVARIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutDAVARIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InDAVARIcon" );
	tb[i].state     =TOOLBUTTON_OUT;
	tb[i].prev_state=TOOLBUTTON_OUT;
	tb[i].flag      =FALSE;
	tb[i].abort		=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "DVAR", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_DAVAR, tb[i].prompt, TOOLPROMPTSIZE);
	//#endif
	#endif
	#endif

	#ifndef SPECIAL_VERSION
	#ifndef LITE_VER
	#ifndef STUDENT_VER
	// Database toolbar
	i=TB_SQL;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimSQLIcon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutSQLIcon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InSQLIcon" );
	tb[i].state     =TOOLBUTTON_OUT;
	tb[i].prev_state=TOOLBUTTON_OUT;
	tb[i].flag      =FALSE;
	tb[i].abort		=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "DBase", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_SQL, tb[i].prompt, TOOLPROMPTSIZE);
	#endif
	#endif
	#endif

	#ifndef SPECIAL_VERSION
	#ifndef LITE_VER
	#ifndef STUDENT_VER
	// Automatic processiog toolbars
	i=TB_AUTO1;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimAuto1Icon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutAuto1Icon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InAuto1Icon" );
	tb[i].state     =TOOLBUTTON_OUT;
	tb[i].prev_state=TOOLBUTTON_OUT;
	tb[i].flag      =FALSE;
	tb[i].abort		=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Auto1", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_AUTO1, tb[i].prompt, TOOLPROMPTSIZE);

	i=TB_AUTO2;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimAuto2Icon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutAuto2Icon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InAuto2Icon" );
	tb[i].state     =TOOLBUTTON_OUT;
	tb[i].prev_state=TOOLBUTTON_OUT;
	tb[i].flag      =FALSE;
	tb[i].abort		=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Auto2", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_AUTO2, tb[i].prompt, TOOLPROMPTSIZE);

	i=TB_AUTO3;
	tb[i].hIcon[0]=LoadIcon(hInst, "BlankIcon");
	tb[i].hIcon[1]=LoadIcon(hInst, "DimAuto3Icon");
	tb[i].hIcon[2]=LoadIcon(hInst, "OutAuto3Icon");
	tb[i].hIcon[3]=LoadIcon(hInst, "InAuto3Icon" );
	tb[i].state     =TOOLBUTTON_OUT;
	tb[i].prev_state=TOOLBUTTON_OUT;
	tb[i].flag      =FALSE;
	tb[i].abort		=FALSE;
	tb[i].type      =TOOLBUTTON_MOMENTARY;
	strlcpy(tb[i].label, "Auto3", TOOLLABELSIZE);
	LoadString(hInst, IDS_TB_AUTO3, tb[i].prompt, TOOLPROMPTSIZE);
	#endif
	#endif
	#endif
}

/*****************************************************************************/
/*                                                                           */
/*               Function to activate or deactivate data functions           */
/*                                                                           */
/*  Parameters:  UINT wEnable  (MF_ENABLED or MF_GRAYED)                     */
/*                                                                           */
/*  Globals:     BOOL bDataType  (TRUE=frequency data, FALSE=phase data)     */
/*               TOOLBUTTON tb[]  Array of toolbutton structures             */
/*                                                                           */
/*  Return: none (void)                                                      */
/*                                                                           */
/*  Revision record:                                                         */
/*  	08/23/96		Added greying of regularize function                 */
/*		11/14/96		Added activation of edit function                    */
/*		08/27/98		Added greying of status bar access controls          */
/*		04/28/01		Added automatic processing buttons                   */
/*                                                                           */
/*****************************************************************************/

void WINAPI ActivateFunctions(UINT wEnable)
{
	// Local variable
	UINT wToolbutton=TOOLBUTTON_DIM;

	if(wEnable==MF_ENABLED)
	{
		wToolbutton=TOOLBUTTON_OUT;
	}

	#ifdef SPECIAL_VERSION
	EnableMenuItem(hMenu, IDM_MAIN_SAVE, MF_GRAYED);
	EnableMenuItem(hMenu, IDM_ADD, MF_GRAYED);
	EnableMenuItem(hMenu, IDM_READ, MF_GRAYED);
	EnableMenuItem(hMenu, IDM_MAIN_PRINT, MF_GRAYED);
	EnableMenuItem(hMenu, IDM_CONV, MF_GRAYED);
	EnableMenuItem(hMenu, IDM_CLEAR, MF_GRAYED);
	EnableMenuItem(hMenu, IDM_NORM, MF_GRAYED);
	EnableMenuItem(hMenu, IDM_AVG, MF_GRAYED);
	EnableMenuItem(hMenu, IDM_FILL, MF_GRAYED);
	EnableMenuItem(hMenu, IDM_SCALE, MF_GRAYED);
	EnableMenuItem(hMenu, IDM_STAT, MF_GRAYED);
	EnableMenuItem(hMenu, IDM_CHECK, MF_GRAYED);
	EnableMenuItem(hMenu, IDM_DRIFT, MF_GRAYED);
	EnableMenuItem(hMenu, IDM_SIGMA, wEnable);
	EnableMenuItem(hMenu, IDM_RUN, wEnable);
	EnableMenuItem(hMenu, IDM_POWER, MF_GRAYED);
	EnableMenuItem(hMenu, IDM_AUTO, MF_GRAYED);
	EnableMenuItem(hMenu, IDM_HIST, MF_GRAYED);
	EnableMenuItem(hMenu, IDM_TIMETAG, MF_GRAYED);
	EnableMenuItem(hMenu, IDM_PART, MF_GRAYED);
	EnableMenuItem(hMenu, IDM_CAL, MF_GRAYED);
	EnableMenuItem(hMenu, IDM_DOMAIN, MF_GRAYED);
	EnableMenuItem(hMenu, IDM_PLAY, MF_GRAYED);
	EnableMenuItem(hMenu, IDM_NOISE, MF_GRAYED);
	EnableMenuItem(hMenu, IDM_NOTEPAD, MF_GRAYED);
	EnableMenuItem(hMenu, IDM_CONFIG, MF_GRAYED);
	EnableMenuItem(hMenu, IDM_MAIN_EDIT, MF_GRAYED);
	
	#else // Normal version
	EnableMenuItem(hMenu, IDM_MAIN_SAVE, wEnable);
	EnableMenuItem(hMenu, IDM_ADD, wEnable);
	EnableMenuItem(hMenu, IDM_MAIN_PRINT, wEnable);
	EnableMenuItem(hMenu, IDM_CONV, wEnable);
	EnableMenuItem(hMenu, IDM_CLEAR, wEnable);
	EnableMenuItem(hMenu, IDM_NORM, wEnable);
	EnableMenuItem(hMenu, IDM_AVG, wEnable);
	EnableMenuItem(hMenu, IDM_FILL, wEnable);
	EnableMenuItem(hMenu, IDM_SCALE, wEnable);
	EnableMenuItem(hMenu, IDM_STAT, wEnable);
	EnableMenuItem(hMenu, IDM_CHECK, wEnable);
	EnableMenuItem(hMenu, IDM_DRIFT, wEnable);
	EnableMenuItem(hMenu, IDM_SIGMA, wEnable);
	EnableMenuItem(hMenu, IDM_RUN, wEnable);
	EnableMenuItem(hMenu, IDM_DAVAR, wEnable);
	EnableMenuItem(hMenu, IDM_POWER, wEnable);
	EnableMenuItem(hMenu, IDM_AUTO, wEnable);
	EnableMenuItem(hMenu, IDM_HIST, wEnable);
	EnableMenuItem(hMenu, IDM_TIMETAG, wEnable);
	EnableMenuItem(hMenu, IDM_PART, wEnable);
	EnableMenuItem(hMenu, IDM_FILTER, wEnable);
	EnableMenuItem(hMenu, IDM_STEP, wEnable);
	EnableMenuItem(hMenu, IDM_MAIN_EDIT, wEnable);
	#endif

	if(bPhaseData)
	{
		EnableMenuItem(hMenu, IDC_PHASETAUSELECT, MF_ENABLED);
		EnableMenuItem(hMenu, IDC_PHASEFILESELECT, MF_ENABLED);
		EnableMenuItem(hMenu, IDC_PHASESTARTSELECT, MF_ENABLED);
		EnableMenuItem(hMenu, IDC_PHASEENDSELECT, MF_ENABLED);
	}
	else
	{
		EnableMenuItem(hMenu, IDC_PHASETAUSELECT, MF_GRAYED);
		EnableMenuItem(hMenu, IDC_PHASEFILESELECT, MF_GRAYED);
		EnableMenuItem(hMenu, IDC_PHASESTARTSELECT, MF_GRAYED);
		EnableMenuItem(hMenu, IDC_PHASEENDSELECT, MF_GRAYED);
	}

	if(bFreqData)
	{
		EnableMenuItem(hMenu, IDC_FREQTAUSELECT, MF_ENABLED);
		EnableMenuItem(hMenu, IDC_FREQFILESELECT, MF_ENABLED);
		EnableMenuItem(hMenu, IDC_FREQSTARTSELECT, MF_ENABLED);
		EnableMenuItem(hMenu, IDC_FREQENDSELECT, MF_ENABLED);
	}
	else
	{
		EnableMenuItem(hMenu, IDC_FREQTAUSELECT, MF_GRAYED);
		EnableMenuItem(hMenu, IDC_FREQFILESELECT, MF_GRAYED);
		EnableMenuItem(hMenu, IDC_FREQSTARTSELECT, MF_GRAYED);
		EnableMenuItem(hMenu, IDC_FREQENDSELECT, MF_GRAYED);
	}

	if(bDataType==FREQ_DATA)
	{
		#ifndef SPECIAL_VERSION
		EnableMenuItem(hMenu, IDM_FREQ_PLOT, wEnable);
		EnableMenuItem(hMenu, IDM_CHECK, wEnable);
		tb[TB_CHECK].state=wToolbutton;
        #endif

		#ifndef LITE_VER
		if(bFreqTimetags) // Enable regularize function
		{
			#ifndef SPECIAL_VERSION
			EnableMenuItem(hMenu, IDM_REGULARIZE, MF_ENABLED);
			tb[TB_REGULARIZE].state=TOOLBUTTON_OUT;
			#endif
		}
		else
		{
			EnableMenuItem(hMenu, IDM_REGULARIZE, MF_GRAYED);
			tb[TB_REGULARIZE].state=TOOLBUTTON_DIM;
		}
		#endif

		// Unstep applies only to phase data
		EnableMenuItem(hMenu, IDM_STEP, MF_GRAYED);
		tb[TB_STEP].state=TOOLBUTTON_DIM;
	}
	else if(bDataType==PHASE_DATA)
	{
		#ifndef SPECIAL_VERSION
		EnableMenuItem(hMenu, IDM_PHASE_PLOT, wEnable);
		#endif

		// Check applies only to freq data
		EnableMenuItem(hMenu, IDM_CHECK, MF_GRAYED);
		tb[TB_CHECK].state=TOOLBUTTON_DIM;

		#ifndef LITE_VER
		if(bPhaseTimetags) // Enable regularize function
		{
			#ifndef SPECIAL_VERSION
			EnableMenuItem(hMenu, IDM_REGULARIZE, MF_ENABLED);
			tb[TB_REGULARIZE].state=TOOLBUTTON_OUT;
			#endif
		}
		else
		{
			EnableMenuItem(hMenu, IDM_REGULARIZE, MF_GRAYED);
			tb[TB_REGULARIZE].state=TOOLBUTTON_DIM;
		}
		#endif

		// Unstep applies to phase data
		if(wEnable==MF_ENABLED)
		{
			EnableMenuItem(hMenu, IDM_STEP, MF_ENABLED);
			tb[TB_STEP].state=TOOLBUTTON_OUT;
		}
		else
		{
			EnableMenuItem(hMenu, IDM_STEP, MF_GRAYED);
			tb[TB_STEP].state=TOOLBUTTON_DIM;
		}
	}

	// Control avtivation of Audio item in Utilities menu
	if(bDataType==FREQ_DATA)
	{
		if(bFreqData)
		{
			EnableMenuItem(hMenu, IDM_AUDIO, MF_ENABLED);
		}
		else
		{
			EnableMenuItem(hMenu, IDM_AUDIO, MF_GRAYED);
		}
	}
	else // Phase data
	{
		if(bPhaseData)
		{
			EnableMenuItem(hMenu, IDM_AUDIO, MF_ENABLED);
		}
		else
		{
			EnableMenuItem(hMenu, IDM_AUDIO, MF_GRAYED);
		}
	}

	#ifdef SPECIAL_VERSION
	tb[TB_SAVE].state=TOOLBUTTON_DIM;
	tb[TB_ADD].state=TOOLBUTTON_DIM;
	tb[TB_PRINT].state=TOOLBUTTON_DIM;
	tb[TB_CONV].state=TOOLBUTTON_DIM;
	tb[TB_CLEAR].state=TOOLBUTTON_DIM;
	tb[TB_NORM].state=TOOLBUTTON_DIM;
	tb[TB_AVG].state=TOOLBUTTON_DIM;
	tb[TB_FILL].state=TOOLBUTTON_DIM;
	tb[TB_SCALE].state=TOOLBUTTON_DIM;
	tb[TB_STAT].state=TOOLBUTTON_DIM;
	tb[TB_DRIFT].state=TOOLBUTTON_DIM;
	tb[TB_SIGMA].state=wToolbutton;
	tb[TB_RUN].state=wToolbutton;
	tb[TB_DAVAR].state=wToolbutton;
	tb[TB_POWER].state=TOOLBUTTON_DIM;
	tb[TB_HIST].state=TOOLBUTTON_DIM;
	tb[TB_PLOT].state=TOOLBUTTON_DIM;
	tb[TB_TIMETAG].state=TOOLBUTTON_DIM;
	tb[TB_PART].state=TOOLBUTTON_DIM;
	tb[TB_EDIT].state=TOOLBUTTON_DIM;
	tb[TB_READ].state=TOOLBUTTON_DIM;
	tb[TB_NOISE].state=TOOLBUTTON_DIM;
	tb[TB_CAL].state=TOOLBUTTON_DIM;
	tb[TB_PLAY].state=TOOLBUTTON_DIM;
	tb[TB_NOTEPAD].state=TOOLBUTTON_DIM;
	tb[TB_DOMAIN].state=TOOLBUTTON_DIM;
	#else // Normal version
	tb[TB_SAVE].state=wToolbutton;
	tb[TB_CONV].state=wToolbutton;
	tb[TB_CLEAR].state=wToolbutton;
	tb[TB_NORM].state=wToolbutton;
	tb[TB_AVG].state=wToolbutton;
	tb[TB_SCALE].state=wToolbutton;
	tb[TB_STAT].state=wToolbutton;
	tb[TB_DRIFT].state=wToolbutton;
	tb[TB_SIGMA].state=wToolbutton;
	tb[TB_RUN].state=wToolbutton;
	tb[TB_DAVAR].state=wToolbutton;
	tb[TB_PLOT].state=wToolbutton;
	tb[TB_EDIT].state=wToolbutton;
	tb[TB_PART].state=wToolbutton;
	tb[TB_TAB].state=wToolbutton;
	tb[TB_FILTER].state=wToolbutton;

	#ifndef LITE_VER
	tb[TB_ADD].state=wToolbutton;
	tb[TB_PRINT].state=wToolbutton;
	tb[TB_FILL].state=wToolbutton;
	tb[TB_POWER].state=wToolbutton;
	tb[TB_HIST].state=wToolbutton;
	tb[TB_ACS].state=wToolbutton;
	tb[TB_TIMETAG].state=wToolbutton;
	#endif
	#endif

	RedrawToolbar(tb, FALSE);
}

/*****************************************************************************/
/*                                                                           */
/*                   Function to subclass edit control                       */
/*                   Uses ENTER key to kill focus                            */
/*                                                                           */
/*****************************************************************************/

LRESULT CALLBACK EditProc(HWND hwnd, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables

	switch(message)
	{
		case WM_KEYDOWN:
		{
			if(GET_WM_COMMAND_ID(wParam, lParam)==VK_RETURN)
			{
				SetFocus(NULL);
			}
		}
		break;
	}
	return CallWindowProc((WNDPROC) lpfnOldEdit, hwnd, message, wParam, lParam);
}

/*****************************************************************************/
/*                                                                           */
/*             Function to write general message in status bar               */
/*                                                                           */
/*                                                                           */
/*****************************************************************************/
void WINAPI WriteMessage(LPSTR szMessage)
{
	// Local variables
	RECT rect;
	HDC hdc;
	HFONT hFont;			// Font handle
	static LOGFONT logfont;	// Font structure - static fills it it with zeros

	// Fill in size of font structure
	logfont.lfHeight=16; // 16 seems to match size of text in dialog boxes

	// Specify highest quality font - avoid scaling of a raster font
	logfont.lfQuality=PROOF_QUALITY;
	// Specify font family
	logfont.lfPitchAndFamily=FF_SWISS;
	// Set the facename
	strlcpy(logfont.lfFaceName, "MS Sans Serif", LF_FACESIZE);

	// Create font
	hFont=CreateFontIndirect(&logfont);

	// Get device context
	hdc=GetDC(hwndMain);

	// Select font into device context
	SelectObject(hdc, hFont);
	
	// Write message in message bar above status bar
	SetRect(&rect, -1, (int)(cyClient-3.25*cyChar-2.5*cyChar/2.5),
		cxClient+1, (int)(cyClient-3.25*cyChar-2));
	FillRect(hdc, &rect, GetStockObject(LTGRAY_BRUSH));
	FrameRect(hdc, &rect, GetStockObject(BLACK_BRUSH));
	SetBkColor(hdc, GetSysColor(COLOR_BTNFACE));
	ExtTextOut(hdc, 0, (int)(cyClient-3.25*cyChar-2.5*cyChar/2.5),
		ETO_OPAQUE, &rect, szMessage, strlen(szMessage),
		NULL);

	// Deselect & delete custom font GDI object
	SelectFont(hdc, GetStockObject(SYSTEM_FONT));
	DeleteObject(hFont);
	
	// Release device context
	ReleaseDC(hwndMain, hdc);
}

/*****************************************************************************/

