/*****************************************************************************/
/*                                                                           */
/*								Stable32_l.c                                 */
/*                                                                           */
/*			Configure Property Sheet Code for Stable32 Program               */
/*                                                                           */
/*   Supports eight Configure property sheet pages as follows:               */
/*                                                                           */
/*   Name			Template					Procedure                    */
/*                                                                           */
/*   General		CONFIGUREGENERALTAB         Page1Proc()                  */
/*   Toolbuttons	CONFIGURETOOLBUTTONSTAB		Page2Proc()                  */
/*   Plots			CONFIGUREPLOTSTAB			Page3Proc()                  */
/*   Data			CONFIGUREDATATAB			Page4Proc()                  */
/*   Inputs			CONFIGUREINPUTSTAB			Page5Proc()                  */
/*   Options		CONFIGUREOPTIONSTAB			Page6Proc()                  */
/*   Audio			CONFIGUREOAUDIOTAB			Page7Proc()                  */
/*   Run			CONFIGURERUNTAB				Page8roc()                   */
/*                                                                           */
/*   Note: I have not found a satisfactory way to trap the Enter key         */
/*   action that terminates a property sheet page.  Intercepting the         */
/*   PSN_KILLACTIVE notification and sending a DWL_MSGRESULT=TRUE            */
/*   doesn't always work, and, when it does,  it messes up the focus         */
/*   so that the tabs don't respond correctly.  No SetFocus() seems to       */
/*   fix this.  So, unless a better way is found, the default response       */
/*   to the Enter key to accept the changes and close the property sheet     */
/*                                                                           */
/*	Revision record:                                                         */
/*      07/23/07    Changed to safe string functions                         */
/*		08/27/08	Added Run page                                           */
/*                                                                           */
/*  (c) 2006-7  W. Riley  Hamilton Technical Services  All Rights Reserved   */
/*                                                                           */
/*****************************************************************************/

// Includes
#define STRICT              // For Win32 compatibility
#include "stable_w.h"

/*****************************************************************************/
/*                                                                           */
/*							Main Property Sheet Code					     */
/*                                                                           */
/*      Ref: R. Simon, "Windows 95 Common Controls & Messages API Bible",    */
/*      Waite Group Press, 1996, ISBN 1-57169-010-7.                         */
/*                                                                           */
/*		Revision record:													 */
/*			02/02/07	Created	from MMS4.c									 */
/*			08/27/08	Added Run page                                       */
/*                                                                           */
/*****************************************************************************/

VOID DisplayProperties(HWND hWnd)
{
	PROPSHEETPAGE	psp;
	PROPSHEETHEADER	psh;
	HPROPSHEETPAGE	hpsp[8];

	// Create the property pages
	psp.dwSize		= sizeof(PROPSHEETPAGE);
	psp.dwFlags		= PSP_DEFAULT;
	psp.hInstance	= hInst;

	psp.pszTemplate	= "CONFIGUREGENERALTAB";
	psp.pfnDlgProc	= (DLGPROC)Page1Proc;
	psp.dwFlags		= PSP_HASHELP;
	hpsp[0]	= CreatePropertySheetPage(&psp);

	psp.pszTemplate	= "CONFIGURETOOLBUTTONSTAB";
	psp.pfnDlgProc	= (DLGPROC)Page2Proc;
	psp.dwFlags		= PSP_HASHELP;
	hpsp[1]	= CreatePropertySheetPage(&psp);

	psp.pszTemplate	= "CONFIGUREPLOTSTAB";
	psp.pfnDlgProc	= (DLGPROC)Page3Proc;
	psp.dwFlags		= PSP_HASHELP;
	hpsp[2]	= CreatePropertySheetPage(&psp);

	psp.pszTemplate	= "CONFIGUREDATATAB";
	psp.pfnDlgProc	= (DLGPROC)Page4Proc;
	psp.dwFlags		= PSP_HASHELP;
	hpsp[3]	= CreatePropertySheetPage(&psp);

	psp.pszTemplate	= "CONFIGUREINPUTSTAB";
	psp.pfnDlgProc	= (DLGPROC)Page5Proc;
	psp.dwFlags		= PSP_HASHELP;
	hpsp[4]	= CreatePropertySheetPage(&psp);

	psp.pszTemplate	= "CONFIGUREOPTIONSTAB";
	psp.pfnDlgProc	= (DLGPROC)Page6Proc;
	psp.dwFlags		= PSP_HASHELP;
	hpsp[5]	= CreatePropertySheetPage(&psp);
	
	psp.pszTemplate	= "CONFIGUREAUDIOTAB";
	psp.pfnDlgProc	= (DLGPROC)Page7Proc;
	psp.dwFlags		= PSP_HASHELP;
	hpsp[6]	= CreatePropertySheetPage(&psp);

	psp.pszTemplate	= "CONFIGURERUNTAB";
	psp.pfnDlgProc	= (DLGPROC)Page8Proc;
	psp.dwFlags		= PSP_HASHELP;
	hpsp[7]	= CreatePropertySheetPage(&psp);

	// Initialize the property sheet structure
	memset(&psh, 0, sizeof(PROPSHEETHEADER));
	psh.dwSize		= sizeof(PROPSHEETHEADER);
	psh.dwFlags		= PSH_USEICONID | PSH_HASHELP | PSH_NOAPPLYNOW;
	psh.hInstance	= hInst;
	psh.hwndParent	= hWnd;
	psh.pszIcon		= "SMALL";
	psh.nPages		= 8;
	psh.phpage		= hpsp;
	psh.pszCaption	= "Configure";
	psh.nStartPage	= nConfigPage; // Open last page opened

	// Display the property sheet
	PropertySheet(&psh);
}

// Property sheet dialog procs
/*****************************************************************************/
/*                                                                           */
/*	              Page1Proc for General Configuration Property Sheet	     */
/*                                                                           */
/*      Revision record:                                                     */
/*			02/02/07	Created	from MMS4.c									 */
/*			02/08/07	Added No Greek, Splash & Notepad                     */
/*			07/27/07	Added Point Size                                     */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK Page1Proc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	// Ints
	int i;							// General index
	static int nPointSizeSave;		// Save org point size
	// BOOLs
	static BOOL bShowFileOpenedSave;
									// Save orig show file opened flag state
	static BOOL bIncExtSave;		// Save original plot label flag state
	static BOOL bWriteSigmaSave;	// Save org write sigma data flag state
	static BOOL bAutoCalcSave;		// Save org autocalc flag state
	static BOOL bAutoPlotSave;		// Save org autoplot flag state
	static BOOL bStatusPlotSave;	// Save org status plot flag state
	static BOOL bNoGreekSave;		// Save org no greek flag state
	static BOOL bSplashSave;		// Save org splash flag state
	static BOOL bDataTypeSave;		// Save org data type
	
	//Chars
	char szBuffer[BUFFER_SIZE+1];	// General text buffer
	static char szNotepadSave[FILENAMESIZE+1]; 
									// Original notepad filename buffer

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Save data type
			bDataTypeSave=bDataType;

			// Save this page # as last one opened
			nConfigPage=0;

			// Read configuration file preference items
			// Not necessary unless the ini file is manually edited
			// while Stable32 is running
			ReadIni(INI_PREFS);

			// Write prompt message
			LoadString(hInst, IDS_MESSAGE_CONFIGURE, szBuffer,
				BUFFER_SIZE);
			WriteMessage(szBuffer);

			// Display the autoinc filename extension checkbox state
			Button_SetCheck(GETHCTL(IDC_CONFIG_INCEXT), bIncExtension);

			// Display the write sigma data file checkbox state
			Button_SetCheck(GETHCTL(IDC_CONFIG_WRITESIGMA), bWriteSigmaFile);

			// Display the autocalc checkbox state
			Button_SetCheck(GETHCTL(IDC_CONFIG_AUTOCALC), bAutoCalc);

			// Display the autoplot checkbox state
			Button_SetCheck(GETHCTL(IDC_CONFIG_AUTOPLOT), bAutoPlot);

			// Display the status plots checkbox state
			Button_SetCheck(GETHCTL(IDC_CONFIG_STATPLOTS), bStatusPlot);

			// Display the show file opened checkbox state
			Button_SetCheck(GETHCTL(IDC_CONFIG_SHOWOPENED), bShowFileOpened);

			// Display the no greek checkbox state
			Button_SetCheck(GETHCTL(IDC_CONFIG_NOGREEK), bNoGreek);

			// Display the show splash checkbox state
			Button_SetCheck(GETHCTL(IDC_CONFIG_SPLASH), bSplash);

			// Display the notepad filename
			SetWindowText(GETHCTL(IDC_CONFIG_NOTEPAD), szNotepad);

			// Fill up the point size list box with avaliable choices
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_CONFIG_POINTSIZE));

			// Put in point sizes from 6 to 12
			// Corresponding to indices from 0 to 6
			// So nPointSize=i+6 and i=nPointSize-6
			for(i=0; i<7; i++)
			{
				_snprintf(szBuffer, sizeof(szBuffer), "%d", i+6);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_CONFIG_POINTSIZE), i,
					szBuffer);
			}

			// Show currently selected point size per nPointSize
			nDummy=ComboBox_SetCurSel(GETHCTL(IDC_CONFIG_POINTSIZE),
				nPointSize-6);

			// Save the original flag values in case cancel is pressed
			bShowFileOpenedSave=bShowFileOpened;
            bIncExtSave=bIncExtension;
            bWriteSigmaSave=bWriteSigmaFile;
            bAutoCalcSave=bAutoCalc;
            bAutoPlotSave=bAutoPlot;
            bStatusPlotSave=bStatusPlot;
            bNoGreekSave=bNoGreek;
            bSplashSave=bSplash;
			nPointSizeSave=nPointSize;

			// Save original string values in case cancel is pressed
			strlcpy(szNotepadSave, szNotepad, sizeof(szNotepadSave));
		}
		return TRUE;

		case WM_NOTIFY:
		{
			switch(((NMHDR FAR*)lParam)->code)
			{
				// Respond to PSN_KILLACTIVATE notification message
				// Pressing OK button, or pressing Enter when in edit box
				// sends this message - No way I know to tell which
				// When the Enter key is pressed while in an edit box
				// the main property sheet box treats this as
				// a default OK button press
				// and closes the entire property sheet.  No way found to make
				// Enter command to reformat the edit box contents.
				case PSN_KILLACTIVE:
				{
					// Restore data type
					bDataType=bDataTypeSave;
					
					// Write the STABLE32.INI configuration file
					WriteIni(INI_PREFS);
				}
				break;

				// Respond to PSN_RESET message
				// Sent in response to user pressing Cancel button
				// on main property sheet
				// We want to restore original settings before property sheet closes
				case PSN_RESET:
				{
					// Restore only if this page was one reset
					if(nConfigPage==0)
					{
						// Restore the original flag values
						bShowFileOpened=bShowFileOpenedSave;
						bIncExtension=bIncExtSave;
						bWriteSigmaFile=bWriteSigmaSave;
						bAutoCalc=bAutoCalcSave;
						bAutoPlot=bAutoPlotSave;
						bStatusPlot=bStatusPlotSave;
						bNoGreek=bNoGreekSave;
						bSplash=bSplashSave;
						nPointSize=nPointSizeSave;

						// Restore original string values
						strlcpy(szNotepad, szNotepadSave, FILE_NAME_SIZE);
					}

					// Restore data type
					bDataType=bDataTypeSave;
				}
				break;

				// Respond to PSN_APPLY message
				case PSN_APPLY:
				{
					;
				}
				break;

				// Respond to PSN_HELP message
				case PSN_HELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::CONFIGURE_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::CONFIGURATION_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "CONFIGURATION_FUNCTION");
					#endif
				}
				break;
			}
		}
		break;

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				case IDC_CONFIG_SHOWOPENED:
				{
					// Get the state of the show file opened checkbox
					bShowFileOpened=
						(BOOL)Button_GetCheck(GETHCTL(IDC_CONFIG_SHOWOPENED));
				}
				break;

				case IDC_CONFIG_INCEXT:
				{
					// Get state of autoinc filename extension checkbox
					bIncExtension=
						(BOOL)Button_GetCheck(GETHCTL(IDC_CONFIG_INCEXT));
				}
				break;

				case IDC_CONFIG_WRITESIGMA:
				{
					// Get the state of the write sigma checkbox
					bWriteSigmaFile=
						(BOOL)Button_GetCheck(GETHCTL(IDC_CONFIG_WRITESIGMA));
				}
				break;

				case IDC_CONFIG_AUTOCALC:
				{
					// Get the state of the autocalc checkbox
					bAutoCalc=
						(BOOL)Button_GetCheck(GETHCTL(IDC_CONFIG_AUTOCALC));
				}
				break;

				case IDC_CONFIG_AUTOPLOT:
				{
					// Get the state of the autoplot checkbox
					bAutoPlot=(BOOL)
						Button_GetCheck(GETHCTL(IDC_CONFIG_AUTOPLOT));
				}
				break;

				case IDC_CONFIG_STATPLOTS:
				{
					// Get the state of the status plot checkbox
					bStatusPlot=(BOOL)
						Button_GetCheck(GETHCTL(IDC_CONFIG_STATPLOTS));
				}
				break;

				case IDC_CONFIG_NOGREEK:
				{
					// Get the state of the no greek checkbox
					bNoGreek=(BOOL)
						Button_GetCheck(GETHCTL(IDC_CONFIG_NOGREEK));
				}
				break;
				case IDC_CONFIG_SPLASH:
				{
					// Get the state of the splash checkbox
					bSplash=(BOOL)
						Button_GetCheck(GETHCTL(IDC_CONFIG_SPLASH));
				}
				break;

				case IDC_CONFIG_POINTSIZE:
				{
					// Get selected point size
					nPointSize=
						6+ComboBox_GetCurSel(GETHCTL(IDC_CONFIG_POINTSIZE));
                }
                break;

				case IDC_CONFIG_NOTEPAD:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(GetFocus()!=GETHCTL(IDC_CONFIG_CANCEL)))
					{
						// Get new text editor filename
						GetWindowText(GETHCTL(IDC_CONFIG_NOTEPAD),
							szNotepad, FILENAMESIZE);

						// Display the text editor filename
						SetWindowText(GETHCTL(IDC_CONFIG_NOTEPAD), szNotepad);
					}
				}
				break;

                return TRUE;
            }
        }
        break;
	 }
     return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*	    Page2Proc for Toolbuttons Configuration Property Sheet		         */
/*                                                                           */
/*      Revision record:                                                     */
/*			02/02/07	Created	from MMS4.c									 */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK Page2Proc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	// Ints
	int i;                             // Index
	int nBlanks;                       // Blank toolbutton count
	// Bools
	static BOOL bDataTypeSave;			// Save org data type
	//Chars
	char szBuffer[BUFFER_SIZE+1];      // Text buffer

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Save data type
			bDataTypeSave=bDataType;

			// Save this page # as last one opened
			nConfigPage=1;

			// Read configuration file toolbutton items
			ReadIni(INI_TOOLS);

			// Write prompt message
			LoadString(hInst, IDS_MESSAGE_CONFIGURE, szBuffer,
				BUFFER_SIZE);
			WriteMessage(szBuffer);

            // Fill Toolbutton list box
            for(i=0; i<NUM_TOOLS; i++)
            {
				nDummy=ListBox_InsertString(GETHCTL(IDC_CONFIG_TOOLBUTTONS), i,
					tb[i].label);
				nDummy=ListBox_SetSel(GETHCTL(IDC_CONFIG_TOOLBUTTONS),
					tb[i].show_flag, i);
            }

            // Go to top of list
			nDummy=ListBox_SetSel(GETHCTL(IDC_CONFIG_TOOLBUTTONS),
				tb[0].show_flag, 0);
	
		}
		return TRUE;

		case WM_NOTIFY:
		{
			switch(((NMHDR FAR*)lParam)->code)
			{
				// Respond to PSN_KILLACTIVATE notification message
				// Pressing OK button, or pressing Enter when in edit box
				// sends this message - No way I know to tell which
				// When the Enter key is pressed while in an edit box
				// the main property sheet box treats this as
				// a default OK button press
				// and closes the entire property sheet.  No way found to make
				// Enter command to reformat the edit box contents.
				case PSN_KILLACTIVE:
				{
					// Update toolbutton flags
					for(i=0; i<NUM_TOOLS; i++)
					{
						// Read the new state of all the toolbutton flags
						tb[i].show_flag=
							ListBox_GetSel(GETHCTL(IDC_CONFIG_TOOLBUTTONS), i);
					}
					
					// Restore data type
					bDataType=bDataTypeSave;
					
					// Write the STABLE32.INI configuration file
					WriteIni(INI_TOOLS);
				}
				break;

				// Respond to PSN_RESET message
				// Sent in response to user pressing Cancel button
				// on main property sheet
				case PSN_RESET:
				{
					// Restore data type
					bDataType=bDataTypeSave;
				}
				break;

				// Respond to PSN_APPLY message
				// This message tells us to save the new settings
				case PSN_APPLY:
				{
					// Reformat toolbuttons
					nBlanks=0;
					for(i=0; i<NUM_TOOLS; i++)
					{
						// Read the new state of all the toolbutton flags
						tb[i].show_flag=
							ListBox_GetSel(GETHCTL(IDC_CONFIG_TOOLBUTTONS), i);

                        // Loop thru toolbuttons, setting screen positions
                        if(tb[i].show_flag) // Display
						{
                            tb[i].position=i-nBlanks;
                        }
                        else // Don't display
                        {
							tb[i].position=-1; // Off screen
                            nBlanks++;
                        }

                        // Update the icon rect
						SetRect(&tb[i].rect, tb[i].position*cxIcon, 0,
                            (tb[i].position+1)*cxIcon, cyIcon);
                    }

                    // Repaint entire toolbar
                    InvalidateRect(hwndToolbar, NULL, TRUE);

					// Force redraw of plots (in case bStatusPlot was changed)
					bPhaseRedraw=TRUE;
					bFreqRedraw=TRUE;

					// Put info into log file
					WriteLog(52, szFile);
				}
				break;

				// Respond to PSN_HELP message
				case PSN_HELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::CONFIGURE_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::CONFIGURATION_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "CONFIGURATION_FUNCTION");
					#endif
				}
				break;
			}
		}
		return TRUE;

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
                return TRUE;
            }
        }
        break;
	 }
     return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*	    Page3Proc for Plots Configuration Property Sheet		             */
/*                                                                           */
/*      Revision record:                                                     */
/*			02/02/07	Created	from MMS4.c									 */
/*			02/11/07	Added bWeight checkbox to Plots page                 */
/*			11/29/11	Added plot style choice                              */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK Page3Proc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	// Ints
	int i;							// General index
	static int  nStyleSave;			// Save plot style
	// BOOLs
	static BOOL bWeight;			// Sigma plot noise line weighting flag  
	static BOOL bPhaseSave;			// Save original phase flag state
	static BOOL bFreqSave;          // Save original freq flag state
	static BOOL bSigmaSave;         // Save original sigma flag state
	static BOOL bHistoSave;         // Save original histo flag state
	static BOOL bSpectSave;         // Save original spect flag state
	static BOOL bAutoSave;          // Save original auto flag state
	static BOOL bDAVARSave;         // Save original DAVAR flag state
	static BOOL bPlotLabelSave;     // Save original plot label flag state
	static BOOL bSmartScaleSave;	// Save smart plot scale flag
	static BOOL bWeightSave;		// Save orig sigma plot line weight flag
	static BOOL bDataTypeSave;		// Save org data type
	
	//Chars
	char szBuffer[BUFFER_SIZE+1];				// Text buffer
	static char szLabelText[BUFFER_SIZE+1];     // Label text buffer

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Save data type
			bDataTypeSave=bDataType;

			// Save this page # as last one opened
			nConfigPage=2;

			// Read configuration file preference items
			// Not necessary unless the ini file is manually edited
			// while Stable32 is running
			ReadIni(INI_PREFS);

			// Get bWeight setting from INI file (default=TRUE)
			// This is not read in ReadIni
			// There is no global variable for it
			// There is also a bWeight local static BOOL in SigmaLineDlgProc()
			// that is set from this ini file item
			bWeight=GetPrivateProfileInt("Preferences", "Weight", 1,
				szIniFile);

			// Write prompt message
			LoadString(hInst, IDS_MESSAGE_CONFIGURE, szBuffer,
				BUFFER_SIZE);
			WriteMessage(szBuffer);

			// Display the phase plot checkbox state
			Button_SetCheck(GETHCTL(IDC_CONFIG_PHASE), bUsePhasePlotIni);

			// Display the freq plot checkbox state
			Button_SetCheck(GETHCTL(IDC_CONFIG_FREQ), bUseFreqPlotIni);

			// Display the sigma plot checkbox state
			Button_SetCheck(GETHCTL(IDC_CONFIG_SIGMA), bUseSigmaPlotIni);

			// Display the histo plot checkbox state
			Button_SetCheck(GETHCTL(IDC_CONFIG_HISTO), bUseHistoPlotIni);

			// Display the spectrum plot checkbox state
			Button_SetCheck(GETHCTL(IDC_CONFIG_SPECT), bUseSpectPlotIni);

			// Display the autocorrelation plot checkbox state
			Button_SetCheck(GETHCTL(IDC_CONFIG_AUTO), bUseAutoPlotIni);

			// Display the dynamic stability plot checkbox state
			Button_SetCheck(GETHCTL(IDC_CONFIG_DAVAR), bUseDAVARPlotIni);

			// Display the label plots checkbox state
			Button_SetCheck(GETHCTL(IDC_CONFIG_PLOTLABEL), bPlotLabel);

			// Display the smart plot scale checkbox state
			Button_SetCheck(GETHCTL(IDC_CONFIG_SMART), bSmartScale);

			// Display the sigma plot weight checkbox state
			Button_SetCheck(GETHCTL(IDC_CONFIG_SIGWEIGHT), bWeight);

			// Display the plot label text
			SetWindowText(GETHCTL(IDC_CONFIG_LABELTEXT), szPlotLabel);

			// Display plot style choice
			// Currently there are only two: 0=original, 1=modern
			if(nStyle==ORIGINAL_STYLE)
			{
				Button_SetCheck(GETHCTL(IDC_CONFIG_ORIGINAL), TRUE);
			}
			else
			{
				Button_SetCheck(GETHCTL(IDC_CONFIG_ORIGINAL), FALSE);
			}
			if(nStyle==MODERN_STYLE)
			{
				Button_SetCheck(GETHCTL(IDC_CONFIG_MODERN), TRUE);
			}
			else
			{
				Button_SetCheck(GETHCTL(IDC_CONFIG_MODERN), FALSE);
			}

 			// Save the original values in case cancel is pressed
			bPhaseSave=bUsePhasePlotIni;
			bFreqSave=bUseFreqPlotIni;
			bSigmaSave=bUseSigmaPlotIni;
			bHistoSave=bUseHistoPlotIni;
			bSpectSave=bUseSpectPlotIni;
			bAutoSave=bUseAutoPlotIni;
			bDAVARSave=bUseDAVARPlotIni;
            bPlotLabelSave=bPlotLabel;
			bSmartScaleSave=bSmartScale;
			bWeightSave=bWeight;
			nStyleSave=nStyle;

			// Save original plot label
			strlcpy(szLabelText, szPlotLabel, sizeof(szLabelText));
		}
		return TRUE;

		case WM_NOTIFY:
		{
			switch(((NMHDR FAR*)lParam)->code)
			{
				// Respond to PSN_KILLACTIVATE notification message
				// Pressing OK button, or pressing Enter when in edit box
				// sends this message - No way I know to tell which
				// When the Enter key is pressed while in an edit box
				// the main property sheet box treats this as
				// a default OK button press
				// and closes the entire property sheet.  No way found to make
				// Enter command to reformat the edit box contents.
				case PSN_KILLACTIVE:
				{
					// Restore data type
					bDataType=bDataTypeSave;
					
					// Write the STABLE32.INI configuration file
					WriteIni(INI_PREFS);
				}
				break;

				// Respond to PSN_RESET message
				// Sent in response to user pressing Cancel button
				// on main property sheet
				// We want to restore original settings
				// before property sheet closes
				case PSN_RESET:
				{
					// Restore only if this page was one reset
					if(nConfigPage==2)
					{
						// Restore the original values
						bUsePhasePlotIni=bPhaseSave;
						bUseFreqPlotIni=bFreqSave;
						bUseSigmaPlotIni=bSigmaSave;
						bUseHistoPlotIni=bHistoSave;
						bUseSpectPlotIni=bSpectSave;
						bUseAutoPlotIni=bAutoSave;
						bUseDAVARPlotIni=bDAVARSave;
						bPlotLabel=bPlotLabelSave;
						bSmartScale=bSmartScaleSave;
						bWeight=bWeightSave;
						nStyle=nStyleSave;

						// Restore plot label
						strlcpy(szPlotLabel, szLabelText, BUFFER_SIZE);

						// Save weight flag in ini file
						_snprintf(szBuffer, sizeof(szBuffer), "%d", bWeight);
						WritePrivateProfileString("Preferences", "Weight",
							szBuffer, szIniFile);
					}

					// Restore data type
					bDataType=bDataTypeSave;
				}
				break;

				// Respond to PSN_APPLY message
				// This message tells us to save the new settings to the ini file
				case PSN_APPLY:
				{
					;
				}
				break;

				// Respond to PSN_HELP message
				case PSN_HELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::CONFIGURE_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::CONFIGURATION_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "CONFIGURATION_FUNCTION");
					#endif
				}
				break;
			}
		}
		break;

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
                case IDC_CONFIG_PHASE:
				{
                    // Get the state of the phase checkbox
					bUsePhasePlotIni=
						(BOOL)Button_GetCheck(GETHCTL(IDC_CONFIG_PHASE));
                }
                break;

                case IDC_CONFIG_FREQ:
                {
                    // Get the state of the freq checkbox
					bUseFreqPlotIni=
						(BOOL)Button_GetCheck(GETHCTL(IDC_CONFIG_FREQ));
				}
				break;

				case IDC_CONFIG_SIGMA:
				{
					// Get the state of the sigma checkbox
					bUseSigmaPlotIni=
						(BOOL)Button_GetCheck(GETHCTL(IDC_CONFIG_SIGMA));
				}
				break;

				case IDC_CONFIG_HISTO:
				{
					// Get the state of the histo checkbox
					bUseHistoPlotIni=
						(BOOL)Button_GetCheck(GETHCTL(IDC_CONFIG_HISTO));
				}
				break;

				case IDC_CONFIG_SPECT:
				{
					// Get the state of the spectrum checkbox
					bUseSpectPlotIni=
						(BOOL)Button_GetCheck(GETHCTL(IDC_CONFIG_SPECT));
				}
				break;

				case IDC_CONFIG_AUTO:
				{
					// Get the state of the autocorrelation checkbox
					bUseAutoPlotIni=
						(BOOL)Button_GetCheck(GETHCTL(IDC_CONFIG_AUTO));
				}
				break;

				case IDC_CONFIG_DAVAR:
				{
					// Get the state of the dynamic stability checkbox
					bUseDAVARPlotIni=
						(BOOL)Button_GetCheck(GETHCTL(IDC_CONFIG_DAVAR));
				}
				break;

				case IDC_CONFIG_PLOTLABEL:
				{
					// Get the state of the plot label checkbox
					bPlotLabel=
						(BOOL)Button_GetCheck(GETHCTL(IDC_CONFIG_PLOTLABEL));
				}
				break;

				case IDC_CONFIG_SMART:
				{
					// Get the state of the smart plot scale checkbox
					bSmartScale=
						(BOOL)Button_GetCheck(GETHCTL(IDC_CONFIG_SMART));

					// Reinitialize plot scale parameters
					if(bPhaseData)
					{
						InitPhasePlotParams(0);
					}

					if(bFreqData)
					{
						InitFreqPlotParams(0);
					}
				}
				break;

				case IDC_CONFIG_SIGWEIGHT:
				{
					// Get the state of the weight checkbox
					bWeight=
						(BOOL)Button_GetCheck(GETHCTL(IDC_CONFIG_SIGWEIGHT));

					// Save weight flag in ini file
					_snprintf(szBuffer, sizeof(szBuffer), "%d", bWeight);
					WritePrivateProfileString("Preferences", "Weight",
						szBuffer, szIniFile);

					// Remove any existing sigma plot noise lines
					// Note: This cannot be undone
					for(i=0; i<SLINE_NUMLINES; i++)
					{
						// Check for noise line type
						if(sSLine[i].nLineType==SLINE_NOISE)
						{
							// Remove noise line
							sSLine[i].nLineType=SLINE_NONE;
						}
					}
				}
				break;

				case IDC_CONFIG_ORIGINAL:
				{
					// Get the state of the original style radiobutton
					if(Button_GetCheck(GETHCTL(IDC_CONFIG_ORIGINAL)))
					{
						nStyle=ORIGINAL_STYLE;
						bPlotLabel=TRUE;
					}
					else // Modern style
					{
						nStyle=MODERN_STYLE;
						bPlotLabel=FALSE;
					}

					// Apply the plot label state
					Button_SetCheck(GETHCTL(IDC_CONFIG_PLOTLABEL), bPlotLabel);
				}
				break;

				case IDC_CONFIG_MODERN:
				{
					// Get the state of the modern style radiobutton
					if(Button_GetCheck(GETHCTL(IDC_CONFIG_MODERN)))
					{
						nStyle=MODERN_STYLE;
						bPlotLabel=FALSE;
					}
					else // Original style
					{
						nStyle=ORIGINAL_STYLE;
						bPlotLabel=TRUE;
					}

					// Apply the plot label state
					Button_SetCheck(GETHCTL(IDC_CONFIG_PLOTLABEL), bPlotLabel);
				}
				break;

				case IDC_CONFIG_LABELTEXT:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(GetFocus()!=GETHCTL(IDC_CONFIG_CANCEL)))
					{
						// Get new plot label
						GetWindowText(GETHCTL(IDC_CONFIG_LABELTEXT),
							szPlotLabel, BUFFER_SIZE);

						// Display the plot label text
						SetWindowText(GETHCTL(IDC_CONFIG_LABELTEXT),
							szPlotLabel);
					}
				}
				break;

                return TRUE;
            }
        }
 	 }
     return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*	    Page4Proc for Data Configuration Property Sheet			             */
/*                                                                           */
/*      Revision record:                                                     */
/*			02/02/07	Created	from MMS4.c									 */
/*			03/19/08	Added freq timetags type radiobuttons                */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK Page4Proc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	// Ints
	static int nMaxSizeSave;		   // Save original max data file size
	static int nSkipCharSave;		   // Save original # skipped characters
	static int nFTagSave;			   // Save original freq timetag type
	// BOOLs
	static BOOL bCommaSave;			   // Save org comma flag state
	static BOOL bWarnZeroFreqSave;	   // Save warn zero freq flag state
	static BOOL bHeaderSave;	       // Save header flag
	static BOOL bDataTypeSave;			// Save org data type
	
	//Chars
	char szBuffer[BUFFER_SIZE+1];      // Text buffer

	// Note: Changes not immediately written to ini file
	// This is simpler and seems OK
	
	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Save data type
			bDataTypeSave=bDataType;

			// Save this page # as last one opened
			nConfigPage=3;

			// Read configuration file preference items
			// Not necessary unless the ini file is manually edited
			// while Stable32 is running
			ReadIni(INI_PREFS);

			// Write prompt message
			LoadString(hInst, IDS_MESSAGE_CONFIGURE, szBuffer,
				BUFFER_SIZE);
			WriteMessage(szBuffer);

			// Display the header checkbox state
			Button_SetCheck(GETHCTL(IDC_CONFIG_HEADER), bHeader);

			// Display the comma checkbox state
			Button_SetCheck(GETHCTL(IDC_CONFIG_COMMA), bComma);

			// Display the warn checkbox state
			Button_SetCheck(GETHCTL(IDC_CONFIG_WARN), bWarnZeroFreq);

			// Display the max data file size value
			_snprintf(szBuffer, sizeof(szBuffer), "%d", nMaxSize);
			SetWindowText(GETHCTL(IDC_CONFIG_SIZE), szBuffer);

			// Display the # non-numerics to skip value
			_snprintf(szBuffer, sizeof(szBuffer), "%d", nSkipChar);
			SetWindowText(GETHCTL(IDC_CONFIG_SKIP), szBuffer);

			// Display freq timetag type
			switch(nFTag)
			{
				case FTAG_FIRST:
				{
					Button_SetCheck(GETHCTL(IDC_CONFIG_TAG0), TRUE);
				}
				break;

				case FTAG_MID:
				{
					Button_SetCheck(GETHCTL(IDC_CONFIG_TAG1), TRUE);
				}
				break;

				case FTAG_LAST:
				{
					Button_SetCheck(GETHCTL(IDC_CONFIG_TAG2), TRUE);
				}
				break;
			}

			// Save the original values in case cancel is pressed
			nMaxSizeSave=nMaxSize;
			nSkipCharSave=nSkipChar;
			bCommaSave=bComma;
			bWarnZeroFreqSave=bWarnZeroFreq;
			bHeaderSave=bHeader;
			nFTagSave=nFTag;

		}
		return TRUE;

		case WM_NOTIFY:
		{
			switch(((NMHDR FAR*)lParam)->code)
			{
				// Respond to PSN_KILLACTIVATE notification message
				// Pressing OK button, or pressing Enter when in edit box
				// sends this message - No way I know to tell which
				// When the Enter key is pressed while in an edit box
				// the main property sheet box treats this as
				// a default OK button press
				// and closes the entire property sheet.
				// No way found to make
				// Enter command to reformat the edit box contents.
				case PSN_KILLACTIVE:
				{
					// Restore data type
					bDataType=bDataTypeSave;
					
					// Write the STABLE32.INI configuration file
					WriteIni(INI_PREFS);
				}
				break;

				// Respond to PSN_RESET message
				// Sent in response to user pressing Cancel button
				// on main property sheet
				// We want to restore original settings
				// before property sheet closes
				case PSN_RESET:
				{
					// Restore only if this page was one reset
					if(nConfigPage==3)
					{
						// Restore the original values
						nMaxSize=nMaxSizeSave;
						nSkipChar=nSkipCharSave;
						bComma=bCommaSave;
						bWarnZeroFreq=bWarnZeroFreqSave;
						bHeader=bHeaderSave;
						nFTag=nFTagSave;
					}
					
					// Restore data type
					bDataType=bDataTypeSave;
				}
				break;

				// Respond to PSN_APPLY message
				// This message tells us to save the new settings
				case PSN_APPLY:
				{
					;
				}
				break;

				// Respond to PSN_HELP message
				case PSN_HELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::CONFIGURE_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::CONFIGURATION_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "CONFIGURATION_FUNCTION");
					#endif
				}
				break;
			}
		}
		break;

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				case IDC_CONFIG_HEADER:
				{
                    // Get the state of the header checkbox
					bHeader=
						(BOOL)Button_GetCheck(GETHCTL(IDC_CONFIG_HEADER));
                }
                break;

				case IDC_CONFIG_COMMA:
				{
					// Get the state of the comma checkbox
					bComma=(BOOL)
						Button_GetCheck(GETHCTL(IDC_CONFIG_COMMA));
				}
				break;

				case IDC_CONFIG_WARN:
				{
					// Get the state of the warn zero freq checkbox
					bWarnZeroFreq=
						(BOOL)Button_GetCheck(GETHCTL(IDC_CONFIG_WARN));
				}
				break;

				case IDC_CONFIG_TAG0:
				{
					// Get the state of the freq tag 0 radiobutton
					nFTag=0;
				}
				break;

				case IDC_CONFIG_TAG1:
				{
					// Get the state of the freq tag 1 radiobutton
					nFTag=1;
				}
				break;

				case IDC_CONFIG_TAG2:
				{
					// Get the state of the freq tag 2 radiobutton
					nFTag=2;
				}
				break;

                case IDC_CONFIG_SIZE:
                {
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(GetFocus()!=GETHCTL(IDC_CONFIG_CANCEL)))
					{
						// Get the new max data file size
						// Edit control accepts only numbers (digits)
						// Int O/F not a problem - it just displays value
						GetWindowText(GETHCTL(IDC_CONFIG_SIZE), szBuffer,
						BUFFER_SIZE);
						nMaxSize=atoi(szBuffer);

						#ifdef STUDENT_VER
						if(nMaxSize>STUDENT_MAX)
						{
							nMaxSize=STUDENT_MAX;
						}
						#endif

						// Display the new max data file size
						_snprintf(szBuffer, sizeof(szBuffer), "%d", nMaxSize);
						SetWindowText(GETHCTL(IDC_CONFIG_SIZE), szBuffer);
					}
                }
                break;

                case IDC_CONFIG_SKIP:
                {
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(GetFocus()!=GETHCTL(IDC_CONFIG_CANCEL)))
					{
						// Get the new # non-numerics to skip
						// Edit control accepts only numbers (digits)
						// Int O/F not a problem - it just displays value
						// Only positive value allowed as entry
						GetWindowText(GETHCTL(IDC_CONFIG_SKIP), szBuffer,
							BUFFER_SIZE);
						nSkipChar=atoi(szBuffer);

						// Display the new max data file size
						_snprintf(szBuffer, sizeof(szBuffer), "%d", nSkipChar);
						SetWindowText(GETHCTL(IDC_CONFIG_SKIP), szBuffer);
					}
                }
                break;

                case IDC_CONFIG_DEFAULTS:
                {
					// Restore default max data size value
					nMaxSize=999999;
					_snprintf(szBuffer, sizeof(szBuffer), "%d", nMaxSize);
					SetWindowText(GETHCTL(IDC_CONFIG_SIZE), szBuffer);

					// Restore default # non-numerics to skip value
					nSkipChar=0;
					_snprintf(szBuffer, sizeof(szBuffer), "%d", nSkipChar);
					SetWindowText(GETHCTL(IDC_CONFIG_SKIP), szBuffer);

					// Restore freq timetag type to 1st phase value
					nFTag=FTAG_FIRST;
					Button_SetCheck(GETHCTL(IDC_CONFIG_TAG0), TRUE);
					Button_SetCheck(GETHCTL(IDC_CONFIG_TAG1), FALSE);
					Button_SetCheck(GETHCTL(IDC_CONFIG_TAG2), FALSE);
				}
                break;

                return TRUE;
            }
        }
 	 }
     return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*	    Page5Proc for Inputs Configuration Property Sheet				     */
/*                                                                           */
/*      Revision record:                                                     */
/*			02/02/07	Created	from MMS4.c									 */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK Page5Proc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	//Chars
	char szBuffer[BUFFER_SIZE+1];      // Text buffer
	char szSection[BUFFER_SIZE+1];     // Section name
	char szKey[BUFFER_SIZE+1];		   // Key name
	// Bools
	static BOOL bDataTypeSave;			// Save org data type
	//F_TYPES
    // Phase
	static F_TYPE fTau1;        // Tau value
	static F_TYPE fAdd1;        // Addend value
    static F_TYPE fMult1;       // Multiplier value
	static F_TYPE fTag1;		// Timetag scale factor
	static F_TYPE fOffset1;		// Timetag offset value
	static F_TYPE fTauSave1;	// Original tau inputs value
	static F_TYPE fAddSave1;	// Original addend inputs value
	static F_TYPE fMultSave1;	// Original multiplier inputs value
	static F_TYPE fTagSave1;	// Original timetag scale inputs value
	static F_TYPE fOffsetSave1;	// Original timetag offset inputs value
	// Freq
    static F_TYPE fTau2;        // Tau value
	static F_TYPE fAdd2;        // Addend value
    static F_TYPE fMult2;       // Multiplier value
	static F_TYPE fTag2;		// Timetag scale factor
	static F_TYPE fOffset2;		// Timetag offset value
	static F_TYPE fTauSave2;	// Original tau inputs value
	static F_TYPE fAddSave2;	// Original addend inputs value
	static F_TYPE fMultSave2;	// Original multiplier inputs value
	static F_TYPE fTagSave2;	// Original timetag scale inputs value
	static F_TYPE fOffsetSave2;	// Original timetag offset inputs value
 
	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Save data type
			bDataTypeSave=bDataType;

			// Save this page # as last one opened
			nConfigPage=4;

			// Read configuration file preference items
			// Not necessary unless the ini file is manually edited
			// while Stable32 is running
			ReadIni(INI_INPUTS);

			// Write prompt message
			LoadString(hInst, IDS_MESSAGE_CONFIGURE, szBuffer,
				BUFFER_SIZE);
			WriteMessage(szBuffer);

			// Put default values from INI file into addends
			_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
				fFreqAddendInput);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_CONFIG_ADD2), szBuffer);
			_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
				fPhaseAddendInput);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_CONFIG_ADD1), szBuffer);

			// Put default values from INI file into multipliers
			_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
				fFreqMultiplierInput);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_CONFIG_MULT2), szBuffer);
			_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
				fPhaseMultiplierInput);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_CONFIG_MULT1), szBuffer);

			// Put default values from INI file into taus
			_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
				fFreqTauInput);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_CONFIG_TAU2), szBuffer);
			_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
				fPhaseTauInput);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_CONFIG_TAU1), szBuffer);

			// Put default values from INI file into tag scale factors
			_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
				fFreqTagScale);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_CONFIG_TAGSCALE2), szBuffer);
			_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
				fPhaseTagScale);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_CONFIG_TAGSCALE1), szBuffer);

			// Put default values from INI file into tag offset values
			_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
				fFreqTagOffset);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_CONFIG_TAGOFFSET2), szBuffer);
			_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
				fPhaseTagOffset);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_CONFIG_TAGOFFSET1), szBuffer);

			// Save original scaling values
			fTauSave2=fFreqTauInput;
			fAddSave2=fFreqAddendInput;
			fMultSave2=fFreqMultiplierInput;
			fTagSave2=fFreqTagScale;
			fOffsetSave2=fFreqTagOffset;
			fTauSave1=fPhaseTauInput;
			fAddSave1=fPhaseAddendInput;
			fMultSave1=fPhaseMultiplierInput;
			fTagSave1=fPhaseTagScale;
			fOffsetSave1=fPhaseTagOffset;
		}
		return TRUE;

		case WM_NOTIFY:
		{
			switch(((NMHDR FAR*)lParam)->code)
			{
				// Respond to PSN_KILLACTIVATE notification message
				// Pressing OK button, or pressing Enter when in edit box
				// sends this message - No way I know to tell which
				// When the Enter key is pressed while in an edit box
				// the main property sheet box treats this as
				// a default OK button press
				// and closes the entire property sheet.
				// No way found to make
				// Enter command to reformat the edit box contents.
				case PSN_KILLACTIVE:
				{
					// Restore data type
					bDataType=bDataTypeSave;
					
					// Write the STABLE32.INI configuration file
					WriteIni(INI_INPUTS);
				}
				break;

				// Respond to PSN_RESET message
				// Sent in response to user pressing Cancel button
				// on main property sheet
				// We want to restore original settings
				// before property sheet closes
				case PSN_RESET:
				{
					// Restore only if this page was one reset
					if(nConfigPage==4)
					{
						// Store values in [Inputs] section of ini file
						LoadString(hInst, IDS_INI_SECTION_15, szSection,
							BUFFER_SIZE);

						// Restore saved values
						fFreqTauInput=fTauSave2;
						fFreqAddendInput=fAddSave2;
						fFreqMultiplierInput=fMultSave2;
						fFreqTagScale=fTagSave2;
						fFreqTagOffset=fOffsetSave2;

						// Freq tau value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							fTauSave2);
						ShortenExp(szBuffer);
						LoadString(hInst, IDS_INI_KEY_50, szKey, BUFFER_SIZE);
						WritePrivateProfileString(szSection, szKey, szBuffer,
							szIniFile);

						// Freq scale addend value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							fAddSave2);
						ShortenExp(szBuffer);
						LoadString(hInst, IDS_INI_KEY_52, szKey, BUFFER_SIZE);
						WritePrivateProfileString(szSection, szKey, szBuffer,
							szIniFile);

						// Freq scale multiplier value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							fMultSave2);
						ShortenExp(szBuffer);
						LoadString(hInst, IDS_INI_KEY_54, szKey, BUFFER_SIZE);
						WritePrivateProfileString(szSection, szKey,
							szBuffer,
							szIniFile);

						// Freq tag scale multiplier value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							fTagSave2);
						ShortenExp(szBuffer);
						LoadString(hInst, IDS_INI_KEY_98, szKey, BUFFER_SIZE);
						WritePrivateProfileString(szSection, szKey,
							szBuffer,
							szIniFile);

						// Freq tag scale offset value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							fOffsetSave2);
						ShortenExp(szBuffer);
						LoadString(hInst, IDS_INI_KEY_102, szKey, BUFFER_SIZE);
						WritePrivateProfileString(szSection, szKey, szBuffer,
							szIniFile);

						// Restore saved values
						fPhaseTauInput=fTauSave1;
						fPhaseAddendInput=fAddSave1;
						fPhaseMultiplierInput=fMultSave1;
						fPhaseTagScale=fTagSave1;
						fPhaseTagOffset=fOffsetSave1;

						// Phase tau value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							fTauSave1);
						ShortenExp(szBuffer);
						LoadString(hInst, IDS_INI_KEY_49, szKey, BUFFER_SIZE);
						WritePrivateProfileString(szSection, szKey, szBuffer,
							szIniFile);

						// Phase scale addend value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							fAddSave1);
						ShortenExp(szBuffer);
						LoadString(hInst, IDS_INI_KEY_51, szKey, BUFFER_SIZE);
						WritePrivateProfileString(szSection, szKey, szBuffer,
							szIniFile);

						// Phase scale multiplier value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							fMultSave1);
						ShortenExp(szBuffer);
						LoadString(hInst, IDS_INI_KEY_53, szKey, BUFFER_SIZE);
						WritePrivateProfileString(szSection, szKey, szBuffer,
							szIniFile);

						// Phase tag scale multiplier value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							fTagSave1);
						ShortenExp(szBuffer);
						LoadString(hInst, IDS_INI_KEY_83, szKey, BUFFER_SIZE);
						WritePrivateProfileString(szSection, szKey, szBuffer,
							szIniFile);

						// Phase tag scale offset value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							fOffsetSave1);
						ShortenExp(szBuffer);
						LoadString(hInst, IDS_INI_KEY_101, szKey, BUFFER_SIZE);
						WritePrivateProfileString(szSection, szKey, szBuffer,
							szIniFile);
					}

					// Restore data type
					bDataType=bDataTypeSave;
				}
				break;

				// Respond to PSN_APPLY message
				case PSN_APPLY:
				{
					;
				}
				break;

				// Respond to PSN_HELP message
				case PSN_HELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::CONFIGURE_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::CONFIGURATION_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "CONFIGURATION_FUNCTION");
					#endif
				}
				break;
			}
		}
		return TRUE;

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
                 case IDC_CONFIG_ADD1:
                {
                    // Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_CONFIG_CANCEL)))
                    {
                        // Get addend
						GetWindowText(GETHCTL(IDC_CONFIG_ADD1), szBuffer,
							BUFFER_SIZE);
                        fPhaseAddendInput=(F_TYPE)atof(szBuffer);
					
                        // Redisplay addend
                        _snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
							fPhaseAddendInput);
						ShortenExp(szBuffer);
                        SetWindowText(GETHCTL(IDC_CONFIG_ADD1), szBuffer);

						// Store values in [Inputs] section of ini file
						LoadString(hInst, IDS_INI_SECTION_15, szSection,
							BUFFER_SIZE);

						// Phase scale addend value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							fPhaseAddendInput);
						ShortenExp(szBuffer);
						LoadString(hInst, IDS_INI_KEY_51, szKey, BUFFER_SIZE);
						WritePrivateProfileString(szSection, szKey, szBuffer,
							szIniFile);
					}
                }
                break;

                case IDC_CONFIG_MULT1:
                {
                    // Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_CONFIG_CANCEL)))
                    {
                        // Get multiplier
						GetWindowText(GETHCTL(IDC_CONFIG_MULT1), szBuffer,
							BUFFER_SIZE);
                        fPhaseMultiplierInput=(F_TYPE)atof(szBuffer);

                        // Redisplay multiplier
                        _snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
							fPhaseMultiplierInput);
						ShortenExp(szBuffer);
                        SetWindowText(GETHCTL(IDC_CONFIG_MULT1), szBuffer);

						// Store values in [Inputs] section of ini file
						LoadString(hInst, IDS_INI_SECTION_15, szSection,
							BUFFER_SIZE);

						// Phase scale multiplier value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							fPhaseMultiplierInput);
						ShortenExp(szBuffer);
						LoadString(hInst, IDS_INI_KEY_53, szKey, BUFFER_SIZE);
						WritePrivateProfileString(szSection, szKey, szBuffer,
							szIniFile);
					}
                }
                break;

                case IDC_CONFIG_TAU1:
                {
                    // Respond to edit control when it loses the input focus
                    // unless it loses it to the cancel button
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_CONFIG_CANCEL)))
                    {
                        // Get tau
						GetWindowText(GETHCTL(IDC_CONFIG_TAU1),	szBuffer,
							BUFFER_SIZE);
                        fPhaseTauInput=(F_TYPE)atof(szBuffer);
					
                        // Redisplay tau
                        _snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
							fPhaseTauInput);
						ShortenExp(szBuffer);
                        SetWindowText(GETHCTL(IDC_CONFIG_TAU1), szBuffer);

						// Store values in [Inputs] section of ini file
						LoadString(hInst, IDS_INI_SECTION_15, szSection,
							BUFFER_SIZE);

						// Phase tau value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							fPhaseTauInput);
						ShortenExp(szBuffer);
						LoadString(hInst, IDS_INI_KEY_49, szKey, BUFFER_SIZE);
						WritePrivateProfileString(szSection, szKey, szBuffer,
							szIniFile);
					 }
                }
                break;

                case IDC_CONFIG_TAGSCALE1:
                {
                    // Respond to edit control when it loses the input focus
                    // unless it loses it to the cancel button
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_CONFIG_CANCEL)))
                    {
                        // Get tag scale
						GetWindowText(GETHCTL(IDC_CONFIG_TAGSCALE1), szBuffer,
							BUFFER_SIZE);
						fPhaseTagScale=(F_TYPE)atof(szBuffer);
					
						// Redisplay tag sacle
						_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
							fPhaseTagScale);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_CONFIG_TAGSCALE1), szBuffer);

						// Store values in [Inputs] section of ini file
						LoadString(hInst, IDS_INI_SECTION_15, szSection,
							BUFFER_SIZE);

						// Phase tag scale multiplier value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							fPhaseTagScale);
						ShortenExp(szBuffer);
						LoadString(hInst, IDS_INI_KEY_83, szKey, BUFFER_SIZE);
						WritePrivateProfileString(szSection, szKey, szBuffer,
							szIniFile);
					}
                }
                break;

                case IDC_CONFIG_TAGOFFSET1:
                {
                    // Respond to edit control when it loses the input focus
                    // unless it loses it to the cancel button
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_CONFIG_CANCEL)))
                    {
                        // Get tag offset
						GetWindowText(GETHCTL(IDC_CONFIG_TAGOFFSET1), szBuffer,
							BUFFER_SIZE);
						fPhaseTagOffset=(F_TYPE)atof(szBuffer);

						// Redisplay tag offset
						_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
							fPhaseTagOffset);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_CONFIG_TAGOFFSET1), szBuffer);

						// Store values in [Inputs] section of ini file
						LoadString(hInst, IDS_INI_SECTION_15, szSection,
							BUFFER_SIZE);

						// Phase tag scale offset value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							fPhaseTagOffset);
						ShortenExp(szBuffer);
						LoadString(hInst, IDS_INI_KEY_101, szKey, BUFFER_SIZE);
						WritePrivateProfileString(szSection, szKey, szBuffer,
							szIniFile);
					}
                }
                break;

                 case IDC_CONFIG_ADD2:
                {
                    // Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_CONFIG_CANCEL)))
                    {
                        // Get addend
						GetWindowText(GETHCTL(IDC_CONFIG_ADD2), szBuffer,
							BUFFER_SIZE);
                        fFreqAddendInput=(F_TYPE)atof(szBuffer);

                        // Redisplay addend
                        _snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
							fFreqAddendInput);
						ShortenExp(szBuffer);
                        SetWindowText(GETHCTL(IDC_CONFIG_ADD2), szBuffer);

						// Store values in [Inputs] section of ini file
						LoadString(hInst, IDS_INI_SECTION_15, szSection,
							BUFFER_SIZE);

						// Freq scale addend value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							fFreqAddendInput);
						ShortenExp(szBuffer);
						LoadString(hInst, IDS_INI_KEY_52, szKey, BUFFER_SIZE);
						WritePrivateProfileString(szSection, szKey, szBuffer,
							szIniFile);
					}
                }
                break;

                case IDC_CONFIG_MULT2:
                {
                    // Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_CONFIG_CANCEL)))
                    {
                        // Get multiplier
						GetWindowText(GETHCTL(IDC_CONFIG_MULT2), szBuffer,
							BUFFER_SIZE);
                        fFreqMultiplierInput=(F_TYPE)atof(szBuffer);

                        // Redisplay multiplier
                        _snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
							fFreqMultiplierInput);
						ShortenExp(szBuffer);
                       SetWindowText(GETHCTL(IDC_CONFIG_MULT2), szBuffer);

						// Store values in [Inputs] section of ini file
						LoadString(hInst, IDS_INI_SECTION_15, szSection,
							BUFFER_SIZE);

						// Freq scale multiplier value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							fFreqMultiplierInput);
						ShortenExp(szBuffer);
						LoadString(hInst, IDS_INI_KEY_54, szKey, BUFFER_SIZE);
						WritePrivateProfileString(szSection, szKey, szBuffer,
							szIniFile);
					}
                }
                break;

                case IDC_CONFIG_TAU2:
                {
                    // Respond to edit control when it loses the input focus
                    // unless it loses it to the cancel button
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_CONFIG_CANCEL)))
                    {
                        // Get tau
						GetWindowText(GETHCTL(IDC_CONFIG_TAU2),	szBuffer,
							BUFFER_SIZE);
                        fFreqTauInput=(F_TYPE)atof(szBuffer);
					
                        // Redisplay tau
                        _snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
							fFreqTauInput);
						ShortenExp(szBuffer);
                        SetWindowText(GETHCTL(IDC_CONFIG_TAU2), szBuffer);

						// Store values in [Inputs] section of ini file
						LoadString(hInst, IDS_INI_SECTION_15, szSection,
							BUFFER_SIZE);

						// Freq tau value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							fFreqTauInput);
						ShortenExp(szBuffer);
						LoadString(hInst, IDS_INI_KEY_50, szKey, BUFFER_SIZE);
						WritePrivateProfileString(szSection, szKey, szBuffer,
							szIniFile);
					 }
                }
                break;

                case IDC_CONFIG_TAGSCALE2:
                {
                    // Respond to edit control when it loses the input focus
                    // unless it loses it to the cancel button
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_CONFIG_CANCEL)))
                    {
                        // Get tag scale
						GetWindowText(GETHCTL(IDC_CONFIG_TAGSCALE2), szBuffer,
							BUFFER_SIZE);
						fFreqTagScale=(F_TYPE)atof(szBuffer);

						// Redisplay tag sacle
						_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
							fFreqTagScale);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_CONFIG_TAGSCALE2), szBuffer);

						// Store values in [Inputs] section of ini file
						LoadString(hInst, IDS_INI_SECTION_15, szSection,
							BUFFER_SIZE);

						// Freq tag scale multiplier value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							fFreqTagScale);
						ShortenExp(szBuffer);
						LoadString(hInst, IDS_INI_KEY_98, szKey, BUFFER_SIZE);
						WritePrivateProfileString(szSection, szKey, szBuffer,
							szIniFile);
					}
                }
                break;

                case IDC_CONFIG_TAGOFFSET2:
                {
                    // Respond to edit control when it loses the input focus
                    // unless it loses it to the cancel button
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_CONFIG_CANCEL)))
                    {
                        // Get tag offset
						GetWindowText(GETHCTL(IDC_CONFIG_TAGOFFSET2), szBuffer,
							BUFFER_SIZE);
						fFreqTagOffset=(F_TYPE)atof(szBuffer);

						// Redisplay tag offset
						_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
							fFreqTagOffset);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_CONFIG_TAGOFFSET2), szBuffer);

						// Store values in [Inputs] section of ini file
						LoadString(hInst, IDS_INI_SECTION_15, szSection,
							BUFFER_SIZE);

						// Freq tag scale offset value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							fFreqTagOffset);
						ShortenExp(szBuffer);
						LoadString(hInst, IDS_INI_KEY_102, szKey, BUFFER_SIZE);
						WritePrivateProfileString(szSection, szKey, szBuffer,
							szIniFile);
					}
                }
                break;

                return TRUE;
           }
        }
	 }
     return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*	    Page6Proc for Options Configuration Property Sheet				     */
/*                                                                           */
/*      Revision record:                                                     */
/*			02/02/07	Created	from MMS4.c									 */
/*			05/17/08	Added spur threshold                                 */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK Page6Proc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	// Ints
	int i;                          // Index
	static int   nPSDAvgSizeSave;	// Save original relative max AF value
	static int   nPSDAvgMaxSave;	// Save original absolute max AF value
	static int   nPSDLFSkipSave;	// Save original # LF points to skip
	static int   nPSDSmoothPPOSave;	// Save original smoothing points/octave
	static int   nManySizeSave;		// Save original many tau size
	static int   bZeroPadSave;		// Save original zero padding state
	// BOOLs
	static BOOL  bManyTauSave;		// Save original many tau state
	static BOOL  bWeightSave;		// Save original weight state
	static BOOL bDataTypeSave;		// Save org data type
	//Chars
	char szBuffer[BUFFER_SIZE+1];   // Text buffer
	// Floats
	static float fSpurLimSave;		// Save original spur limit
	static float fTemp;				// Temporary float variable
	// Doubles
	double fInt;					// Integer part from modf()

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Save data type
			bDataTypeSave=bDataType;

			// Save this page # as last one opened
			nConfigPage=5;

			// Read configuration file preference items
			// Not necessary unless the ini file is manually edited
			// while Stable32 is running
			ReadIni(INI_PREFS);

			// Write prompt message
			LoadString(hInst, IDS_MESSAGE_CONFIGURE, szBuffer, BUFFER_SIZE);
			WriteMessage(szBuffer);

			// Display the many tau checkbox state
			Button_SetCheck(GETHCTL(IDC_CONFIG_MANY), bManyTau);

			// Display the weight checkbox state
			Button_SetCheck(GETHCTL(IDC_CONFIG_WEIGHT), sPSPlot.weight);

			// Display the zero padding checkbox state
			Button_SetCheck(GETHCTL(IDC_CONFIG_ZP), bZeroPad);

			// Display the PSD avg size value
			_snprintf(szBuffer, sizeof(szBuffer), "%d", nPSDAvgSize);
			SetWindowText(GETHCTL(IDC_CONFIG_AVGSIZE), szBuffer);

			// Display the PSD avg max value
			_snprintf(szBuffer, sizeof(szBuffer), "%d", nPSDAvgMax);
			SetWindowText(GETHCTL(IDC_CONFIG_AVGMAX), szBuffer);

			// Display the PSD LF skip value
			_snprintf(szBuffer, sizeof(szBuffer), "%d", nPSDLFSkip);
			SetWindowText(GETHCTL(IDC_CONFIG_LFSKIP), szBuffer);

			// Display the spur limit value
			_snprintf(szBuffer, sizeof(szBuffer), "%2.0f", sPSPlot.limit);
			SetWindowText(GETHCTL(IDC_CONFIG_SPURLIM), szBuffer);

			// Display the PPO value
			_snprintf(szBuffer, sizeof(szBuffer), "%d", sPSPlot.ppo);
			SetWindowText(GETHCTL(IDC_CONFIG_PPO), szBuffer);

			// Display the many tau size
			_snprintf(szBuffer, sizeof(szBuffer), "%d", nManySize);
			SetWindowText(GETHCTL(IDC_CONFIG_MANYSIZE), szBuffer);

			// Save the original values in case cancel is pressed
			bManyTauSave=bManyTau;
			bWeightSave=sPSPlot.weight;
			bZeroPadSave=bZeroPad;
			nPSDAvgSizeSave=nPSDAvgSize;
			nPSDAvgMaxSave=nPSDAvgMax;
			nPSDLFSkipSave=nPSDLFSkip;
			nPSDSmoothPPOSave=sPSPlot.ppo;
			fSpurLimSave=sPSPlot.limit;
			nManySizeSave=nManySize;
		}
		return TRUE;

		case WM_NOTIFY:
		{
			switch(((NMHDR FAR*)lParam)->code)
			{
				// Respond to PSN_KILLACTIVATE notification message
				// Pressing OK button, or pressing Enter when in edit box
				// sends this message - No way I know to tell which
				// When the Enter key is pressed while in an edit box
				// the main property sheet box treats this as
				// a default OK button press
				// and closes the entire property sheet.
				// No way found to make
				// Enter command to reformat the edit box contents.
				case PSN_KILLACTIVE:
				{
					// Restore data type
					bDataType=bDataTypeSave;
					
					// Write the STABLE32.INI configuration file
					WriteIni(INI_PREFS);
				}
				break;

				// Respond to PSN_RESET notification message
				// Sent in response to user pressing Cancel button
				// on main property sheet
				// We want to restore original settings
				// before property sheet closes
				case PSN_RESET:
				{
					// Restore only if this page was one reset
					if(nConfigPage==5)
					{
						// Restore original many tau state
						bManyTau=bManyTauSave;
						_snprintf(szBuffer, sizeof(szBuffer), "%d",
							bManyTauSave);
						WritePrivateProfileString("Preferences", "ManyTau",
							szBuffer, szIniFile);

						// Restore original weight state
						sPSPlot.weight=bWeightSave;
						_snprintf(szBuffer, sizeof(szBuffer), "%d",
							bWeightSave);
						WritePrivateProfileString("Preferences",
							"PSDLineWeight", szBuffer, szIniFile);

						// Restore original zero padding state
						bZeroPad=bZeroPadSave;
						_snprintf(szBuffer, sizeof(szBuffer), "%d",
							bZeroPadSave);
						WritePrivateProfileString("Preferences",
							"ZeroPad", szBuffer, szIniFile);

						// Restore original relative max AF value
						nPSDAvgSize=nPSDAvgSizeSave;
						_snprintf(szBuffer, sizeof(szBuffer), "%d",
							nPSDAvgSizeSave);
						WritePrivateProfileString("Preferences",
							"PSDAvgSize", szBuffer, szIniFile);

						// Restore original absolute max AF value
						nPSDAvgMax=nPSDAvgMaxSave;
						_snprintf(szBuffer, sizeof(szBuffer), "%d",
							nPSDAvgMaxSave);
						WritePrivateProfileString("Preferences",
							"PSDAvgMax", szBuffer, szIniFile);

						// Restore original # LF points to skip
						nPSDLFSkip=nPSDLFSkipSave;
						_snprintf(szBuffer, sizeof(szBuffer), "%d",
							nPSDLFSkipSave);
						WritePrivateProfileString("Preferences",
							"PSDLFSkip", szBuffer, szIniFile);

						// Restore original smoothing points/octave
						sPSPlot.ppo=nPSDSmoothPPOSave;
						_snprintf(szBuffer, sizeof(szBuffer), "%d",
							nPSDSmoothPPOSave);
						WritePrivateProfileString("Preferences",
							"PSDSmoothPPO", szBuffer, szIniFile);

						// Restore original spur limit
						sPSPlot.limit=fSpurLimSave;
						_snprintf(szBuffer, sizeof(szBuffer), "%2.0f",
							fSpurLimSave);
						WritePrivateProfileString("Preferences",
							"PSDSpurLim", szBuffer, szIniFile);

						// Restore original many tau size
						nManySize=nManySizeSave;
						_snprintf(szBuffer, sizeof(szBuffer), "%d",
							nManySizeSave);
						WritePrivateProfileString("Preferences",
							"ManySize", szBuffer, szIniFile);
					}

					// Restore data type
					bDataType=bDataTypeSave;
				}
				break;

				// Respond to PSN_APPLY notification message
				case PSN_APPLY:
				{
					// Nothing to do
				}
				break;

				// Respond to PSN_HELP message
				case PSN_HELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::CONFIGURE_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::CONFIGURATION_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "CONFIGURATION_FUNCTION");
					#endif
				}
				break;
			}
		}
		return TRUE;

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				case IDC_CONFIG_MANY:
				{
                    // Get the state of the many tau checkbox
					bManyTau=(BOOL)Button_GetCheck(GETHCTL(IDC_CONFIG_MANY));
                }
                break;

                case IDC_CONFIG_AVGSIZE:
                {
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(GetFocus()!=GETHCTL(IDC_CONFIG_CANCEL)))
					{
						// Get the new relative PAD auto AF maximum
						// Only positive value allowed as entry
						GetWindowText(GETHCTL(IDC_CONFIG_AVGSIZE), szBuffer,
							BUFFER_SIZE);
						i=abs(atoi(szBuffer));

						// Exclude zero - restore original value
						if(i==0)
						{
							i=nPSDAvgSize;
						}

						// Make sure value is a power-of-2
						// It is if log2(value) is an exact integer
						if(fabs(modf((log10(i)/log10(2)), &fInt))<1e-6)
						{
							// Accept the new value
							nPSDAvgSize=i;

							// Display the new PSD avg size value
							_snprintf(szBuffer, sizeof(szBuffer), "%d",
								nPSDAvgSize);
							SetWindowText(GETHCTL(IDC_CONFIG_AVGSIZE),
								szBuffer);

							// Save new PSD avg size value in ini file
							WritePrivateProfileString("Preferences",
								"PSDAvgSize", szBuffer,	szIniFile);
						}
						else // Bad value
						{
							// Display error message
			                MessageBox(hwndMain,
								"Value must be a power of 2.\n"
								"Original value will be restored.",
								"PSD Relative Max AF", MB_ICONEXCLAMATION);

							// Redisplay the original PSD avg size value
							_snprintf(szBuffer, sizeof(szBuffer), "%d",
								nPSDAvgSize);
							SetWindowText(GETHCTL(IDC_CONFIG_AVGSIZE),
								szBuffer);
						}
					}
				}
                break;

                case IDC_CONFIG_AVGMAX:
                {
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(GetFocus()!=GETHCTL(IDC_CONFIG_CANCEL)))
					{
						// Get the new absolute PSD auto AF maximum
						// Only positive value allowed as entry
						GetWindowText(GETHCTL(IDC_CONFIG_AVGMAX), szBuffer,
							BUFFER_SIZE);
						i=abs(atoi(szBuffer));

						// Exclude zero - restore original value
						if(i==0)
						{
							i=nPSDAvgMax;
						}

						// Make sure value is a power-of-2
						// It is if log2(value) is an exact integer
						if(fabs(modf((log10(i)/log10(2)), &fInt))<1e-6)
						{
							// Accept the new value
							nPSDAvgMax=i;

							// Display the new PSD avg max value
							_snprintf(szBuffer, sizeof(szBuffer), "%d",
								nPSDAvgMax);
							SetWindowText(GETHCTL(IDC_CONFIG_AVGMAX),
								szBuffer);

							// Save new PSD avg max value in ini file
							WritePrivateProfileString("Preferences",
								"PSDAvgMax", szBuffer, szIniFile);
						}
						else // Bad value
						{
							// Display error message
			                MessageBox(hwndMain,
								"Value must be a power of 2.\n"
								"Original value will be restored.",
								"PSD Absolute Max AF", MB_ICONEXCLAMATION);

							// Redisplay the original PSD avg size value
							_snprintf(szBuffer, sizeof(szBuffer), "%d",
								nPSDAvgMax);
							SetWindowText(GETHCTL(IDC_CONFIG_AVGMAX),
								szBuffer);
						}
					}
				}
                break;

                case IDC_CONFIG_LFSKIP:
                {
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(GetFocus()!=GETHCTL(IDC_CONFIG_CANCEL)))
					{
						// Get the new # LF PSD points to skip
						// Only positive value or zero allowed as entry
						GetWindowText(GETHCTL(IDC_CONFIG_LFSKIP), szBuffer,
							BUFFER_SIZE);
						nPSDLFSkip=abs(atoi(szBuffer));

						// Display the new PSD LF skip value
						_snprintf(szBuffer, sizeof(szBuffer), "%d",
							nPSDLFSkip);
						SetWindowText(GETHCTL(IDC_CONFIG_LFSKIP), szBuffer);

						// Save new PSD LF skip in ini file
						WritePrivateProfileString("Preferences", "PSDLFSkip",
							szBuffer, szIniFile);
					}
				}
                break;

                case IDC_CONFIG_WEIGHT:
                {
                    // Get the state of the weight checkbox
					sPSPlot.weight=
						(BOOL)Button_GetCheck(GETHCTL(IDC_CONFIG_WEIGHT));

					// Save new weight setting in ini file
					_snprintf(szBuffer, sizeof(szBuffer), "%d",
						sPSPlot.weight);
					WritePrivateProfileString("Preferences", "PSDLineWeight",
						szBuffer, szIniFile);
				}
                break;

                case IDC_CONFIG_ZP:
                {
                    // Get the state of the zero padding checkbox
					bZeroPad=
						(BOOL)Button_GetCheck(GETHCTL(IDC_CONFIG_ZP));

					// Save new zero padding setting in ini file
					_snprintf(szBuffer, sizeof(szBuffer), "%d",
						bZeroPad);
					WritePrivateProfileString("Preferences", "ZeroPad",
						szBuffer, szIniFile);
				}
                break;

                case IDC_CONFIG_PPO:
                {
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(GetFocus()!=GETHCTL(IDC_CONFIG_CANCEL)))
					{
						// Get the new # points per octave
						// Only positive value allowed as entry
						GetWindowText(GETHCTL(IDC_CONFIG_PPO), szBuffer,
							BUFFER_SIZE);
						i=abs(atoi(szBuffer));

						// Exclude zero - restore original value
						if(i==0)
						{
							i=sPSPlot.ppo;
						}

						// Make sure value is a power-of-2
						// It is if log2(value) is an exact integer
						if(fabs(modf((log10(i)/log10(2)), &fInt))<1e-6)
						{
							// Accept the new value
							sPSPlot.ppo=i;

							// Display the new ppo value
							_snprintf(szBuffer, sizeof(szBuffer), "%d",
								sPSPlot.ppo);
							SetWindowText(GETHCTL(IDC_CONFIG_PPO), szBuffer);

							// Save new PSD smooth ppo value in ini file
							WritePrivateProfileString("Preferences",
								"PSDSmoothPPO", szBuffer, szIniFile);
						}
						else // Bad value
						{
							// Display error message
			                MessageBox(hwndMain,
								"Value must be a power of 2.\n"
								"Original value will be restored.",
								"PSD Smoothing Points/Octave",
										MB_ICONEXCLAMATION);

							// Redisplay the original PSD avg size value
							_snprintf(szBuffer, sizeof(szBuffer), "%d",
								sPSPlot.ppo);
							SetWindowText(GETHCTL(IDC_CONFIG_PPO), szBuffer);
						}
					}
				}
                break;

                case IDC_CONFIG_SPURLIM:
                {
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(GetFocus()!=GETHCTL(IDC_CONFIG_CANCEL)))
					{
						// Get the new spur limit
						// Only positive value allowed as entry
						GetWindowText(GETHCTL(IDC_CONFIG_SPURLIM), szBuffer,
							BUFFER_SIZE);
						fTemp=(float)abs(atoi(szBuffer));

						if(TRUE)
						{
							// Accept the new value
							sPSPlot.limit=fTemp;

							// Display the new spur limit
							_snprintf(szBuffer, sizeof(szBuffer), "%2.0d",
								sPSPlot.limit);
							SetWindowText(GETHCTL(IDC_CONFIG_SPURLIM), szBuffer);

							// Save new PSD spur limit in ini file
							WritePrivateProfileString("Preferences",
								"PSDSpurLim", szBuffer, szIniFile);
						}
						else // Bad value
						{
							// Redisplay the original PSD avg size value
							_snprintf(szBuffer, sizeof(szBuffer), "%2.0d",
								sPSPlot.limit);
							SetWindowText(GETHCTL(IDC_CONFIG_SPURLIM), szBuffer);
						}
					}
				}
                break;

                case IDC_CONFIG_MANYSIZE:
                {
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(GetFocus()!=GETHCTL(IDC_CONFIG_CANCEL)))
					{
						// Get the new many tau size
						// Only positive value allowed as entry
						GetWindowText(GETHCTL(IDC_CONFIG_MANYSIZE), szBuffer,
							BUFFER_SIZE);
						i=abs(atoi(szBuffer));

						// Exclude zero - restore original value
						if(i==0)
						{
							i=nManySize;
						}

						if(TRUE) // No particular validation required
						{
							// Accept the new value
							nManySize=i;

							// Display the new many tau size
							_snprintf(szBuffer, sizeof(szBuffer), "%d",
								nManySize);
							SetWindowText(GETHCTL(IDC_CONFIG_MANYSIZE),
								szBuffer);

							// Save new many size in ini file
							WritePrivateProfileString("Preferences",
								"ManySize", szBuffer, szIniFile);
						}
						else // Bad value - Not used
						{
							// Display error message
			                MessageBox(hwndMain,
								"Value must be ....\n"
								"Original value will be restored.",
								"Many Tau Size", MB_ICONEXCLAMATION);

							// Redisplay the original many tau size
							_snprintf(szBuffer, sizeof(szBuffer), "%d",
								sPSPlot.ppo);
							SetWindowText(GETHCTL(IDC_CONFIG_MANYSIZE),
								szBuffer);
						}
					}
				}
                break;

                case IDC_CONFIG_DEFAULTS:
                {
					// Restore default PSD avg size value
					nPSDAvgSize=64;
					_snprintf(szBuffer, sizeof(szBuffer), "%d", 64);
					WritePrivateProfileString("Preferences", "PSDAvgSize",
						szBuffer, szIniFile);
					SetWindowText(GETHCTL(IDC_CONFIG_AVGSIZE), szBuffer);
					// Restore default PSD avg size value
					nPSDAvgMax=256;
					_snprintf(szBuffer, sizeof(szBuffer), "%d", 256);
					WritePrivateProfileString("Preferences", "PSDAvgMax",
						szBuffer, szIniFile);
					SetWindowText(GETHCTL(IDC_CONFIG_AVGMAX), szBuffer);
					// Restore default PSD LF skip value
					nPSDLFSkip=1;
					_snprintf(szBuffer, sizeof(szBuffer), "%d", 1);
					WritePrivateProfileString("Preferences", "PSDLFSkip",
						szBuffer, szIniFile);
					SetWindowText(GETHCTL(IDC_CONFIG_LFSKIP), szBuffer);
					// Restore default PSD avg size value
					sPSPlot.ppo=64;
					_snprintf(szBuffer, sizeof(szBuffer), "%d", 64);
					WritePrivateProfileString("Preferences",
						"PSDSmoothPPO", szBuffer, szIniFile);
					SetWindowText(GETHCTL(IDC_CONFIG_PPO), szBuffer);
					// Restore default PSD spur limit value
					sPSPlot.limit=(float)20;
					_snprintf(szBuffer, sizeof(szBuffer), "%2.0f", 20.0);
					WritePrivateProfileString("Preferences",
						"PSDSpurLim", szBuffer, szIniFile);
					SetWindowText(GETHCTL(IDC_CONFIG_SPURLIM), szBuffer);
					// Restore PSD zero padding flag
					bZeroPad=TRUE;
					_snprintf(szBuffer, sizeof(szBuffer), "%d", 1);
					WritePrivateProfileString("Preferences",
						"ZeroPad", szBuffer, szIniFile);
					Button_SetCheck(GETHCTL(IDC_CONFIG_ZP), TRUE);
				}
                break;

                case IDC_CONFIG_MANYRESET:
                {
					// Restore default many tau size
					nManySize=500;
					_snprintf(szBuffer, sizeof(szBuffer), "%d", 500);
					WritePrivateProfileString("Preferences", "ManySize",
						szBuffer, szIniFile);
					SetWindowText(GETHCTL(IDC_CONFIG_MANYSIZE), szBuffer);
				}
                break;

                return TRUE;
           }
        }
	 }
     return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*	              Page7Proc for Audio Configuration Property Sheet	         */
/*                                                                           */
/*      Revision record:                                                     */
/*			07/28/07	Added this page to property sheet                    */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK Page7Proc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	// Ints
	int i;								// General index
	static int nSampleRateSave;			// Save original sample rate
	// Bools
	static BOOL bDataTypeSave;		// Save org data type
	//Chars
	char szBuffer[FILE_NAME_SIZE+1];	// General text buffer
	static char szAudioPlayerSave[FILE_NAME_SIZE+1];
										// Original audio player filename

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Save data type
			bDataTypeSave=bDataType;

			// Save this page # as last one opened
			nConfigPage=6;

			// Read configuration file preference items
			// Not necessary unless the ini file is manually edited
			// while Stable32 is running
			ReadIni(INI_AUDIO);

			// Write prompt message
			LoadString(hInst, IDS_MESSAGE_CONFIGURE, szBuffer,
				BUFFER_SIZE);
			WriteMessage(szBuffer);

			// Display the audio player filename
			SetWindowText(GETHCTL(IDC_CONFIG_AUDIOPLAYER), szAudioPlayer);

			// Display the WAV filename - not editable
			// Compose wave filename as it will actually be
			// (see WindProc() case IDM_AUDIO: in Stable_w.c)
			// This is composed here because otherwise it may not have been yet
			// It is displayed in up to 3 lines of static text
			// because no scrolling is possible with a static text box
			strlcpy(szBuffer, szPath, sizeof(szBuffer));
			strlcat(szBuffer, "\nStable32.wav", sizeof(szBuffer));
			SetWindowText(GETHCTL(IDC_CONFIG_WAVFILE), szBuffer);

			// Fill up the sample rate list box with avaliable choices
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_CONFIG_SAMPLERATE));

			// Note: The index is equal to the macro value
			// Have 5 choices: 8000, 11025, 22050, 32000, 44100
			// Stored in strings IDS_CONFIG_RATE_0 thru IDS_CONFIG_RATE_4
			for(i=0; i<NUM_CONFIG_SAMPLERATES; i++)
			{
				LoadString(hInst, IDS_CONFIG_RATE_0+i, szBuffer, BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_CONFIG_SAMPLERATE), i,
					szBuffer);
			}

			// Show currently selected sample rate per nSampleRate
			_snprintf(szBuffer, sizeof(szBuffer), "%d", nSampleRate);
			i=ComboBox_FindStringExact(GETHCTL(IDC_CONFIG_SAMPLERATE), 0,
				szBuffer);
			nDummy=ComboBox_SetCurSel(GETHCTL(IDC_CONFIG_SAMPLERATE), i);

			// Save the original sample rate in case cancel is pressed
			nSampleRateSave=nSampleRate;

			// Save original sound player filename in case cancel is pressed
			strlcpy(szAudioPlayerSave, szAudioPlayer, FILE_NAME_SIZE);
		}
		return TRUE;

		case WM_NOTIFY:
		{
			switch(((NMHDR FAR*)lParam)->code)
			{
				// Respond to PSN_KILLACTIVATE notification message
				// Pressing OK button, or pressing Enter when in edit box
				// sends this message - No way I know to tell which
				// When the Enter key is pressed while in an edit box
				// the main property sheet box treats this an a default OK
				// button press and closes the entire property sheet.
				// No way found to make Enter command to reformat
				// the edit box contents.
				case PSN_KILLACTIVE:
				{
					// Restore data type
					bDataType=bDataTypeSave;
					
					// Write the STABLE32.INI configuration file
					WriteIni(INI_AUDIO);
				}
				break;

				// Respond to PSN_RESET message
				// Sent in response to user pressing Cancel button
				// on main property sheet
				// We want to restore original settings
				// before property sheet closes
				case PSN_RESET:
				{
					// Restore only if this page was one reset
					if(nConfigPage==6)
					{
						// Restore the original sampling rate value
						nSampleRate=nSampleRateSave;

						// Restore original sound player filename
						strlcpy(szAudioPlayer, szAudioPlayerSave,
							FILE_NAME_SIZE);
					}

					// Restore data type
					bDataType=bDataTypeSave;
				}
				break;

				// Respond to PSN_APPLY message
				case PSN_APPLY:
				{
					;
				}
				break;

				// Respond to PSN_HELP message
				case PSN_HELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::CONFIGURE_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::CONFIGURATION_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "CONFIGURATION_FUNCTION");
					#endif
				}
				break;
			}
		}
		break;

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				case IDC_CONFIG_SAMPLERATE:
				{
					// Get selected audio rate
					nDummy=ComboBox_GetText(GETHCTL(IDC_CONFIG_SAMPLERATE),
						szBuffer, sizeof(szBuffer));
					nSampleRate=atoi(szBuffer);
                }
                break;

				case IDC_CONFIG_AUDIOPLAYER:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(GetFocus()!=GETHCTL(IDC_CONFIG_CANCEL)))
					{
						// Get new audio player filename
						GetWindowText(GETHCTL(IDC_CONFIG_AUDIOPLAYER),
							szAudioPlayer, FILE_NAME_SIZE);

						// Display the audio player filename
						SetWindowText(GETHCTL(IDC_CONFIG_AUDIOPLAYER),
							szAudioPlayer);
					}
				}
				break;

                return TRUE;
            }
        }
        break;
	 }
     return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*	              Page8Proc for Run Function                    	         */
/*                                                                           */
/*      Revision record:                                                     */
/*			08/27/08	Added this page to property sheet                    */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK Page8Proc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	// Ints
	// int i;								// General index
	//Chars
	char szBuffer[FILE_NAME_SIZE+1];	// General text buffer

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Save this page # as last one opened
			nConfigPage=7;

			// Write prompt message
			LoadString(hInst, IDS_MESSAGE_CONFIGURE, szBuffer,
				BUFFER_SIZE);
			WriteMessage(szBuffer);

			// Get run calc time limit from ini file
			GetPrivateProfileString("Run", "RunLimit", "60", szBuffer, BUFFER_SIZE,
				szIniFile);
			fRunLimit=(float)atof(szBuffer);

			// Display current run calc time limit
			_snprintf(szBuffer, sizeof(szBuffer), "%d", (int)fRunLimit);
			SetWindowText(GETHCTL(IDC_CONFIG_RUNTIME), szBuffer);
		}
		return TRUE;

		case WM_NOTIFY:
		{
			switch(((NMHDR FAR*)lParam)->code)
			{
				// Respond to PSN_KILLACTIVATE notification message
				// Pressing OK button, or pressing Enter when in edit box
				// sends this message - No way I know to tell which
				// When the Enter key is pressed while in an edit box
				// the main property sheet box treats this an a default OK
				// button press and closes the entire property sheet.
				// No way found to make Enter command to reformat
				// the edit box contents.
				case PSN_KILLACTIVE:
				{
					// Save run calc time limit in ini file
					_snprintf(szBuffer, sizeof(szBuffer), "%d", (int)fRunLimit);
					ShortenExp(szBuffer);
					WritePrivateProfileString("Run", "RunLimit", szBuffer, szIniFile);
				}
				break;

				// Respond to PSN_RESET message
				// Sent in response to user pressing Cancel button
				// on main property sheet
				// We want to restore original settings
				// before property sheet closes
				case PSN_RESET:
				{
					// Restore only if this page was one reset
					if(nConfigPage==7)
					{
						// Restore any original values
					}
				}
				break;

				// Respond to PSN_APPLY message
				case PSN_APPLY:
				{
					;
				}
				break;

				// Respond to PSN_HELP message
				case PSN_HELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::CONFIGURE_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::CONFIGURATION_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "CONFIGURATION_FUNCTION");
					#endif
				}
				break;
			}
		}
		break;

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				case IDC_CONFIG_RUNTIME:
				{
					// Get new run calc time
					nDummy=ComboBox_GetText(GETHCTL(IDC_CONFIG_RUNTIME),
						szBuffer, sizeof(szBuffer));
					// Don't allow run calc time limit to be less than zero
					// Zero value is flag to turn off this feature
					fRunLimit=(float)fabs(atoi(szBuffer));
                }
                break;

                return TRUE;
            }
        }
        break;
	 }
     return FALSE;
}

/*****************************************************************************/
