/***************************************************************************/
/*																		   */
/*								   TIErms()								   */
/*																		   */
/*		Function to calc rms time interval error from phase data		   */
/*																		   */
/*		Parameters:		F_TYPE x[]	  = phase data						   */
/*										x[0] = # data points			   */
/*										x[1] = analysis start			   */
/*										x[2] = analysis end				   */
/*						F_TYPE *p_tie = pointer to Allan deviation		   */
/*						int af		  = averaging factor				   */
/*																		   */
/*		Returns:		int			  = # analysis points,				   */
/*										or -1 if error					   */
/*																		   */
/*		Note:			Embedded zero value treated as gap in phase data.  */
/*						Must have at least 1 analysis point; this		   */
/*						requires at least 2 adjacent non-gap phase		   */
/*						data points.									   */
/*																		   */
/*		Revision record:												   */
/*			06/03/98	Created											   */
/*																		   */
/* (c) Copyright 1998  Hamilton Technical Services	All Rights Reserved	   */
/*																		   */
/***************************************************************************/

#include "frequenc.h"

int WINAPI TIErms(F_TYPE x[], F_TYPE *p_tie, int af)

{
	double sum=0;						   /* summing variable to calc TIE */
	int i;											  /* index for summing */
	int num = 0;									  /* # analysis points */

	for( i = (int)(*(x+1)+2); i <= (int)(*(x+2)+2-af); i++)
											  /* index goes from 1 to n-af */
					 /* for n data points from 1 to n; data starts at x[3] */
	{
		if(	   (i==*(x+1)+2 && *(x+i+af))
			|| (*(x+i) && *(x+i+af)		)
			|| (i==*(x+2)+2-af && *(x+i)))
						  /* skip if any embedded phase data value is zero */
		{
			sum += SQR( *(x+i+af) - *(x+i) );
			num++;
		}														 
	}
															   
	if(num>0)
	{
		*p_tie = sqrt( sum / num );
		return(num);								  /* # analysis points */
	}
	else
	{
		*p_tie=0;
		return(-1);												  /* error */
	}
}														   

/***************************************************************************/
