/*****************************************************************************/
/*                                                                           */
/*                            STABLE_X.C                                     */
/*                                                                           */
/*		Plotting Dialog Box Procedures for Stable Windows 95/NT              */
/*                                                                           */
/*		Functions:		PhasePlotDlgProc()                                   */
/*                      FreqPlotDlgProc()                                    */
/*						SigmaPlotDlgProc()                                   */
/*						SpectrumPlotDlgProc()                                */
/*						HistoPlotDlgProc()                                   */
/*						ReadPlotDlgProc()                                    */
/*                      FreqLineDlgProc()                                    */
/*                      PhaseLineDlgProc()                                   */
/*                      SigmaLineDlgProc()                                   */
/*                      FreqNoteDlgProc()                                    */
/* 						PhaseNoteDlgProc()                                   */
/*						SigmaNoteDlgProc()                                   */
/*						AutocorrelationPlotDlgProc()                         */
/*						DynamicStabilityDlgProc()                            */
/*						CalcDynamicPhaseOverlapSigma()                       */
/*						CalcDynamicPhaseOverlapHadamardDev()                 */
/*                                                                           */
/*	Revision record:                                                         */
/*                                                                           */
/*			06/29/97	Use GET_WM_COMMAND_ID, etc. WIN32 compatibility      */
/*						macros to process WM_COMMAND messages:               */
/*						wParam <- GET_WM_COMMAND_ID(wParam, lParam)          */
/*						HIWORD(lParam) <- GET_WM_COMMAND_CMD(wParam, lParam) */
/*						Replaced WORD with UINT                              */
/*			06/30/97	Replaced FAR PASCAL _export with WINAPI              */
/*			07/14/97	More Win32 compatibility changes                     */
/*			12/24/97	Made changes for error-free BC 32 bit compilation    */
/*						Move plot initialization functions to STABLE_V.C     */
/*			08/05/03	Added AutocorrelationPlotDlgProc()                   */
/*			11/12/05	Added DynamicStabilityDlgProc()                      */
/*			12/27/06	Added CalcDynamicPhaseOverlapSigma() and             */
/*						CalcDynamicPhaseOverlapHadamardDev()                 */
/*			07/29/07    Changed to safe string functions                     */
/*                                                                           */
/* (c) 1996-2007 W. Riley  Hamilton Technical Services  All Rights Reserved  */
/*                                                                           */
/*****************************************************************************/

#define STRICT 					// For Win32 compatibility

// Include the stable_w header file
#include "stable_w.h"           // STABLE_W header file
#include <limits.h>				// For INT_MAX definition

/*****************************************************************************/
/*                                                                           */
/*                Phase Plot Parameter Entry Dialog Procedure                */
/*                                                                           */
/* 	Dialog box controls:                                                     */
/*			ID					Description		Variable or struct member    */
/*	IDC_DPLOT_TITLE		 		Plot Title              .title{}             */
/*	IDC_DPLOT_SUBTITLE	 		Plot Subtitle           .sub_title{}         */
/*	IDC_DPLOT_MESSAGE	 		Plot Message            .message_str[]       */
/*	IDC_DPLOT_XLABEL            X-Axis Label            .x_label[]           */
/*	IDC_DPLOT_YLABEL	 		Y-Axis Label            .left_y_label[]      */
/*	IDC_DPLOT_XOFFSET	 		X-Axis Scale Offset		.x_offset            */
/*	IDC_DPLOT_XMULT		 		X-Axis Scale Mult       .x_mult              */
/*	IDC_DPLOT_YOFFSET	 		Y-Axis Scale Offset     .y_offset            */
/*	IDC_DPLOT_YMULT		 		Y-Axis Scale Mult       .y_mult              */
/*	IDC_DPLOT_DATE		 		Date Flag               .do_date             */
/*	IDC_DPLOT_BOX		 		Box Flag                .do_box              */
/*	IDC_DPLOT_DOFIT				Fit Flag				.do_fit              */
/*	IDC_DPLOT_FIT		 		Fit Type                .do_line             */
/*	IDC_DPLOT_CURSOR			Cursor Flag             .do_mouse            */
/*	IDC_DPLOT_FILENAME	 		Plot Filename           .plot_filename[]     */
/*	IDC_DPLOT_YMAX		 		Y Scale Maximum         .y_max               */
/*	IDC_DPLOT_YMIN		 		Y Scale Minimum         .y_min               */
/*	IDC_DPLOT_YDIV		 		# Y Scale Divs          .y_div               */
/*	IDC_DPLOT_YTIC		 		# Y Scale Tics          .y_tic               */
/*	IDC_DPLOT_POSITION			Message position		.position            */
/*	IDC_DPLOT_RESET		 		Reset Param Flag                             */
/*	IDC_DPLOT_DATAMAX	 		Data Maximum                                 */
/*	IDC_DPLOT_DATAMIN	 		Data Minimum                                 */
/*                                                                           */
/*	struct plotdata             structure template for plot data             */
/*	{                                                                        */
/*		float x_offset;                            x-axis data offset factor */
/*		float x_mult;                          x-axis data multiplier factor */
/*		float y_offset;                            y-axis data offset factor */
/*		float y_mult;                          y_axis data multiplier factor */
/*		float x_min;                                     x-axis plot minimum */
/*		float x_max;                                     x-axis plot maximum */
/*		float y_min;                                     y-axis plot minimum */
/*		float y_max;                                     y-axis plot maximum */
/*		char title[TITLESIZE];                                    plot title */
/*		char subtitle[SUBTITLESIZE];                           plot subtitle */
/*		char x_label[XLABELSIZE];                          plot x-axis label */
/*		char left_y_label[YLABELSIZE];           plot y-axis left side label */
/*		char right_y_label[YLABELSIZE];         plot y-axis right side label */
/*		char plot_filename[FILENAMESIZE];                 plot .TKF filename */
/*		char message_str[MESSAGESIZE];                   plot message string */
/*		int do_date;                               flag to draw date on plot */
/*		int do_box;                             flag to draw box around plot */
/*		int do_errbar;                    flag to include error bars on plot */
/*		int do_line;                code to control drawing of lines on plot */
/*		int do_mouse;              flag to activate mouse after drawing plot */
/*		int do_table;        flag to write sigma-tau table on stability plot */
/*		int new_file;                  flag that plot is for a new data file */
/*		int new_name;             flag that plot is for a new basic filename */
/*		int plotype;                       code to identify the type of plot */
/*		int position;        code to control position of message box on plot */
/*		int x_div;                                  # x-axis major divisions */
/*		int x_tic;                     # x-axis tics between major divisions */
/*		int y_div;                                  # y-axis major divisions */
/*		int y_tic;                     # y-axis tics between major divisions */
/*		int config;                       flag for active configuration file */
/*	}                                                                        */
/*                                                                           */
/*		Phase data plot do_line types:                                       */
/*                                                                           */
/* 		Revision record:                                                     */
/*			11/08/96	Adapted from FreqPlotDlgProc()                       */
/*			11/10/96	Added Start and End controls                         */
/*			11/23/96	Changed title, subtitle & message to comboboxes      */
/*			01/01/97	Added additional message options                     */
/*			01/25/97	Added code to push user-entered titles, subtitles &  */
/*						messages into combo listboxes with CR                */
/*			04/27/97	Added x_div control logic                            */
/*			06/01/00	Added PlotX config usage                             */
/*			03/11/01	Added wide checkbox for wide plot lines              */
/*			03/16/02	Improved x-axis scale                                */
/*			03/23/02	Made more changes in plot scale code                 */
/*			03/24/02	Made x-axis scale determination a separate block     */
/*						Improved x_mult entry handling                       */
/*          05/10/02	Added bPXDefault usage                               */
/*			10/01/02	Changed to DetermineXScale() usage                   */
/*			11/24/04	Added test to avoid O/F for large timetags           */
/*			12/13/07	Added polynominal fit and its controls               */
/*			12/19/07	Added function fit and its controls                  */
/*			                                                                 */
/*****************************************************************************/

#ifndef _MSC_VER
	#pragma argsused
#endif

BOOL CALLBACK PhasePlotDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local macro to allow function fit
	#define ALLOW_PHASE_FUNCTION_FIT
	
	// Local variables
	// Chars
	char szBuffer[BUFFER_SIZE+1];  	// Text buffer
	char szMsg[BUFFER_SIZE+1];		// Message buffer
	// Temporary filename buffers
	char szTempFile[FILENAMESIZE+1];	// Temp full filename buffer
	char szTempTitle[FILENAMESIZE+1];	// Temp file title buffer
	char szTempPath[FILENAMESIZE+1];	// Temp file path buffer
	char szTempName[FILENAMESIZE+1];    // Temp file name buffer
	char szTempExt[BUFFER_SIZE+1];		// Temp file extension buffer
	char *ptr;							// General pointer to character */
	// Unsigned Ints
	static unsigned uTitle;			// HWND of Title combo control
	static unsigned uSubtitle;	  	// HWND of Subtitle combo control
	static unsigned uMessage;	  	// HWND of Message combo control
	// Ints
	int i;							// General index
	int nIndex;                     // Listbox index
	int nLength;					// String length
	int nDOY;						// Day of year
	int nDay;						// Day of month
	int nMonth;						// Month of year
	int nYear;						// Year (4-digit)
	int nCoarseMJD;					// Leading digits of MJD
	int nDecade;					// Decade to remove from MJD scale
	static int nMessageCount;		// # non-user messages entered into list
	static int nEntry;        		// Entry to be validated
	static int nPrevStart;			// Previous analysis start point
	static int nPrevEnd;			// Previous analysis end point
	// BOOLs
	BOOL bSave;						// BOOL to save state of ini flag
	//BOOL bNarrow;					// Flag for small relative x scale range
	static BOOL bErrorTrap=FALSE;   // Flag for entry error
	static BOOL bPrevRead;			// BOOL to store original read flag
	static BOOL bFirstTime=TRUE;	// Flag for dlg box opened

	// Floats
	static float fTau;				// Tau value
	static float fEntry;        	// Entry to be validated
	// F_TYPEs
	F_TYPE fMin, fMax, fAvg;        // Message min, max & avg phase parameters
	F_TYPE fA, fB, fC, fV; 		  	// Message freq drift parameters
	static F_TYPE fDataMax;
	static F_TYPE fDataMin;
	//F_TYPE smin;					// Scale min
	//F_TYPE smax;					// Scale max
	//F_TYPE sdiv;					// Scale div

	// Note: The phase plot data structs, sPPlot & sPPrev, are defined globally
	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Reinitialize when data changes
			// Note: This code is both here & before call to phase plot
			// The plot scale will be initialized whichever is opened 1st
			// if the data has changed so that a new scale is required
			if(bPhaseScaleChanged)
			{
				// Initialize freq plot parameters
				InitPhasePlotParams(1);

				// Reset scale recalc flag
				bPhaseScaleChanged=FALSE;
			}

			// Set dialog box title
			LoadString(hInst, IDS_TITLE_PHASEOPT, szBuffer, BUFFER_SIZE);
			SetWindowText(hDlg, szBuffer);

			// Save previous analysis start and end points
			nPrevStart=(int)fPhaseData[1];
			nPrevEnd=(int)fPhaseData[2];

			// Save previous phase plot parameters
			strlcpy(sPPrev.title, sPPlot.title, TITLESIZE);
			strlcpy(sPPrev.subtitle, sPPlot.subtitle, SUBTITLESIZE);
			strlcpy(sPPrev.message_str, sPPlot.message_str, MESSAGESIZE);
			strlcpy(sPPrev.x_label, sPPlot.x_label, XLABELSIZE);
			strlcpy(sPPrev.left_y_label, sPPlot.left_y_label, YLABELSIZE);
			strlcpy(sPPrev.plot_filename, sPPlot.plot_filename, FILENAMESIZE);
			strlcpy(sPPrev.function, sPPlot.function, FUNCTIONSIZE);
			sPPrev.x_offset=sPPlot.x_offset;
			sPPrev.x_mult=sPPlot.x_mult;
			sPPrev.x_div=sPPlot.x_div;
			sPPrev.y_offset=sPPlot.y_offset;
			sPPrev.y_mult=sPPlot.y_mult;
			sPPrev.y_max=sPPlot.y_max;
			sPPrev.y_min=sPPlot.y_min;
			sPPrev.y_div=sPPlot.y_div;
			sPPrev.y_tic=sPPlot.y_tic;
			sPPrev.do_date=sPPlot.do_date;
			sPPrev.do_box=sPPlot.do_box;
			sPPrev.do_fit=sPPlot.do_fit;
			sPPrev.do_wide=sPPlot.do_wide;
			sPPrev.do_mouse=sPPlot.do_mouse;
			sPPrev.do_line=sPPlot.do_line;
			sPPrev.position=sPPlot.position;
			sPPrev.order=sPPlot.order;

			// Save previous read config flag;
			bPrevRead=bUsePhasePlotIni;

			// Find data range
			FindMinMax(fPhaseData, &fDataMin, &fDataMax, PHASE_DATA);

			// Fill up line fit types list box using string table
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_DPLOT_FIT));
			for(i=0; i<NUM_PPLOT_FITS; i++)
			{
				LoadString(hInst, IDS_PPLOT_FIT_0+i, szBuffer, BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_DPLOT_FIT), i,
					szBuffer);
			}

			// Add function fit if allowed
			#ifdef ALLOW_PHASE_FUNCTION_FIT
			nDummy=ComboBox_InsertString(GETHCTL(IDC_DPLOT_FIT), i,
				"Function (x=f(t))");
			#endif

			// Fill up x-axis label list box using string table
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_DPLOT_XLABEL));

			#if(0) // Original code
			// Allow all non-timetag x-axis labels
			for(i=0; i<NUM_DPLOT_XLABELS; i++)
			{
				LoadString(hInst, IDS_DPLOT_XLABEL_0+i, szBuffer, BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_DPLOT_XLABEL), i,
					szBuffer);
			}

			// Allow Timetag Point choice only if there are timetags
			if(bPhaseTimetags)
			{
				LoadString(hInst, IDS_DPLOT_XLABEL_10, szBuffer, BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_DPLOT_XLABEL), 10,
					szBuffer);
			}
			#endif

			#if(1) // New code 03/02/08
			// Allow all non-timetag x-axis labels
			for(i=0; i<NUM_DPLOT_XLABELS-3; i++)
			{
				LoadString(hInst, IDS_DPLOT_XLABEL_0+i, szBuffer, BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_DPLOT_XLABEL), i,
					szBuffer);
			}

			// Allow timetag choices only if there are timetags
			// and they are not reversed
			if( (bPhaseTimetags) &&
				(fPhaseTimetags[ARRAY_OFFSET]<fPhaseTimetags[ARRAY_OFFSET+1]) )
			{
				for(i=NUM_DPLOT_XLABELS-3; i<NUM_DPLOT_XLABELS; i++)
				{
					LoadString(hInst, IDS_DPLOT_XLABEL_0+i, szBuffer, BUFFER_SIZE);
					nDummy=ComboBox_InsertString(GETHCTL(IDC_DPLOT_XLABEL), i,
						szBuffer);
				}
			}
			#endif

			// Fill up y-axis label list box using string table
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_DPLOT_YLABEL));
			for(i=0; i<NUM_PPLOT_YLABELS; i++)
			{
				LoadString(hInst, IDS_PPLOT_YLABEL_0+i, szBuffer, BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_DPLOT_YLABEL),	i,
					szBuffer);
			}

			// Fill up message position list box using string table
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_DPLOT_POSITION));
			nDummy=ComboBox_InsertString(GETHCTL(IDC_DPLOT_POSITION),
				0, "None");
			for(i=0; i<NUM_DPLOT_POSITIONS; i++)
			{
				LoadString(hInst, IDS_DPLOT_POSITION_0+i, szBuffer,
					BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_DPLOT_POSITION), i,
					szBuffer);
			}

			// Fill up polynominal order list box
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_DPLOT_ORDER));
			for(i=0; i<9; i++)
			{
				_snprintf(szBuffer, sizeof(szBuffer), "%d", i+1);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_DPLOT_ORDER),	i,
					szBuffer);
			}

			// Hide the poly order list box if poly fit not selected
			if(sPPlot.do_line==PPLOT_POLY)
			{
				// Show the poly order list box if poly fit selected
				ShowWindow(GETHCTL(IDC_DPLOT_ORDER), SW_SHOWNORMAL);
				ShowWindow(GETHCTL(IDC_DPLOT_POLY), SW_SHOWNORMAL);
			}
			else
			{
				// Don't show the poly order list box
				ShowWindow(GETHCTL(IDC_DPLOT_ORDER), SW_HIDE);
				ShowWindow(GETHCTL(IDC_DPLOT_POLY), SW_HIDE);
			}

			// Show function edit box if function fit selected
			if(sPPlot.do_line==PPLOT_FUNC)
			{
				// Show the function edit box if function fit selected
				ShowWindow(GETHCTL(IDC_DPLOT_FUNCT), SW_SHOWNORMAL);
				SetWindowText(GETHCTL(IDC_DPLOT_FUNCT),
					sPPlot.function);
				SetWindowText(GETHCTL(IDC_DPLOT_DOFIT), "Fit &6     x(t)=");

				// Show the parameter initialization button
				// if non-blank function
				if(strlen(sPPlot.function))
				{
					// Show parameter initialization button
					ShowWindow(GETHCTL(IDC_DPLOT_PARAM), SW_SHOWNORMAL);
				}
				else
				{
					// Hide parameter initialization button
					ShowWindow(GETHCTL(IDC_DPLOT_PARAM), SW_HIDE);
				}
			}
			else
			{
				// Don't show the function edit box
				ShowWindow(GETHCTL(IDC_DPLOT_FUNCT), SW_HIDE);
				SetWindowText(GETHCTL(IDC_DPLOT_DOFIT), "Fit Params &6");

				// Hide the parameter initialization button
				ShowWindow(GETHCTL(IDC_DPLOT_PARAM), SW_HIDE);
			}

			// Show line type
			nDummy=nDummy=ComboBox_SetCurSel(GETHCTL(IDC_DPLOT_FIT),
				sPPlot.do_line);

			// Show position
			nDummy=ComboBox_SetCurSel(GETHCTL(IDC_DPLOT_POSITION),
				sPPlot.position);

			// Show poly order
			nDummy=ComboBox_SetCurSel(GETHCTL(IDC_DPLOT_ORDER),
				sPPlot.order-1);

			// Clear the title list box
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_DPLOT_TITLE));

			// Fill up title list box using string table
			for(i=0; i<NUM_PPLOT_TITLES; i++)
			{
				LoadString(hInst, IDS_PPLOT_TITLE_0+i, szBuffer, BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_DPLOT_TITLE), i,
					szBuffer);
			}

			// Load previous user-entered title strings into list box
			if(nUserTitles)
			{
				for(i=0; i<nUserTitles; i++)
				{
					// Load title string
					nDummy=ComboBox_InsertString(GETHCTL(IDC_DPLOT_TITLE),
						i, szPlotTitle[i]);
				}
			}

			// Load the current title
			SetWindowText(GETHCTL(IDC_DPLOT_TITLE),
				sPPlot.title);

			// Clear the subtitle list box
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_DPLOT_SUBTITLE));

			// Load the filenames into the subtitle list box
			nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_SUBTITLE),
				szPhaseFileTitle);
			nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_SUBTITLE),
				szPhaseFile);

			// Load previous user-entered subtitle strings into list box
			if(nUserSubtitles)
			{
				for(i=0; i<nUserSubtitles; i++)
				{
					// Load subtitle string
					nDummy=ComboBox_InsertString(GETHCTL(IDC_DPLOT_SUBTITLE),
						i, szPlotSubtitle[i]);
				}
			}

			// Load the current subtitle
			SetWindowText(GETHCTL(IDC_DPLOT_SUBTITLE),
				sPPlot.subtitle);

			// Set up plot messages
			SendMessage(hDlg, WM_COMMAND,
				GET_WM_COMMAND_MPS(IDC_DPLOT_MESSAGES, NULL, 0));

			// Load line parameter messages
			for(i=0; i<PLINE_NUMLINES; i++)
			{
				switch(sPLine[i].nLineType)
				{
					case PLINE_QUAD:
					{
						_snprintf(szBuffer, sizeof(szBuffer),
							"Line %d: Freq Slope=%10.3e", i+1,
							sPLine[i].fSlope);
						ShortenExp(szBuffer);
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;
					}
					break;

					// Note:  This case wasn't activated until 07/24/10
					case PLINE_LIN:
					{
						_snprintf(szBuffer, sizeof(szBuffer),
							"Line %d: Freq Slope=%10.3e", i+1,
							sPLine[i].fSlope);
						ShortenExp(szBuffer);
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;

						#if(1) // New code 07/24/10
						// Also add message re frequency offset
						// which is line slope divided by tau
						_snprintf(szBuffer, sizeof(szBuffer),
							"Freq Offset=%10.3e", sPLine[i].fSlope/fTau);
						ShortenExp(szBuffer);
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;
						#endif
					}
					break;

					case PLINE_AVG:
					{
						_snprintf(szBuffer, sizeof(szBuffer),
							"Line %d: Average=%10.5e", i+1,
							sPLine[i].fAverage);
						ShortenExp(szBuffer);
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;
					}
					break;

					default:
					{
						// Do nothing
						;
					}
					break;
				}
			}

			// Load previous user-entered message strings into list box
			if(nUserMessages)
			{
				for(i=0; i<nUserMessages; i++)
				{
					// Load message string
					nDummy=ComboBox_InsertString(GETHCTL(IDC_DPLOT_MESSAGE),
						i, szPlotMessage[i]);
				}
			}

			// Load the current message
			SetWindowText(GETHCTL(IDC_DPLOT_MESSAGE),
				sPPlot.message_str);

			// Load the plot filename
			SetWindowText(GETHCTL(IDC_DPLOT_FILENAME),
				sPPlot.plot_filename);

			if(bFirstTime)
			{
				// Set phase plot x-axis label
				LoadString(hInst, IDS_DPLOT_XLABEL_0+nPPlotX, szBuffer,
					BUFFER_SIZE);
				strlcpy(sPPlot.x_label, szBuffer, XLABELSIZE);
			
				// Get phase tau
				GetWindowText(GetDlgItem(hwndMain, IDC_PHASETAU),
					szBuffer, BUFFER_SIZE);

				// Use its absolute value
				fTau=(float)fabs(atof(szBuffer));

				// Set the x-axis multiplier factor
				switch(nPPlotX)
				{
					case X_POINT:
					case X_TIMETAG:
					{
						sPPlot.x_mult=(float)1.0;
					}
					break;

					case X_KPOINT:
					{
						sPPlot.x_mult=(float)0.001;
					}
					break;

					case X_MILLISECOND:
					{
						sPPlot.x_mult=(float)(fTau*1000.0);
					}
					break;

					case X_SECOND:
					{
						sPPlot.x_mult=(float)fTau;
					}
					break;

					case X_MINUTE:
					{
						sPPlot.x_mult=(float)(fTau/60.0);
					}
					break;

					case X_HOUR:
					{
						sPPlot.x_mult=(float)(fTau/3600.0);
					}
					break;

					case X_DAY:
					case X_DOY:
					case X_MJD:
					{
						sPPlot.x_mult=(float)(fTau/86400.0);
					}
					break;

					case X_WEEK:
					{
						sPPlot.x_mult=(float)(fTau/(86400.0*7));
					}
					break;
				}

				// Determine x-axis scale
				SendMessage(hDlg, WM_COMMAND,
					GET_WM_COMMAND_MPS(IDC_DPLOT_XSCALE, NULL, 0));

				// Load default initial parameters into function fit
				for(i=0; i<NUMPARAMS; i++)
				{
					sPPlot.param[i]=1.0;
				}

				// Reset flag
				bFirstTime=FALSE;
			}

			// Initialize MJD-XXXXX and DOY XXXX labels
			// when dialog box is opened and there are timetags
			// Redetermine x-axis scale
			SendMessage(hDlg, WM_COMMAND,
				GET_WM_COMMAND_MPS(IDC_DPLOT_XSCALE, NULL, 0));

			// Load the x-axis label
			SetWindowText(GETHCTL(IDC_DPLOT_XLABEL),
				sPPlot.x_label);

			// Load the y-axis label
			SetWindowText(GETHCTL(IDC_DPLOT_YLABEL),
				sPPlot.left_y_label);

			// Load the x_offset value
			_snprintf(szBuffer, sizeof(szBuffer),
				"%10.5e", sPPlot.x_offset);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_DPLOT_XOFFSET), szBuffer);

			// Load the x_mult value
			_snprintf(szBuffer, sizeof(szBuffer),
				"%10.5e", sPPlot.x_mult);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_DPLOT_XMULT), szBuffer);

			// Load the x-axis start value
			_snprintf(szBuffer, sizeof(szBuffer),
				"%d", (int)fPhaseData[1]);
			SetWindowText(GETHCTL(IDC_DPLOT_XSTART),
				szBuffer);

			// Load the x-axis end value
			_snprintf(szBuffer, sizeof(szBuffer),
				"%d", (int)fPhaseData[2]);
			SetWindowText(GETHCTL(IDC_DPLOT_XEND),
				szBuffer);

			// Load the y_offset value
			_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", sPPlot.y_offset);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_DPLOT_YOFFSET), szBuffer);

			// Load the fDataMax value
			_snprintf(szBuffer, sizeof(szBuffer),
				"%10.5e", fDataMax);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_DPLOT_DATAMAX), szBuffer);

			// Load the y_max value
			_snprintf(szBuffer, sizeof(szBuffer),
				"%10.5e", sPPlot.y_max);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_DPLOT_YMAX), szBuffer);

			// Load the fDataMin value
			_snprintf(szBuffer, sizeof(szBuffer),
				"%10.5e", fDataMin);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_DPLOT_DATAMIN), szBuffer);

			// Load the y_min value
			_snprintf(szBuffer, sizeof(szBuffer),
				"%10.5e", sPPlot.y_min);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_DPLOT_YMIN), szBuffer);

			// Load the x_div value
			_snprintf(szBuffer, sizeof(szBuffer),
				"%d", sPPlot.x_div);
			SetWindowText(GETHCTL(IDC_DPLOT_XDIV), szBuffer);

			// Load the y_div value
			_snprintf(szBuffer, sizeof(szBuffer),
				"%d", sPPlot.y_div);
			SetWindowText(GETHCTL(IDC_DPLOT_YDIV), szBuffer);

			// Load the y_tic value
			_snprintf(szBuffer, sizeof(szBuffer),
				"%d", sPPlot.y_tic);
			SetWindowText(GETHCTL(IDC_DPLOT_YTIC), szBuffer);

			// Load the y_mult value
			_snprintf(szBuffer, sizeof(szBuffer),
				"%10.5e", sPPlot.y_mult);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_DPLOT_YMULT), szBuffer);

			// Restore the date checkbox state
			Button_SetCheck(GETHCTL(IDC_DPLOT_DATE), sPPlot.do_date);

			// Restore the box checkbox state
			Button_SetCheck(GETHCTL(IDC_DPLOT_BOX), sPPlot.do_box);

			// Restore the do fit checkbox state
			Button_SetCheck(GETHCTL(IDC_DPLOT_DOFIT), sPPlot.do_fit);

			// Restore the x-axis scale stick checkbox state
			Button_SetCheck(GETHCTL(IDC_DPLOT_XSTICK), !bPXDefault);

			// Activate only if there is at least one quadratic line
			// or do_line is TRUE
			EnableWindow(GETHCTL(IDC_DPLOT_DOFIT), FALSE);

			for(i=0; i<PLINE_NUMLINES; i++)
			{
				if(sPLine[i].nLineType==PLINE_QUAD)
				{
					EnableWindow(GETHCTL(IDC_DPLOT_DOFIT), TRUE);
				}
			}

			if(sPPlot.do_line)
			{
				EnableWindow(GETHCTL(IDC_DPLOT_DOFIT), TRUE);
			}

			// Restore the wide checkbox state
			Button_SetCheck(GETHCTL(IDC_DPLOT_WIDE), sPPlot.do_wide);

			// Restore the cursor checkbox state
			Button_SetCheck(GETHCTL(IDC_DPLOT_CURSOR), sPPlot.do_mouse);

			// Get & save HWNDs returned by GetFocus() for Title, Subtitle &
			// Message combo boxes
			SetFocus(GETHCTL(IDC_DPLOT_TITLE));
			uTitle=(UINT)GetFocus();
			SetFocus(GETHCTL(IDC_DPLOT_SUBTITLE));
			uSubtitle=(UINT)GetFocus();
			SetFocus(GETHCTL(IDC_DPLOT_MESSAGE));
			uMessage=(UINT)GetFocus();

			return TRUE;
		}

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg,
						"Stable32.chm::PLOT_OPTIONS_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::PLOT_OPTIONS_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "PLOT_OPTIONS_FUNCTION");
					#endif
				}
				break;

				// Detect parameter changes
				// Title change
				case IDC_DPLOT_TITLE:
				{
					//  Respond to losing focus
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_KILLFOCUS)
					{
						// Get new title
						GetWindowText(GETHCTL(IDC_DPLOT_TITLE),
						sPPlot.title, TITLESIZE-1);

						// Redisplay title -perhaps shortened
						SetWindowText(GETHCTL(IDC_DPLOT_TITLE),
							sPPlot.title);

						// Put new string into list
						// Don't store string if it is same as before
						if(ComboBox_FindString(GETHCTL(IDC_DPLOT_TITLE),
							-1, sPPlot.title)==CB_ERR)
						{
							// Don't store blank title either
							if(strlen(sPPlot.title))
							{
								nDummy=ComboBox_InsertString(GETHCTL(
									IDC_DPLOT_TITLE), 0, sPPlot.title);
							}
						}
					}
				}
				break;

				// Subtitle change
				case IDC_DPLOT_SUBTITLE:
				{
					//  Respond to losing focus
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_KILLFOCUS)
					{
						// Get new subtitle
						GetWindowText(GETHCTL(IDC_DPLOT_SUBTITLE),
							sPPlot.subtitle, SUBTITLESIZE-1);

						// Redisplay subtitle - perhaps shortened
						SetWindowText(GETHCTL(IDC_DPLOT_SUBTITLE),
							sPPlot.subtitle);

						// Put new string into list
						// Don't store string if it is same as before
						if(ComboBox_FindString(GETHCTL(IDC_DPLOT_SUBTITLE),
							-1, sPPlot.subtitle)==CB_ERR)
						{
							// Don't store blank subtitle either
							if(strlen(sPPlot.subtitle))
							{
								nDummy=ComboBox_InsertString(GETHCTL(
									IDC_DPLOT_SUBTITLE), 0, sPPlot.subtitle);
							}
						}
					}
				}
				break;

				// Message change
				case IDC_DPLOT_MESSAGE:
				{
					//  Respond to losing focus
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_KILLFOCUS)
					{
						// Get new message
						GetWindowText(GETHCTL(IDC_DPLOT_MESSAGE),
							sPPlot.message_str, MESSAGESIZE-1);

						// Redisplay message - perhaps shortened
						SetWindowText(GETHCTL(IDC_DPLOT_MESSAGE),
							sPPlot.message_str);

						// Put new string into list
						// Don't store string if it is same as before
						if(ComboBox_FindString(GETHCTL(IDC_DPLOT_MESSAGE),
							-1, sPPlot.message_str)==CB_ERR)
						{
							// Don't store blank message either
							if(strlen(sPPlot.message_str))
							{
								nDummy=ComboBox_InsertString(GETHCTL(
									IDC_DPLOT_MESSAGE), 0, sPPlot.message_str);
							}
						}
					}
				}
				break;

				// Plot Filename change
				case IDC_DPLOT_FILENAME:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// The default *.TKF filename includes full drive/path
						// where program started to avoid writing to floppy
						// or non-writable media.
						// The edit window AutoHScrolls.

						GetWindowText(GETHCTL(IDC_DPLOT_FILENAME),
							szTempFile, FILENAMESIZE-1);

						// Validate new filename
						if(CheckFilename(szTempFile, szTempTitle, szTempPath,
							szTempName, szTempExt, hDlg,
							"Phase Plot Filename"))
						{
							// Filename OK
							strlcpy(sPPlot.plot_filename, szTempFile,
								FILENAMESIZE);
						}
						else // Filename NG
						{
							// Restore original filename
							SetWindowText(GETHCTL(IDC_DPLOT_FILENAME),
								sPPlot.plot_filename);
							SetFocus(GETHCTL(IDC_DPLOT_FILENAME));
							break;
						}
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// X-Axis label change
				case IDC_DPLOT_XLABEL:
				{
					GetWindowText(GETHCTL(IDC_DPLOT_XLABEL),
							sPPlot.x_label, XLABELSIZE-1);

					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_SELCHANGE)
					{
						// Scale x-axis according to x_label:
						nIndex=
							ComboBox_GetCurSel(GETHCTL(IDC_DPLOT_XLABEL));

						// Save x-axis label # in global variable
						nPPlotX=nIndex;

						// Get phase tau
						GetWindowText(GetDlgItem(hwndMain, IDC_PHASETAU),
							szBuffer, BUFFER_SIZE);

						// Use its absolute value
						fTau=(float)fabs(atof(szBuffer));

						switch(nIndex)
						{
							case X_POINT:
							case X_TIMETAG:
							{
								sPPlot.x_mult=(float)1.0;
							}
							break;

							case X_KPOINT:
							{
								sPPlot.x_mult=(float)0.001;
							}
							break;

							case X_MILLISECOND:
							{
								sPPlot.x_mult=(float)(fTau*1000.0);
							}
							break;

							case X_SECOND:
							{
								sPPlot.x_mult=(float)fTau;
							}
							break;

							case X_MINUTE:
							{
								sPPlot.x_mult=(float)(fTau/60.0);
							}
							break;

							case X_HOUR:
							{
								sPPlot.x_mult=(float)(fTau/3600.0);
							}
							break;

							case X_DAY:
							case X_DOY:
							case X_MJD:
							{
								sPPlot.x_mult=(float)(fTau/86400.0);
							}
							break;

							case X_WEEK:
							{
								sPPlot.x_mult=(float)(fTau/(86400.0*7));
							}
							break;
						}

						// Reload the x_mult value
						_snprintf(szBuffer, sizeof(szBuffer),
							"%10.5e", sPPlot.x_mult);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_DPLOT_XMULT),
							szBuffer);

						// Determine x-axis scale
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DPLOT_XSCALE, NULL, 0));
					}
				}
				break;

				// Y-Axis label change
				case IDC_DPLOT_YLABEL:
				{
					GetWindowText(GETHCTL(IDC_DPLOT_YLABEL),
						sPPlot.left_y_label, YLABELSIZE-1);
				}
				break;

				// X-Axis offset change
				case IDC_DPLOT_XOFFSET:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new x_offset value
						GetWindowText(GETHCTL(IDC_DPLOT_XOFFSET),
							szBuffer, BUFFER_SIZE);
						fEntry=(float)atof(szBuffer);

						// Validate new x_offset value?
						sPPlot.x_offset=fEntry;

						// Redisplay x_offset value
						_snprintf(szBuffer, sizeof(szBuffer),
							"%10.5e", sPPlot.x_offset);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_DPLOT_XOFFSET),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// X-Axis mult change
				case IDC_DPLOT_XMULT:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new x_mult value
						GetWindowText(GETHCTL(IDC_DPLOT_XMULT),
							szBuffer, BUFFER_SIZE);
						fEntry=(float)fabs(atof(szBuffer));

						// Validate new x_mult value
						// Multiplier can't be zero
						if(fEntry)
						{
							sPPlot.x_mult=fEntry;
						}
						else
						{
							CannotBeZero(hDlg);
							SetFocus(GETHCTL(IDC_DPLOT_XMULT));
						}

						// Redisplay x_mult value
						_snprintf(szBuffer, sizeof(szBuffer),
							"%10.5e", sPPlot.x_mult);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_DPLOT_XMULT),
							szBuffer);

						// Change to generic x-axis label
						SetWindowText(GETHCTL(IDC_DPLOT_XLABEL), "Time");
						strlcpy(sPPlot.x_label, "Time", XLABELSIZE);

						// Redetermine x-axis scale
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DPLOT_XSCALE, NULL, 0));
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// X-Axis start change
				// Note:  This is just the analysis start point #
				case IDC_DPLOT_XSTART:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new analysis start value
						GetWindowText(GETHCTL(IDC_DPLOT_XSTART),
							szBuffer, BUFFER_SIZE);
						nEntry=abs(atoi(szBuffer));

						// Validate new analysis start value
						// Must be between 1 and analysis end -1
						if(ValidateInteger(hDlg, nEntry, 1,
							(int)fPhaseData[2]-1)==TRUE)
						{
							// Valid entry - change analysis start value
							fPhaseData[1]=(F_TYPE)nEntry;

							// Force new scale determination
							bPhaseScaleChanged=TRUE;
						}
						else
						{
							// Invalid entry - restore previous value
							_snprintf(szBuffer, sizeof(szBuffer),
								"%d", (int)fPhaseData[1]);
							SetWindowText(GETHCTL(IDC_DPLOT_XSTART),
								szBuffer);
							SetFocus(GETHCTL(IDC_DPLOT_XSTART));
						}

						// Redisplay x-axis start value
						_snprintf(szBuffer, sizeof(szBuffer),
							"%d", (int)fPhaseData[1]);
						SetWindowText(GETHCTL(IDC_DPLOT_XSTART),
							szBuffer);

						// Update the analysis start in the status bar
						SetWindowText(GetDlgItem(hwndMain,IDC_PHASESTART),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// X-Axis end change
				// Note:  This is just the analysis end point #
				case IDC_DPLOT_XEND:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new analysis end value
						GetWindowText(GETHCTL(IDC_DPLOT_XEND),
							szBuffer, BUFFER_SIZE);
						nEntry=abs(atoi(szBuffer));

						// Validate new analysis end value
						// Must be between analysis start +1 and # data points
						if(ValidateInteger(hDlg, nEntry, (int)fPhaseData[1]+1,
							(int)fPhaseData[0])==TRUE)
						{
							// Valid entry - change analysis end value
							fPhaseData[2]=(F_TYPE)nEntry;

							// Force new scale determination
							bPhaseScaleChanged=TRUE;
						}
						else
						{
							// Invalid entry - restore previous value
							_snprintf(szBuffer, sizeof(szBuffer),
								"%d", (int)fPhaseData[2]);
							SetWindowText(GETHCTL(IDC_DPLOT_XEND),
								szBuffer);
							SetFocus(GETHCTL(IDC_DPLOT_XEND));
						}

						// Redisplay x-axis end value
						_snprintf(szBuffer, sizeof(szBuffer),
							"%d", (int)fPhaseData[2]);
						SetWindowText(GETHCTL(IDC_DPLOT_XEND),
							szBuffer);

						// Update the analysis end in the status bar
						SetWindowText(GetDlgItem(hwndMain,IDC_PHASEEND),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Y-Axis offset change
				case IDC_DPLOT_YOFFSET:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new y_offset value
						GetWindowText(GETHCTL(IDC_DPLOT_YOFFSET),
							szBuffer, BUFFER_SIZE);
						fEntry=(float)atof(szBuffer);

						// Validate new y_offset value?
						sPPlot.y_offset=fEntry;

						// Redisplay y_offset value
						_snprintf(szBuffer, sizeof(szBuffer),
							"%10.5e", sPPlot.y_offset);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_DPLOT_YOFFSET),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Y_Axis mult change
				case IDC_DPLOT_YMULT:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new y_mult value
						GetWindowText(GETHCTL(IDC_DPLOT_YMULT),
							szBuffer, BUFFER_SIZE);
						fEntry=(float)fabs(atof(szBuffer));

						// Validate new y_mult value
						// Multiplier can't be zero
						if(fEntry)
						{
							sPPlot.y_mult=fEntry;
						}
						else
						{
							CannotBeZero(hDlg);
							SetFocus(GETHCTL(IDC_DPLOT_YMULT));
						}

						// Redisplay y_mult value
						_snprintf(szBuffer, sizeof(szBuffer),
							"%10.5e", sPPlot.y_mult);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_DPLOT_YMULT),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Function expression change
				case IDC_DPLOT_FUNCT:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new function
						GetWindowText(GETHCTL(IDC_DPLOT_FUNCT),
							sPPlot.function, FUNCTIONSIZE);

						// Redisplay function
						SetWindowText(GETHCTL(IDC_DPLOT_FUNCT),
							sPPlot.function);

						// Show the parameter initialization button
						// if non-blank function
						if(strlen(sPPlot.function))
						{
							// Show parameter initialization button
							ShowWindow(GETHCTL(IDC_DPLOT_PARAM), SW_SHOWNORMAL);
						}
						else
						{
							// Hide parameter initialization button
							ShowWindow(GETHCTL(IDC_DPLOT_PARAM), SW_HIDE);
						}
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Fit type change
				case IDC_DPLOT_FIT:
				{
					sPPlot.do_line=ComboBox_GetCurSel(GETHCTL(IDC_DPLOT_FIT));

					// Set up plot messages
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_DPLOT_MESSAGES, NULL, 0));

					EnableWindow(GETHCTL(IDC_DPLOT_DOFIT), FALSE);

					for(i=0; i<PLINE_NUMLINES; i++)
					{
						if(sPLine[i].nLineType==PLINE_QUAD)
						{
							EnableWindow(GETHCTL(IDC_DPLOT_DOFIT), TRUE);
						}
					}

					// Hide the poly order list box and label
					ShowWindow(GETHCTL(IDC_DPLOT_ORDER), SW_HIDE);
					ShowWindow(GETHCTL(IDC_DPLOT_POLY), SW_HIDE);

					// Hide the function edit box
				    ShowWindow(GETHCTL(IDC_DPLOT_FUNCT), SW_HIDE);
					SetWindowText(GETHCTL(IDC_DPLOT_DOFIT), "Fit Params &6");

					// Hide the parameter initialization button
					ShowWindow(GETHCTL(IDC_DPLOT_PARAM), SW_HIDE);

					if(sPPlot.do_line)
					{
						EnableWindow(GETHCTL(IDC_DPLOT_DOFIT), TRUE);

						// Polynomial fit
						if(sPPlot.do_line==PPLOT_POLY)
						{
							// Show the poly order list box if poly fit selected
							ShowWindow(GETHCTL(IDC_DPLOT_ORDER), SW_SHOWNORMAL);
							ShowWindow(GETHCTL(IDC_DPLOT_POLY), SW_SHOWNORMAL);
						}

						// Function fit
						if(sPPlot.do_line==PPLOT_FUNC)
						{
							// Show the function edit box if function fit selected
							ShowWindow(GETHCTL(IDC_DPLOT_FUNCT), SW_SHOWNORMAL);
							SetWindowText(GETHCTL(IDC_DPLOT_FUNCT),
								sPPlot.function);
							SetWindowText(GETHCTL(IDC_DPLOT_DOFIT), "Fit &6     x(t)=");

							// Read function
							GetWindowText(GETHCTL(IDC_DPLOT_FUNCT),
								sPPlot.function, FUNCTIONSIZE);

							// Show the parameter initialization button
							// if non-blank function
							if(strlen(sPPlot.function))
							{
								// Show parameter initialization button
								ShowWindow(GETHCTL(IDC_DPLOT_PARAM), SW_SHOWNORMAL);
							}
							else
							{
								// Hide parameter initialization button
								ShowWindow(GETHCTL(IDC_DPLOT_PARAM), SW_HIDE);
							}
						}
					}
				}
				break;

				// Poly order change
				case IDC_DPLOT_ORDER:
				{
					sPPlot.order=
						ComboBox_GetCurSel(GETHCTL(IDC_DPLOT_ORDER))+1;
				}
				break;

				// Position change
				case IDC_DPLOT_POSITION:
				{
					sPPlot.position=
						ComboBox_GetCurSel(GETHCTL(IDC_DPLOT_POSITION));
				}
				break;

				// Date flag change
				case IDC_DPLOT_DATE:
				{
					sPPlot.do_date=Button_GetCheck(GETHCTL(IDC_DPLOT_DATE));
				}
				break;

				// Box flag change
				case IDC_DPLOT_BOX:
				{
					sPPlot.do_box=Button_GetCheck(GETHCTL(IDC_DPLOT_BOX));
				}
				break;

				// Do fit flag change
				case IDC_DPLOT_DOFIT:
				{
					sPPlot.do_fit=Button_GetCheck(GETHCTL(IDC_DPLOT_DOFIT));
				}
				break;

				// Wide flag change
				case IDC_DPLOT_WIDE:
				{
					sPPlot.do_wide=Button_GetCheck(GETHCTL(IDC_DPLOT_WIDE));
				}
				break;

				// Cursor flag change
				case IDC_DPLOT_CURSOR:
				{
					sPPlot.do_mouse=Button_GetCheck(GETHCTL(IDC_DPLOT_CURSOR));
				}
				break;

				// X-axis scale stick flag change
				case IDC_DPLOT_XSTICK:
				{
					bPXDefault=!Button_GetCheck(GETHCTL(IDC_DPLOT_XSTICK));
				}
				break;

				// Function fit initial parameters change button
				case IDC_DPLOT_PARAM:
				{
					// Determine # function parameters (max=NUMPARAMS=10)
					// Scan szFunction for chars between a to j
					// not followed by an alphabetic character
					// or a left parenthesis (indicating end of math function name)
					sPPlot.num=0;
					for(i=0; i<NUMPARAMS; i++)
					{
						// Look for a character between a and j
						if((ptr=strchr(sPPlot.function, 'a'+i)))
						{
							// Check if the next character is non-alphabetic
							if((isalpha(*(ptr+1)))==0)
							{
								// Check if the next character is not a left parenthesis
								if((*(ptr+1)!='('))
								{
									sPPlot.num++;
								}
							}
						}
					}
		
					// Open fit paramater initialization dialog box
					InvokeDialogBox(hInst, "FuncBox", hwndMain, (DLGPROC)PhaseFuncDlgProc);
				}
				break;

				// Read config button
				case IDC_DPLOT_READ:
				{
					bSave=bUsePhasePlotIni;
					bUsePhasePlotIni=TRUE;
					ReadIni(INI_PHASE);
					bUsePhasePlotIni=bSave;
					SendMessage(hDlg, WM_INITDIALOG, (WPARAM)0, (LPARAM)0);

					// Redetermine x-axis scale
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_DPLOT_XSCALE, NULL, 0));
				}
				break;

				// Save config button
				case IDC_DPLOT_WRITE:
				{
					bSave=bUsePhasePlotIni;
					bUsePhasePlotIni=TRUE;
					WriteIni(INI_PHASE);
					bUsePhasePlotIni=bSave;
				}
				break;

				// Y-axis plot scale max change
				case IDC_DPLOT_YMAX:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						!bErrorTrap && (GetFocus()!=GETHCTL(IDC_DPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new y_max value
						GetWindowText(GETHCTL(IDC_DPLOT_YMAX),
							szBuffer, BUFFER_SIZE);
						fEntry=(float)atof(szBuffer);

						// Validate new y_max value?
						sPPlot.y_max=fEntry;

						// Redisplay y_max value
						_snprintf(szBuffer, sizeof(szBuffer),
							"%10.5e", sPPlot.y_max);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_DPLOT_YMAX),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Y-axis plot scale min change
				case IDC_DPLOT_YMIN:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						!bErrorTrap && (GetFocus()!=GETHCTL(IDC_DPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new y_min value
						GetWindowText(GETHCTL(IDC_DPLOT_YMIN),
							szBuffer, BUFFER_SIZE);
						fEntry=(float)atof(szBuffer);

						// Validate new y_min value?
						sPPlot.y_min=fEntry;
						
						// Redisplay y_min value
						_snprintf(szBuffer, sizeof(szBuffer),
							"%10.5e", sPPlot.y_min);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_DPLOT_YMIN),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// X-axis plot scale # div change
				case IDC_DPLOT_XDIV:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new x_div value
						GetWindowText(GETHCTL(IDC_DPLOT_XDIV),
							szBuffer, BUFFER_SIZE);
						nEntry=abs(atoi(szBuffer));

						// Validate new x_div value
						// # divs can't be zero
						if(nEntry)
						{
							sPPlot.x_div=nEntry;
						}
						else
						{
							CannotBeZero(hDlg);
							SetFocus(GETHCTL(IDC_DPLOT_XDIV));
						}

						// Redisplay x_div value
						_snprintf(szBuffer, sizeof(szBuffer),
							"%d", sPPlot.x_div);
						SetWindowText(GETHCTL(IDC_DPLOT_XDIV),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Y-axis plot scale # div change
				case IDC_DPLOT_YDIV:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new y_div value
						GetWindowText(GETHCTL(IDC_DPLOT_YDIV),
							szBuffer, BUFFER_SIZE);
						nEntry=abs(atoi(szBuffer));

						// Validate new y_div value
						// # divs can't be zero
						if(nEntry)
						{
							sPPlot.y_div=nEntry;
						}
						else
						{
							CannotBeZero(hDlg);
							SetFocus(GETHCTL(IDC_DPLOT_YDIV));
						}

						// Redisplay y_div value
						_snprintf(szBuffer, sizeof(szBuffer),
							"%d", sPPlot.y_div);
						SetWindowText(GETHCTL(IDC_DPLOT_YDIV),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Y-axis plot scale # tic change
				case IDC_DPLOT_YTIC:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new y_tic value
						GetWindowText(GETHCTL(IDC_DPLOT_YTIC),
							szBuffer, BUFFER_SIZE);
						nEntry=abs(atoi(szBuffer));

						// Validate new y_tic value?
						// # tics can't be zero
						if(nEntry)
						{
							sPPlot.y_tic=nEntry;
						}
						else
						{
							CannotBeZero(hDlg);
							SetFocus(GETHCTL(IDC_DPLOT_YTIC));
						}

						// Redisplay y_tic value
						_snprintf(szBuffer, sizeof(szBuffer),
							"%d", sPPlot.y_tic);
						SetWindowText(GETHCTL(IDC_DPLOT_YTIC),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Set up plot messages
				case IDC_DPLOT_MESSAGES:
				{
					// Clear the message list box
					nDummy=ComboBox_ResetContent(GETHCTL(IDC_DPLOT_MESSAGE));
					nMessageCount=0;

					// Load gaps filled message
					if(bPhaseGapFill)
					{
						_snprintf(szBuffer, sizeof(szBuffer),
							"%d Gaps Filled", nPhaseGapsFilled);
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;
					}

					// Note: Stringtable used to save DGROUP space
					// Load maximum & minumum phase messages
					FindMinMax(fData, &fMin, &fMax, PHASE_DATA);
					LoadString(hInst, IDS_PPLOT_MESSAGE_3, szMsg, BUFFER_SIZE);
					_snprintf(szBuffer, sizeof(szBuffer), szMsg, fMin);
					ShortenExp(szBuffer);
					nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
						szBuffer);
					nMessageCount++;
					LoadString(hInst, IDS_PPLOT_MESSAGE_4, szMsg, BUFFER_SIZE);
					_snprintf(szBuffer, sizeof(szBuffer), szMsg, fMax);
					ShortenExp(szBuffer);
					nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
						szBuffer);
					nMessageCount++;

					// Load an average phase message
					CalcMean(fData, &fAvg, PHASE_DATA);
					LoadString(hInst, IDS_PPLOT_MESSAGE_5, szMsg, BUFFER_SIZE);
					_snprintf(szBuffer, sizeof(szBuffer), szMsg, fAvg);
					ShortenExp(szBuffer);
					nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
						szBuffer);
					nMessageCount++;

					// Load slope and drift messages
					// Note use of quadratic() instead of CalcQuadraticDrift()
					GetWindowText(hwndPhaseTau, szBuffer, BUFFER_SIZE);
					fTau=(float)atof(szBuffer);
					CalcQuadraticDrift(fData, 1.0, &fA, &fB, &fC, &fV);
					LoadString(hInst, IDS_PPLOT_MESSAGE_6, szMsg, BUFFER_SIZE);
					_snprintf(szBuffer, sizeof(szBuffer), szMsg, 2*fC/fTau);
					ShortenExp(szBuffer);
					nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
						szBuffer);
					nMessageCount++;
					LoadString(hInst, IDS_PPLOT_MESSAGE_7, szMsg, BUFFER_SIZE);
					_snprintf(szBuffer, sizeof(szBuffer), szMsg,
						2*fC*86400./(fTau*fTau));
					ShortenExp(szBuffer);
					nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
						szBuffer);
					nMessageCount++;

					// Load phase offset removed message
					if(bPhaseNorm)
					{
						LoadString(hInst, IDS_PPLOT_MESSAGE_8, szMsg,
							BUFFER_SIZE);
						_snprintf(szBuffer, sizeof(szBuffer), szMsg,
							fPhaseOffsetRemoved);
						ShortenExp(szBuffer);
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;
					}

					// Load quadratic drift removed messages
					if(bQuadDriftRem)
					{
						// Load freq slope removed message
						LoadString(hInst, IDS_PPLOT_MESSAGE_9, szMsg,
							BUFFER_SIZE);
						_snprintf(szBuffer, sizeof(szBuffer), szMsg,
								fPhaseSlopeRemoved);
						ShortenExp(szBuffer);
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;

						// Load freq drift removed message
						LoadString(hInst, IDS_PPLOT_MESSAGE_10, szMsg,
							BUFFER_SIZE);
						_snprintf(szBuffer, sizeof(szBuffer), szMsg,
								fPhaseSlopeRemoved*86400./fTau);
						ShortenExp(szBuffer);
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;
					}

					// Load linear phase slope (freq offset) removed messages
					if(bFreqOffsetRem)
					{
						// Load freq slope removed message
						LoadString(hInst, IDS_PPLOT_MESSAGE_9, szMsg,
							BUFFER_SIZE);
						_snprintf(szBuffer, sizeof(szBuffer), szMsg,
								fPhaseSlopeRemoved);
						ShortenExp(szBuffer);
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;

						// Load freq offset removed message
						LoadString(hInst, IDS_PPLOT_MESSAGE_11, szMsg,
							BUFFER_SIZE);
						_snprintf(szBuffer, sizeof(szBuffer), szMsg,
								fPhaseSlopeRemoved/fTau);
						ShortenExp(szBuffer);
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;
					}

					// Load phase offset added message
					if(bPhaseAddend)
					{
						LoadString(hInst, IDS_PPLOT_MESSAGE_13, szMsg,
							BUFFER_SIZE);
							_snprintf(szBuffer, sizeof(szBuffer), szMsg,
								fPhaseAddend);
						ShortenExp(szBuffer);
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;
					}
					
					// Load phase data scaled message
					if(bPhaseScaled)
					{
						LoadString(hInst, IDS_PPLOT_MESSAGE_14, szMsg,
							BUFFER_SIZE);
						_snprintf(szBuffer, sizeof(szBuffer), szMsg,
							fPhaseScaled);
						ShortenExp(szBuffer);
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;
					}

					// Load quadratic fit message
					if(sPPlot.do_line==PPLOT_QUAD)
					{
						// Load quadratic fit message
						LoadString(hInst, IDS_PPLOT_MESSAGE_12, szMsg,
							BUFFER_SIZE);
						_snprintf(szBuffer, sizeof(szBuffer), szMsg);
						ShortenExp(szBuffer);
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;
					}
				}
				break;

				// Reset all plot params to defaults
				case IDC_DPLOT_RESET:
				{
					// Use default analysis start and end points
					fPhaseData[1]=1.0;;
					fPhaseData[2]=fPhaseData[0];

					// Update the analysis start in the status bar
					_snprintf(szBuffer, sizeof(szBuffer), "%d",
						(int)fPhaseData[1]);
					SetWindowText(GetDlgItem(hwndMain,IDC_PHASESTART),
						szBuffer);

					// Update the analysis end in the status bar
					_snprintf(szBuffer, sizeof(szBuffer), "%d",
						(int)fPhaseData[2]);
					SetWindowText(GetDlgItem(hwndMain,IDC_PHASEEND),
						szBuffer);

					// Full filename where program started
					// This set here rather than in InitPhasePlotParams()
					strlcpy(sPPlot.plot_filename, szDrive, FILENAMESIZE);
					strlcat(sPPlot.plot_filename, szDirectory, FILENAMESIZE);
					strlcat(sPPlot.plot_filename, "PHASE.TKF", FILENAMESIZE);

					// Reset keep flag
					bPXDefault=TRUE;

					// Initialize phase plot parameters
					bSave=bUsePhasePlotIni;
					bUsePhasePlotIni=FALSE;
					InitPhasePlotParams(1);
					SendMessage(hDlg, WM_INITDIALOG, (WPARAM)0, (LPARAM)0);
					bUsePhasePlotIni=bSave;
				}
				break;

				// Respond to CR in an edit control
				// Note: No button is a DEFPUSHBUTTON
				case IDOK:
				{
					// The HWND returned by GetFocus() is not the same as the
					// one returned by GetDlgItem(), so the uTitle, etc
					// variables are used in these tests
					if((UINT)GetFocus()==uTitle)
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DPLOT_TITLE, NULL, CBN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to SUBTITLE edit control
					if((UINT)GetFocus()==uSubtitle)
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DPLOT_SUBTITLE, NULL, CBN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to MESSAGE edit control
					if((UINT)GetFocus()==uMessage)
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DPLOT_MESSAGE, NULL, CBN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to XOFFSET edit control
					if(GetFocus()==GETHCTL(IDC_DPLOT_XOFFSET))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DPLOT_XOFFSET, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to XMULT edit control
					if(GetFocus()==GETHCTL(IDC_DPLOT_XMULT))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DPLOT_XMULT, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to XSTART edit control
					if(GetFocus()==GETHCTL(IDC_DPLOT_XSTART))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DPLOT_XSTART, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to XEND edit control
					if(GetFocus()==GETHCTL(IDC_DPLOT_XEND))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DPLOT_XEND, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to YOFFSET edit control
					if(GetFocus()==GETHCTL(IDC_DPLOT_YOFFSET))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DPLOT_YOFFSET, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to YMULT edit control
					if(GetFocus()==GETHCTL(IDC_DPLOT_YMULT))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DPLOT_YMULT, NULL, EN_KILLFOCUS));
					}
					// Send EN_KILLFOCUS message to YMAX edit control
					if(GetFocus()==GETHCTL(IDC_DPLOT_YMAX))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DPLOT_YMAX, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to YMIN edit control
					if(GetFocus()==GETHCTL(IDC_DPLOT_YMIN))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DPLOT_YMIN, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to XDIV edit control
					if(GetFocus()==GETHCTL(IDC_DPLOT_XDIV))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DPLOT_XDIV, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to YDIV edit control
					if(GetFocus()==GETHCTL(IDC_DPLOT_YDIV))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DPLOT_YDIV, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to YTIC edit control
					if(GetFocus()==GETHCTL(IDC_DPLOT_YTIC))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DPLOT_YTIC, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to FILENAME edit control
					if(GetFocus()==GETHCTL(IDC_DPLOT_FILENAME))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DPLOT_FILENAME, NULL, EN_KILLFOCUS));
					}
					// Send EN_KILLFOCUS message to FUNCT edit control
					if(GetFocus()==GETHCTL(IDC_DPLOT_FUNCT))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DPLOT_FUNCT, NULL, EN_KILLFOCUS));
					}
				}
				break;

				// Subroutine for x-axis scale determination
				case IDC_DPLOT_XSCALE:
				{
					// Calc x-offset
					// Normally offset is zero
					// But for MJD or DOY scale, if there are timetags,
					// the offset is set to the value of MJD or DOY
					// of the first data point to be plotted

					// Set x_offset to default				
					sPPlot.x_offset=0.0;
					
					// Add special info to MJD & DOY labels if have timetags
					// and they are not reversed
					if( (bPhaseTimetags) &&
						(fPhaseTimetags[ARRAY_OFFSET]<fPhaseTimetags[ARRAY_OFFSET+1]) )
					{
						// Find start point
						i=(int)fPhaseData[1]; // Start point #

						// Find # days in data
						nDay=(int)ceil((fPhaseData[2]-fPhaseData[1])*
							sPPlot.x_mult);

						// Determine # decades to remove from MJD scale
						nDecade=1000;
						if(nDay<10)
						{
							nDecade=100;
						}

						// Find # 100s or 1000s in MJD
						nCoarseMJD=0;

						// Test to avoid integer overflow
						if(fPhaseTimetags[i+2]<INT_MAX)
						{
							// Set offset to start point timetag
							while((float)fPhaseTimetags[i+2]-
								nCoarseMJD>=(float)nDecade)
							{
								nCoarseMJD+=nDecade;
							}
						}
							
						if(nPPlotX==X_MJD) // Adjust MJD scale
						{
							// Set offset to start point timetag
							sPPlot.x_offset=(float)fPhaseTimetags[i+2];

							#if(1) // Original code
							// Subtract leading part of MJD
							sPPlot.x_offset-=nCoarseMJD;
							#endif

							#if(0) // New code 03/20/08
							// Subtract leading part of MJD
							sPPlot.x_offset-=(nCoarseMJD+1);
							#endif

							// Note 06/01/11: Why was one more subtracted
							// in new code of 03/2-/08
							// That seems to give the wrong scale
							// Go back to original code

							// Scale to data point units
							sPPlot.x_offset*=(float)(86400.0/fTau);

							// Add leading part of MJD to x-scale label
							_snprintf(sPPlot.x_label, XLABELSIZE, "MJD - %d",
								nCoarseMJD);
							SetWindowText(GETHCTL(IDC_DPLOT_XLABEL),
								sPPlot.x_label);
							nDummy=ComboBox_DeleteString(GETHCTL(
								IDC_DPLOT_XLABEL), nPPlotX);
							nDummy=ComboBox_InsertString(GETHCTL(
								IDC_DPLOT_XLABEL), nPPlotX, sPPlot.x_label);
							nDummy=ComboBox_SetCurSel(GETHCTL(
								IDC_DPLOT_XLABEL), nPPlotX);
						}
						else 
						{
							// Just put MJD-XXXXX into combo box
							_snprintf(szBuffer, sizeof(szBuffer), "MJD - %d",
								nCoarseMJD);
							nDummy=ComboBox_DeleteString(GETHCTL(
								IDC_DPLOT_XLABEL), X_MJD);
							nDummy=ComboBox_InsertString(GETHCTL(
								IDC_DPLOT_XLABEL), X_MJD, szBuffer);
						}

						 // Start point MJD
						lnMJD=(long)floor(fPhaseTimetags[i+2]);
						nDOY=MJDtoDOY(lnMJD); // Start point DOY

						// Convert integer MJD to date
						MJDToDate(lnMJD, &nDay, &nMonth, &nYear);

						if(nPPlotX==X_DOY)
						{
							#if(0) // Original code
							// Set x offset
							sPPlot.x_offset=(float)nDOY; // DOY
							#endif

							#if(1) // New code 03/20/08
							// Set x offset
							sPPlot.x_offset=(float)(nDOY-1); // DOY-1
							#endif

							 // Add fractional day
							sPPlot.x_offset+=
								(float)fPhaseTimetags[i+2]-(float)lnMJD;

							 // Scale to data point units
							sPPlot.x_offset*=(float)(86400.0/fTau);

							// Add year to x-scale label
							_snprintf(sPPlot.x_label, XLABELSIZE, "DOY %d",
								nYear);
							SetWindowText(GETHCTL(IDC_DPLOT_XLABEL),
								sPPlot.x_label);
							nDummy=ComboBox_DeleteString(GETHCTL(
								IDC_DPLOT_XLABEL), nPPlotX);
							nDummy=ComboBox_InsertString(GETHCTL(
								IDC_DPLOT_XLABEL), nPPlotX, sPPlot.x_label);
							nDummy=ComboBox_SetCurSel(GETHCTL(
								IDC_DPLOT_XLABEL), nPPlotX);
						}
						else
						{
							// Just put DOY XXXX into combo box
							_snprintf(szBuffer, sizeof(szBuffer), "DOY %d",
								nYear);
							nDummy=ComboBox_DeleteString(GETHCTL(
								IDC_DPLOT_XLABEL), X_DOY);
							nDummy=ComboBox_InsertString(GETHCTL(
								IDC_DPLOT_XLABEL), X_DOY, szBuffer);
						}
					}

					// Redisplay x_offset value
					_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
						sPPlot.x_offset);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_DPLOT_XOFFSET),
						szBuffer);

					// Get x-axis max & min
					sPPlot.x_max=(float)
						(sPPlot.x_mult*(fPhaseData[2]+sPPlot.x_offset));
					sPPlot.x_min=(float)
						(sPPlot.x_mult*(fPhaseData[1]+sPPlot.x_offset));

					// Determine x-axis plot scale
					DetermineXScale(&sPPlot);

					// Redisplay x_div value
					_snprintf(szBuffer, sizeof(szBuffer), "%d", sPPlot.x_div);
					SetWindowText(GETHCTL(IDC_DPLOT_XDIV),
						szBuffer);
				}
				break;				
				
				// Respond to esc key or cancel button
				case IDCANCEL:
				case IDC_DPLOT_CANCEL:
				{
					// Restore previous analysis start and end points
					fPhaseData[1]=(F_TYPE)nPrevStart;
					fPhaseData[2]=(F_TYPE)nPrevEnd;
					// Restore the analysis start in the status bar
					_snprintf(szBuffer, sizeof(szBuffer), "%d",
						(int)fPhaseData[1]);
					SetWindowText(GetDlgItem(hwndMain,IDC_PHASESTART),
						szBuffer);
					// Restore the analysis end in the status bar
					_snprintf(szBuffer, sizeof(szBuffer), "%d",
						(int)fPhaseData[2]);
					SetWindowText(GetDlgItem(hwndMain,IDC_PHASEEND),
						szBuffer);

					// Restore previous phase plot parameters
					strlcpy(sPPlot.title, sPPrev.title, TITLESIZE);
					strlcpy(sPPlot.subtitle, sPPrev.subtitle, SUBTITLESIZE);
					strlcpy(sPPlot.message_str, sPPrev.message_str,
						MESSAGESIZE);
					strlcpy(sPPlot.x_label, sPPrev.x_label, XLABELSIZE);
					strlcpy(sPPlot.left_y_label, sPPrev.left_y_label,
						YLABELSIZE);
					strlcpy(sPPlot.plot_filename, sPPrev.plot_filename,
						FILENAMESIZE);
					strlcpy(sPPlot.function, sPPrev.function,
						FUNCTIONSIZE);
					sPPlot.x_offset=sPPrev.x_offset;
					sPPlot.x_mult=sPPrev.x_mult;
					sPPlot.y_offset=sPPrev.y_offset;
					sPPlot.y_mult=sPPrev.y_mult;
					sPPlot.y_max=sPPrev.y_max;
					sPPlot.y_min=sPPrev.y_min;
					sPPlot.x_div=sPPrev.x_div;
					sPPlot.y_div=sPPrev.y_div;
					sPPlot.y_tic=sPPrev.y_tic;
					sPPlot.do_date=sPPrev.do_date;
					sPPlot.do_box=sPPrev.do_box;
					sPPlot.do_fit=sPPrev.do_fit;
					sPPlot.do_wide=sPPrev.do_wide;
					sPPlot.do_mouse=sPPrev.do_mouse;
					sPPlot.do_line=sPPrev.do_line;
					sPPlot.position=sPPrev.position;
					sPPlot.order=sPPrev.order;

					// Restore previous read config flag;
					bUsePhasePlotIni=bPrevRead;

					// Redetermine x-axis scale
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_DPLOT_XSCALE, NULL, 0));

					// Close dialog box
					EndDialog (hDlg, 0);
				}
				return TRUE;

				case IDC_DPLOT_ACCEPT:
				{
					// Save # user-entered title strings
					nUserTitles=ComboBox_GetCount(GETHCTL(IDC_DPLOT_TITLE))-
						NUM_PPLOT_TITLES;

					// Limit # user titles
					nUserTitles=min(nUserTitles, NUM_TITLES);

					// Save user titles
					if(nUserTitles)
					{
						for(i=0; i<nUserTitles; i++)
						{
							// Get size of title string
							nLength=ComboBox_GetLBTextLen(GETHCTL(
								IDC_DPLOT_TITLE), i);

							// Realloc title array
							if((szPlotTitle[i]=
								(LPSTR)realloc(szPlotTitle[i],
								(nLength+1)*sizeof(char)))==NULL)
							{
								// Just dsp err msg & skip saving string
								// We are closing dlg box anyway
								AllocErrorMessage();
							}
							else
							{
								// Save title string
								nDummy=ComboBox_GetLBText(GETHCTL(
									IDC_DPLOT_TITLE), i, szPlotTitle[i]);
							}
						}
					}

					// Save # user-entered subtitle strings
					nUserSubtitles=
						ComboBox_GetCount(GETHCTL(IDC_DPLOT_SUBTITLE))-
						NUM_PPLOT_SUBTITLES;

					// Limit # user subtitles
					nUserSubtitles=min(nUserSubtitles, NUM_SUBTITLES);

					// Save user subtitles
					if(nUserSubtitles)
					{
						for(i=0; i<nUserSubtitles; i++)
						{
							// Get size of subtitle string
							nLength=ComboBox_GetLBTextLen(GETHCTL(
								IDC_DPLOT_SUBTITLE), i);

							if((szPlotSubtitle[i]=
								(LPSTR)realloc(szPlotSubtitle[i],
								(nLength+1)*sizeof(char)))==NULL)
							{
								// Just dsp err msg & skip saving string
								// We are closing dlg box anyway
								AllocErrorMessage();
							}
							else
							{
								// Save subtitle string
								nDummy=ComboBox_GetLBText(GETHCTL(
									IDC_DPLOT_SUBTITLE), i, szPlotSubtitle[i]);
							}
						}
					}

					// Save # user-entered message strings
					nUserMessages=
						ComboBox_GetCount(GETHCTL(IDC_DPLOT_MESSAGE))-
						nMessageCount;

					// Limit # user messages
					nUserMessages=min(nUserMessages, NUM_MESSAGES);

					// Save user messages
					if(nUserMessages)
					{
						for(i=0; i<nUserMessages; i++)
						{
							// Get size of message string
							nLength=nDummy=ComboBox_GetLBTextLen(GETHCTL(
								IDC_DPLOT_MESSAGE), i);

							// Realloc message array
							if((szPlotMessage[i]=
								(LPSTR)realloc(szPlotMessage[i],
								(nLength+1)*sizeof(char)))==NULL)
							{
								// Just dsp err msg & skip saving string
								// We are closing dlg box anyway
								AllocErrorMessage();
							}
							else
							{
								// Save message string
								nDummy=ComboBox_GetLBText(GETHCTL(
									IDC_DPLOT_MESSAGE), i, szPlotMessage[i]);
							}
						}
					}

					// Set line thickness
					if(sPPlot.do_wide)
					{
						sPPlot.thick=WIDELINESIZE;
					}
					else
					{
						sPPlot.thick=0;
					}

					// Could invoke this here
					// But don't have all information yet
					// InvokeDialogBox(hInst, "FuncBox", hwndMain, (DLGPROC)PhaseFuncDlgProc);
					
					// Close dialog box
					EndDialog (hDlg, 0);
				}
				return TRUE;
			}
		}
		break;
	 }
	 return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*                Freq Plot Parameter Entry Dialog Procedure                 */
/*                                                                           */
/* 	Dialog box controls:                                                     */
/*			ID					Description		Variable or struct member    */
/*	IDC_DPLOT_TITLE		 		Plot Title              .title{}             */
/*	IDC_DPLOT_SUBTITLE	 		Plot Subtitle           .sub_title{}         */
/*	IDC_DPLOT_MESSAGE	 		Plot Message            .message_str[]       */
/*	IDC_DPLOT_XLABEL            X-Axis Label            .x_label[]           */
/*	IDC_DPLOT_YLABEL	 		Y-Axis Label            .left_y_label[]      */
/*	IDC_DPLOT_XOFFSET	 		X-Axis Scale Offset		.x_offset            */
/*	IDC_DPLOT_XMULT		 		X-Axis Scale Mult       .x_mult              */
/*	IDC_DPLOT_YOFFSET	 		Y-Axis Scale Offset     .y_offset            */
/*	IDC_DPLOT_YMULT		 		Y-Axis Scale Mult       .y_mult              */
/*	IDC_DPLOT_DATE		 		Date Flag               .do_date             */
/*	IDC_DPLOT_BOX		 		Box Flag                .do_box              */
/*	IDC_DPLOT_DOFIT				Fit Flag				.do_fit              */
/*	IDC_DPLOT_FIT		 		Fit Type                .do_line             */
/*	IDC_DPLOT_CURSOR			Cursor Flag             .do_mouse            */
/*	IDC_DPLOT_FILENAME	 		Plot Filename           .plot_filename[]     */
/*	IDC_DPLOT_YMAX		 		Y Scale Maximum         .y_max               */
/*	IDC_DPLOT_YMIN		 		Y Scale Minimum         .y_min               */
/*	IDC_DPLOT_YDIV		 		# Y Scale Divs          .y_div               */
/*	IDC_DPLOT_YTIC		 		# Y Scale Tics          .y_tic               */
/*	IDC_DPLOT_POSITION			Message position		.position            */
/*	IDC_DPLOT_RESET		 		Reset Param Flag                             */
/*	IDC_DPLOT_DATAMAX	 		Data Maximum                                 */
/*	IDC_DPLOT_DATAMIN	 		Data Minimum                                 */
/*                                                                           */
/*	struct plotdata             structure template for plot data             */
/*	{                                                                        */
/*		float x_offset;                            x-axis data offset factor */
/*		float x_mult;                          x-axis data multiplier factor */
/*		float y_offset;                            y-axis data offset factor */
/*		float y_mult;                          y_axis data multiplier factor */
/*		float x_min;                                     x-axis plot minimum */
/*		float x_max;                                     x-axis plot maximum */
/*		float y_min;                                     y-axis plot minimum */
/*		float y_max;                                     y-axis plot maximum */
/*		char title[TITLESIZE];                                    plot title */
/*		char subtitle[SUBTITLESIZE];                           plot subtitle */
/*		char x_label[XLABELSIZE];                          plot x-axis label */
/*		char left_y_label[YLABELSIZE];           plot y-axis left side label */
/*		char right_y_label[YLABELSIZE];         plot y-axis right side label */
/*		char plot_filename[FILENAMESIZE];                 plot .TKF filename */
/*		char message_str[MESSAGESIZE];                   plot message string */
/*		int do_date;                               flag to draw date on plot */
/*		int do_box;                             flag to draw box around plot */
/*		int do_errbar;                    flag to include error bars on plot */
/*		int do_line;                code to control drawing of lines on plot */
/*		int do_mouse;              flag to activate mouse after drawing plot */
/*		int do_table;        flag to write sigma-tau table on stability plot */
/*		int new_file;                  flag that plot is for a new data file */
/*		int new_name;             flag that plot is for a new basic filename */
/*		int plotype;                       code to identify the type of plot */
/*		int position;        code to control position of message box on plot */
/*		int x_div;                                  # x-axis major divisions */
/*		int x_tic;                     # x-axis tics between major divisions */
/*		int y_div;                                  # y-axis major divisions */
/*		int y_tic;                     # y-axis tics between major divisions */
/*		int config;                       flag for active configuration file */
/*	}                                                                        */
/*                                                                           */
/*		Frequency data plot do_line types:                                   */
/*			FPLOT_NONE	0                                                    */
/*			FPLOT_LINE	1                                                    */
/*			FPLOT_LOG	2                                                    */
/*			FPLOT_MENU	3                                                    */
/*			FPLOT_DUAL	4                                                    */
/*                                                                           */
/* 		Revision record:                                                     */
/*			07/13/96	Activated line code                                  */
/*			11/08/96	Added edit control CR logic and validity checking    */
/*			11/10/96	Added Start and End controls                         */
/*			11/22/96	Changed title, subtitle & message to comboboxes      */
/*			01/01/97	Added additional message options                     */
/*			01/25/97	Added code to push user-entered titles, subtitles &  */
/*						messages into combo listboxes with CR                */
/*			04/27/97	Added x_div control logic                            */
/*			06/02/00	Added PlotX config usage                             */
/*			03/11/01	Added wide checkbox for wide plot lines              */
/*			03/16/02	Improved x-axis scale                                */
/*			03/24/02	Made x-axis scale determination a separate block     */
/*						Improved x_mult entry handling                       */
/*          05/10/02	Added bPXDefault usage                               */
/*			09/11/02	Added Timetag Point to x-label options               */
/*			10/01/02	Changed to DetermineXScale() usage                   */
/*			04/11/03	Added log drift spec usage                           */
/*			04/15/03	Added log & diffusion drift/day messages             */
/*			11/24/04	Added test to avoid O/F for large timetags           */
/*			12/15/07	Added polynominal fit and its controls               */
/*			12/20/07	Added function fit and its controls                  */
/*			02/02/08	Added jump detection and its controls                */
/*                                                                           */
/*****************************************************************************/

#ifndef _MSC_VER
	#pragma argsused
#endif

BOOL CALLBACK FreqPlotDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	// Chars
	char szBuffer[BUFFER_SIZE+1];  	// Text buffer
	char szMsg[BUFFER_SIZE+1];  	// Message buffer
	char *pSub;						// Pointer to substring
	// Temporary filename buffers
	char szTempFile[FILENAMESIZE+1];	// Temp full filename buffer
	char szTempTitle[FILENAMESIZE+1];	// Temp file title buffer
	char szTempPath[FILENAMESIZE+1];	// Temp file path buffer
	char szTempName[FILENAMESIZE+1];    // Temp file name buffer
	char szTempExt[BUFFER_SIZE+1];		// Temp file extension buffer
	char *ptr;							// General pointer to character */
	// Unsigned Ints
	static unsigned uTitle;			// HWND of Title combo control
	static unsigned uSubtitle;	  	// HWND of Subtitle combo control
	static unsigned uMessage;	  	// HWND of Message combo control
	// Ints
	int i;							// General index
	int nIndex;                     // Listbox index
	int nLength;					// String length
	int nDOY;						// Day of year
	int nDay;						// Day of month
	int nMonth;						// Month of year
	int nYear;						// Year (4-digit)
	int nCoarseMJD;					// Leading digits of MJD
	int nDecade;					// Decade to remove from MJD scale
	static int nMessageCount;		// # non-user messages entered into list
	static int nEntry;        		// Entry to be validated
	static int nPrevStart;			// Previous analysis start point
	static int nPrevEnd;			// Previous analysis end point
	// BOOLs
	BOOL bSave;						// BOOL to save state of ini flag
	//BOOL bNarrow;					// Flag for small relative x scale range
	static BOOL bErrorTrap=FALSE;   // Flag for entry error
	static BOOL bPrevRead;			// BOOL to store original read flag
	static BOOL bFirstTime=TRUE;	// Flag for dlg box opened

	// Floats
	static float fTau;				// Tau value
	static float fEntry;        	// Entry to be validated
	// F_TYPEs
	F_TYPE fMin, fMax, fAvg;        // Message min, max & avg freq parameters
	F_TYPE fA, fB, fV; 		  		// Message freq drift parameters
	F_TYPE fTime;					// Time to reach slope spec
	static F_TYPE fDataMax;
	static F_TYPE fDataMin;
	//F_TYPE smin;					// Scale min
	//F_TYPE smax;					// Scale max
	//F_TYPE sdiv;					// Scale div

	// Note: The freq plot data structs, sFPlot & sFPrev, are defined globally

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Reinitialize when data changes
			// Note: This code is both here & before call to freq plot
			// The plot scale will be initialized whichever is opened 1st
			// if the data has changed so that a new scale is required
			if(bFreqScaleChanged)
			{
				// Initialize freq plot parameters
				InitFreqPlotParams(1);

				// Reset scale recalc flag
				bFreqScaleChanged=FALSE;
			}

			// Set dialog box title
			LoadString(hInst, IDS_TITLE_FREQOPT, szBuffer, BUFFER_SIZE);
			SetWindowText(hDlg, szBuffer);

			// Save previous analysis start and end points
			nPrevStart=(int)fFreqData[1];
			nPrevEnd=(int)fFreqData[2];

			// Save previous freq plot parameters
			strlcpy(sFPrev.title, sFPlot.title, TITLESIZE);
			strlcpy(sFPrev.subtitle, sFPlot.subtitle, SUBTITLESIZE);
			strlcpy(sFPrev.message_str, sFPlot.message_str, MESSAGESIZE);
			strlcpy(sFPrev.x_label, sFPlot.x_label, XLABELSIZE);
			strlcpy(sFPrev.left_y_label, sFPlot.left_y_label, YLABELSIZE);
			strlcpy(sFPrev.plot_filename, sFPlot.plot_filename, FILENAMESIZE);
			sFPrev.x_offset=sFPlot.x_offset;
			sFPrev.x_mult=sFPlot.x_mult;
			sFPrev.y_offset=sFPlot.y_offset;
			sFPrev.y_mult=sFPlot.y_mult;
			sFPrev.y_max=sFPlot.y_max;
			sFPrev.y_min=sFPlot.y_min;
			sFPrev.x_div=sFPlot.x_div;
			sFPrev.y_div=sFPlot.y_div;
			sFPrev.y_tic=sFPlot.y_tic;
			sFPrev.do_date=sFPlot.do_date;
			sFPrev.do_box=sFPlot.do_box;
			sFPrev.do_fit=sFPlot.do_fit;
			sFPrev.do_mouse=sFPlot.do_mouse;
			sFPrev.do_wide=sFPlot.do_wide;
			sFPrev.position=sFPlot.position;
			sFPrev.order=sFPlot.order;

			// Save previous read config flag;
			bPrevRead=bUseFreqPlotIni;

			// Find data range
			FindMinMax(fFreqData, &fDataMin, &fDataMax, FREQ_DATA);

			// Fill up line fit types list box using string table
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_DPLOT_FIT));
			for(i=0; i<NUM_FPLOT_FITS; i++)
			{
				LoadString(hInst, IDS_FPLOT_FIT_0+i, szBuffer, BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_DPLOT_FIT), i,
					szBuffer);
			}

			// Fill up x-axis label list box using string table
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_DPLOT_XLABEL));

			#if(0) // Original code
			// Allow all non-timetag x-axis labels
			for(i=0; i<NUM_DPLOT_XLABELS; i++)
			{
				LoadString(hInst, IDS_DPLOT_XLABEL_0+i, szBuffer, BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_DPLOT_XLABEL), i,
					szBuffer);
			}

			// Allow Timetag Point choice only if there are timetags
			if(bFreqTimetags)
			{
				LoadString(hInst, IDS_DPLOT_XLABEL_10, szBuffer, BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_DPLOT_XLABEL), 10,
					szBuffer);
			}
			#endif

			#if(1) // New code 03/02/08
			// Allow all non-timetag x-axis labels
			for(i=0; i<NUM_DPLOT_XLABELS-3; i++)
			{
				LoadString(hInst, IDS_DPLOT_XLABEL_0+i, szBuffer, BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_DPLOT_XLABEL), i,
					szBuffer);
			}

			// Allow timetag choices only if there are timetags
			// and they are not reversed
			if( (bFreqTimetags) &&
				(fFreqTimetags[ARRAY_OFFSET]<fFreqTimetags[ARRAY_OFFSET+1]) )
			{
				for(i=NUM_DPLOT_XLABELS-3; i<NUM_DPLOT_XLABELS; i++)
				{
					LoadString(hInst, IDS_DPLOT_XLABEL_0+i, szBuffer, BUFFER_SIZE);
					nDummy=ComboBox_InsertString(GETHCTL(IDC_DPLOT_XLABEL), i,
						szBuffer);
				}
			}
			#endif

			// Fill up y-axis label list box using string table
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_DPLOT_YLABEL));
			for(i=0; i<NUM_FPLOT_YLABELS; i++)
			{
				LoadString(hInst, IDS_FPLOT_YLABEL_0+i, szBuffer, BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_DPLOT_YLABEL), i,
					szBuffer);
			}

			// Fill up message position list box using string table
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_DPLOT_POSITION));
			nDummy=ComboBox_InsertString(GETHCTL(IDC_DPLOT_POSITION),
				0, "None");
			for(i=0; i<NUM_DPLOT_POSITIONS; i++)
			{
				LoadString(hInst, IDS_DPLOT_POSITION_0+i, szBuffer,
					BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_DPLOT_POSITION),
					i, szBuffer);
			}

			// Fill up polynominal order list box
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_DPLOT_ORDER));
			for(i=0; i<9; i++)
			{
				_snprintf(szBuffer, sizeof(szBuffer), "%d", i+1);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_DPLOT_ORDER),	i,
					szBuffer);
			}

			// Hide the poly order list box if poly fit not selected
			if(sFPlot.do_line==FPLOT_POLY)
			{
				// Show the poly order list box if poly fit selected
				ShowWindow(GETHCTL(IDC_DPLOT_ORDER), SW_SHOWNORMAL);
				ShowWindow(GETHCTL(IDC_DPLOT_POLY), SW_SHOWNORMAL);
			}
			else
			{
				// Don't show the poly order list box
				ShowWindow(GETHCTL(IDC_DPLOT_ORDER), SW_HIDE);
				ShowWindow(GETHCTL(IDC_DPLOT_POLY), SW_HIDE);
			}

			// Show function edit box if function fit selected
			if(sFPlot.do_line==FPLOT_FUNC)
			{
				// Show the function edit box if function fit selected
				ShowWindow(GETHCTL(IDC_DPLOT_FUNCT), SW_SHOWNORMAL);
				SetWindowText(GETHCTL(IDC_DPLOT_FUNCT),
					sFPlot.function);
				SetWindowText(GETHCTL(IDC_DPLOT_DOFIT), "Fit &6       y(t)=");

				// Show the parameter initialization button
				// if non-blank function
				if(strlen(sFPlot.function))
				{
					// Show parameter initialization button
					ShowWindow(GETHCTL(IDC_DPLOT_PARAM), SW_SHOWNORMAL);
				}
				else
				{
					// Hide parameter initialization button
					ShowWindow(GETHCTL(IDC_DPLOT_PARAM), SW_HIDE);
				}
			}
			else
			{
				// Don't show the function edit box
				ShowWindow(GETHCTL(IDC_DPLOT_FUNCT), SW_HIDE);
				SetWindowText(GETHCTL(IDC_DPLOT_DOFIT), "Fit Params &6");
				
				// Hide the parameter initialization button
				ShowWindow(GETHCTL(IDC_DPLOT_PARAM), SW_HIDE);
			}

			// Show configure label and button if jump detection selected
			if(sFPlot.do_line==FPLOT_JUMP)
			{
				// Show the poly order label text (used for jump config)
				ShowWindow(GETHCTL(IDC_DPLOT_POLY), SW_SHOWNORMAL);

				// Set IDC_DPLOT_POLY label text
				SetWindowText(GETHCTL(IDC_DPLOT_POLY), "Configure:");

				// Show the parameter initialization button
				ShowWindow(GETHCTL(IDC_DPLOT_PARAM), SW_SHOWNORMAL);
			}
			else if(sFPlot.do_line!=FPLOT_POLY)
			{
				// Hide the poly order label text (used for jump config)
				ShowWindow(GETHCTL(IDC_DPLOT_POLY), SW_HIDE);

				// Hide the parameter initialization button
				ShowWindow(GETHCTL(IDC_DPLOT_PARAM), SW_HIDE);
			}

			// Show line type
			nDummy=ComboBox_SetCurSel(GETHCTL(IDC_DPLOT_FIT), sFPlot.do_line);

			// Show position
			nDummy=ComboBox_SetCurSel(GETHCTL(IDC_DPLOT_POSITION),
				sFPlot.position);

			// Show poly order
			nDummy=ComboBox_SetCurSel(GETHCTL(IDC_DPLOT_ORDER),
				sFPlot.order-1);

			// Clear the title list box
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_DPLOT_TITLE));

			// Fill up title list box using string table
			for(i=0; i<NUM_FPLOT_TITLES; i++)
			{
				LoadString(hInst, IDS_FPLOT_TITLE_0+i, szBuffer, BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_DPLOT_TITLE), i,
					szBuffer);
			}

			// Load previous user-entered title strings into list box
			if(nUserTitles)
			{
				for(i=0; i<nUserTitles; i++)
				{
					// Load title string
					nDummy=ComboBox_InsertString(GETHCTL(IDC_DPLOT_TITLE),
						i, szPlotTitle[i]);
				}
			}

			// Load the current title
			SetWindowText(GETHCTL(IDC_DPLOT_TITLE),
				sFPlot.title);

			// Clear the subtitle list box
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_DPLOT_SUBTITLE));

			// Load the filenames into the subtitle list box
			nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_SUBTITLE),
				szFreqFileTitle);
			nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_SUBTITLE), szFreqFile);

			// Load previous user-entered subtitle strings into list box
			if(nUserSubtitles)
			{
				for(i=0; i<nUserSubtitles; i++)
				{
					// Load subtitle string
					nDummy=ComboBox_InsertString(GETHCTL(IDC_DPLOT_SUBTITLE),
						i, szPlotSubtitle[i]);
				}
			}

			// Load the current subtitle
			SetWindowText(GETHCTL(IDC_DPLOT_SUBTITLE),
				sFPlot.subtitle);

			// Set up plot messages
			SendMessage(hDlg, WM_COMMAND,
				GET_WM_COMMAND_MPS(IDC_DPLOT_MESSAGES, NULL, 0));

			// Load line parameter messages
			for(i=0; i<FLINE_NUMLINES; i++)
			{
				switch(sFLine[i].nLineType)
				{
					case FLINE_LIN:
					{
						_snprintf(szBuffer, sizeof(szBuffer),
							"Line %d: Slope=%10.3e", i+1, sFLine[i].fSlope);
						ShortenExp(szBuffer);
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;
					}
					break;

					case FLINE_AVG:
					{
						_snprintf(szBuffer, sizeof(szBuffer),
							"Line %d: Average=%10.5e", i+1,
							sFLine[i].fAverage);
						ShortenExp(szBuffer);
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;
					}
					break;

					default:
					{
						// Do nothing
						;
					}
					break;
				}
			}

			// Load previous user-entered message strings into list box
			if(nUserMessages)
			{
				for(i=0; i<nUserMessages; i++)
				{
					// Load message string
					nDummy=ComboBox_InsertString(GETHCTL(IDC_DPLOT_MESSAGE),
						i, szPlotMessage[i]);
				}
			}

			// Load the current message
			SetWindowText(GETHCTL(IDC_DPLOT_MESSAGE),
				sFPlot.message_str);

			// Load the plot filename
			SetWindowText(GETHCTL(IDC_DPLOT_FILENAME),
				sFPlot.plot_filename);

			if(bFirstTime)
			{
				// Set freq plot x-axis label
				LoadString(hInst, IDS_DPLOT_XLABEL_0+nFPlotX, szBuffer,
					BUFFER_SIZE);
				strlcpy(sFPlot.x_label, szBuffer, XLABELSIZE);
			
				// Get freq tau
				GetWindowText(GetDlgItem(hwndMain, IDC_FREQTAU),
					szBuffer, BUFFER_SIZE);

				// Use its absolute value
				fTau=(float)fabs(atof(szBuffer));

				// Set the x-axis multiplier factor
				switch(nFPlotX)
				{
					case X_POINT:
					case X_TIMETAG:
					{
						sFPlot.x_mult=(float)1.0;
					}
					break;

					case X_KPOINT:
					{
						sFPlot.x_mult=(float)0.001;
					}
					break;

					case X_MILLISECOND:
					{
						sFPlot.x_mult=(float)(fTau*1000.0);
					}
					break;

					case X_SECOND:
					{
						sFPlot.x_mult=(float)fTau;
					}
					break;

					case X_MINUTE:
					{
						sFPlot.x_mult=(float)(fTau/60.0);
					}
					break;

					case X_HOUR:
					{
						sFPlot.x_mult=(float)(fTau/3600.0);
					}
					break;

					case X_DAY:
					case X_DOY:
					case X_MJD:
					{
						sFPlot.x_mult=(float)(fTau/86400.0);
					}
					break;

					case X_WEEK:
					{
						sFPlot.x_mult=(float)(fTau/(86400.0*7));
					}
					break;
				}

				// Determine x-axis scale
				SendMessage(hDlg, WM_COMMAND,
					GET_WM_COMMAND_MPS(IDC_DPLOT_XSCALE, NULL, 0));

				// Load default initial parameters into function fit
				for(i=0; i<NUMPARAMS; i++)
				{
					sFPlot.param[i]=1.0;
				}

				// Reset flag
				bFirstTime=FALSE;
			}

			// Initialize MJD-XXXXX and DOY XXXX labels
			// when dialog box is opened and there are timetags
			// Does it have any bad side effects?
			// Redetermine x-axis scale
			SendMessage(hDlg, WM_COMMAND,
				GET_WM_COMMAND_MPS(IDC_DPLOT_XSCALE, NULL, 0));

			// Load the x-axis label
			SetWindowText(GETHCTL(IDC_DPLOT_XLABEL),
				sFPlot.x_label);

			// Load the y-axis label
			SetWindowText(GETHCTL(IDC_DPLOT_YLABEL),
				sFPlot.left_y_label);

			// Load the x_offset value
			_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", sFPlot.x_offset);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_DPLOT_XOFFSET), szBuffer);

			// Load the x_mult value
			_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", sFPlot.x_mult);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_DPLOT_XMULT), szBuffer);

			// Load the x-axis start value
			_snprintf(szBuffer, sizeof(szBuffer), "%d", (int)fFreqData[1]);
			SetWindowText(GETHCTL(IDC_DPLOT_XSTART),
				szBuffer);

			// Load the x-axis end value
			_snprintf(szBuffer, sizeof(szBuffer), "%d", (int)fFreqData[2]);
			SetWindowText(GETHCTL(IDC_DPLOT_XEND),
				szBuffer);

			// Load the y_offset value
			_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", sFPlot.y_offset);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_DPLOT_YOFFSET), szBuffer);

			// Load the fDataMax value
			_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fDataMax);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_DPLOT_DATAMAX), szBuffer);

			// Load the y_max value
			_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", sFPlot.y_max);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_DPLOT_YMAX), szBuffer);

			// Load the fDataMin value
			_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fDataMin);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_DPLOT_DATAMIN), szBuffer);

			// Load the y_min value
			_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", sFPlot.y_min);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_DPLOT_YMIN), szBuffer);

			// Load the x_div value
			_snprintf(szBuffer, sizeof(szBuffer), "%d", sFPlot.x_div);
			SetWindowText(GETHCTL(IDC_DPLOT_XDIV), szBuffer);

			// Load the y_div value
			_snprintf(szBuffer, sizeof(szBuffer), "%d", sFPlot.y_div);
			SetWindowText(GETHCTL(IDC_DPLOT_YDIV), szBuffer);

			// Load the y_tic value
			_snprintf(szBuffer, sizeof(szBuffer), "%d", sFPlot.y_tic);
			SetWindowText(GETHCTL(IDC_DPLOT_YTIC), szBuffer);

			// Load the y_mult value
			_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", sFPlot.y_mult);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_DPLOT_YMULT), szBuffer);

			// Restore the date checkbox state
			Button_SetCheck(GETHCTL(IDC_DPLOT_DATE), sFPlot.do_date);

			// Restore the box checkbox state
			Button_SetCheck(GETHCTL(IDC_DPLOT_BOX), sFPlot.do_box);

			// Restore the wide checkbox state
			Button_SetCheck(GETHCTL(IDC_DPLOT_WIDE), sFPlot.do_wide);

			// Restore the do fit checkbox state
			Button_SetCheck(GETHCTL(IDC_DPLOT_DOFIT), sFPlot.do_fit);

			// Restore the x-axis scale stick checkbox state
			Button_SetCheck(GETHCTL(IDC_DPLOT_XSTICK), !bFXDefault);

			// Activate only if there is at least one regression line
			// or do_line is TRUE
			EnableWindow(GETHCTL(IDC_DPLOT_DOFIT), FALSE);

			for(i=0; i<FLINE_NUMLINES; i++)
			{
				if(sFLine[i].nLineType==FLINE_LIN)
				{
					EnableWindow(GETHCTL(IDC_DPLOT_DOFIT), TRUE);
				}
			}

			if(sFPlot.do_line)
			{
				EnableWindow(GETHCTL(IDC_DPLOT_DOFIT), TRUE);
			}

			// Restore the cursor checkbox state
			Button_SetCheck(GETHCTL(IDC_DPLOT_CURSOR), sFPlot.do_mouse);

			// Get & save HWNDs returned by GetFocus() for Title, Subtitle &
			// Message combo boxes
			SetFocus(GETHCTL(IDC_DPLOT_TITLE));
			uTitle=(UINT)GetFocus();
			SetFocus(GETHCTL(IDC_DPLOT_SUBTITLE));
			uSubtitle=(UINT)GetFocus();
			SetFocus(GETHCTL(IDC_DPLOT_MESSAGE));
			uMessage=(UINT)GetFocus();

			return TRUE;
		}

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				case IDHELP:
				{
					// Invoke help file
					// Note:  HH_HELP_CONTEXT is much more complicated to use
					// HH_DISPLAY_TOPIC doesn't require any map or h files,
					// topic ordinal #s, or aliases, etc.
					// Just give the name of the htm file for the topic
					#if(0)
					HtmlHelp(hDlg, "Stable32.chm::PLOT_OPTIONS_FUNCTION.HTM",
						HH_DISPLAY_TOPIC,
                        0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::PLOT_OPTIONS_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "PLOT_OPTIONS_FUNCTION");
					#endif
				}
				break;

				// Detect parameter changes
				// Title change
				case IDC_DPLOT_TITLE:
				{
					// Respond to focus lost
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_KILLFOCUS)
					{
						GetWindowText(GETHCTL(IDC_DPLOT_TITLE),
							sFPlot.title, TITLESIZE-1);

						// Redisplay title - perhaps shortened
						SetWindowText(GETHCTL(IDC_DPLOT_TITLE),
							sFPlot.title);

						// Put new string into list
						// Don't store string if it is same as before
						if(ComboBox_FindString(GETHCTL(IDC_DPLOT_TITLE),
							-1, sFPlot.title)==CB_ERR)
						{
							// Don't store blank title either
							if(strlen(sFPlot.title))
							{
								nDummy=ComboBox_InsertString(GETHCTL(
									IDC_DPLOT_TITLE), 0, sFPlot.title);
							}
						}
					}
				}
				break;

				// Subtitle change
				case IDC_DPLOT_SUBTITLE:
				{
					// Respond to focus lost
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_KILLFOCUS)
					{
						GetWindowText(GETHCTL(IDC_DPLOT_SUBTITLE),
							sFPlot.subtitle, SUBTITLESIZE-1);

						// Redisplay subtitle - perhaps shortened
						SetWindowText(GETHCTL(IDC_DPLOT_SUBTITLE),
							sFPlot.subtitle);

						// Put new string into list
						// Don't store string if it is same as before
						if(ComboBox_FindString(GETHCTL(IDC_DPLOT_SUBTITLE),
							-1, sFPlot.subtitle)==CB_ERR)
						{
							// Don't store blank subtitle either
							if(strlen(sFPlot.subtitle))
							{
								nDummy=ComboBox_InsertString(GETHCTL(
									IDC_DPLOT_SUBTITLE), 0, sFPlot.subtitle);
							}
						}
					}
				}
				break;

				// Message change
				case IDC_DPLOT_MESSAGE:
				{
					// Respond to focus lost
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_KILLFOCUS)
					{
						GetWindowText(GETHCTL(IDC_DPLOT_MESSAGE),
							sFPlot.message_str, MESSAGESIZE-1);

						// Redisplay message - perhaps shortened
						SetWindowText(GETHCTL(IDC_DPLOT_MESSAGE),
							sFPlot.message_str);

						// Put new string into list
						// Don't store string if it is same as before
						if(ComboBox_FindString(GETHCTL(IDC_DPLOT_MESSAGE),
							-1, sFPlot.message_str)==CB_ERR)
						{
							// Don't store blank message either
							if(strlen(sFPlot.message_str))
							{
								nDummy=ComboBox_InsertString(GETHCTL(
									IDC_DPLOT_MESSAGE), 0, sFPlot.message_str);
							}
						}
					}
				}
				break;

				// Plot Filename change
				case IDC_DPLOT_FILENAME:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						GetWindowText(GETHCTL(IDC_DPLOT_FILENAME),
							szTempFile, FILENAMESIZE-1);

						// Validate new filename
						if(CheckFilename(szTempFile, szTempTitle, szTempPath,
							szTempName, szTempExt, hDlg,
							"Freq Plot Filename"))
						{
							// Filename OK
							strlcpy(sFPlot.plot_filename, szTempFile,
								FILENAMESIZE);
						}
						else // Filename NG
						{
							// Restore original filename
							SetWindowText(GETHCTL(IDC_DPLOT_FILENAME),
								sFPlot.plot_filename);
							SetFocus(GETHCTL(IDC_DPLOT_FILENAME));
							break;
						}
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// X-Axis label change
				case IDC_DPLOT_XLABEL:
				{
					GetWindowText(GETHCTL(IDC_DPLOT_XLABEL),
							sFPlot.x_label, XLABELSIZE-1);

					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_SELCHANGE)
					{
						// Scale x-axis according to x_label:
						nIndex=
							ComboBox_GetCurSel(GETHCTL(IDC_DPLOT_XLABEL));

						// Save x-axis label # in global variable
						nFPlotX=nIndex;

						// Get freq tau
						GetWindowText(GetDlgItem(hwndMain, IDC_FREQTAU),
							szBuffer, BUFFER_SIZE);

						// Use its absolute value
						fTau=(float)fabs(atof(szBuffer));

						switch(nIndex)
						{
							case X_POINT:
							case X_TIMETAG:
							{
								sFPlot.x_mult=(float)1.0;
							}
							break;

							case X_KPOINT:
							{
								sFPlot.x_mult=(float)0.001;
							}
							break;

							case X_MILLISECOND:
							{
								sFPlot.x_mult=(float)(fTau*1000.0);
							}
							break;

							case X_SECOND:
							{
								sFPlot.x_mult=(float)fTau;
							}
							break;

							case X_MINUTE:
							{
								sFPlot.x_mult=(float)(fTau/60.0);
							}
							break;

							case X_HOUR:
							{
								sFPlot.x_mult=(float)(fTau/3600.0);
							}
							break;

							case X_DAY:
							case X_DOY:
							case X_MJD:
							{
								sFPlot.x_mult=(float)(fTau/86400.0);
							}
							break;
							
							case X_WEEK:
							{
								sFPlot.x_mult=(float)(fTau/(86400.0*7));
							}
							break;
						}

						// Reload the x_mult value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							sFPlot.x_mult);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_DPLOT_XMULT),
							szBuffer);

						// Redetermine x-axis scale
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DPLOT_XSCALE, NULL, 0));
					}
				}
				break;

				// Y-Axis label change
				case IDC_DPLOT_YLABEL:
				{
					GetWindowText(GETHCTL(IDC_DPLOT_YLABEL),
						sFPlot.left_y_label, YLABELSIZE-1);

					// Do automatic data scaling per y-axis label
					// if std exponent format is entered as label
					strlcpy(szBuffer, "pp10[", sizeof(szBuffer));
					if((pSub=strstr(sFPlot.left_y_label, szBuffer))!=NULL)
					{
						// Compose scale factor
						strlcpy(szBuffer, "1.00000e+", sizeof(szBuffer));
						strlcat(szBuffer, pSub+5, sizeof(szBuffer));

						// Avoid crazy values
						// Note: The float limits exp to 38 even w/o 2nd test
						fEntry=(float)atof(szBuffer);
						if( (fEntry<1.0) || (fEntry>1e99) )
						{
							strlcpy(szBuffer, "1.00000e+00", sizeof(szBuffer));
						}

						// Enter value into edit control
						SetWindowText(GETHCTL(IDC_DPLOT_YMULT), szBuffer);
					}
					else // To assure clean YMULT value if not pp10[ entry
					{
						strlcpy(szBuffer, "1.00000e+00", sizeof(szBuffer));
						SetWindowText(GETHCTL(IDC_DPLOT_YMULT), szBuffer);
					}

					// Read new y_mult value
					GetWindowText(GETHCTL(IDC_DPLOT_YMULT),
						szBuffer, BUFFER_SIZE);
					fEntry=(float)fabs(atof(szBuffer));

					sFPlot.y_mult=fEntry;

					// Redisplay y_mult value
					_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
						sFPlot.y_mult);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_DPLOT_YMULT),
						szBuffer);
				}
				break;

				// X-Axis offset change
				case IDC_DPLOT_XOFFSET:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new x_offset value
						GetWindowText(GETHCTL(IDC_DPLOT_XOFFSET),
							szBuffer, BUFFER_SIZE);
						fEntry=(float)atof(szBuffer);

						// Validate new x_offset value?
						sFPlot.x_offset=fEntry;

						// Redisplay x_offset value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							sFPlot.x_offset);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_DPLOT_XOFFSET),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// X-Axis mult change
				case IDC_DPLOT_XMULT:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new x_mult value
						GetWindowText(GETHCTL(IDC_DPLOT_XMULT),
							szBuffer, BUFFER_SIZE);
						fEntry=(float)fabs(atof(szBuffer));

						// Validate new x_mult value
						// Multiplier can't be zero
						if(fEntry)
						{
							sFPlot.x_mult=fEntry;
						}
						else
						{
							CannotBeZero(hDlg);
							SetFocus(GETHCTL(IDC_DPLOT_XMULT));
						}

						// Redisplay x_mult value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							sFPlot.x_mult);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_DPLOT_XMULT),
							szBuffer);

						// Change to generic x-axis label
						SetWindowText(GETHCTL(IDC_DPLOT_XLABEL), "Time");
						strlcpy(sFPlot.x_label, "Time", XLABELSIZE);

						// Redetermine x-axis scale
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DPLOT_XSCALE, NULL, 0));
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// X-Axis start change
				// Note:  This is just the analysis start point #
				case IDC_DPLOT_XSTART:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new analysis start value
						GetWindowText(GETHCTL(IDC_DPLOT_XSTART),
							szBuffer, BUFFER_SIZE);
						nEntry=abs(atoi(szBuffer));

						// Validate new analysis start value
						// Must be between 1 and analysis end -1
						if(ValidateInteger(hDlg, nEntry, 1,
							(int)fFreqData[2]-1)==TRUE)
						{
							// Valid entry - change analysis start value
							fFreqData[1]=(F_TYPE)nEntry;

							// Force new scale determination
							bFreqScaleChanged=TRUE;
						}
						else
						{
							// Invalid entry - restore previous value
							_snprintf(szBuffer, sizeof(szBuffer), "%d",
								(int)fFreqData[1]);
							SetWindowText(GETHCTL(IDC_DPLOT_XSTART),
								szBuffer);
							SetFocus(GETHCTL(IDC_DPLOT_XSTART));
						}

						// Redisplay x-axis start value
						_snprintf(szBuffer, sizeof(szBuffer), "%d",
							(int)fFreqData[1]);
						SetWindowText(GETHCTL(IDC_DPLOT_XSTART),
							szBuffer);

						// Update the analysis start in the status bar
						SetWindowText(GetDlgItem(hwndMain,IDC_FREQSTART),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// X-Axis end change
				// Note:  This is just the analysis end point #
				case IDC_DPLOT_XEND:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new analysis end value
						GetWindowText(GETHCTL(IDC_DPLOT_XEND),
							szBuffer, BUFFER_SIZE);
						nEntry=abs(atoi(szBuffer));

						// Validate new analysis end value
						// Must be between analysis start +1 and # data points
						if(ValidateInteger(hDlg, nEntry, (int)fFreqData[1]+1,
							(int)fFreqData[0])==TRUE)
						{
							// Valid entry - change analysis end value
							fFreqData[2]=(F_TYPE)nEntry;

							// Force new scale determination
							bFreqScaleChanged=TRUE;
						}
						else
						{
							// Invalid entry - restore previous value
							_snprintf(szBuffer, sizeof(szBuffer), "%d",
								(int)fFreqData[2]);
							SetWindowText(GETHCTL(IDC_DPLOT_XEND),
								szBuffer);
							SetFocus(GETHCTL(IDC_DPLOT_XEND));
						}

						// Redisplay x-axis end value
						_snprintf(szBuffer, sizeof(szBuffer), "%d",
							(int)fFreqData[2]);
						SetWindowText(GETHCTL(IDC_DPLOT_XEND),
							szBuffer);

						// Update the analysis end in the status bar
						SetWindowText(GetDlgItem(hwndMain,IDC_FREQEND),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Y-Axis offset change
				case IDC_DPLOT_YOFFSET:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new y_offset value
						GetWindowText(GETHCTL(IDC_DPLOT_YOFFSET),
							szBuffer, BUFFER_SIZE);
						fEntry=(float)atof(szBuffer);

						// Validate new y_offset value?
						sFPlot.y_offset=fEntry;

						// Redisplay y_offset value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							sFPlot.y_offset);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_DPLOT_YOFFSET),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Y_Axis mult change
				case IDC_DPLOT_YMULT:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new y_mult value
						GetWindowText(GETHCTL(IDC_DPLOT_YMULT),
							szBuffer, BUFFER_SIZE);
						fEntry=(float)fabs(atof(szBuffer));

						// Validate new y_mult value
						// Multiplier can't be zero
						if(fEntry)
						{
							sFPlot.y_mult=fEntry;
						}
						else
						{
							CannotBeZero(hDlg);
							SetFocus(GETHCTL(IDC_DPLOT_YMULT));
						}

						// Redisplay y_mult value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							sFPlot.y_mult);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_DPLOT_YMULT),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Function expression change
				case IDC_DPLOT_FUNCT:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new function
						GetWindowText(GETHCTL(IDC_DPLOT_FUNCT),
							sFPlot.function, FUNCTIONSIZE);

						// Redisplay function
						SetWindowText(GETHCTL(IDC_DPLOT_FUNCT),
							sFPlot.function);

						// Show the parameter initialization button
						// if non-blank function
						if(strlen(sFPlot.function))
						{
							// Show parameter initialization button
							ShowWindow(GETHCTL(IDC_DPLOT_PARAM), SW_SHOWNORMAL);
						}
						else
						{
							// Hide parameter initialization button
							ShowWindow(GETHCTL(IDC_DPLOT_PARAM), SW_HIDE);
						}
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Fit type change
				case IDC_DPLOT_FIT:
				{
					sFPlot.do_line=ComboBox_GetCurSel(GETHCTL(IDC_DPLOT_FIT));

					// Force new log fit calc if log fit chosen
					if(sFPlot.do_line==FPLOT_LOG)
					{
						// Set new file flag
						sFPlot.new_file=TRUE;
					}

					// Force new diffusion fit calc if diffusion fit chosen
					if(sFPlot.do_line==FPLOT_DIFF)
					{
						// Set new file flag
						sFPlot.new_file=TRUE;
					}

					// Set up plot messages
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_DPLOT_MESSAGES, NULL, 0));

					EnableWindow(GETHCTL(IDC_DPLOT_DOFIT), FALSE);

					for(i=0; i<FLINE_NUMLINES; i++)
					{
						if(sFLine[i].nLineType==FLINE_LIN)
						{
							EnableWindow(GETHCTL(IDC_DPLOT_DOFIT), TRUE);
						}
					}

					// Hide the poly order list box and label
					ShowWindow(GETHCTL(IDC_DPLOT_ORDER), SW_HIDE);
					ShowWindow(GETHCTL(IDC_DPLOT_POLY), SW_HIDE);

					// Hide the function edit box
				    ShowWindow(GETHCTL(IDC_DPLOT_FUNCT), SW_HIDE);
					SetWindowText(GETHCTL(IDC_DPLOT_DOFIT), "Fit Params &6");

					// Hide the parameter initialization button
					ShowWindow(GETHCTL(IDC_DPLOT_PARAM), SW_HIDE);

					if(sFPlot.do_line)
					{
						EnableWindow(GETHCTL(IDC_DPLOT_DOFIT), TRUE);

						// Polynomial fit
						if(sFPlot.do_line==FPLOT_POLY)
						{
							// Show the poly order list box if poly fit selected
							ShowWindow(GETHCTL(IDC_DPLOT_ORDER), SW_SHOWNORMAL);
							ShowWindow(GETHCTL(IDC_DPLOT_POLY), SW_SHOWNORMAL);

							// Set IDC_DPLOT_POLY label text
							SetWindowText(GETHCTL(IDC_DPLOT_POLY), "Poly Order &7:");
						}

						// Function fit
						if(sFPlot.do_line==FPLOT_FUNC)
						{
							// Show the function edit box if function fit selected
							ShowWindow(GETHCTL(IDC_DPLOT_FUNCT), SW_SHOWNORMAL);
							SetWindowText(GETHCTL(IDC_DPLOT_FUNCT),
								sFPlot.function);
							SetWindowText(GETHCTL(IDC_DPLOT_DOFIT), "Fit &6       y(t)=");
							
							// Read function
							GetWindowText(GETHCTL(IDC_DPLOT_FUNCT),
								sFPlot.function, FUNCTIONSIZE);

							// Show the parameter initialization button
							// if non-blank function
							if(strlen(sFPlot.function))
							{
								// Show parameter initialization button
								ShowWindow(GETHCTL(IDC_DPLOT_PARAM), SW_SHOWNORMAL);
							}
							else
							{
								// Hide parameter initialization button
								ShowWindow(GETHCTL(IDC_DPLOT_PARAM), SW_HIDE);
							}
						}

						// Jump fit
						if(sFPlot.do_line==FPLOT_JUMP)
						{
							// Show the poly order label text (used for jump config)
							ShowWindow(GETHCTL(IDC_DPLOT_POLY), SW_SHOWNORMAL);

							// Set IDC_DPLOT_POLY label text
							SetWindowText(GETHCTL(IDC_DPLOT_POLY), "Configure:");

							// Show parameter initialization button
							ShowWindow(GETHCTL(IDC_DPLOT_PARAM), SW_SHOWNORMAL);
						}
					}
				}
				break;

				// Poly order change
				case IDC_DPLOT_ORDER:
				{
					sFPlot.order=
						ComboBox_GetCurSel(GETHCTL(IDC_DPLOT_ORDER))+1;
				}
				break;

				// Position change
				case IDC_DPLOT_POSITION:
				{
					sFPlot.position=
						ComboBox_GetCurSel(GETHCTL(IDC_DPLOT_POSITION));
				}
				break;

				// Date flag change
				case IDC_DPLOT_DATE:
				{
					sFPlot.do_date=Button_GetCheck(GETHCTL(IDC_DPLOT_DATE));
				}
				break;

				// Box flag change
				case IDC_DPLOT_BOX:
				{
					sFPlot.do_box=Button_GetCheck(GETHCTL(IDC_DPLOT_BOX));
				}
				break;

				// Do fit flag change
				case IDC_DPLOT_DOFIT:
				{
					sFPlot.do_fit=Button_GetCheck(GETHCTL(IDC_DPLOT_DOFIT));
				}
				break;

				// Cursor flag change
				case IDC_DPLOT_CURSOR:
				{
					sFPlot.do_mouse=Button_GetCheck(GETHCTL(IDC_DPLOT_CURSOR));
				}
				break;

				// Wide flag change
				case IDC_DPLOT_WIDE:
				{
					sFPlot.do_wide=Button_GetCheck(GETHCTL(IDC_DPLOT_WIDE));
				}
				break;

				// X-axis scale stick flag change
				case IDC_DPLOT_XSTICK:
				{
					bFXDefault=!Button_GetCheck(GETHCTL(IDC_DPLOT_XSTICK));
				}
				break;

				// Function fit initial parameters change button
				case IDC_DPLOT_PARAM:
				{
					if(sFPlot.do_line==FPLOT_FUNC)
					{
						// Determine # function parameters (max=NUMPARAMS=10)
						// Scan szFunction for chars between a to j
						// not followed by an alphabetic character
						// or a left parenthesis (indicating end of math function name)
						sFPlot.num=0;
						for(i=0; i<NUMPARAMS; i++)
						{
							// Look for a character between a and j
							if((ptr=strchr(sFPlot.function, 'a'+i)))
							{
								// Check if the next character is non-alphabetic
								if((isalpha(*(ptr+1)))==0)
								{
									// Check if the next character is not a left parenthesis
									if((*(ptr+1)!='('))
									{
										sFPlot.num++;
									}
								}
							}
						}
		
						// Open fit paramater initialization dialog box
						InvokeDialogBox(hInst, "FuncBox", hwndMain, (DLGPROC)FreqFuncDlgProc);
					}

					if(sFPlot.do_line==FPLOT_JUMP)
					{
						// Open jump detection paramater dialog box
						InvokeDialogBox(hInst, "JumpBox", hwndMain, (DLGPROC)FreqJumpDlgProc);
					}
				}
				break;

				// Read config button
				case IDC_DPLOT_READ:
				{
					bSave=bUseFreqPlotIni;
					bUseFreqPlotIni=TRUE;
					ReadIni(INI_FREQ);
					bUseFreqPlotIni=bSave;
					SendMessage(hDlg, WM_INITDIALOG, (WPARAM)0, (LPARAM)0);

					// Redetermine x-axis scale
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_DPLOT_XSCALE, NULL, 0));
				}
				break;

				// Save config button
				case IDC_DPLOT_WRITE:
				{
					bSave=bUseFreqPlotIni;
					bUseFreqPlotIni=TRUE;
					WriteIni(INI_FREQ);
					bUseFreqPlotIni=bSave;
				}
				break;

				// Y-axis plot scale max change
				case IDC_DPLOT_YMAX:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new y_max value
						GetWindowText(GETHCTL(IDC_DPLOT_YMAX),
							szBuffer, BUFFER_SIZE);
						fEntry=(float)atof(szBuffer);

						// Validate new y_max value?
						sFPlot.y_max=fEntry;

						// Redisplay y_max value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							sFPlot.y_max);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_DPLOT_YMAX),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Y-axis plot scale min change
				case IDC_DPLOT_YMIN:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new y_min value
						GetWindowText(GETHCTL(IDC_DPLOT_YMIN),
							szBuffer, BUFFER_SIZE);
						fEntry=(float)atof(szBuffer);

						// Validate new y_min value?
						sFPlot.y_min=fEntry;

						// Redisplay y_min value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							sFPlot.y_min);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_DPLOT_YMIN),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// X-axis plot scale # div change
				case IDC_DPLOT_XDIV:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new x_div value
						GetWindowText(GETHCTL(IDC_DPLOT_XDIV),
							szBuffer, BUFFER_SIZE);
						nEntry=abs(atoi(szBuffer));

						// Validate new x_div value
						// # divs can't be zero
						if(nEntry)
						{
							sFPlot.x_div=nEntry;
						}
						else
						{
							CannotBeZero(hDlg);
							SetFocus(GETHCTL(IDC_DPLOT_XDIV));
						}

						// Redisplay x_div value
						_snprintf(szBuffer, sizeof(szBuffer), "%d",
							sFPlot.x_div);
						SetWindowText(GETHCTL(IDC_DPLOT_XDIV),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Y-axis plot scale # div change
				case IDC_DPLOT_YDIV:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new y_div value
						GetWindowText(GETHCTL(IDC_DPLOT_YDIV),
							szBuffer, BUFFER_SIZE);
						nEntry=abs(atoi(szBuffer));

						// Validate new y_div value
						// # divs can't be zero
						if(nEntry)
						{
							sFPlot.y_div=nEntry;
						}
						else
						{
							CannotBeZero(hDlg);
							SetFocus(GETHCTL(IDC_DPLOT_YDIV));
						}

						// Redisplay y_div value
						_snprintf(szBuffer, sizeof(szBuffer), "%d",
							sFPlot.y_div);
						SetWindowText(GETHCTL(IDC_DPLOT_YDIV),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Y-axis plot scale # tic change
				case IDC_DPLOT_YTIC:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new y_tic value
						GetWindowText(GETHCTL(IDC_DPLOT_YTIC),
							szBuffer, BUFFER_SIZE);
						nEntry=abs(atoi(szBuffer));

						// Validate new y_tic value?
						// # tics can't be zero
						if(nEntry)
						{
							sFPlot.y_tic=nEntry;
						}
						else
						{
							CannotBeZero(hDlg);
							SetFocus(GETHCTL(IDC_DPLOT_YTIC));
						}

						// Redisplay y_tic value
						_snprintf(szBuffer, sizeof(szBuffer), "%d",
							sFPlot.y_tic);
						SetWindowText(GETHCTL(IDC_DPLOT_YTIC),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Set up plot messages
				case IDC_DPLOT_MESSAGES:
				{
					// Clear the message list box
					nDummy=ComboBox_ResetContent(GETHCTL(IDC_DPLOT_MESSAGE));
					nMessageCount=0;

					// Load outliers removed message
					if(bOutRem)
					{
						LoadString(hInst, IDS_FPLOT_MESSAGE_3, szMsg,
							BUFFER_SIZE);
						_snprintf(szBuffer, sizeof(szBuffer), szMsg,
							nOutliersRemoved);
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;
					}

					// Load gaps filled message
					if(bFreqGapFill)
					{
						LoadString(hInst, IDS_FPLOT_MESSAGE_4, szMsg,
							BUFFER_SIZE);
						_snprintf(szBuffer, sizeof(szBuffer), szMsg,
							nFreqGapsFilled);
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;
					}

					// Load maximum & minumum freq messages
					FindMinMax(fData, &fMin, &fMax, FREQ_DATA);
					LoadString(hInst, IDS_FPLOT_MESSAGE_5, szMsg, BUFFER_SIZE);
					_snprintf(szBuffer, sizeof(szBuffer), szMsg, fMin);
					ShortenExp(szBuffer);
					nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
						szBuffer);
					nMessageCount++;
					LoadString(hInst, IDS_FPLOT_MESSAGE_6, szMsg, BUFFER_SIZE);
					_snprintf(szBuffer, sizeof(szBuffer), szMsg, fMax);
					ShortenExp(szBuffer);
					nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
						szBuffer);
					nMessageCount++;

					// Load an average freq message
					CalcMean(fData, &fAvg, FREQ_DATA);
					LoadString(hInst, IDS_FPLOT_MESSAGE_7, szMsg, BUFFER_SIZE);
					_snprintf(szBuffer, sizeof(szBuffer), szMsg, fAvg);
					ShortenExp(szBuffer);
					nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
						szBuffer);
					nMessageCount++;

					// Load slope and drift messages
					CalcLinFreqDrift(fData, &fA, &fB, &fV);
					LoadString(hInst, IDS_FPLOT_MESSAGE_8, szMsg, BUFFER_SIZE);
					_snprintf(szBuffer, sizeof(szBuffer), szMsg, fB);
					ShortenExp(szBuffer);
					nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
						szBuffer);
					nMessageCount++;
					GetWindowText(hwndFreqTau, (LPSTR)szBuffer, BUFFER_SIZE);
					fTau=(float)atof(szBuffer);
					LoadString(hInst, IDS_FPLOT_MESSAGE_9, szMsg, BUFFER_SIZE);
					_snprintf(szBuffer, sizeof(szBuffer), szMsg,
						fB*86400./fTau);
					ShortenExp(szBuffer);
					nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
						szBuffer);
					nMessageCount++;

					// Load freq offset removed message
					if(bFreqNorm)
					{
						LoadString(hInst, IDS_FPLOT_MESSAGE_10, szMsg,
							BUFFER_SIZE);
						_snprintf(szBuffer, sizeof(szBuffer), szMsg,
							fFreqOffsetRemoved);
						ShortenExp(szBuffer);
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;
					}

					// Load linear drift removed message
					if(bLinDriftRem)
					{
						// Load linear freq slope removed message
						LoadString(hInst, IDS_FPLOT_MESSAGE_11, szMsg,
							BUFFER_SIZE);
						_snprintf(szBuffer, sizeof(szBuffer), szMsg,
							fFreqSlopeRemoved);
						ShortenExp(szBuffer);
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;

						// Load linear freq drift removed message
						LoadString(hInst, IDS_FPLOT_MESSAGE_12, szMsg,
							BUFFER_SIZE);
						_snprintf(szBuffer, sizeof(szBuffer), szMsg,
							fFreqSlopeRemoved*86400./fTau);
						ShortenExp(szBuffer);
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;
					}

					// Load log drift removed messages
					if(bLogDriftRem)
					{
						// Load log freq drift removed message
						LoadString(hInst, IDS_FPLOT_MESSAGE_13, szMsg,
							BUFFER_SIZE);
						_snprintf(szBuffer, sizeof(szBuffer), szMsg);
						ShortenExp(szBuffer);
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;

						// Load log fit slope removed message
						LoadString(hInst, IDS_FPLOT_MESSAGE_20, szMsg,
							BUFFER_SIZE);
						_snprintf(szBuffer, sizeof(szBuffer), szMsg,
							fLogSlope);
						ShortenExp(szBuffer);
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;

						// Load log fit drift removed message
						LoadString(hInst, IDS_FPLOT_MESSAGE_21, szMsg,
							BUFFER_SIZE);
						_snprintf(szBuffer, sizeof(szBuffer), szMsg,
							fLogSlope*86400./fTau);
						ShortenExp(szBuffer);
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;
					}

					// Load diffusion drift removed messages
					if(bDiffDriftRem)
					{
						// Load diffusion freq drift removed message
						LoadString(hInst, IDS_FPLOT_MESSAGE_14, szMsg,
							BUFFER_SIZE);
						_snprintf(szBuffer, sizeof(szBuffer), szMsg);
						ShortenExp(szBuffer);
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;

						// Load diffusion fit slope removed message
						LoadString(hInst, IDS_FPLOT_MESSAGE_22, szMsg,
							BUFFER_SIZE);
						_snprintf(szBuffer, sizeof(szBuffer), szMsg,
							fDiffusionSlope);
						ShortenExp(szBuffer);
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;

						// Load diffusion fit drift removed message
						LoadString(hInst, IDS_FPLOT_MESSAGE_23, szMsg,
							BUFFER_SIZE);
						_snprintf(szBuffer, sizeof(szBuffer), szMsg,
							fDiffusionSlope*86400./fTau);
						ShortenExp(szBuffer);
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;
					}

					// Load freq offset added message
					if(bFreqAddend)
					{
						LoadString(hInst, IDS_FPLOT_MESSAGE_18, szMsg,
							BUFFER_SIZE);
						_snprintf(szBuffer, sizeof(szBuffer), szMsg,
							fFreqAddend);
						ShortenExp(szBuffer);
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;
					}

					// Load freq data scaled message
					if(bFreqScaled)
					{
						LoadString(hInst, IDS_FPLOT_MESSAGE_19, szMsg,
							BUFFER_SIZE);
						_snprintf(szBuffer, sizeof(szBuffer), szMsg,
							fFreqScaled);
						ShortenExp(szBuffer);
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;
					}

					// Load linear fit message
					if(sFPlot.do_line==FPLOT_LINE)
					{
						// Load linear fit message
						LoadString(hInst, IDS_FPLOT_MESSAGE_15, szMsg,
							BUFFER_SIZE);
						_snprintf(szBuffer, sizeof(szBuffer), szMsg);
						ShortenExp(szBuffer);
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;
					}

					// Load log fit message
					if(sFPlot.do_line==FPLOT_LOG)
					{
						// Load log fit message
						LoadString(hInst, IDS_FPLOT_MESSAGE_16, szMsg,
							BUFFER_SIZE);
						_snprintf(szBuffer, sizeof(szBuffer), szMsg);
						ShortenExp(szBuffer);
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;
					}

					// Load log slope per day message
					// Calculated log slope at end is fLogSlope
					// per tau interval
					// Tau is fTau in seconds
					// So slope per day is fLogSlope*86400/fTau
					if( (sFPlot.do_line==FPLOT_LOG) && (fLogSlope) &&
						(!sFPlot.new_file) )
					{
						_snprintf(szBuffer, sizeof(szBuffer),
							"Log Drift/Day at End = %4.2e",
							fLogSlope*86400./fTau);
						ShortenExp(szBuffer);
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;
					}

					// Load diffusion fit message
					if(sFPlot.do_line==FPLOT_DIFF)
					{
						// Load diffusion fit message
						LoadString(hInst, IDS_FPLOT_MESSAGE_17, szMsg,
							BUFFER_SIZE);
						_snprintf(szBuffer, sizeof(szBuffer), szMsg);
						ShortenExp(szBuffer);
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;
					}

					// Load diffusion slope per day message
					// Calculated diffusion slope at end is
					// fDiffusionSlope per tau interval
					// Tau is fTau in seconds
					// So slope per day is fDiffusionSlope*86400/fTau
					if( (sFPlot.do_line==FPLOT_DIFF) && (fDiffusionSlope) &&
						(!sFPlot.new_file) )
					{
						_snprintf(szBuffer, sizeof(szBuffer),
							"Diffusion Drift/Day at End = %4.2e",
							fDiffusionSlope*86400./fTau);
						ShortenExp(szBuffer);
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;
					}

					// Load log fit spec message
					// Do this only if log fit is selected,
					// and the slope spec flag is
					// set. and the log slope spec value is not zero,
					// and this is not a new frequency data set
					if( (sFPlot.do_line==FPLOT_LOG) && (bSlopeSpec) &&
						(fLogSlope) &&
						(!sFPlot.new_file)  &&
						((fabs(fLogSlope)*86400./fTau)>fSlopeSpec) )
					{
						// Assign sign of calculated slope to slope spec
						fSlopeSpec=fabs(fSlopeSpec);
						if(fLogSlope<0.0)
						{
							fSlopeSpec*=-1.0;
						}

						// Calc # tau intervals to reach drift spec
						// Tau is fTau in seconds
						// Drift spec is fSlopeSpec per day
						// or d=fSlopeSpec*fTau/86400 per tau interval
						// Calculated log slope at end is fLogSlope
						// per tau interval
						// Time in tau intervals to stabilize to slope d
						// per tau interval is (ab-d)/db
						// where a & b are log fit params of y(t)=a*ln(bt+1)+c
						fTime=((fLogA*fLogB)-(fSlopeSpec*fTau/86400.))/
							(fSlopeSpec*fTau*fLogB/86400.);

						// Convert time to days
						fTime*=fTau/86400.;

						// Don't allow negative time
						if(fTime<0.0)
						{
							fTime=0.0;
						}

						// Compose time to slope spec message
						_snprintf(szBuffer, sizeof(szBuffer),
							"%4.1f Days to %4.2e/Day",
							fTime, fSlopeSpec);
						ShortenExp(szBuffer);

						// Add log fit spec  message to combo box
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;
					}

					// Load diffusion fit spec message
					// Do this only if diffusion fit is selected,
					// and the slope spec flag
					// is set. and the log slope spec value is not zero,
					// and this is not a new frequency data set
					if( (sFPlot.do_line==FPLOT_DIFF) && (bSlopeSpec) &&
						(fDiffusionSlope) && (!sFPlot.new_file)  &&
						((fabs(fDiffusionSlope)*86400./fTau)>fSlopeSpec))
					{
						// Assign sign of calculated slope to slope spec
						fSlopeSpec=fabs(fSlopeSpec);
						if(fDiffusionSlope<0.0)
						{
							fSlopeSpec*=-1.0;
						}

						// Calc # tau intervals to reach drift spec
						// Tau is fTau in seconds
						// Drift spec is fSlopeSpec per day
						// or d=fSlopeSpec*fTau/86400 per tau interval
						// Calculated diffusion slope at end is fDiffusionSlope
						// per tau interval
						// Time in tau intervals to stabilize to slope d
						// per tau interval is (0.25*b*b/d*d)-c
						// where b and c are diffusion fit params of
						// y(t)=a+b*sqrt(t+c)
						fTime=((0.25*fDiffB*fDiffB*86400.*86400.)/
							(fSlopeSpec*fTau*fSlopeSpec*fTau))-fDiffC;

						// Convert time to days
						fTime*=fTau/86400.;

						// Don't allow negative time
						if(fTime<0.0)
						{
							fTime=0.0;
						}

						// Compose time to slope spec message
						_snprintf(szBuffer, sizeof(szBuffer),
							"%4.1f Days to %4.2e/Day",
							fTime, fSlopeSpec);
						ShortenExp(szBuffer);

						// Add log fit spec  message to combo box
						nDummy=ComboBox_AddString(GETHCTL(IDC_DPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;
					}
				}
				break;

				// Reset all plot params to defaults
				case IDC_DPLOT_RESET:
				{
					// Use default analysis start and end points
					fFreqData[1]=1.0;
					fFreqData[2]=fFreqData[0];

					// Update the analysis start in the status bar
					_snprintf(szBuffer, sizeof(szBuffer), "%d",
						(int)fFreqData[1]);
					SetWindowText(GetDlgItem(hwndMain,IDC_FREQSTART),
						szBuffer);

					// Update the analysis end in the status bar
					_snprintf(szBuffer, sizeof(szBuffer), "%d",
						(int)fFreqData[2]);
					SetWindowText(GetDlgItem(hwndMain,IDC_FREQEND),
						szBuffer);

					// Full filename where program started
					// This set here rather than in InitPhasePlotParams()
					strlcpy(sFPlot.plot_filename, szDrive, FILENAMESIZE);
					strlcat(sFPlot.plot_filename, szDirectory, FILENAMESIZE);
					strlcat(sFPlot.plot_filename, "FREQ.TKF", FILENAMESIZE);

					// Reset keep flag
					bFXDefault=TRUE;
					
					// Initialize freq plot parameters
					bSave=bUseFreqPlotIni;
					bUseFreqPlotIni=FALSE;
					InitFreqPlotParams(1);
					SendMessage(hDlg, WM_INITDIALOG, (WPARAM)0, (LPARAM)0);
					bUseFreqPlotIni=bSave;
				}
				break;

				// Respond to CR in an edit control
				// Note: No button is a DEFPUSHBUTTON
				case IDOK:
				{
					// The HWND returned by GetFocus() is not the same as the
					// one returned by GetDlgItem(), so the uTitle, etc
					// variables are used in these tests
					if((UINT)GetFocus()==uTitle)
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DPLOT_TITLE, NULL, CBN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to SUBTITLE edit control
					if((UINT)GetFocus()==uSubtitle)
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DPLOT_SUBTITLE, NULL, CBN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to MESSAGE edit control
					if((UINT)GetFocus()==uMessage)
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DPLOT_MESSAGE, NULL, CBN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to XOFFSET edit control
					if(GetFocus()==GETHCTL(IDC_DPLOT_XOFFSET))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DPLOT_XOFFSET, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to XMULT edit control
					if(GetFocus()==GETHCTL(IDC_DPLOT_XMULT))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DPLOT_XMULT, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to XSTART edit control
					if(GetFocus()==GETHCTL(IDC_DPLOT_XSTART))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DPLOT_XSTART, NULL,	EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to XEND edit control
					if(GetFocus()==GETHCTL(IDC_DPLOT_XEND))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DPLOT_XEND, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to YOFFSET edit control
					if(GetFocus()==GETHCTL(IDC_DPLOT_YOFFSET))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DPLOT_YOFFSET, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to YMULT edit control
					if(GetFocus()==GETHCTL(IDC_DPLOT_YMULT))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DPLOT_YMULT, NULL, EN_KILLFOCUS));
					}
					// Send EN_KILLFOCUS message to YMAX edit control
					if(GetFocus()==GETHCTL(IDC_DPLOT_YMAX))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DPLOT_YMAX, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to YMIN edit control
					if(GetFocus()==GETHCTL(IDC_DPLOT_YMIN))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DPLOT_YMIN, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to XDIV edit control
					if(GetFocus()==GETHCTL(IDC_DPLOT_XDIV))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DPLOT_XDIV, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to YDIV edit control
					if(GetFocus()==GETHCTL(IDC_DPLOT_YDIV))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DPLOT_YDIV, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to YTIC edit control
					if(GetFocus()==GETHCTL(IDC_DPLOT_YTIC))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DPLOT_YTIC, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to FILENAME edit control
					if(GetFocus()==GETHCTL(IDC_DPLOT_FILENAME))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DPLOT_FILENAME, NULL, EN_KILLFOCUS));
					}
					// Send EN_KILLFOCUS message to FUNCT edit control
					if(GetFocus()==GETHCTL(IDC_DPLOT_FUNCT))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DPLOT_FUNCT, NULL, EN_KILLFOCUS));
					}
				}
				break;

				// Subroutine for x-axis scale determination
				case IDC_DPLOT_XSCALE:
				{
					// Calc x-offset
					// Normally offset is zero
					// But for MJD or DOY scale, if there are timetags,
					// the offset is set to the value of MJD or DOY
					// of the first data point to be plotted

					// Set x_offset to default				
					sFPlot.x_offset=0.0;
					
					// Add special info to MJD & DOY labels if have timetags
					// and they are not reversed
					if( (bFreqTimetags) &&
						(fFreqTimetags[ARRAY_OFFSET]<fFreqTimetags[ARRAY_OFFSET+1]) )
					{
						// Find start point
						i=(int)fFreqData[1]; // Start point #

						// Find # days in data
						nDay=(int)ceil((fFreqData[2]-fFreqData[1])*
							sFPlot.x_mult);

						// Determine # decades to remove from MJD scale
						nDecade=1000;
						if(nDay<10)
						{
							nDecade=100;
						}

						// Find # 100s or 1000s in MJD
						nCoarseMJD=0;

						// Test to avoid integer overflow
						if(fFreqTimetags[i+2]<INT_MAX)
						{
							// Set offset to start point timetag
							while((float)fFreqTimetags[i+2]-
								nCoarseMJD>=(float)nDecade)
							{
								nCoarseMJD+=nDecade;
							}
						}

						// For testing
						// TRACE_INT(nCoarseMJD);
							
						if(nFPlotX==X_MJD) // Adjust MJD scale
						{
							// Set offset to start point timetag
							sFPlot.x_offset=(float)fFreqTimetags[i+2];

							// Subtract leading part of MJD
							sFPlot.x_offset-=nCoarseMJD;

							// Scale to data point units
							sFPlot.x_offset*=(float)(86400.0/fTau);

							// Add leading part of MJD to x-scale label
							_snprintf(sFPlot.x_label, XLABELSIZE, "MJD - %d",
								nCoarseMJD);
							SetWindowText(GETHCTL(IDC_DPLOT_XLABEL),
								sFPlot.x_label);
							nDummy=ComboBox_DeleteString(GETHCTL(
								IDC_DPLOT_XLABEL), nFPlotX);
							nDummy=ComboBox_InsertString(GETHCTL(
								IDC_DPLOT_XLABEL), nFPlotX, sFPlot.x_label);
							nDummy=ComboBox_SetCurSel(GETHCTL(
								IDC_DPLOT_XLABEL), nFPlotX);
						}
						else 
						{
							// Just put MJD-XXXXX into combo box
							_snprintf(szBuffer, sizeof(szBuffer), "MJD - %d",
								nCoarseMJD);
							nDummy=ComboBox_DeleteString(GETHCTL(
								IDC_DPLOT_XLABEL), X_MJD);
							nDummy=ComboBox_InsertString(GETHCTL(
								IDC_DPLOT_XLABEL), X_MJD, szBuffer);
						}

						 // Start point MJD
						lnMJD=(long)floor(fFreqTimetags[i+2]);
						nDOY=MJDtoDOY(lnMJD); // Start point DOY

						// Convert integer MJD to date
						MJDToDate(lnMJD, &nDay, &nMonth, &nYear);

						if(nFPlotX==X_DOY)
						{
							// Set x offset
							sFPlot.x_offset=(float)nDOY; // DOY

							 // Add fractional day
							sFPlot.x_offset+=
								(float)fFreqTimetags[i+2]-(float)lnMJD;

							 // Scale to data point units
							sFPlot.x_offset*=(float)(86400.0/fTau);

							// Add year to x-scale label
							_snprintf(sFPlot.x_label, XLABELSIZE, "DOY %d",
								nYear);
							SetWindowText(GETHCTL(IDC_DPLOT_XLABEL),
								sFPlot.x_label);
							nDummy=ComboBox_DeleteString(GETHCTL(
								IDC_DPLOT_XLABEL), nFPlotX);
							nDummy=ComboBox_InsertString(GETHCTL(
								IDC_DPLOT_XLABEL), nFPlotX, sFPlot.x_label);
							nDummy=ComboBox_SetCurSel(GETHCTL(
								IDC_DPLOT_XLABEL), nFPlotX);
						}
						else
						{
							// Just put DOY XXXX into combo box
							_snprintf(szBuffer, sizeof(szBuffer), "DOY %d",
								nYear);
							nDummy=ComboBox_DeleteString(GETHCTL(
								IDC_DPLOT_XLABEL), X_DOY);
							nDummy=ComboBox_InsertString(GETHCTL(
								IDC_DPLOT_XLABEL), X_DOY, szBuffer);
						}
					}

					// Redisplay x_offset value
					_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
						sFPlot.x_offset);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_DPLOT_XOFFSET),
						szBuffer);
	
					// Get x-axis max & min
					sFPlot.x_max=(float)
						(sFPlot.x_mult*(fFreqData[2]+sFPlot.x_offset));
					sFPlot.x_min=(float)
						(sFPlot.x_mult*(fFreqData[1]+sFPlot.x_offset));

					#if(1) // New code 03/20/08
					// Adjust x_min so first point is plotted
					// This is certainly better for points scales
					// and is probably OK for all
					{
						sFPlot.x_min-=(float)1.0*sFPlot.x_mult;
					}
					#endif

					// Determine x-axis plot scale
					DetermineXScale(&sFPlot);

					// Redisplay x_div value
					_snprintf(szBuffer, sizeof(szBuffer), "%d", sFPlot.x_div);
					SetWindowText(GETHCTL(IDC_DPLOT_XDIV),
						szBuffer);
				}
				break;

				// Respond to esc key or cancel button
				case IDCANCEL:
				case IDC_DPLOT_CANCEL:
				{
					// Restore previous analysis start and end points
					fFreqData[1]=(F_TYPE)nPrevStart;
					fFreqData[2]=(F_TYPE)nPrevEnd;

					// Restore the analysis start in the status bar
					_snprintf(szBuffer, sizeof(szBuffer), "%d",
						(int)fFreqData[1]);
					SetWindowText(GetDlgItem(hwndMain,IDC_FREQSTART),
						szBuffer);

					// Restore the analysis end in the status bar
					_snprintf(szBuffer, sizeof(szBuffer), "%d",
						(int)fFreqData[2]);
					SetWindowText(GetDlgItem(hwndMain,IDC_FREQEND),
						szBuffer);

					// Restore previous freq plot parameters
					strlcpy(sFPlot.title, sFPrev.title, TITLESIZE);
					strlcpy(sFPlot.subtitle, sFPrev.subtitle, SUBTITLESIZE);
					strlcpy(sFPlot.message_str, sFPrev.message_str,
						MESSAGESIZE);
					strlcpy(sFPlot.x_label, sFPrev.x_label, XLABELSIZE);
					strlcpy(sFPlot.left_y_label, sFPrev.left_y_label,
						YLABELSIZE);
					strlcpy(sFPlot.plot_filename, sFPrev.plot_filename,
						FILENAMESIZE);
					sFPlot.x_offset=sFPrev.x_offset;
					sFPlot.x_mult=sFPrev.x_mult;
					sFPlot.y_offset=sFPrev.y_offset;
					sFPlot.y_mult=sFPrev.y_mult;
					sFPlot.y_max=sFPrev.y_max;
					sFPlot.y_min=sFPrev.y_min;
					sFPlot.x_div=sFPrev.x_div;
					sFPlot.y_div=sFPrev.y_div;
					sFPlot.y_tic=sFPrev.y_tic;
					sFPlot.do_date=sFPrev.do_date;
					sFPlot.do_box=sFPrev.do_box;
					sFPlot.do_fit=sFPrev.do_fit;
					sFPlot.do_mouse=sFPrev.do_mouse;
					sFPlot.do_wide=sFPrev.do_wide;
					sFPlot.position=sFPrev.position;
					sFPlot.order=sFPrev.position;

					// Restore previous read config flag;
					bUseFreqPlotIni=bPrevRead;

					// Redetermine x-axis scale
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_DPLOT_XSCALE, NULL, 0));

					// Close dialog box
					EndDialog (hDlg, 0);
				}
				return TRUE;

				case IDC_DPLOT_ACCEPT:
				{
					// Save # user-entered title strings
					nUserTitles=ComboBox_GetCount(GETHCTL(IDC_DPLOT_TITLE))-
						NUM_FPLOT_TITLES;

					// Limit # user titles
					nUserTitles=min(nUserTitles, NUM_TITLES);

					// Save user titles
					if(nUserTitles)
					{
						for(i=0; i<nUserTitles; i++)
						{
							// Get size of title string
							nLength=ComboBox_GetLBTextLen(GETHCTL(
								IDC_DPLOT_TITLE), i);

							// Realloc title array
							if((szPlotTitle[i]=
								(LPSTR)realloc(szPlotTitle[i],
								(nLength+1)*sizeof(char)))==NULL)
							{
								// Just dsp err msg & skip saving string
								// We are closing dlg box anyway
								AllocErrorMessage();
							}
							else
							{
								// Save title string
								nDummy=
									ComboBox_GetLBText(GETHCTL(
									IDC_DPLOT_TITLE), i, szPlotTitle[i]);
							}
						}
					}

					// Save # user-entered subtitle strings
					nUserSubtitles=
						ComboBox_GetCount(GETHCTL(IDC_DPLOT_SUBTITLE))-
						NUM_FPLOT_SUBTITLES;

					// Limit # user subtitles
					nUserSubtitles=min(nUserSubtitles, NUM_SUBTITLES);

					// Save user subtitles
					if(nUserSubtitles)
					{
						for(i=0; i<nUserSubtitles; i++)
						{
							// Get size of subtitle string
							nLength=ComboBox_GetLBTextLen(GETHCTL(
								IDC_DPLOT_SUBTITLE), i);

							// Realloc subtitle array
							if((szPlotSubtitle[i]=
								(LPSTR)realloc(szPlotSubtitle[i],
								(nLength+1)*sizeof(char)))==NULL)
							{
								// Just dsp err msg & skip saving string
								// We are closing dlg box anyway
								AllocErrorMessage();
							}
							else
							{
								// Save subtitle string
								nDummy=ComboBox_GetLBText(GETHCTL(
									IDC_DPLOT_SUBTITLE), i, szPlotSubtitle[i]);
							}
						}
					}

					// Save # user-entered message strings
					nUserMessages=
						ComboBox_GetCount(GETHCTL(IDC_DPLOT_MESSAGE))-
						nMessageCount;

					// Limit # user messages
					nUserMessages=min(nUserMessages, NUM_MESSAGES);

					// Save user messages
					if(nUserMessages)
					{
						for(i=0; i<nUserMessages; i++)
						{
							// Get size of message string
							nLength=ComboBox_GetLBTextLen(GETHCTL(
								IDC_DPLOT_MESSAGE), i);

							// Realloc message array
							if((szPlotMessage[i]=
								(LPSTR)realloc(szPlotMessage[i],
								(nLength+1)*sizeof(char)))==NULL)
							{
								// Just dsp err msg & skip saving string
								// We are closing dlg box anyway
								AllocErrorMessage();
							}
							else
							{
								// Save message string
								nDummy=ComboBox_GetLBText(GETHCTL(
									IDC_DPLOT_MESSAGE), i, szPlotMessage[i]);
							}
						}
					}

					// Set line thickness
					if(sFPlot.do_wide)
					{
						sFPlot.thick=WIDELINESIZE;
					}
					else
					{
						sFPlot.thick=0;
					}

					// Close dialog box
					EndDialog (hDlg, 0);
				}
				return TRUE;
			}
		}
		break;
	 }
	 return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*                Sigma Plot Parameter Entry Dialog Procedure                */
/*                                                                           */
/* 	Dialog box controls:                                                     */
/*			ID					Description		Variable or struct member    */
/*	IDC_SPLOT_TITLE		 		Plot Title              .title{}             */
/*	IDC_SPLOT_SUBTITLE	 		Plot Subtitle           .sub_title{}         */
/*	IDC_SPLOT_MESSAGE	 		Plot Message            .message_str[]       */
/*	IDC_SPLOT_DATE		 		Date Flag               .do_date             */
/*	IDC_SPLOT_BOX		 		Box Flag                .do_box              */
/*	IDC_SPLOT_FIT				Fit Flag				.do_fit              */
/*	IDC_SPLOT_ERRBAR		 	Error Bar Flag          .do_errbar           */
/*	IDC_SPLOT_TABLE		 		Table Flag              .do_table            */
/*	IDC_SPLOT_FILENAME	 		Plot Filename           .plot_filename[]     */
/*	IDC_SPLOT_YMAX		 		Y Scale Maximum         .y_max               */
/*	IDC_SPLOT_YMIN		 		Y Scale Minimum         .y_min               */
/*	IDC_SPLOT_XMAX		 		X Scale Maximum                              */
/*	IDC_SPLOT_XMIN		 		X Scale Minimum                              */
/*	IDC_SPLOT_POSITION			Message position		.position            */
/*	IDC_SPLOT_RESET		 		Reset Param Flag                             */
/*	IDC_SPLOT_SIGMAMAX	 		Sigma Maximum                                */
/*	IDC_SPLOT_SIGMAMIN	 		Sigma Minimum                                */
/*	IDC_SPLOT_YMULTLABEL 		Y Multiplier Label                           */
/*	IDC_SPLOT_YOFFLABEL         Y Offset Label                               */
/*	IDC_SPLOT_YLABLABEL         Y Label Label                                */
/*	IDC_SPLOT_XMULTLABEL        X Multiplier Label                           */
/*	IDC_SPLOT_XOFFLABEL         X Offset Label                               */
/*	IDC_SPLOT_XLABLABEL         X Label Label                                */
/*                                                                           */
/*	struct plotdata             structure template for plot data             */
/*	{                                                                        */
/*		float x_offset;                                             not used */
/*		float x_mult;                                               not used */
/*		float y_offset;                                             not used */
/*		float y_mult;                                               not used */
/*		float x_min;                                     x-axis plot minimum */
/*		float x_max;                                     x-axis plot maximum */
/*		float y_min;                                     y-axis plot minimum */
/*		float y_max;                                     y-axis plot maximum */
/*		char title[TITLESIZE];                                    plot title */
/*		char subtitle[SUBTITLESIZE];                           plot subtitle */
/*		char x_label[XLABELSIZE];                          plot x-axis label */
/*		char left_y_label[YLABELSIZE];           plot y-axis left side label */
/*		char right_y_label[YLABELSIZE];         plot y-axis right side label */
/*		char plot_filename[FILENAMESIZE];                 plot .TKF filename */
/*		char message_str[MESSAGESIZE];                   plot message string */
/*		int do_date;                               flag to draw date on plot */
/*		int do_box;                             flag to draw box around plot */
/*		int do_errbar;                    flag to include error bars on plot */
/*		int do_line;                code to control drawing of lines on plot */
/*		int do_mouse;                                               not used */
/*		int do_table;        flag to write sigma-tau table on stability plot */
/*		int do_fit;           flag to write fit parameters at bottom of plot */
/*		int new_file;                  flag that plot is for a new data file */
/*		int new_name;             flag that plot is for a new basic filename */
/*		int plotype;                       code to identify the type of plot */
/*		int position;        code to control position of message box on plot */
/*		int x_div;                                                  not used */
/*		int x_tic;                                                  not used */
/*		int y_div;                                                  not used */
/*		int y_tic;                                                  not used */
/*		int config;                       flag for active configuration file */
/*	}                                                                        */
/*                                                                           */
/*		Sigma Types            nSigmaPlotType                                */
/*		NORMAL_SIGMA           0                                             */
/*		OVERLAPPING_SIGMA      1                                             */
/*		MODIFIED_SIGMA         2                                             */
/*		TIME_SIGMA             3                                             */
/*		HADAMARD_SIGMA         4                                             */
/*		TOTAL_SIGMA            5                                             */
/*		BOTH_SIGMA             6                                             */
/*		ALLTAU_SIGMA           7                                             */
/*                                                                           */
/*		X-label strings for sigma box                                        */
/*		IDS_SPLOT_XLABEL_0	"Averaging Time, Seconds"                        */
/*                                                                           */
/*		Y-label strings for sigma box                                        */
/*		IDS_SPLOT_YLABEL_0	"Allan Deviation"                                */
/*		IDS_SPLOT_YLABEL_1	"Overlapping Allan Deviation"                    */
/*		IDS_SPLOT_YLABEL_2	"Modified Allan Deviation"                       */
/*		IDS_SPLOT_YLABEL_3	"Time Deviation"                                 */
/*		IDS_SPLOT_YLABEL_4  "Hadamard Deviation"                             */
/*		IDS_SPLOT_YLABEL_5	"Total Allan Deviation"                          */
/*		IDS_SPLOT_YLABEL_6	"Allan Deviation"                                */
/*		IDS_SPLOT_YLABEL_7	"Allan Deviation"                                */
/*                                                                           */
/* 		Revision record:                                                     */
/*			10/06/96	Adapted from FreqPlotDlgProc()                       */
/*			10/26/96	Added errorbar & table checkbox logic                */
/*			11/07/96	Added entry checking and CR processing               */
/*			11/23/96	Changed title, subtitle & message to comboboxes      */
/*			01/04/97	Changed drift message options                        */
/*			01/25/97	Added code to push user-entered titles, subtitles &  */
/*						messages into combo listboxes with CR                */
/*			01/28/97	Added some code for all tau sigma type               */
/*			03/15/97	Added control for stability table position           */
/*			05/30/98	Changed axis labels from static to combo box entries */
/*			06/05/98	Made changes to add TIE rms and MTIE                 */
/*			08/30/98	Added do_fit usage                                   */
/*			03/03/99	Added 1 of 2 unit variance scaling message choice    */
/*			12/25/99	Added Mod Totdev                                     */
/*			03/11/01	Added wide checkbox for wide plot lines              */
/*			11/23/01	Added bNoGreek test                                  */
/*                                                                           */
/*****************************************************************************/

#ifndef _MSC_VER
	#pragma argsused
#endif

BOOL CALLBACK SigmaPlotDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	// Chars
	char szBuffer[BUFFER_SIZE+1]; 	// Text buffer
	char szTemp[BUFFER_SIZE+1];	    // Temp buffer
	// Temporary filename buffers
	char szTempFile[FILENAMESIZE+1];	// Temp full filename buffer
	char szTempTitle[FILENAMESIZE+1];	// Temp file title buffer
	char szTempPath[FILENAMESIZE+1];	// Temp file path buffer
	char szTempName[FILENAMESIZE+1];    // Temp file name buffer
	char szTempExt[BUFFER_SIZE+1];		// Temp file extension buffer
	// Unsigned Ints
	static unsigned uTitle;			// HWND of Title combo control
	static unsigned uSubtitle;	  	// HWND of Subtitle combo control
	static unsigned uMessage;	  	// HWND of Message combo control
	// Ints
	int i;							// Index
	int nLength;					// String length
	static int nPoints;         	// # sigma data points
	static int nMessageCount;		// # non-user messages entered into list
	// BOOLs
	BOOL bSave;						// BOOL to save state of ini flag
	static BOOL bErrorTrap=FALSE;   // Flag for entry error
	// Floats
	float fTau;	// Tau value
	static float fTauMax;      		// Tau data maximum
	static float fTauMin;       	// Tau data minimum
	static float fSigmaMax;     	// Sigma data maximum
	static float fSigmaMin;     	// Sigma data minimum
	static float fEntry;        	// Entry to be validated

	// Note: The sigma plot data structs, sSPlot & sSPrev, are defined globally

	// Put plot dialog box handle into global
	// NO - the RunDlgProc box is the one to close during command line execution
	// hPlotBox=hDlg;

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Set dialog box title
			LoadString(hInst, IDS_TITLE_SIGMAOPT, szBuffer, BUFFER_SIZE);
			SetWindowText(hDlg, szBuffer);

			// Get tau value
			if(bDataType==FREQ_DATA)
			{
				GetWindowText(hwndFreqTau, (LPSTR)szBuffer, BUFFER_SIZE);
				fTau=(float)atof(szBuffer);
			}
			else // Phase data
			{
				GetWindowText(hwndPhaseTau, (LPSTR)szBuffer, BUFFER_SIZE);
				fTau=(float)atof(szBuffer);
			}

			// Get sigma & tau min & max
			SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDC_SPLOT_MINMAX,
				NULL, 0));

			// Load selectable x-axis tau label - not wanted 09/24/98
			// SetWindowText(GETHCTL(IDC_SPLOT_XLABLABEL), "Label:");

			// Fill up x-axis label combo box using string table
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_SPLOT_XLABEL));
			for(i=0; i<NUM_SPLOT_XLABELS; i++)
			{
				LoadString(hInst, IDS_SPLOT_XLABEL_0+i, szBuffer, BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_SPLOT_XLABEL), i,
					szBuffer);
			}

			// Is modern style selected?
			if(nStyle==MODERN_STYLE)
			{
				// Load simple x-axis label
				nDummy=ComboBox_AddString(GETHCTL(IDC_SPLOT_XLABEL),
					"Averaging Time, s");

				// Select it
				ComboBox_SetCurSel(GETHCTL(IDC_SPLOT_XLABEL), NUM_SPLOT_XLABELS);
			}

			// Avoid Greek characters
			if(bNoGreek)
			{
				// Load the 2nd x-axis label
				LoadString(hInst, IDS_SPLOT_XLABEL_0+1, sSPlot.x_label,
					BUFFER_SIZE);

				// Eliminate comma and all later characters from y-axis label
				if(strchr(sSPlot.left_y_label, ','))
				{
					*strchr(sSPlot.left_y_label, ',')=(char)'\0';
				}
			}

			// Load the x-axis label
			SetWindowText(GETHCTL(IDC_SPLOT_XLABEL), sSPlot.x_label);

			// Load selectable y-axis sigma label - not wanted 09/24/98
			// SetWindowText(GETHCTL(IDC_SPLOT_YLABLABEL), "Label:");

			// Fill up y-axis label list box using string table
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_SPLOT_YLABEL));

			// Have NUM_SPLOT_YLABELS sigma types
			// Allow NUM_SPLOT_YNAMES for each sigma type
			// Strings are organized in NUM_SPLOT_YNAMES=3 groups of
			for(i=0; i<NUM_SPLOT_YNAMES; i++)
			{
				LoadString(hInst,
					IDS_SPLOT_YLABEL_0+(i*NUM_SPLOT_YLABELS)+nSigmaPlotType,
					szBuffer, BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_SPLOT_YLABEL), i,
					szBuffer);
			}

			#if(1) // Patch to support cross sigma 02/16/10
			// Should add these labels to string table
			// but that requires a lot of shifting
			// Note also that this code forces the top label to be used
			if(nSigmaPlotType==CROSS_RUN)
			{
				nDummy=ComboBox_ResetContent(GETHCTL(IDC_SPLOT_YLABEL));
				nDummy=ComboBox_InsertString(GETHCTL(IDC_SPLOT_YLABEL), 0,
					"Crosscorrelation Sigma");
				nDummy=ComboBox_InsertString(GETHCTL(IDC_SPLOT_YLABEL), 0,
					"Cross ADEV, @#s]y[(t)");
				nDummy=ComboBox_InsertString(GETHCTL(IDC_SPLOT_YLABEL), 0,
					"Crosscorrelation Allan Deviation");
				strcpy(sSPlot.left_y_label, "Crosscorrelation Allan Deviation");
			}
			#endif

			// Load the y-axis label
			SetWindowText(GETHCTL(IDC_SPLOT_YLABEL), sSPlot.left_y_label);

			// Save previous sigma plot parameters
			strlcpy(sSPrev.title, sSPlot.title, TITLESIZE);
			strlcpy(sSPrev.subtitle, sSPlot.subtitle, SUBTITLESIZE);
			strlcpy(sSPrev.message_str, sSPlot.message_str, MESSAGESIZE);
			strlcpy(sSPrev.plot_filename, sSPlot.plot_filename, FILENAMESIZE);
			sSPrev.x_max=sSPlot.x_max;
			sSPrev.x_min=sSPlot.x_min;
			sSPrev.y_max=sSPlot.y_max;
			sSPrev.y_min=sSPlot.y_min;
			sSPrev.do_date=sSPlot.do_date;
			sSPrev.do_box=sSPlot.do_box;
			sSPrev.do_fit=sSPlot.do_fit;
			sSPrev.do_table=sSPlot.do_table;
			sSPrev.do_mouse=sSPlot.do_mouse;
			sSPrev.do_fit=sSPlot.do_fit;
			sSPrev.do_wide=sSPlot.do_wide;
			sSPrev.position=sSPlot.position;
			sSPrev.table_position=sSPlot.table_position;
			strlcpy(szPrevStabFile, szStabFile, FILE_NAME_SIZE);
			strlcpy(szPrevStabFileTitle, szStabFileTitle, FILE_TITLE_SIZE);
			strlcpy(sSPrev.x_label, sSPlot.x_label, XLABELSIZE);
			strlcpy(sSPrev.left_y_label, sSPlot.left_y_label, YLABELSIZE);

			// Fill up message position list box using string table
			// Note usage of DPLOT rather than SPLOT strings
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_SPLOT_POSITION));
			nDummy=ComboBox_InsertString(GETHCTL(IDC_SPLOT_POSITION),
				0, "None");
			for(i=0; i<NUM_DPLOT_POSITIONS; i++)
			{
				LoadString(hInst, IDS_DPLOT_POSITION_0+i, szBuffer,
					BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_SPLOT_POSITION),
					i, szBuffer);
			}

			// Show position
			nDummy=ComboBox_SetCurSel(GETHCTL(IDC_SPLOT_POSITION),
				sSPlot.position);

			// Fill up table position list box using string table
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_SPLOT_TABPOS));
			for(i=0; i<NUM_TABLE_POSITIONS; i++)
			{
				LoadString(hInst, IDS_TABLE_POSITION_0+i, szBuffer,
					BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_SPLOT_TABPOS),
					i, szBuffer);
			}

			// Show position
			nDummy=ComboBox_SetCurSel(GETHCTL(IDC_SPLOT_TABPOS),
				sSPlot.table_position);

			// Disable table position control if table is not checked
			EnableWindow(GETHCTL(IDC_SPLOT_TABPOS), sSPlot.do_table);

			// Clear the title list box
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_SPLOT_TITLE));

			// Fill up title list box using string table
			for(i=0; i<NUM_SPLOT_TITLES; i++)
			{
				LoadString(hInst, IDS_SPLOT_TITLE_0+i, szBuffer, BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_SPLOT_TITLE),
					i, szBuffer);
			}

			// Load previous user-entered title strings into list box
			if(nUserTitles)
			{
				for(i=0; i<nUserTitles; i++)
				{
					// Load title string
					nDummy=ComboBox_InsertString(GETHCTL(IDC_SPLOT_TITLE),
						i, szPlotTitle[i]);
				}
			}

			// Load the current title
			SetWindowText(GETHCTL(IDC_SPLOT_TITLE), sSPlot.title);

			// Clear the subtitle list box
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_SPLOT_SUBTITLE));

			// Load the filenames into the subtitle list box
			nDummy=ComboBox_AddString(GETHCTL(IDC_SPLOT_SUBTITLE),
				szFileTitle);
			nDummy=ComboBox_AddString(GETHCTL(IDC_SPLOT_SUBTITLE), szFile);

			// Load previous user-entered subtitle strings into list box
			if(nUserSubtitles)
			{
				for(i=0; i<nUserSubtitles; i++)
				{
					// Load subtitle string
					nDummy=ComboBox_InsertString(GETHCTL(IDC_SPLOT_SUBTITLE),
						i, szPlotSubtitle[i]);
				}
			}

			// Load the current subtitle
			SetWindowText(GETHCTL(IDC_SPLOT_SUBTITLE),
				sSPlot.subtitle);

			// Clear the message list box
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_SPLOT_MESSAGE));
			nMessageCount=0;

			// Load drift removed message
			if(bDataType==FREQ_DATA)
			{
				// Display generic lin drift removed msg however it was removed
				if(bLinDriftRem || bRemove)
				{
					LoadString(hInst, IDS_SPLOT_MESSAGE_3, szBuffer,
						BUFFER_SIZE);
					nDummy=ComboBox_AddString(GETHCTL(IDC_SPLOT_MESSAGE),
						szBuffer);
					nMessageCount++;
				}

				// Don't show prev slope & drift if also removed
				// during sigma calc
				if(bLinDriftRem && !bRemove)
				{
					// Load linear freq slope removed message
					LoadString(hInst, IDS_FPLOT_MESSAGE_11, szTemp,
						BUFFER_SIZE);
					_snprintf(szBuffer, sizeof(szBuffer), szTemp,
						fFreqSlopeRemoved);
					ShortenExp(szBuffer);
					nDummy=ComboBox_AddString(GETHCTL(IDC_SPLOT_MESSAGE),
						szBuffer);
					nMessageCount++;

					// Load linear freq drift removed message
					LoadString(hInst, IDS_FPLOT_MESSAGE_12, szTemp,
						BUFFER_SIZE);
					_snprintf(szBuffer, sizeof(szBuffer), szTemp,
						fFreqSlopeRemoved*86400./fTau);
					ShortenExp(szBuffer);
					nDummy=ComboBox_AddString(GETHCTL(IDC_SPLOT_MESSAGE),
						szBuffer);
					nMessageCount++;
				}

				// Don't show prev slope & drift if also removed
				// during sigma calc
				if(bLogDriftRem && !bRemove)
				{
					LoadString(hInst, IDS_SPLOT_MESSAGE_4, szBuffer,
						BUFFER_SIZE);
					nDummy=ComboBox_AddString(GETHCTL(IDC_SPLOT_MESSAGE),
						szBuffer);
					nMessageCount++;

					// Load log fit slope removed message
					LoadString(hInst, IDS_FPLOT_MESSAGE_20, szTemp,
						BUFFER_SIZE);
					_snprintf(szBuffer, sizeof(szBuffer), szTemp, fLogSlope);
					ShortenExp(szBuffer);
					nDummy=ComboBox_AddString(GETHCTL(IDC_SPLOT_MESSAGE),
						szBuffer);
					nMessageCount++;

					// Load log fit drift removed message
					LoadString(hInst, IDS_FPLOT_MESSAGE_21, szTemp,
						BUFFER_SIZE);
					_snprintf(szBuffer, sizeof(szBuffer), szTemp,
						fLogSlope*86400./fTau);
					ShortenExp(szBuffer);
					nDummy=ComboBox_AddString(GETHCTL(IDC_SPLOT_MESSAGE),
						szBuffer);
					nMessageCount++;
				}

				// Don't show prev slope & drift if also removed
				// during sigma calc
				if(bDiffDriftRem && !bRemove)
				{
					LoadString(hInst, IDS_SPLOT_MESSAGE_5, szBuffer,
						BUFFER_SIZE);
					nDummy=ComboBox_AddString(GETHCTL(IDC_SPLOT_MESSAGE),
						szBuffer);
					nMessageCount++;

					// Load diffusion fit slope removed message
					LoadString(hInst, IDS_FPLOT_MESSAGE_22, szTemp,
						BUFFER_SIZE);
					_snprintf(szBuffer, sizeof(szBuffer), szTemp,
						fDiffusionSlope);
					ShortenExp(szBuffer);
					nDummy=ComboBox_AddString(GETHCTL(IDC_SPLOT_MESSAGE),
						szBuffer);
					nMessageCount++;

					// Load diffusion fit drift removed message
					LoadString(hInst, IDS_FPLOT_MESSAGE_23, szTemp,
						BUFFER_SIZE);
					_snprintf(szBuffer, sizeof(szBuffer), szTemp,
						fDiffusionSlope*86400./fTau);
					ShortenExp(szBuffer);
					nDummy=ComboBox_AddString(GETHCTL(IDC_SPLOT_MESSAGE),
						szBuffer);
					nMessageCount++;
				}
			}
			else // Phase data
			{
				if(bQuadDriftRem || bRemove)
				{
					LoadString(hInst, IDS_SPLOT_MESSAGE_6, szBuffer,
						BUFFER_SIZE);
					nDummy=ComboBox_AddString(GETHCTL(IDC_SPLOT_MESSAGE),
						szBuffer);
					nMessageCount++;
				}

				// Don't show prev slope & drift if also removed
				// during sigma calc
				if(bQuadDriftRem && !bRemove)
				{
					// Load freq slope removed message
					LoadString(hInst, IDS_PPLOT_MESSAGE_9, szTemp,
						BUFFER_SIZE);
						_snprintf(szBuffer, sizeof(szBuffer), szTemp,
							fPhaseSlopeRemoved);
					ShortenExp(szBuffer);
					nDummy=ComboBox_AddString(GETHCTL(IDC_SPLOT_MESSAGE),
						szBuffer);
					nMessageCount++;

					// Load freq drift removed message
					LoadString(hInst, IDS_PPLOT_MESSAGE_10, szTemp,
						BUFFER_SIZE);
						_snprintf(szBuffer, sizeof(szBuffer), szTemp,
							fPhaseSlopeRemoved*86400./fTau);
					ShortenExp(szBuffer);
					nDummy=ComboBox_AddString(GETHCTL(IDC_SPLOT_MESSAGE),
						szBuffer);
					nMessageCount++;
				}
			}

			// Load 1 of 2 units scaling message
			if(b1of2)
			{
					LoadString(hInst, IDS_SPLOT_MESSAGE_7, szBuffer,
						BUFFER_SIZE);
					nDummy=ComboBox_AddString(GETHCTL(IDC_SPLOT_MESSAGE),
						szBuffer);
					nMessageCount++;
			}

			// Load line parameter messages
			for(i=0; i<SLINE_NUMLINES; i++)
			{
				switch(sSLine[i].nLineType)
				{
					case SLINE_NOISE:
					{
						// Compose noise line parameter message
						// Example: Line 1: W FM Sigma(1)=1.234e-12
						// nSlope	Noise
						// 0		W PM
						// 1		F PM
						// 2		W FM
						// 3       F FM
						// 4       RW FM
						// 5       Aging
						LoadString(hInst, IDS_FORMAT_LINE_0+sSLine[i].nSlope,
							szTemp, BUFFER_SIZE);
						_snprintf(szBuffer, sizeof(szBuffer), szTemp, i+1,
							sSLine[i].fSigma1);
						ShortenExp(szBuffer);
						nDummy=ComboBox_AddString(GETHCTL(IDC_SPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;
					}
					break;
				}
			}

			// Load previous user-entered message strings into list box
			if(nUserMessages)
			{
				for(i=0; i<nUserMessages; i++)
				{
					// Load message string
					nDummy=ComboBox_InsertString(GETHCTL(IDC_SPLOT_MESSAGE),
						i, szPlotMessage[i]);
				}
			}

			// Load the current message
			SetWindowText(GETHCTL(IDC_SPLOT_MESSAGE),
				sSPlot.message_str);

			// Load the plot filename (*.TKF file)
			SetWindowText(GETHCTL(IDC_SPLOT_FILENAME),
				sSPlot.plot_filename);

			// Load the default stability filename (sigma-tau table)
			SetWindowText(GETHCTL(IDC_SPLOT_STABFILE), szStabFile);

			// Load the fTauMax value
			_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fTauMax);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_SPLOT_TAUMAX), szBuffer);

			// Load the fSigmaMax value
			_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fSigmaMax);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_SPLOT_SIGMAMAX), szBuffer);

			// Load the x_max value
			_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", sSPlot.x_max);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_SPLOT_XMAX), szBuffer);

			// Load the y_max value
			_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", sSPlot.y_max);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_SPLOT_YMAX), szBuffer);

			// Load the fTauMin value
			_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fTauMin);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_SPLOT_TAUMIN), szBuffer);

			// Load the fSigmaMin value
			_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fSigmaMin);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_SPLOT_SIGMAMIN), szBuffer);

			// Load the x_min value
			_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", sSPlot.x_min);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_SPLOT_XMIN), szBuffer);

			// Load the y_min value
			_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", sSPlot.y_min);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_SPLOT_YMIN), szBuffer);

			// Restore the date checkbox state
			Button_SetCheck(GETHCTL(IDC_SPLOT_DATE), sSPlot.do_date);

			// Restore the box checkbox state
			Button_SetCheck(GETHCTL(IDC_SPLOT_BOX), sSPlot.do_box);

			// Restore the wide checkbox state
			Button_SetCheck(GETHCTL(IDC_SPLOT_WIDE), sSPlot.do_wide);

			// Restore the append checkbox state
			Button_SetCheck(GETHCTL(IDC_SPLOT_APPEND), bWriteAppend);

			// Restore the fit checkbox state
			Button_SetCheck(GETHCTL(IDC_SPLOT_FIT), sSPlot.do_fit);

			// Activate only if there are noise or TDEV lines
			EnableWindow(GETHCTL(IDC_SPLOT_FIT), FALSE);

			for(i=0; i<SLINE_NUMLINES; i++)
			{
				if( (sSLine[i].nLineType==SLINE_NOISE) ||
					(sSLine[i].nLineType==SLINE_TDEV) )
				{
					EnableWindow(GETHCTL(IDC_SPLOT_FIT), TRUE);
				}
			}

			// Set errorbar checkbox state
			if( (!bAllTau) && (nSigmaPlotType!=TIERMS_RUN) &&
				(nSigmaPlotType!=MTIE_RUN) )
			{
				// Restore the errorbar checkbox state
				Button_SetCheck(GETHCTL(IDC_SPLOT_ERRBAR), sSPlot.do_errbar);
				EnableWindow(GETHCTL(IDC_SPLOT_ERRBAR), TRUE);
			}
			else // All tau sigma or TIE rms or MTIE
			{
				// Disable error bars
				sSPlot.do_errbar=FALSE;
				Button_SetCheck(GETHCTL(IDC_SPLOT_ERRBAR), sSPlot.do_errbar);
				EnableWindow(GETHCTL(IDC_SPLOT_ERRBAR), FALSE);
			}

			if(!bAllTau)
			{
				// Restore the table checkbox state
				Button_SetCheck(GETHCTL(IDC_SPLOT_TABLE), sSPlot.do_table);
				EnableWindow(GETHCTL(IDC_SPLOT_TABLE), TRUE);
			}
			else // All tau sigma
			{
				#if(0) // Allow new all tau table
				// Test added 01/28/01
				if(nSigmaPlotType!=MTIE_RUN)
				{
					// Disable table
					sSPlot.do_table=FALSE;
					Button_SetCheck(GETHCTL(IDC_SPLOT_TABLE), sSPlot.do_table);
					EnableWindow(GETHCTL(IDC_SPLOT_TABLE), FALSE);
				}
				#endif

				#if(1) // Allow new all tau table
				// Restore the table checkbox state
				Button_SetCheck(GETHCTL(IDC_SPLOT_TABLE), sSPlot.do_table);
				EnableWindow(GETHCTL(IDC_SPLOT_TABLE), TRUE);
				#endif
			}

			// Get & save HWNDs returned by GetFocus() for Title, Subtitle &
			// Message combo boxes
			SetFocus(GETHCTL(IDC_SPLOT_TITLE));
			uTitle=(UINT)GetFocus();
			SetFocus(GETHCTL(IDC_SPLOT_SUBTITLE));
			uSubtitle=(UINT)GetFocus();
			SetFocus(GETHCTL(IDC_SPLOT_MESSAGE));
			uMessage=(UINT)GetFocus();

			return TRUE;
		}

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				case IDHELP:
				{
					// Invoke help file
					// Note:  HH_HELP_CONTEXT is much more complicated to use
					// HH_DISPLAY_TOPIC doesn't require any map or h files,
					// topic ordinal #s, or aliases, etc.
					// Just give the name of the htm file for the topic
					#if(0)
					HtmlHelp(hDlg, "Stable32.chm::RUN_OPTIONS_FUNCTION.HTM",
						HH_DISPLAY_TOPIC,
                        0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::RUN_OPTIONS_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "RUN_OPTIONS_FUNCTION");
					#endif
				}
				break;

				// Detect parameter changes
				// Title change
				case IDC_SPLOT_TITLE:
				{
					// Respond to focus lost
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_KILLFOCUS)
					{
						GetWindowText(GETHCTL(IDC_SPLOT_TITLE),
							sSPlot.title, TITLESIZE-1);

						// Redisplay title - perhaps shortened
						SetWindowText(GETHCTL(IDC_SPLOT_TITLE),
							sSPlot.title);

						// Put new string into list
						// Don't store string if it is same as before
						if(ComboBox_FindString(GETHCTL(IDC_SPLOT_TITLE),
							-1, sSPlot.title)==CB_ERR)
						{
							// Don't store blank title either
							if(strlen(sSPlot.title))
							{
								nDummy=ComboBox_InsertString(GETHCTL(
									IDC_SPLOT_TITLE), 0, sSPlot.title);
							}
						}
					}
				}
				break;

				// Subtitle change
				case IDC_SPLOT_SUBTITLE:
				{
					// Respond to focus lost
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_KILLFOCUS)
					{
						GetWindowText(GETHCTL(IDC_SPLOT_SUBTITLE),
						sSPlot.subtitle, SUBTITLESIZE-1);

						// Redisplay subtitle - perhaps shortened
						SetWindowText(GETHCTL(IDC_SPLOT_SUBTITLE),
							sSPlot.subtitle);

						// Put new string into list
						// Don't store string if it is same as before
						if(ComboBox_FindString(GETHCTL(IDC_SPLOT_SUBTITLE),
							-1, sSPlot.subtitle)==CB_ERR)
						{
							// Don't store blank subtitle either
							if(strlen(sSPlot.subtitle))
							{
								nDummy=ComboBox_InsertString(GETHCTL(
									IDC_SPLOT_SUBTITLE), 0, sSPlot.subtitle);
							}
						}
					}
				}
				break;

				// X-Axis label change
				case IDC_SPLOT_XLABEL:
				{
					GetWindowText(GETHCTL(IDC_SPLOT_XLABEL),
						sSPlot.x_label, XLABELSIZE-1);
				}
				break;

				// Y-Axis label change
				case IDC_SPLOT_YLABEL:
				{
					GetWindowText(GETHCTL(IDC_SPLOT_YLABEL),
						sSPlot.left_y_label, YLABELSIZE-1);
				}
				break;

				// Message change
				case IDC_SPLOT_MESSAGE:
				{
					// Respond to focus lost
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_KILLFOCUS)
					{
						GetWindowText(GETHCTL(IDC_SPLOT_MESSAGE),
						sSPlot.message_str, MESSAGESIZE-1);

						// Redisplay message - perhaps shortened
						SetWindowText(GETHCTL(IDC_SPLOT_MESSAGE),
							sSPlot.message_str);

						// Put new string into list
						// Don't store string if it is same as before
						if(ComboBox_FindString(GETHCTL(IDC_SPLOT_MESSAGE),
							-1, sSPlot.message_str)==CB_ERR)
						{
							// Don't store blank message either
							if(strlen(sSPlot.message_str))
							{
								nDummy=ComboBox_InsertString(GETHCTL(
									IDC_SPLOT_MESSAGE), 0, sSPlot.message_str);
							}
						}
					}
				}
				break;

				// Plot Filename change (*.TKF file)
				case IDC_SPLOT_FILENAME:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_SPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// The default *.TKF filename includes full drive/path
						// where program started to avoid writing to floppy
						// or non-writable media.
						// The edit window AutoHScrolls.

						// Get new plot filename
						GetWindowText(GETHCTL(IDC_SPLOT_FILENAME),
							szTempFile, FILENAMESIZE-1);

						// Validate new filename
						if(CheckFilename(szTempFile, szTempTitle, szTempPath,
							szTempName, szTempExt, hDlg,
							"Sigma Plot Filename"))
						{
							// Filename OK
							strlcpy(sSPlot.plot_filename, szTempFile,
								FILENAMESIZE);
						}
						else // Filename NG
						{
							// Restore original filename
							SetWindowText(GETHCTL(IDC_SPLOT_FILENAME),
								sSPlot.plot_filename);
							SetFocus(GETHCTL(IDC_SPLOT_FILENAME));
							break;
						}
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Stability Filename change (sigma-tau table)
				case IDC_SPLOT_STABFILE:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_SPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get new stability filename
						GetWindowText(GETHCTL(IDC_SPLOT_STABFILE),
							szTempFile, FILENAMESIZE-1);

						// Validate new filename
						if(CheckFilename(szTempFile, szTempTitle, szTempPath,
							szTempName, szTempExt, hDlg,
							"Stability Data Filename"))
						{
							// Filename OK
							strlcpy(szStabFile, szTempFile, FILE_NAME_SIZE);
						}
						else // Filename NG
						{
							// Restore original filename
							SetWindowText(GETHCTL(IDC_SPLOT_STABFILE),
								szStabFile);
							SetFocus(GETHCTL(IDC_SPLOT_STABFILE));
							break;
						}
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Message position change
				case IDC_SPLOT_POSITION:
				{
					sSPlot.position=
						ComboBox_GetCurSel(GETHCTL(IDC_SPLOT_POSITION));
				}
				break;

				// Table position change
				case IDC_SPLOT_TABPOS:
				{
					sSPlot.table_position=
						ComboBox_GetCurSel(GETHCTL(IDC_SPLOT_TABPOS));
				}
				break;

				// Date flag change
				case IDC_SPLOT_DATE:
				{
					sSPlot.do_date=Button_GetCheck(GETHCTL(IDC_SPLOT_DATE));
				}
				break;

				// Box flag change
				case IDC_SPLOT_BOX:
				{
					sSPlot.do_box=Button_GetCheck(GETHCTL(IDC_SPLOT_BOX));
				}
				break;

				// Append flag change
				case IDC_SPLOT_APPEND:
				{
					bWriteAppend=Button_GetCheck(GETHCTL(IDC_SPLOT_APPEND));
				}
				break;

				// Errorbar flag change
				case IDC_SPLOT_ERRBAR:
				{
					sSPlot.do_errbar=
						Button_GetCheck(GETHCTL(IDC_SPLOT_ERRBAR));
				}
				break;

				// Fit label flag change
				case IDC_SPLOT_FIT:
				{
					sSPlot.do_fit=Button_GetCheck(GETHCTL(IDC_SPLOT_FIT));
				}
				break;

				// Table flag change
				case IDC_SPLOT_TABLE:
				{
					sSPlot.do_table=Button_GetCheck(GETHCTL(IDC_SPLOT_TABLE));

					// Disable table position control if table is not checked
					EnableWindow(GETHCTL(IDC_SPLOT_TABPOS),
						sSPlot.do_table);
				}
				break;

				// Wide flag change
				case IDC_SPLOT_WIDE:
				{
					sSPlot.do_wide=Button_GetCheck(GETHCTL(IDC_SPLOT_WIDE));
				}
				break;

				// Read config button
				case IDC_SPLOT_READ:
				{
					bSave=bUseSigmaPlotIni;
					bUseSigmaPlotIni=TRUE;
					ReadIni(INI_SIGMA);
					bUseSigmaPlotIni=bSave;
					SendMessage(hDlg, WM_INITDIALOG, (WPARAM)0, (LPARAM)0);
				}
				break;

				// Save config button
				case IDC_SPLOT_WRITE:
				{
					bSave=bUseSigmaPlotIni;
					bUseSigmaPlotIni=TRUE;
					WriteIni(INI_SIGMA);
					bUseSigmaPlotIni=bSave;
				}
				break;

				// Y-axis plot scale max change
				case IDC_SPLOT_YMAX:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_SPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new y_max value
						GetWindowText(GETHCTL(IDC_SPLOT_YMAX),
							szBuffer, BUFFER_SIZE);
						fEntry=(float)fabs(atof(szBuffer));

						// Validate new y_max value
						// Can't be less than or equal to y_min
						if(fEntry>sSPlot.y_min)
						{
							// New value OK
							sSPlot.y_max=fEntry;
						}
						else
						{
							MessageBeep(0);
							LoadString(hInst, IDS_FORMAT_GT, szTemp,
								BUFFER_SIZE);
							_snprintf(szBuffer, sizeof(szBuffer), szTemp,
								fEntry,	sSPlot.y_min);
							MessageBox(hDlg, szBuffer, "Invalid Entry",
								MB_ICONEXCLAMATION);
							SetFocus(GETHCTL(IDC_SPLOT_YMAX));
						}

						// Redisplay y_max value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							sSPlot.y_max);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_SPLOT_YMAX),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Y-axis plot scale min change
				case IDC_SPLOT_YMIN:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_SPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new y_min value
						GetWindowText(GETHCTL(IDC_SPLOT_YMIN),
							szBuffer, BUFFER_SIZE);
						fEntry=(float)fabs(atof(szBuffer));

						// Validate new y_min value
						// Can't be greater than or equal to y_max
						if(fEntry<sSPlot.y_max)
						{
							// New value OK
							sSPlot.y_min=fEntry;
						}
						else
						{
							MessageBeep(0);
							LoadString(hInst, IDS_FORMAT_LT, szTemp,
								BUFFER_SIZE);
							_snprintf(szBuffer, sizeof(szBuffer), szTemp,
								fEntry, sSPlot.y_max);

							MessageBox(hDlg, szBuffer, "Invalid Entry",
								MB_ICONEXCLAMATION);
							SetFocus(GETHCTL(IDC_SPLOT_YMIN));
						}

						// Redisplay y_min value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							sSPlot.y_min);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_SPLOT_YMIN),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// X-axis plot scale max change
				case IDC_SPLOT_XMAX:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_SPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new x_max value
						GetWindowText(GETHCTL(IDC_SPLOT_XMAX),
							szBuffer, BUFFER_SIZE);
						fEntry=(float)fabs(atof(szBuffer));

						// Validate new x_max value
						// Can't be less than or equal to x_min
						if(fEntry>sSPlot.x_min)
						{
							// New value OK
							sSPlot.x_max=fEntry;
						}
						else
						{
							MessageBeep(0);
							LoadString(hInst, IDS_FORMAT_GT, szTemp,
								BUFFER_SIZE);
							_snprintf(szBuffer, sizeof(szBuffer), szTemp,
								fEntry, sSPlot.x_min);

							MessageBox(hDlg, szBuffer, "Invalid Entry",
								MB_ICONEXCLAMATION);
							SetFocus(GETHCTL(IDC_SPLOT_XMAX));
						}

						// Redisplay x_max value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							sSPlot.x_max);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_SPLOT_XMAX),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// X-axis plot scale min change
				case IDC_SPLOT_XMIN:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_SPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new x_min value
						GetWindowText(GETHCTL(IDC_SPLOT_XMIN),
							szBuffer, BUFFER_SIZE);
						fEntry=(float)fabs(atof(szBuffer));

						// Validate new x_min value
						// Can't be greater than or equal to x_max
						if(fEntry<sSPlot.x_max)
						{
							// New value OK
							sSPlot.x_min=fEntry;
						}
						else
						{
							MessageBeep(0);
							LoadString(hInst, IDS_FORMAT_LT, szTemp,
								BUFFER_SIZE);
							_snprintf(szBuffer, sizeof(szBuffer), szTemp,
								fEntry, sSPlot.x_max);

							MessageBox(hDlg, szBuffer, "Invalid Entry",
								MB_ICONEXCLAMATION);
							SetFocus(GETHCTL(IDC_SPLOT_XMIN));
						}

						// Redisplay x_min value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							sSPlot.x_min);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_SPLOT_XMIN),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Respond to CR in an edit control
				// Note: No button is a DEFPUSHBUTTON
				case IDOK:
				{
					// The HWND returned by GetFocus() is not the same as the
					// one returned by GetDlgItem(), so the uTitle, etc
					// variables are used in these tests
					if((UINT)GetFocus()==uTitle)
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_SPLOT_TITLE, NULL, CBN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to SUBTITLE edit control
					if((UINT)GetFocus()==uSubtitle)
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_SPLOT_SUBTITLE, NULL, CBN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to MESSAGE edit control
					if((UINT)GetFocus()==uMessage)
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_SPLOT_MESSAGE, NULL, CBN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to XMIN edit control
					if(GetFocus()==GETHCTL(IDC_SPLOT_XMIN))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_SPLOT_XMIN, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to XMAX edit control
					if(GetFocus()==GETHCTL(IDC_SPLOT_XMAX))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_SPLOT_XMAX, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to YMIN edit control
					if(GetFocus()==GETHCTL(IDC_SPLOT_YMIN))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_SPLOT_YMIN, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to YMAX edit control
					if(GetFocus()==GETHCTL(IDC_SPLOT_YMAX))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_SPLOT_YMAX, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to FILENAME edit control
					if(GetFocus()==GETHCTL(IDC_SPLOT_FILENAME))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_SPLOT_FILENAME, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to STABFILE edit control
					if(GetFocus()==GETHCTL(IDC_SPLOT_STABFILE))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_SPLOT_STABFILE, NULL, EN_KILLFOCUS));
					}
				}
				break;

				// Get sigma & tau min & max
				case IDC_SPLOT_MINMAX:
				{
					if( (nSigmaPlotType==MODIFIED_RUN) ||
						(nSigmaPlotType==MODTOTAL_RUN) ||
						(nSigmaPlotType==TIME_RUN)     ||
						(nSigmaPlotType==TIMETOTAL_RUN) )
					{
						nPoints=sModSigData.points;
						minmax(&fTauMin, &fTauMax, sModSigData.tau,
							nPoints);
						minmax(&fSigmaMin, &fSigmaMax, sModSigData.sigma,
							nPoints);
					}
					else // ADEV
					{
						nPoints=sNormSigData.points;
						minmax(&fTauMin, &fTauMax, sNormSigData.tau,
							nPoints);
						minmax(&fSigmaMin, &fSigmaMax, sNormSigData.sigma,
							nPoints);
					}
				}
				break;

				// Reset all plot params to defaults
				case IDC_SPLOT_RESET:
				{
					// Initialize sigma plot filename
					// Full filename inc drive & directory where prgm started
					strlcpy(sSPlot.plot_filename, szDrive, FILENAMESIZE);
					strlcat(sSPlot.plot_filename, szDirectory, FILENAMESIZE);
					strlcat(sSPlot.plot_filename, "SIGMA.TKF", FILENAMESIZE);

					// Initialize stability data filename
					// Full filename inc drive & directory where prgm started
					strlcpy(szStabFile, szDrive, FILE_NAME_SIZE);
					strlcat(szStabFile, szDirectory, FILE_NAME_SIZE);
					strlcat(szStabFile, "SIGMA.TAU", FILE_NAME_SIZE);

					// Initialize sigma plot parameters
					bSave=bUseSigmaPlotIni;
					bUseSigmaPlotIni=FALSE;
					InitSigmaPlotParams();
					CalcSigmaPlotScale();
					SendMessage(hDlg, WM_INITDIALOG, (WPARAM)0, (LPARAM)0);
					bUseSigmaPlotIni=bSave;
				}
				break;

				// Respond to esc key or cancel button
				case IDCANCEL:
				case IDC_SPLOT_CANCEL:
				{
					// Restore previous sigma plot parameters
					strlcpy(sSPlot.title, sSPrev.title, TITLESIZE);
					strlcpy(sSPlot.subtitle, sSPrev.subtitle, SUBTITLESIZE);
					strlcpy(sSPlot.message_str, sSPrev.message_str,
						MESSAGESIZE);
					strlcpy(sSPlot.plot_filename, sSPrev.plot_filename,
						FILENAMESIZE);
					sSPlot.x_max=sSPrev.x_max;
					sSPlot.x_min=sSPrev.x_min;
					sSPlot.y_max=sSPrev.y_max;
					sSPlot.y_min=sSPrev.y_min;
					sSPlot.do_date=sSPrev.do_date;
					sSPlot.do_box=sSPrev.do_box;
					sSPlot.do_fit=sSPrev.do_fit;
					sSPlot.do_table=sSPrev.do_table;
					sSPlot.do_mouse=sSPrev.do_mouse;
					sSPlot.do_fit=sSPrev.do_fit;
					sSPlot.do_wide=sSPrev.do_wide;
					sSPlot.position=sSPrev.position;
					sSPlot.table_position=sSPrev.table_position;
					strlcpy(szStabFile, szPrevStabFile, FILE_NAME_SIZE);
					strlcpy(szStabFileTitle, szPrevStabFileTitle,
						FILE_TITLE_SIZE);
					strlcpy(sSPlot.x_label, sSPrev.x_label, XLABELSIZE);
					strlcpy(sSPlot.left_y_label, sSPrev.left_y_label,
						YLABELSIZE);

					// Close dialog box
					EndDialog (hDlg, 0);
				}
				return TRUE;

				case IDC_SPLOT_ACCEPT:
				{
					// Save # user-entered title strings
					nUserTitles=ComboBox_GetCount(GETHCTL(IDC_SPLOT_TITLE))-
					NUM_SPLOT_TITLES;

					// Limit # user titles
					nUserTitles=min(nUserTitles, NUM_TITLES);

					// Save user titles
					if(nUserTitles)
					{
						for(i=0; i<nUserTitles; i++)
						{
							// Get size of title string
							nLength=ComboBox_GetLBTextLen(GETHCTL(
								IDC_SPLOT_TITLE), i);

							// Realloc title array
							if((szPlotTitle[i]=
								(LPSTR)realloc(szPlotTitle[i],
								(nLength+1)*sizeof(char)))==NULL)
							{
								// Just dsp err msg & skip saving string
								// We are closing dlg box anyway
								AllocErrorMessage();
							}
							else
							{
								// Save title string
								nDummy=
									ComboBox_GetLBText(GETHCTL(IDC_SPLOT_TITLE),
									i, szPlotTitle[i]);
							}
						}
					}

					// Save # user-entered subtitle strings
					nUserSubtitles=
						ComboBox_GetCount(GETHCTL(IDC_SPLOT_SUBTITLE))-
						NUM_SPLOT_SUBTITLES;

					// Limit # user subtitles
					nUserSubtitles=min(nUserSubtitles, NUM_SUBTITLES);

					// Save user subtitles
					if(nUserSubtitles)
					{
						for(i=0; i<nUserSubtitles; i++)
						{
							// Get size of subtitle string
							nLength=ComboBox_GetLBTextLen(GETHCTL(
								IDC_SPLOT_SUBTITLE), i);

							// Realloc subtitle array
							if((szPlotSubtitle[i]=
								(LPSTR)realloc(szPlotSubtitle[i],
								(nLength+1)*sizeof(char)))==NULL)
							{
								// Just dsp err msg & skip saving string
								// We are closing dlg box anyway
								AllocErrorMessage();
							}
							else
							{
								// Save subtitle string
								nDummy=ComboBox_GetLBText(GETHCTL(
									IDC_SPLOT_SUBTITLE), i,	szPlotSubtitle[i]);
							}
						}
					}

					// Save # user-entered message strings
					nUserMessages=
						ComboBox_GetCount(GETHCTL(IDC_SPLOT_MESSAGE))-
						nMessageCount;

					// Limit # user messages
					nUserMessages=min(nUserMessages, NUM_MESSAGES);

					// Save user messages
					if(nUserMessages)
					{
						for(i=0; i<nUserMessages; i++)
						{
							// Get size of message string
							nLength=ComboBox_GetLBTextLen(GETHCTL(
								IDC_SPLOT_MESSAGE), i);

							// Realloc message array
							if((szPlotMessage[i]=
								(LPSTR)realloc(szPlotMessage[i],
								(nLength+1)*sizeof(char)))==NULL)
							{
								// Just dsp err msg & skip saving string
								// We are closing dlg box anyway
								AllocErrorMessage();
							}
							else
							{
								// Save message string
								nDummy=ComboBox_GetLBText(GETHCTL(
									IDC_SPLOT_MESSAGE), i, szPlotMessage[i]);
							}
						}
					}

					// Set line thickness
					if(sSPlot.do_wide)
					{
						sSPlot.thick=WIDELINESIZE;
					}
					else
					{
						sSPlot.thick=0;
					}

					// Close dialog box
					EndDialog (hDlg, 0);
				}
				return TRUE;
			}
		}
		break;
	 }
	 return FALSE;
}

#ifndef LITE_VER
/*****************************************************************************/
/*                                                                           */
/*          Power Spectrum Plot Dialog Procedure                             */
/*                                                                           */
/*                                                                           */
/*  PSDType          DataType       		bDataType*3+sPSPlot.type         */
/*				0=Phase		1=Freq             IDS_PSDTYPE_                  */
/*	0			_SX=Sx(f)	_SY=Sy(f)       0                3               */
/*  1           _SP=So(f)	                1                4               */
/*  2           _L =L(f)                    2                5               */
/*                                                                           */
/* 		Revision record:                                                     */
/*			12/23/96	Adapted from SigmaPlotDlgProc()                      */
/*			12/25/96	Ditto - Up & running                                 */
/*			01/23/97	Added INI file initialization option                 */
/*			01/25/97	Added code to push user-entered titles, subtitles &  */
/*						messages into combo listboxes with CR                */
/*			12/07/97	Added checkbox to control display of points          */
/*			02/02/02	Added provisions for user control of y-scale         */
/*			04/01/02	Added provisions for spectrum averaging              */
/*			07/12/02	Added PSD Filename edit box                          */
/*			02/23/02	Added support for multitaper PSD                     */
/*			01/25/07	Added support fot auto af periodogram PSD            */
/*			01/28/07	Added PSD smoothing                                  */
/*			07/31/07	Added automatic PSD plot with F10 key                */
/*			08/19/07	Added AUTONOPAD macro for auto af w/o zero padding   */
/*			08/20/07	Added bFirstAF flag and usage                        */
/*			08/21/07	Added NOPAD macro for std psd calc w/o zero padding  */
/*			08/21/07	Corrected L(f) correction factor                     */
/*			08/27/07	Added bZeroPad usage                                 */
/*          08/28/07	Added ENBW display in message box                    */
/*			08/29/07	Added display of narrowband log or dB corrections    */
/*			05/16/08	Added use of Spurs checkbox                          */
/*			05/18/08	Revised ENBW calc for multitaper method              */
/*			06/03/08	Added spur removal from plot and data                */
/*                                                                           */
/*****************************************************************************/

#ifndef _MSC_VER
	#pragma argsused
#endif

BOOL CALLBACK SpectrumPlotDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	// Handles
	HWND hChildWnd=NULL;
	HANDLE hChildAccel=NULL;
	// Chars
	char szBuffer[BUFFER_SIZE+1]; 	// Text buffer
	char szTemp[BUFFER_SIZE+1]; 	// Text buffer
	// Temporary filename buffers
	char szTempFile[FILENAMESIZE+1];	// Temp full filename buffer
	char szTempTitle[FILENAMESIZE+1];	// Temp file title buffer
	char szTempPath[FILENAMESIZE+1];	// Temp file path buffer
	char szTempName[FILENAMESIZE+1];    // Temp file name buffer
	char szTempExt[BUFFER_SIZE+1];		// Temp file extension buffer
    // Equivalent noise bandwidth in bins for windowing functions
	// 1st index is window type
	// 2nd index is # windowings (0 thru 3)
	// Multitaper added 05/17/08 - Made same as rectangular
	// enbw[3][4] changed to enbw[4][4]
	// Argument is that combination of multitaper windows
	// acts like rectangular one
	// If nothing else, this make things basically work
	// and can apply other factors separately
	// Other information says that multitaper BW is given by
	// 2*J/N*t
	// where J is BW factor, N is # points & t is sampling interval
	// Note: The multitaper case is not used
	static float enbw[4][4] =
    {
         { (float)1.000, (float)1.000, (float)1.000, (float)1.000 },
            // Rectangular
         { (float)1.000, (float)1.500, (float)1.944, (float)2.310 },
            // Hanning
         { (float)1.000, (float)1.363, (float)1.817, (float)2.184 },
            // Hamming
         { (float)1.000, (float)1.000, (float)1.000, (float)1.000 }
            // Multitaper
   };

	// Unsigned Ints
	static unsigned uTitle;			// HWND of Title combo control
	static unsigned uSubtitle;	  	// HWND of Subtitle combo control
	static unsigned uMessage;	  	// HWND of Message combo control
	// Ints
	int i;							// Index
	int a,b,c;						// Working ints
	static int nData;               // # analysis points
	int nAlloc;						// Memory allocation size
	int nLength;					// String length
	static int nYTic=0;				// # y scale tics
	static int nAvg=1;				// PSD averaging factor
	static int nWin=5;				// # multitaper windows
	static int nFreq;				// # MT FFT frequencies
	static int nMaxAF;				// Max af of auto spect calc
	static int nfft;				// nfft of auto spect calc
	static int nPPO;				// # points per decade for smoothing
									// Read from PSDSmoothPPO in ini file
	static int nNum;				// Total # of data points
	static int nPSDMax;				// Index of max PSD value in fPSD[]
	// BOOLs
	BOOL bSave;						// BOOL to save state of ini flag
	static BOOL bErrorTrap=FALSE;   // Flag for entry error
	static BOOL bFirstTime=TRUE;    // Flag for initial opening
	static BOOL bFirstAF=TRUE;		// Flag for initial AF setting
	static BOOL bPrevDataType=0;	// Flag for previous data type
	static BOOL bSmooth=FALSE;		// Flag to smooth PSD
	static BOOL bENBW=FALSE;		// Flag for ENBW message displayed
	static BOOL bPrevZeroPad;		// Previous zero padding flag setting
	// Floats
	float fCF;						// Correction factor
	float fPSDMax;					// PSD data maximum
	float fPSDMin;					// PSD data minimum
	//float fPSDOffset;				// PSD max location offset
	//float fFreqPeak;				// Estimated peak PSD frequency
	//float fPSDPeak;					// Estimated peak PSD magnitude
	float fYMax;					// Max PSD scale
	float fYMin;					// Min PSD Scale
	static float fPi=3.0;			// # multitaper pi prolate functions
	float fENBW;					// Equivalent noise BW, Hz
	// F_TYPEs
	static F_TYPE fBin;				// FFT frequency interval
	F_TYPE fMax;					// Max FFT frequency
	static F_TYPE fTau;			   	// Tau value
	static F_TYPE fAvg;				// Average value of data
	// F_TYPE Pointers
	static F_TYPE *fTempData;		// Pointer to temporary data array

	// Note: The spectrum plot structs, sPSPlot & sPSPrev, are defined globally

	// Definitions of on-screen displays:
	//	# FFT Points: IDC_PSPLOT_NFFT
	//				  The # of zero-padded phase or frequency data points
	//				  that are used to calculate the PSD results, equal to
	//				  (int)pow(2.0,
	//                (double)(ceil(log(sPSPlot.nfft)/log(2))))/nAvg
	//	# PSD Points: IDC_PSPLOT_NPSD
	//				  The # of points in PSD and Fourier frequency arrays
	//                passed to the PowerSpectrumPlot() function, equal to
	//				  (sPSPlot.nfft/2)-1 at the point of PSD plotting

	// Put plot dialog box handle into global
	hPlotBox=hDlg;

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Put dialog box handle into global variable
			// Used at end of GraphiC plotting to assure safe return here
			hDialog=hDlg;

			// Check if data type changed
			if(bDataType!=bPrevDataType)
			{
				// Make sure subtitle is correct
				strlcpy(sPSPlot.subtitle, szFileTitle, SUBTITLESIZE);

				// Reset plot scale
				sPSPlot.y_tic=0;
			}

			// Save new data type
			bPrevDataType=bDataType;

			// Check if data changed
			if(bDataType==PHASE_DATA && bPhaseDataChanged)
			{
				// Make sure subtitle is correct
				strlcpy(sPSPlot.subtitle, szFileTitle, SUBTITLESIZE);

				// Reset plot scale
				sPSPlot.y_tic=0;

				// Clear data changed flag
				bPhaseDataChanged=FALSE;
			}
			if(bDataType==FREQ_DATA && bFreqDataChanged)
			{
				// Make sure subtitle is correct
				strlcpy(sPSPlot.subtitle, szFileTitle, SUBTITLESIZE);

				// Reset plot scale
				sPSPlot.y_tic=0;

				// Clear data changed flag
				bFreqDataChanged=FALSE;
			}

			// Force Sy(f) type if freq data
			if(bDataType==FREQ_DATA)
			{
				sPSPlot.plotype=0;
			}

			// Full initialization
			if(bFirstTime)
			{
				// Disable y scale boxes so crazy values can't be entered
				EnableWindow(GETHCTL(IDC_PSPLOT_YMAX), FALSE);
				EnableWindow(GETHCTL(IDC_PSPLOT_YMIN), FALSE);
				EnableWindow(GETHCTL(IDC_PSPLOT_YTIC), FALSE);

				// Set # y-axis tics to zero as code to calc scale
				sPSPlot.y_tic=0;

				if(bUseSpectPlotIni)
				{
					ReadIni(INI_SPECT);
					bSmooth=sPSPlot.smooth;
					Button_SetCheck(GETHCTL(IDC_PSPLOT_SMOOTH), bSmooth);
					nPPO=sPSPlot.ppo;
				}
				else
				{
					// Initialize spectrum plot parameters to defaults
					strlcpy(sPSPlot.title, "POWER SPECTRUM", TITLESIZE);
					strlcpy(sPSPlot.subtitle, szFileTitle, SUBTITLESIZE);
					strlcpy(sPSPlot.message_str, "", MESSAGESIZE);
		
					sPSPlot.do_date=TRUE;
					sPSPlot.do_box=TRUE;
					sPSPlot.do_mouse=FALSE;
					sPSPlot.do_line=TRUE;
					sPSPlot.do_errbar=TRUE;
					sPSPlot.do_table=TRUE; // Controls windowing info display
					sPSPlot.do_fit=TRUE;
					sPSPlot.do_wide=FALSE;
					sPSPlot.do_spur=FALSE;
					sPSPlot.nospur_plot=FALSE;
					sPSPlot.nospur_data=FALSE;
					sPSPlot.position=0;
					sPSPlot.smooth=FALSE;

					// Adjust settings for modern plot style
					if(nStyle==MODERN_STYLE)
					{
						sPSPlot.do_date=FALSE;
						sPSPlot.do_wide=TRUE;
						sPSPlot.do_fit=FALSE;
						sPSPlot.do_line=FALSE;
						sPSPlot.do_table=FALSE;
						strlcpy(sPSPlot.subtitle, "", sizeof(sPSPlot.subtitle));
					}

					// Added 08/20/07
					bSmooth=FALSE;

					if(bDataType==FREQ_DATA)
					{
						sPSPlot.plotype=0; // Sy(f)
					}
					else // Phase data
					{
						sPSPlot.plotype=2; // L(f)
					}
					sPSPlot.win=2; // Hamming supposedly best for noise
					sPSPlot.num=1;
					sPSPlot.carrier=1.0e7;
				}
				bFirstTime=FALSE;
			}

			// Read new configuration file items
			nPSDAvgSize=GetPrivateProfileInt("Preferences", "PSDAvgSize",
				64, szIniFile);
			nPSDAvgMax=GetPrivateProfileInt("Preferences", "PSDAvgMax",
				256, szIniFile);
			nPSDLFSkip=GetPrivateProfileInt("Preferences", "PSDLFSkip",
				1, szIniFile);
			bSmooth=GetPrivateProfileInt("Preferences", "Smooth", 0,
				szIniFile);
			nPPO=GetPrivateProfileInt("Preferences", "PSDSmoothPPO",
				64, szIniFile);

			// Load x label
			LoadString(hInst, IDS_PSPLOT_XLABEL, szBuffer, BUFFER_SIZE);
			SetWindowText(GETHCTL(IDC_PSPLOT_XLABEL), szBuffer);

			// Load y label
			// Label depends on both bDataType and sPSPlot.plotype
			i=(bDataType)*3+sPSPlot.plotype;
			LoadString(hInst, IDS_PSPLOT_YLABEL_0+i, szBuffer, BUFFER_SIZE);
			SetWindowText(GETHCTL(IDC_PSPLOT_YLABEL), szBuffer);

			// Fill up message position list box using string table
			// Note usage of DPLOT rather than PSPLOT strings
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_PSPLOT_POSITION));
			nDummy=ComboBox_InsertString(GETHCTL(IDC_PSPLOT_POSITION),
				0, "None");
			for(i=0; i<NUM_DPLOT_POSITIONS; i++)
			{
				LoadString(hInst, IDS_DPLOT_POSITION_0+i, szBuffer,
					BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_PSPLOT_POSITION),
					i, szBuffer);
			}

			// Show position
			nDummy=ComboBox_SetCurSel(GETHCTL(IDC_PSPLOT_POSITION),
				sPSPlot.position);

			// Fill up PSD type list box using string table
			// Contents depend on both bDataType and nPSDType
			// 3 choices for phase data, 1 for freq data
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_PSPLOT_PSD));
			for(i=0; i<(3-(bDataType*2)); i++)
			{
				LoadString(hInst, IDS_PSDTYPE_0+(bDataType)*3+i, szBuffer,
					BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_PSPLOT_PSD),
					i, szBuffer);
			}

			// Show PSD type
			nDummy=ComboBox_SetCurSel(GETHCTL(IDC_PSPLOT_PSD),
				sPSPlot.plotype);

			// Fill up windowing type list box using string table
			// Multitaper choice added 7/21/02
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_PSPLOT_WIN));
			for(i=0; i<4; i++)
			{
				LoadString(hInst, IDS_WINTYPE_0+i, szBuffer, BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_PSPLOT_WIN),
					i, szBuffer);
			}

			// Show carrier freq - applies to S(f) & L(f) phase data
			if( (sPSPlot.plotype==1) || (sPSPlot.plotype==2) )
			{
				_snprintf(szBuffer, sizeof(szBuffer), "%10.7e",
					sPSPlot.carrier);
			}
			else
			{
				LoadString(hInst, IDS_MESSAGE_NA, szBuffer, BUFFER_SIZE);
			}
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_PSPLOT_CARRIER), szBuffer);

			// Show windowing type
			nDummy=ComboBox_SetCurSel(GETHCTL(IDC_PSPLOT_WIN), sPSPlot.win);

			// Fill # windows or # windowings list box
			if(sPSPlot.win==MULTITAPER_WIN)
			{
				// Set label for # windows control
				SetWindowText(GETHCTL(IDC_PSPLOT_WINS), "# Wi&ndows:");

				// Fill up # windows type list box
				// nWin varies in steps of 1 from 1-3 thru 1-9 depending on fPi
				// Maximum nWin is (fPi*2)-1
				nDummy=ComboBox_ResetContent(GETHCTL(IDC_PSPLOT_NUM));
				for(i=1; i<(int)(fPi*2); i++)
				{
					_snprintf(szBuffer, sizeof(szBuffer), "%d", i);
					nDummy=ComboBox_InsertString(GETHCTL(IDC_PSPLOT_NUM),
						i-1, szBuffer);
				}

				// Set fPi to 3.0 (nominal)
				fPi=3.0;

				// Set nWin to largest allowable
				nWin=(int)((fPi*2)-1);

				// Show # windows
				nDummy=ComboBox_SetCurSel(GETHCTL(IDC_PSPLOT_NUM), nWin-1);
			}
			else
			{
				// Set label for # windowings control
				SetWindowText(GETHCTL(IDC_PSPLOT_WINS), "# Wi&ndowings:");

				// Fill up # windowings type list box
				nDummy=ComboBox_ResetContent(GETHCTL(IDC_PSPLOT_NUM));
				for(i=0; i<4; i++)
				{
					_snprintf(szBuffer, sizeof(szBuffer), "%d", i);
					nDummy=ComboBox_InsertString(GETHCTL(IDC_PSPLOT_NUM),
						i, szBuffer);
				}

				// Show # windowings
				nDummy=ComboBox_SetCurSel(GETHCTL(IDC_PSPLOT_NUM), sPSPlot.num);
			}

			// Fill up BW or Avg factor list box 
			if(sPSPlot.win==MULTITAPER_WIN)
			{
				// Set label for BW factor control
				SetWindowText(GETHCTL(IDC_PSPLOT_FACTOR), "BW (&J) Factor:");

				// Fill up BW factor list box
				// Seven choices from 2.0 to 5.0 in steps of 0.5
				nDummy=ComboBox_ResetContent(GETHCTL(IDC_PSPLOT_AVERAGE));
				for(i=0; i<7; i++)
				{
					_snprintf(szBuffer, sizeof(szBuffer), "%2.1f",
						(i*0.5)+2.0);
					nDummy=ComboBox_InsertString(GETHCTL(IDC_PSPLOT_AVERAGE),
						i, szBuffer);
				}

				// Show default bandwidth selection
				nDummy=ComboBox_SetCurSel(GETHCTL(IDC_PSPLOT_AVERAGE),
					(int)((fPi*2)-4.0));
			}
			else
			{
				// Set label for avg factor control
				SetWindowText(GETHCTL(IDC_PSPLOT_FACTOR), "Avg Factor (&4):");

				// Fill up avg factor combo box
				// Contents calculated as power-of-2 ints up to # points/16
				nData=(int)(fData[2]-fData[1]+1);
				nDummy=ComboBox_ResetContent(GETHCTL(IDC_PSPLOT_AVERAGE));

				// Put Auto into 1st position of AVERAGE list box
				nDummy=ComboBox_InsertString(GETHCTL(IDC_PSPLOT_AVERAGE),
						0, "Auto");

				// Fill combo box
				// do loop used to assure at least 1 loop execution
				// so will always get 1 in list box
				i=0;
				do
				{
					_snprintf(szBuffer, sizeof(szBuffer), "%1.0f", pow(2.0,
						(double)i));
					nDummy=ComboBox_InsertString(GETHCTL(IDC_PSPLOT_AVERAGE),
						i+1, szBuffer);
					i++;
				} while(pow(2.0, (double)i)<(double)(nData/16));

				if(nData>9) // Note: Both cases same as programmed
				{
					#if(1) // Trial code 08/27/07
					nDummy=ComboBox_SetCurSel(GETHCTL(IDC_PSPLOT_AVERAGE), nAvg);
					#endif
					
					#if(0) // Original code
					// Show default average selection (AF=1)
					nDummy=ComboBox_SetCurSel(GETHCTL(IDC_PSPLOT_AVERAGE), 1);

					// Set nAvg=1 (AF=1)
					nAvg=1;
					#endif
				}
				else // Too few data points to use auto af - force af=1
					 // Note: This doesn't prevent Auto from being selected
					 // but it does discourage it
					 // If Auto is selected with too few points
					 // will get error message during plot
				{
					// Show default average selection (AF=1)
					nDummy=ComboBox_SetCurSel(GETHCTL(IDC_PSPLOT_AVERAGE), 1);

					// Set nAvg=1
					nAvg=1;
				}
			}

			// Clear the title list box
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_PSPLOT_TITLE));

			// Load the title
			SetWindowText(GETHCTL(IDC_PSPLOT_TITLE), sPSPlot.title);

			// Load previous user-entered title strings into list box
			if(nUserTitles)
			{
				for(i=0; i<nUserTitles; i++)
				{
					// Load title string
					nDummy=ComboBox_InsertString(GETHCTL(IDC_PSPLOT_TITLE),
						i, szPlotTitle[i]);
				}
			}

			// Load the current title
			nDummy=ComboBox_AddString(GETHCTL(IDC_PSPLOT_TITLE),
				sPSPlot.title);
			SetWindowText(GETHCTL(IDC_PSPLOT_TITLE),
				sPSPlot.title);

			// Clear the subtitle list box
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_PSPLOT_SUBTITLE));

			// Load the filenames into the subtitle list box
			nDummy=ComboBox_AddString(GETHCTL(IDC_PSPLOT_SUBTITLE),
				szFileTitle);
			nDummy=ComboBox_AddString(GETHCTL(IDC_PSPLOT_SUBTITLE), szFile);

			// Load previous user-entered subtitle strings into list box
			if(nUserSubtitles)
			{
				for(i=0; i<nUserSubtitles; i++)
				{
					// Load subtitle string
					nDummy=ComboBox_InsertString(GETHCTL(IDC_PSPLOT_SUBTITLE),
						i, szPlotSubtitle[i]);
				}
			}

			// Load the subtitle
			SetWindowText(GETHCTL(IDC_PSPLOT_SUBTITLE),
				sPSPlot.subtitle);

			// Clear the message list box
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_PSPLOT_MESSAGE));

			// Load previous user-entered message strings into list box
			if(nUserMessages)
			{
				for(i=0; i<nUserMessages; i++)
				{
					// Load message string
					nDummy=ComboBox_InsertString(GETHCTL(IDC_PSPLOT_MESSAGE),
						i, szPlotMessage[i]);
				}
			}

			#if(1) // Added 05/17/08
			// Remove any previous message strings associated with spurs
			nDummy=ComboBox_FindString(GETHCTL(IDC_PSPLOT_MESSAGE), 0, "# Spurs ");
			if(nDummy!=CB_ERR)
			{
				nDummy=ComboBox_DeleteString(GETHCTL(IDC_PSPLOT_MESSAGE), nDummy);
			}
			nDummy=ComboBox_FindString(GETHCTL(IDC_PSPLOT_MESSAGE), 0, "Largest Spur: Freq=");
			if(nDummy!=CB_ERR)
			{
				nDummy=ComboBox_DeleteString(GETHCTL(IDC_PSPLOT_MESSAGE), nDummy);
			}
			#endif

			// Load the current message
			SetWindowText(GETHCTL(IDC_PSPLOT_MESSAGE),
				sPSPlot.message_str);

			// Load the plot filename
			SetWindowText(GETHCTL(IDC_PSPLOT_FILENAME),
				sPSPlot.plot_filename);

			// Load the PSD data filename
			SetWindowText(GETHCTL(IDC_PSPLOT_PSDFILE),
				szPSDFile);

			// Show previous avg factor per sPSPlot.af
			#if(1) // New code 08/27/08
			// Special case for Auto AF
			// sPSPlot.af will have the max AF used by Auto AF
			// but nAvg still has the 0 code for it
			if(nAvg==0)
			{
				nDummy=ComboBox_SetCurSel(GETHCTL(IDC_PSPLOT_AVERAGE), 0);
			}
			else // Not Auto AF
			{
				_snprintf(szBuffer, sizeof(szBuffer), "%d", sPSPlot.af);
				i=ComboBox_FindStringExact(GETHCTL(IDC_PSPLOT_AVERAGE), 0,
					szBuffer);
				// Was previous avg factor not found?
				if(i<0)
				{
					// Use default avg factor = 1
					nDummy=ComboBox_SetCurSel(GETHCTL(IDC_PSPLOT_AVERAGE), 1);
					nAvg=1;
				}
				else // OK - avg factor found
				{
					nDummy=ComboBox_SetCurSel(GETHCTL(IDC_PSPLOT_AVERAGE), i);
					nAvg=sPSPlot.af;
				}
			}
			#endif

			#if(0) // Original code
			_snprintf(szBuffer, sizeof(szBuffer), "%d", sPSPlot.af);
			i=ComboBox_FindStringExact(GETHCTL(IDC_PSPLOT_AVERAGE), 0,
				szBuffer);
			// Was previous avg factor not found?
			if(i<0)
			{
				// Use default avg factor = 1
				nDummy=ComboBox_SetCurSel(GETHCTL(IDC_PSPLOT_AVERAGE), 1);
				nAvg=1;
			}
			else // OK - avg factor found
			{
				nDummy=ComboBox_SetCurSel(GETHCTL(IDC_PSPLOT_AVERAGE), i);
				nAvg=sPSPlot.af;
			}
			#endif

			// Restore the date checkbox state
			Button_SetCheck(GETHCTL(IDC_PSPLOT_DATE), sPSPlot.do_date);

			// Restore the box checkbox state
			Button_SetCheck(GETHCTL(IDC_PSPLOT_BOX), sPSPlot.do_box);

			// Restore the cursor checkbox state
			Button_SetCheck(GETHCTL(IDC_PSPLOT_CURSOR), sPSPlot.do_mouse);

			// Restore the fit checkbox state - uses do_line flag
			Button_SetCheck(GETHCTL(IDC_PSPLOT_FIT), sPSPlot.do_line);

			// Restore the wide checkbox state
			Button_SetCheck(GETHCTL(IDC_PSPLOT_WIDE), sPSPlot.do_wide);

			// Restore the spurs checkbox state
			Button_SetCheck(GETHCTL(IDC_PSPLOT_SPUR), sPSPlot.do_spur);

			// Restore the remove spurs from plot checkbox state
			Button_SetCheck(GETHCTL(IDC_PSPLOT_NOSPURPLOT), sPSPlot.nospur_plot);

			// Restore the remove spurs from data checkbox state
			Button_SetCheck(GETHCTL(IDC_PSPLOT_NOSPURDATA), sPSPlot.nospur_data);

			// Hide/show remove spurs checkboxes
			if(sPSPlot.do_spur)
			{
				EnableWindow(GETHCTL(IDC_PSPLOT_NOSPURPLOT), TRUE);
				EnableWindow(GETHCTL(IDC_PSPLOT_NOSPURDATA), TRUE);
			}
			else
			{
				EnableWindow(GETHCTL(IDC_PSPLOT_NOSPURPLOT), FALSE);
				EnableWindow(GETHCTL(IDC_PSPLOT_NOSPURDATA), FALSE);
			}

			// Disable spur removal from data if multitaper or averaging or smoothing
			// if( (sPSPlot.win==MULTITAPER_WIN) || ((nAvg!=1) && (sPSPlot.win!=MULTITAPER_WIN)) || (sPSPlot.smooth))
			// Disable spur removal from data if multitaper or smoothing
			// if( (sPSPlot.win==MULTITAPER_WIN) || (sPSPlot.smooth))
			// Disable spur removal from data if multitaper or auto averaging or smoothing
			if( (sPSPlot.win==MULTITAPER_WIN) || ((nAvg==0) && (sPSPlot.win!=MULTITAPER_WIN)) || (sPSPlot.smooth))
			{
				// Must disable spur removal from data
				sPSPlot.nospur_data=FALSE;
				Button_SetCheck(GETHCTL(IDC_PSPLOT_NOSPURDATA), sPSPlot.nospur_data);
				EnableWindow(GETHCTL(IDC_PSPLOT_NOSPURDATA), FALSE);
			}

			// Restore the points checkbox state
			// Note: The do_errbar flag is used to control the plotting
			// of the data points
			Button_SetCheck(GETHCTL(IDC_PSPLOT_POINTS), sPSPlot.do_errbar);

			// Restore the windowing info checkbox state
			Button_SetCheck(GETHCTL(IDC_PSPLOT_INFO), sPSPlot.do_table);

			// Restore the smoothing checkbox state
			// Button_SetCheck(GETHCTL(IDC_PSPLOT_SMOOTH), bSmooth);
			Button_SetCheck(GETHCTL(IDC_PSPLOT_SMOOTH), sPSPlot.smooth);

			// Enable Smooth checkbox unless Auto AF periodogram
			// Note: Probably not needed - Auto AF initialized off
			if((sPSPlot.win==MULTITAPER_WIN) || (nAvg))
			{
				EnableWindow(GETHCTL(IDC_PSPLOT_SMOOTH), TRUE);
			}
			else
			if((sPSPlot.win==MULTITAPER_WIN) || (nAvg))
			{
				EnableWindow(GETHCTL(IDC_PSPLOT_SMOOTH), FALSE);
			}

			// Load scale parameter edit boxes		
			if(sPSPlot.y_tic)
			{
				fYMax=sPSPlot.y_max;
				_snprintf(szBuffer, sizeof(szBuffer), "%4.2f", fYMax);
				SetWindowText(GETHCTL(IDC_PSPLOT_YMAX),	szBuffer);
				fYMin=sPSPlot.y_min;
				_snprintf(szBuffer, sizeof(szBuffer), "%4.2f", fYMin);
				SetWindowText(GETHCTL(IDC_PSPLOT_YMIN),	szBuffer);
				nYTic=sPSPlot.y_tic;
				_snprintf(szBuffer, sizeof(szBuffer), "%d", nYTic);
				SetWindowText(GETHCTL(IDC_PSPLOT_YTIC),	szBuffer);
			}
			else
			{
				SetWindowText(GETHCTL(IDC_PSPLOT_YMAX), "");
				SetWindowText(GETHCTL(IDC_PSPLOT_YMIN), "");
				SetWindowText(GETHCTL(IDC_PSPLOT_YTIC), "");
			}

			// Get tau value
			if(bDataType)
			{
				GetWindowText(hwndFreqTau, (LPSTR)szBuffer, BUFFER_SIZE);
				fTau=(F_TYPE)atof(szBuffer);
			}
			else
			{
				GetWindowText(hwndPhaseTau, (LPSTR)szBuffer, BUFFER_SIZE);
				fTau=(F_TYPE)atof(szBuffer);
			}

			// Display PSD parameters
			SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
				IDC_PSPLOT_DISPLAY, NULL, 0));

			// Display blank data max and min
			SetWindowText(GETHCTL(IDC_PSPLOT_DATAMAX), "Press Plot");
			SetWindowText(GETHCTL(IDC_PSPLOT_DATAMIN), "To Calc");
			
			// Get & save HWNDs returned by GetFocus() for Title, Subtitle &
			// Message combo boxes
			SetFocus(GETHCTL(IDC_PSPLOT_TITLE));
			uTitle=(UINT)GetFocus();
			SetFocus(GETHCTL(IDC_PSPLOT_SUBTITLE));
			uSubtitle=(UINT)GetFocus();
			SetFocus(GETHCTL(IDC_PSPLOT_MESSAGE));
			uMessage=(UINT)GetFocus();

			// This code produces power spectrum plot automatically
			// It is used only by the F10 function key run command
			// which sets this flag
			if(bAutoPowerPlot)
			{
				// Automatically produce PSD plot
				SendMessage(hDlg, WM_COMMAND,
					GET_WM_COMMAND_MPS(IDC_PSPLOT_PLOT, NULL, 0));

				// Turn off auto PSD plot flag
				// Have to turn on this flag each time it is used
				bAutoPowerPlot=FALSE;
			}

			return TRUE;
		}

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::POWER_FUNCTION.HTM",
						HH_DISPLAY_TOPIC,
                        0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::POWER_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "POWER_FUNCTION");
					#endif
				}
				break;

				// Detect parameter changes
				// Title change
				case IDC_PSPLOT_TITLE:
				{
					// Respond to focus lost
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_KILLFOCUS)
					{
						GetWindowText(GETHCTL(IDC_PSPLOT_TITLE),
						sPSPlot.title, TITLESIZE-1);

						// Redisplay title - perhaps shortened
						SetWindowText(GETHCTL(IDC_PSPLOT_TITLE),
							sPSPlot.title);

						// Put new string into list
						// Don't store string if it is same as before
						if(ComboBox_FindString(GETHCTL(IDC_PSPLOT_TITLE),
							-1, sPSPlot.title)==CB_ERR)
						{
							// Don't store blank title either
							if(strlen(sPSPlot.title))
							{
								nDummy=ComboBox_InsertString(GETHCTL(
									IDC_PSPLOT_TITLE), 0, sPSPlot.title);
							}
						}
					}
				}
				break;

				// Subtitle change
				case IDC_PSPLOT_SUBTITLE:
				{
					// Respond to focus lost
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_KILLFOCUS)
					{
						GetWindowText(GETHCTL(IDC_PSPLOT_SUBTITLE),
						sPSPlot.subtitle, SUBTITLESIZE-1);

						// Redisplay subtitle - perhaps shortened
						SetWindowText(GETHCTL(IDC_PSPLOT_SUBTITLE),
							sPSPlot.subtitle);

						// Put new string into list
						// Don't store string if it is same as before
						if(ComboBox_FindString(GETHCTL(IDC_PSPLOT_SUBTITLE),
							-1, sPSPlot.subtitle)==CB_ERR)
						{
							// Don't store blank subtitle either
							if(strlen(sPSPlot.subtitle))
							{
								nDummy=ComboBox_InsertString(GETHCTL(
									IDC_PSPLOT_SUBTITLE), 0, sPSPlot.subtitle);
							}
						}
					}
				}
				break;

				// Message change
				case IDC_PSPLOT_MESSAGE:
				{
					// Respond to focus lost
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_KILLFOCUS)
					{
						GetWindowText(GETHCTL(IDC_PSPLOT_MESSAGE),
						sPSPlot.message_str, MESSAGESIZE-1);

						// Redisplay message - perhaps shortened
						SetWindowText(GETHCTL(IDC_PSPLOT_MESSAGE),
							sPSPlot.message_str);

						// Put new string into list
						// Don't store string if it is same as before
						if(ComboBox_FindString(GETHCTL(IDC_PSPLOT_MESSAGE),
							-1, sPSPlot.message_str)==CB_ERR)
						{
							// Don't store blank message either
							if(strlen(sPSPlot.message_str))
							{
								nDummy=ComboBox_InsertString(GETHCTL(
									IDC_PSPLOT_MESSAGE),0,sPSPlot.message_str);
							}
						}
					}
				}
				break;

				// Plot Filename change
				case IDC_PSPLOT_FILENAME:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_PSPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// The default *.TKF filename includes full drive/path
						// where program started to avoid writing to floppy
						// or non-writable media.  The edit window AutoHScrolls.
						GetWindowText(GETHCTL(IDC_PSPLOT_FILENAME),
							szTempFile, FILENAMESIZE-1);

						// Validate new filename
						if(CheckFilename(szTempFile, szTempTitle, szTempPath,
							szTempName, szTempExt, hDlg,
							"Spectrum Plot Filename"))
						{
							// Filename OK
							strlcpy(sPSPlot.plot_filename, szTempFile,
								FILENAMESIZE);

							// Redisplay the new filename
							SetWindowText(GETHCTL(IDC_PSPLOT_FILENAME),
								szTempFile);
						}
						else // Filename NG
						{
							// Restore original filename
							SetWindowText(GETHCTL(IDC_PSPLOT_FILENAME),
								sPSPlot.plot_filename);
							SetFocus(GETHCTL(IDC_PSPLOT_FILENAME));
							break;
						}
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// PSD data filename change
				case IDC_PSPLOT_PSDFILE:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_PSPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// The default PSD data filename includes full
						// drive/path where program started.
						// The edit window AutoHScrolls.
						GetWindowText(GETHCTL(IDC_PSPLOT_PSDFILE),
							szTempFile, FILENAMESIZE-1);

						// Validate new filename
						if(CheckFilename(szTempFile, szTempTitle, szTempPath,
							szTempName, szTempExt, hDlg,
							"PSD Data Filename"))
						{
							// Filename OK
							strlcpy(szPSDFile, szTempFile, FILE_NAME_SIZE);

							// Redisplay the new filename
							SetWindowText(GETHCTL(IDC_PSPLOT_PSDFILE),
								szTempFile);
						}
						else // Filename NG
						{
							// Restore original filename
							SetWindowText(GETHCTL(IDC_PSPLOT_PSDFILE),
								szPSDFile);
							SetFocus(GETHCTL(IDC_PSPLOT_PSDFILE));
							break;
						}
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Position change
				case IDC_PSPLOT_POSITION:
				{
					sPSPlot.position=
						ComboBox_GetCurSel(GETHCTL(IDC_PSPLOT_POSITION));
				}
				break;

				// Date flag change
				case IDC_PSPLOT_DATE:
				{
					sPSPlot.do_date=Button_GetCheck(GETHCTL(IDC_PSPLOT_DATE));
				}
				break;

				// Box flag change
				case IDC_PSPLOT_BOX:
				{
					sPSPlot.do_box=Button_GetCheck(GETHCTL(IDC_PSPLOT_BOX));
				}
				break;

				// Cursor flag change
				case IDC_PSPLOT_CURSOR:
				{
					sPSPlot.do_mouse=
						Button_GetCheck(GETHCTL(IDC_PSPLOT_CURSOR));
				}
				break;

				// Wide flag change
				case IDC_PSPLOT_WIDE:
				{
					sPSPlot.do_wide=
						Button_GetCheck(GETHCTL(IDC_PSPLOT_WIDE));
				}
				break;

				// Spurs flag change
				case IDC_PSPLOT_SPUR:
				{
					sPSPlot.do_spur=
						Button_GetCheck(GETHCTL(IDC_PSPLOT_SPUR));

					// Hide/show remove spurs checkboxes
					if(sPSPlot.do_spur)
					{
						EnableWindow(GETHCTL(IDC_PSPLOT_NOSPURPLOT), TRUE);
						EnableWindow(GETHCTL(IDC_PSPLOT_NOSPURDATA), TRUE);
						sPSPlot.nospur_plot=Button_GetCheck(GETHCTL(IDC_PSPLOT_NOSPURPLOT));
						sPSPlot.nospur_data=Button_GetCheck(GETHCTL(IDC_PSPLOT_NOSPURDATA));
					}
					else
					{
						EnableWindow(GETHCTL(IDC_PSPLOT_NOSPURPLOT), FALSE);
						EnableWindow(GETHCTL(IDC_PSPLOT_NOSPURDATA), FALSE);
						sPSPlot.nospur_plot=FALSE;
						sPSPlot.nospur_data=FALSE;
					}

					// Disable spur removal from data if multitaper or averaging or smoothing
					// if( (sPSPlot.win==MULTITAPER_WIN) || ((nAvg>1) && (sPSPlot.win!=MULTITAPER_WIN)) || (sPSPlot.smooth) )
					// Disable spur removal from data if multitaper or smoothing
					// if( (sPSPlot.win==MULTITAPER_WIN) || (sPSPlot.smooth) )
					// Disable spur removal from data if multitaper or auto averaging or smoothing
					if( (sPSPlot.win==MULTITAPER_WIN) || ((nAvg==0) && (sPSPlot.win!=MULTITAPER_WIN)) || (sPSPlot.smooth))
					{
						// Must disable spur removal from data
						sPSPlot.nospur_data=FALSE;
						Button_SetCheck(GETHCTL(IDC_PSPLOT_NOSPURDATA), sPSPlot.nospur_data);
						EnableWindow(GETHCTL(IDC_PSPLOT_NOSPURDATA), FALSE);
					}
				}
				break;

				// Points display flag change
				// Note: The do_errbar flag is used to control the plotting
				// of the data points
				case IDC_PSPLOT_POINTS:
				{
					sPSPlot.do_errbar=
						Button_GetCheck(GETHCTL(IDC_PSPLOT_POINTS));
				}
				break;

				// Read config button
				case IDC_PSPLOT_READ:
				{
					bSave=bUseSpectPlotIni;
					bUseSpectPlotIni=TRUE;
					ReadIni(INI_SPECT);
					bUseSpectPlotIni=bSave;
					SendMessage(hDlg, WM_INITDIALOG, (WPARAM)0, (LPARAM)0);
					bSmooth=sPSPlot.smooth;
					Button_SetCheck(GETHCTL(IDC_PSPLOT_SMOOTH), bSmooth);
					nPPO=sPSPlot.ppo;
				}
				break;

				// Save config button
				case IDC_PSPLOT_WRITE:
				{
					bSave=bUseSpectPlotIni;
					bUseSpectPlotIni=TRUE;
					WriteIni(INI_SPECT);
					bUseSpectPlotIni=bSave;
				}
				break;

				// Respond to options button
				case IDC_PSPLOT_OPTS:
				{
					// Set page # to Options
					nConfigPage=5;
					
					// Open Configure property sheet
					DisplayProperties(hwndMain);
				}
				break;

				// Fit flag change - note that this uses do_line flag
				case IDC_PSPLOT_FIT:
				{
					sPSPlot.do_line=Button_GetCheck(GETHCTL(IDC_PSPLOT_FIT));
				}
				break;

				// Info flag change
				case IDC_PSPLOT_INFO:
				{
					sPSPlot.do_table=Button_GetCheck(GETHCTL(IDC_PSPLOT_INFO));
				}
				break;

				// Remove spurs from plot flag change
				case IDC_PSPLOT_NOSPURPLOT:
				{
					sPSPlot.nospur_plot=Button_GetCheck(GETHCTL(IDC_PSPLOT_NOSPURPLOT));
				}
				break;

				// Remove spurs from data flag change
				case IDC_PSPLOT_NOSPURDATA:
				{
					sPSPlot.nospur_data=Button_GetCheck(GETHCTL(IDC_PSPLOT_NOSPURDATA));

					// If spur removal from data is activated, must use PSD zero padding
					if(sPSPlot.nospur_data)
					{
						// Save previous zero padding flag setting
						bPrevZeroPad=bZeroPad;

						// Set global zero padding flag
						bZeroPad=TRUE;

						// For consistency, also save it in ini file
						_snprintf(szBuffer, sizeof(szBuffer), "%d", bZeroPad);
						WritePrivateProfileString("Preferences",
							"ZeroPad", szBuffer, szIniFile);
					}
					else // No spur removal from data
					{
						// Restore previous zero padding choice
						bZeroPad=bPrevZeroPad;

						// For consistency, also save it in ini file
						_snprintf(szBuffer, sizeof(szBuffer), "%d", bZeroPad);
						WritePrivateProfileString("Preferences",
							"ZeroPad", szBuffer, szIniFile);
					}
				}
				break;

				// Smoothing flag change
				case IDC_PSPLOT_SMOOTH:
				{
					// Get and save state of smooth checkbox
					bSmooth=Button_GetCheck(GETHCTL(IDC_PSPLOT_SMOOTH));
					sPSPlot.smooth=Button_GetCheck(GETHCTL(IDC_PSPLOT_SMOOTH));
					_snprintf(szBuffer, sizeof(szBuffer), "%d", sPSPlot.smooth);
					WritePrivateProfileString("Preferences", "Smooth", szBuffer,
						szIniFile);

					// Make sure FirstAF flag is off
					bFirstAF=FALSE;
					
					// Display PSD parameters
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_PSPLOT_DISPLAY, NULL, 0));

					// Disable spur removal from data if multitaper or averaging or smoothing
					// if( (sPSPlot.win==MULTITAPER_WIN) || ((nAvg>1) && (sPSPlot.win!=MULTITAPER_WIN)) || (sPSPlot.smooth) )
					// Disable spur removal from data if multitaper or smoothing
					// if( (sPSPlot.win==MULTITAPER_WIN) || (sPSPlot.smooth) )
					// Disable spur removal from data if multitaper or auto averaging or smoothing
					if( (sPSPlot.win==MULTITAPER_WIN) || ((nAvg==0) && (sPSPlot.win!=MULTITAPER_WIN)) || (sPSPlot.smooth))
					{
						// Must disable spur removal from data
						sPSPlot.nospur_data=FALSE;
						Button_SetCheck(GETHCTL(IDC_PSPLOT_NOSPURDATA), sPSPlot.nospur_data);
						EnableWindow(GETHCTL(IDC_PSPLOT_NOSPURDATA), FALSE);
					}
					else
					{
						// Can enable spur removal from data if spurs checkbox active
						if(sPSPlot.do_spur)
						{
							EnableWindow(GETHCTL(IDC_PSPLOT_NOSPURDATA), TRUE);
						}
					}
				}
				break;

				// PSD type change:
				case IDC_PSPLOT_PSD:
				{
					// Get PSD type
					sPSPlot.plotype=
						ComboBox_GetCurSel(GETHCTL(IDC_PSPLOT_PSD));

					// Update y label
					// Label depends on both bDataType and nPSDType
					i=(bDataType)*3+sPSPlot.plotype;
					LoadString(hInst, IDS_PSPLOT_YLABEL_0+i, szBuffer,
						BUFFER_SIZE);
					SetWindowText(GETHCTL(IDC_PSPLOT_YLABEL),
						szBuffer);

					// Put message into PSD & scale max & min displays
					SetWindowText(GETHCTL(IDC_PSPLOT_DATAMAX), "Press Plot");
					SetWindowText(GETHCTL(IDC_PSPLOT_DATAMIN), "To Calc");
					SetWindowText(GETHCTL(IDC_PSPLOT_YMAX), "");
					SetWindowText(GETHCTL(IDC_PSPLOT_YMIN), "");
					SetWindowText(GETHCTL(IDC_PSPLOT_YTIC), "");

					// Set # y-axis scale tics to zero as code to calc scale
					sPSPlot.y_tic=0;
					
					// Redisplay carrier freq value
					// Applies to S(f) & L(f) phase data
					if( (sPSPlot.plotype==1) || (sPSPlot.plotype==2) )
					{
						_snprintf(szBuffer, sizeof(szBuffer), "%10.7e",
							sPSPlot.carrier);
					}
					else
					{
						LoadString(hInst, IDS_MESSAGE_NA, szBuffer,
							BUFFER_SIZE);
					}
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_PSPLOT_CARRIER),
						szBuffer);

					// Put ENBW & NB correction into message box
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDC_PSPLOT_ENBW,
						NULL, 0));
				}
				break;

				// Windowing type change:
				case IDC_PSPLOT_WIN:
				{
					// Reset plot scale
					sPSPlot.y_tic=0;

					// Get windowing type
					sPSPlot.win=ComboBox_GetCurSel(GETHCTL(IDC_PSPLOT_WIN));

					// Fill # windows or # windowings list box
					if(sPSPlot.win==MULTITAPER_WIN)
					{
						// Set label for # windows control
						SetWindowText(GETHCTL(IDC_PSPLOT_WINS), "# Wi&ndows:");

						// Fill up # windows type list box
						// nWin varies in steps of 1 from 1-3 thru 1-9
						// depending on fPi.  Maximum nWin is (fPi*2)-1
						nDummy=ComboBox_ResetContent(GETHCTL(IDC_PSPLOT_NUM));
						for(i=1; i<(int)(fPi*2); i++)
						{
							_snprintf(szBuffer, sizeof(szBuffer), "%d", i);
							nDummy=
								ComboBox_InsertString(GETHCTL(IDC_PSPLOT_NUM),
								i-1, szBuffer);
						}

						// Set fPi to 3.0 (nominal)
						fPi=3.0;

						// Set nWin to largest allowable
						nWin=(int)((fPi*2)-1);
						
						// Show # windows
						nDummy=ComboBox_SetCurSel(GETHCTL(IDC_PSPLOT_NUM),
							nWin-1);

						// Show std dev %
						_snprintf(szBuffer, sizeof(szBuffer), "%1.1f",
							100.0/sqrt(nWin));
						SetWindowText(GETHCTL(IDC_PSPLOT_VARIANCE),	szBuffer);
					}
					else if(sPSPlot.win==RECTANGULAR_WIN) // None
					{
						// Set label for # windowings control
						SetWindowText(GETHCTL(IDC_PSPLOT_WINS),
							"# Wi&ndowings:");

						// Put zero only into # windowings type list box
						nDummy=ComboBox_ResetContent(GETHCTL(IDC_PSPLOT_NUM));
						nDummy=ComboBox_InsertString(GETHCTL(IDC_PSPLOT_NUM),
								0, "0");

						// Set # windowings to zero
						sPSPlot.num=0;

						// Show # windowings
						nDummy=ComboBox_SetCurSel(GETHCTL(IDC_PSPLOT_NUM),
							sPSPlot.num);
					}
					else // Windowed periodogram
					{
						// Set label for # windowings control
						SetWindowText(GETHCTL(IDC_PSPLOT_WINS),
							"# Wi&ndowings:");

						// Fill up # windowings type list box
						nDummy=ComboBox_ResetContent(GETHCTL(IDC_PSPLOT_NUM));
						for(i=0; i<4; i++)
						{
							_snprintf(szBuffer, sizeof(szBuffer), "%d", i);
							nDummy=
								ComboBox_InsertString(GETHCTL(IDC_PSPLOT_NUM),
								i, szBuffer);
						}

						// Set # windowings to one
						sPSPlot.num=1;

						// Show # windowings
						nDummy=ComboBox_SetCurSel(GETHCTL(IDC_PSPLOT_NUM),
							sPSPlot.num);

						// Get # averages
						// Works OK for "Auto" - nAvg gets set to 0
						GetWindowText(GETHCTL(IDC_PSPLOT_AVERAGE),
							(LPSTR)szBuffer, BUFFER_SIZE);
						nAvg=abs(atoi(szBuffer));

						if(nAvg)
						{
							// Show std dev %
							_snprintf(szBuffer, sizeof(szBuffer), "%1.1f",
								100.0/sqrt(nAvg));
							SetWindowText(GETHCTL(IDC_PSPLOT_VARIANCE),
								szBuffer);
						}
						else // nAvg==0
						{
							// Show std dev % = "Auto"
							SetWindowText(GETHCTL(IDC_PSPLOT_VARIANCE),
								"Auto");
						}
					}

					// Fill up BW or Avg factor list box 
					if(sPSPlot.win==MULTITAPER_WIN)
					{
						// Set label for BW factor control
						SetWindowText(GETHCTL(IDC_PSPLOT_FACTOR),
							"BW (&J) Factor:");

						// Fill up BW factor list box
						// Seven choices from 2.0 to 5.0 in steps of 0.5
						nDummy=
							ComboBox_ResetContent(GETHCTL(IDC_PSPLOT_AVERAGE));
						for(i=0; i<7; i++)
						{
							_snprintf(szBuffer, sizeof(szBuffer), "%2.1f",
								(i*0.5)+2.0);
							nDummy=ComboBox_InsertString(GETHCTL(
								IDC_PSPLOT_AVERAGE), i, szBuffer);
						}

						// Show default bandwidth selection
						nDummy=ComboBox_SetCurSel(GETHCTL(IDC_PSPLOT_AVERAGE),
							(int)((fPi*2)-4.0));
					}
					else // Periodogram
					{
						// Set label for avg factor control
						SetWindowText(GETHCTL(IDC_PSPLOT_FACTOR),
							"Avg Factor (&4):");

						// Fill up avg factor combo box
						// Contents calculated as power-of-2 ints
						// up to # points/16
						nData=(int)(fData[2]-fData[1]+1);
						nDummy=
							ComboBox_ResetContent(GETHCTL(IDC_PSPLOT_AVERAGE));

						// Put Auto into 1st position of AVERAGE list box
						nDummy=
							ComboBox_InsertString(GETHCTL(IDC_PSPLOT_AVERAGE),
								0, "Auto");

						// Fill combo box
						i=0;
						while(pow(2.0, (double)i)<(double)(nData/16))
						{
							_snprintf(szBuffer, sizeof(szBuffer), "%1.0f",
								pow(2.0, (double)i));
							nDummy=ComboBox_InsertString(GETHCTL(
								IDC_PSPLOT_AVERAGE), i+1, szBuffer);
							i++;
						}

						// Show default average selection (AF=1)
						nDummy=ComboBox_SetCurSel(GETHCTL(IDC_PSPLOT_AVERAGE)
							, 1);

						// Set AF to default
						nAvg=1;
					}

					// Enable Smooth checkbox unless Auto AF periodogram
					if((sPSPlot.win==MULTITAPER_WIN) || (nAvg))
					{
						EnableWindow(GETHCTL(IDC_PSPLOT_SMOOTH), TRUE);
					}
					else
					{
						EnableWindow(GETHCTL(IDC_PSPLOT_SMOOTH), FALSE);
					}

					// Display PSD parameters
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_PSPLOT_DISPLAY, NULL, 0));

					// Disable spur removal from data if multitaper or averaging or smoothing
					// if( (sPSPlot.win==MULTITAPER_WIN) || ((nAvg>1) && (sPSPlot.win!=MULTITAPER_WIN)) || (sPSPlot.smooth) )
					// Disable spur removal from data if multitaper or smoothing
					// if( (sPSPlot.win==MULTITAPER_WIN) || (sPSPlot.smooth) )
					// Disable spur removal from data if multitaper or auto averaging or smoothing
					if( (sPSPlot.win==MULTITAPER_WIN) || ((nAvg==0) && (sPSPlot.win!=MULTITAPER_WIN)) || (sPSPlot.smooth))
					{
						// Must disable spur removal from data
						sPSPlot.nospur_data=FALSE;
						Button_SetCheck(GETHCTL(IDC_PSPLOT_NOSPURDATA), sPSPlot.nospur_data);
						EnableWindow(GETHCTL(IDC_PSPLOT_NOSPURDATA), FALSE);
					}
					else
					{
						// Can enable spur removal from data if spurs checkbox active
						if(sPSPlot.do_spur)
						{
							EnableWindow(GETHCTL(IDC_PSPLOT_NOSPURDATA), TRUE);
						}
					}
				}
				break;

				// Averaging factor change:
				case IDC_PSPLOT_AVERAGE:
				{
					if((GET_WM_COMMAND_CMD(wParam, lParam)==CBN_SELCHANGE))
					{
						// Reset plot scale
						sPSPlot.y_tic=0;

						if(sPSPlot.win==MULTITAPER_WIN)
						{
							// Get BW factor
							GetWindowText(GETHCTL(IDC_PSPLOT_AVERAGE),
								(LPSTR)szBuffer, BUFFER_SIZE);
							fPi=(float)fabs(atof(szBuffer));

							// Update # windows choices
							// nWin varies in steps of 1 from 1-3 thru 1-9
							// depending on fPi.  Maximum nWin is (fPi*2)-1
							nDummy=
								ComboBox_ResetContent(GETHCTL(IDC_PSPLOT_NUM));

							for(i=1; i<(int)(fPi*2); i++)
							{
								_snprintf(szBuffer, sizeof(szBuffer), "%d", i);
								nDummy=ComboBox_InsertString(GETHCTL(
									IDC_PSPLOT_NUM), i-1, szBuffer);
							}

							// Set nWin to largest allowable
							nWin=(int)((fPi*2)-1);

							// Show # windows
							nDummy=ComboBox_SetCurSel(GETHCTL(IDC_PSPLOT_NUM),
								nWin-1);

							// Show std dev %
							_snprintf(szBuffer, sizeof(szBuffer), "%1.1f",
								100.0/sqrt(nWin));
							SetWindowText(GETHCTL(IDC_PSPLOT_VARIANCE),
								szBuffer);
						}
						else // Periodogram
						{
							// Get # averages
							GetWindowText(GETHCTL(IDC_PSPLOT_AVERAGE),
								(LPSTR)szBuffer, BUFFER_SIZE);
							nAvg=abs(atoi(szBuffer));

							// Put # averages into plot structure
							sPSPlot.af=nAvg;

							// Show std dev %
							if(nAvg)
							{
								_snprintf(szBuffer, sizeof(szBuffer), "%1.1f",
									100.0/sqrt(nAvg));
								SetWindowText(GETHCTL(IDC_PSPLOT_VARIANCE),
									szBuffer);
							}
							else // nAvg==0
							{
								SetWindowText(GETHCTL(IDC_PSPLOT_VARIANCE),
									"Auto");
							}
						}

						// Set # FFT points
						if(bZeroPad)
						{
							// Set # FFT points (inc zero padding)
							// to next higher power-of-2)
							sPSPlot.nfft=(int)pow(2.0,
								(double)ceil(log(nData)/log(2)));
						}
						else // No zero padding
						{
							// Set # FFT points to next lower power-of-2
							sPSPlot.nfft=(int)pow(2.0,
								(double)floor(log(nData)/log(2)));
						}

						// Enable Smooth checkbox unless Auto AF periodogram
						if((sPSPlot.win==MULTITAPER_WIN) || (nAvg))
						{
							EnableWindow(GETHCTL(IDC_PSPLOT_SMOOTH), TRUE);
						}
						else
						{
							EnableWindow(GETHCTL(IDC_PSPLOT_SMOOTH), FALSE);
						}

						// Display PSD parameters
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
							IDC_PSPLOT_DISPLAY, NULL, 0));

						// Disable spur removal from data if multitaper or averaging or smoothing
						// if( (sPSPlot.win==MULTITAPER_WIN) || ((nAvg!=1) && (sPSPlot.win!=MULTITAPER_WIN)) || (sPSPlot.smooth) )
						// Disable spur removal from data if multitaper or smoothing
						// if( (sPSPlot.win==MULTITAPER_WIN) || (sPSPlot.smooth) )
						// Disable spur removal from data if multitaper or auto averaging or smoothing
						if( (sPSPlot.win==MULTITAPER_WIN) || ((nAvg==0) && (sPSPlot.win!=MULTITAPER_WIN)) || (sPSPlot.smooth))
						{
							// Must disable spur removal from data
							sPSPlot.nospur_data=FALSE;
							Button_SetCheck(GETHCTL(IDC_PSPLOT_NOSPURDATA), sPSPlot.nospur_data);
							EnableWindow(GETHCTL(IDC_PSPLOT_NOSPURDATA), FALSE);
						}
						else
						{
							// Can enable spur removal from data if spurs checkbox active
							if(sPSPlot.do_spur)
							{
								EnableWindow(GETHCTL(IDC_PSPLOT_NOSPURDATA), TRUE);
							}
						}
					}
				}
				break;

				// # Windowings change:
				case IDC_PSPLOT_NUM:
				{
					// Reset plot scale
					sPSPlot.y_tic=0;

					if(sPSPlot.win==MULTITAPER_WIN)
					{
						// Get # windows
						nWin=1+ComboBox_GetCurSel(GETHCTL(IDC_PSPLOT_NUM));

						// Show std dev %
						_snprintf(szBuffer, sizeof(szBuffer), "%1.1f",
							100.0/sqrt(nWin));
						SetWindowText(GETHCTL(IDC_PSPLOT_VARIANCE),
							szBuffer);
					}
					else
					{
						// Get # windowings
						sPSPlot.num=
							ComboBox_GetCurSel(GETHCTL(IDC_PSPLOT_NUM));
					}

					// Put ENBW & NB correction into message box
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDC_PSPLOT_ENBW,
						NULL, 0));
				}
				break;

				// Carrier freq change:
				case IDC_PSPLOT_CARRIER:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_PSPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get carrier freq
						GetWindowText(GETHCTL(IDC_PSPLOT_CARRIER),
							(LPSTR)szBuffer, BUFFER_SIZE);
						sPSPlot.carrier=(float)fabs(atof(szBuffer));

						// Redisplay carrier freq value
						// Applies to S(f) & L(f) phase data
						if( (sPSPlot.plotype==1) || (sPSPlot.plotype==2) )
						{
							_snprintf(szBuffer, sizeof(szBuffer), "%10.7e",
								sPSPlot.carrier);
						}
						else
						{
							LoadString(hInst, IDS_MESSAGE_NA, szBuffer,
								BUFFER_SIZE);
						}
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_PSPLOT_CARRIER),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Scale max change:
				case IDC_PSPLOT_YMAX:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_PSPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get max PSD scale entry
						GetWindowText(GETHCTL(IDC_PSPLOT_YMAX),
							(LPSTR)szBuffer, BUFFER_SIZE);
						fYMax=(float)atof(szBuffer);

						// Redisplay max PSD value
						_snprintf(szBuffer, sizeof(szBuffer), "%4.2f", fYMax);
						SetWindowText(GETHCTL(IDC_PSPLOT_YMAX),
							szBuffer);

						// Put y-axis scale max into plot struct
						sPSPlot.y_max=fYMax;
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Scale min change:
				case IDC_PSPLOT_YMIN:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_PSPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get min PSD scale entry
						GetWindowText(GETHCTL(IDC_PSPLOT_YMIN),
							(LPSTR)szBuffer, BUFFER_SIZE);
						fYMin=(float)atof(szBuffer);

						// Redisplay min PSD value
						_snprintf(szBuffer, sizeof(szBuffer), "%4.2f", fYMin);
						SetWindowText(GETHCTL(IDC_PSPLOT_YMIN),
							szBuffer);

						// Put y-axis scale min into plot struct
						sPSPlot.y_min=fYMin;
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Scale # tics change:
				case IDC_PSPLOT_YTIC:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_PSPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get # y-axis tics entry
						GetWindowText(GETHCTL(IDC_PSPLOT_YTIC),
							(LPSTR)szBuffer, BUFFER_SIZE);
						nYTic=abs(atoi(szBuffer));

						// Redisplay # tics value
						_snprintf(szBuffer, sizeof(szBuffer), "%d", nYTic);
						SetWindowText(GETHCTL(IDC_PSPLOT_YTIC),
							szBuffer);

						// Put y-axis scale # tics into plot struct
						sPSPlot.y_tic=nYTic;
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Respond to CR in an edit control
				// Note: No button is a DEFPUSHBUTTON
				case IDOK:
				{
					// The HWND returned by GetFocus() is not the same as the
					// one returned by GetDlgItem(), so the uTitle, etc
					// variables are used in these tests
					if((UINT)GetFocus()==uTitle)
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_PSPLOT_TITLE, NULL, CBN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to SUBTITLE edit control
					if((UINT)GetFocus()==uSubtitle)
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_PSPLOT_SUBTITLE, NULL, CBN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to MESSAGE edit control
					if((UINT)GetFocus()==uMessage)
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_PSPLOT_MESSAGE, NULL, CBN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to FILENAME edit control
					if(GetFocus()==GETHCTL(IDC_PSPLOT_FILENAME))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_PSPLOT_FILENAME, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to PSDFILE edit control
					if(GetFocus()==GETHCTL(IDC_PSPLOT_PSDFILE))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_PSPLOT_PSDFILE, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to CARRIER edit control
					if(GetFocus()==GETHCTL(IDC_PSPLOT_CARRIER))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_PSPLOT_CARRIER, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to YMAX edit control
					if(GetFocus()==GETHCTL(IDC_PSPLOT_YMAX))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_PSPLOT_YMAX, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to YMIN edit control
					if(GetFocus()==GETHCTL(IDC_PSPLOT_YMIN))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_PSPLOT_YMIN, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to YTIC edit control
					if(GetFocus()==GETHCTL(IDC_PSPLOT_YTIC))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_PSPLOT_YTIC, NULL, EN_KILLFOCUS));
					}
				}
				break;

				// Subroutine to display PSD parameters
				case IDC_PSPLOT_DISPLAY:
				{
					// Get # analysis points
					nData=(int)(fData[2]-fData[1]+1);

					// Set # FFT points
					if(bZeroPad)
					{
						// Set # FFT points (inc zero padding
						// to next higher power-of-2)
						sPSPlot.nfft=(int)pow(2.0,
							(double)ceil(log(nData)/log(2)));
					}
					else // No zero padding
					{
						// Set # FFT points (inc zero padding
						// to next lower power-of-2)
						sPSPlot.nfft=(int)pow(2.0,
							(double)floor(log(nData)/log(2)));
					}

					if(nAvg)
					{
						if(bSmooth)
						// PSD smoothing uses a fixed # of points per octave
						// It starts at the high freq end with an AF to produce
						// that many points in the top octave
						// Then the AF is successively halved to produce that
						// many points at decreasing octaves until the last
						// AF=1 octave, at whicvh low freq point the smoothed
						// PSD data stops
						{
							// Note: Symbols in this note not actual variables
							// # original zero padded data points is nFFT 
							// # original PSD points is nPSD = nFFT/2
							// # points/octave is nPPO = 64 (default)
							// # octaves in smoothed PSD data is nOCT
							// nOCT = log2(nPSD) - log2(nPPO)
							// # smoothed PSD points is nPPO * nOCT
							// So, given nFFT and nPPO,
							// we can find smoothed nPSD
							// Smoothed nPSD = nPPO * (log2(nFFT/2)-log2(nPPO))
							// log2(n)=log10(n)/log10(2)
							// Smoothed nPSD =
							// nPPO*((log10(nFFT/2)/log10(2))-
							// (log10(nPPO)/log10(2)))
							// This expression works correctly
							// To use, should round and convert to int
							// Note:  The above does not consider AF
							// Must divide original zero padded nFFT by nAvg
							// to include that
							// Then there's the matter of the max AF for
							// smoothed fixed AF
							// The net max AF is basic AF times max smoothing
							// factor
							// The smoothing factor is 2^(nOCT-1) =
							// 2^(log2(nPSD) - log2(nPPO) -1)
							// or pow(2.0, log2(nFFT/2*nAvg) - log2(64) -1)
							// or pow(2.0,
							// (log10(sPSPlot.nfft/(2*nAvg))/log10(2)) -
							// log10(64)/log10(2)) -1)

							// Show std dev %
							SetWindowText(GETHCTL(IDC_PSPLOT_VARIANCE),
								"Variable");

							// Show the # of FFT points
							if(sPSPlot.win==MULTITAPER_WIN)
							{
								_snprintf(szBuffer, sizeof(szBuffer), "%d",
									sPSPlot.nfft);
							}
							else // Periodogram
							{
								// The # FFT points is independent of af
								// It is simply the # of zero-padded
								// phase or frequency data points
								// used to calculate the FFT
								_snprintf(szBuffer, sizeof(szBuffer), "%d",
									sPSPlot.nfft);
							}
							SetWindowText(GETHCTL(IDC_PSPLOT_NFFT), szBuffer);

							// Show the # of PSD points
							if(sPSPlot.win==MULTITAPER_WIN)
							{
								// Note: Divide nFFT by 1
								// instead of 2*nAvg for periodogram
								_snprintf(szBuffer, sizeof(szBuffer), "%d",
									(int)((nPPO*((log10(sPSPlot.nfft/(1))/
									log10(2))-(log10(nPPO)/log10(2))))+0.5));
							}
							else // Periodogram
							{
								_snprintf(szBuffer, sizeof(szBuffer), "%d",
									(int)((nPPO*((log10(sPSPlot.nfft/(2*nAvg))/
									log10(2))-(log10(nPPO)/log10(2))))+0.5));
							}
							SetWindowText(GETHCTL(IDC_PSPLOT_NPSD), szBuffer);

							// Display the Fourier interval
							if(sPSPlot.win==MULTITAPER_WIN)
							{
								// Fourier Interval (Hz) = fBin =
								// nAvg/(2*nFFT*fTau)
								// But we ignore the variation with AF
								// Note factor of 2 compared with periodogram
								fBin=nAvg/(2*sPSPlot.nfft*fTau);
								_snprintf(szBuffer, sizeof(szBuffer), "%8.4e",
									fBin);
								ShortenExp(szBuffer);
							}
							else // Periodogram
							{
								// Fourier Interval (Hz) =
								// fBin = nAvg/(nFFT*fTau)
								// But we ignore the variation with AF
								fBin=nAvg/(sPSPlot.nfft*fTau);
								_snprintf(szBuffer, sizeof(szBuffer), "%8.4e",
									fBin);
								ShortenExp(szBuffer);
							}
							SetWindowText(GETHCTL(IDC_PSPLOT_FBIN), szBuffer);
							
							// Display Max AF
							if(sPSPlot.win==MULTITAPER_WIN)
							{
								// Note: Divide nFFT by 1
								// instead of 2*nAvg for periodogram
								_snprintf(szBuffer, sizeof(szBuffer), "%d",
									nAvg*(int)(pow(2.0,
									((int)((log10(sPSPlot.nfft/(1))/log10(2))
									-(log10(nPPO)/log10(2))-1+0.5)))));
							}
							else // Periodogram
							{
								_snprintf(szBuffer, sizeof(szBuffer), "%d",
									1*(int)(pow(2.0,
									((int)((log10(sPSPlot.nfft/
									(2*nAvg))/log10(2))
									-(log10(nPPO)/log10(2))-1+0.5)))));
							}
							SetWindowText(GETHCTL(IDC_PSPLOT_MAXAF), szBuffer);
							
							// Added 08/20/07
							// Set no smoothing and Max AF=1 when program starts
							if(bFirstAF)
							{
								SetWindowText(GETHCTL(IDC_PSPLOT_MAXAF), "1");
								bSmooth=FALSE;
								bFirstAF=FALSE;
							}
						}
						else // Unsmoothed
						{
							// Show std dev %
							_snprintf(szBuffer, sizeof(szBuffer), "%1.1f",
								100.0/sqrt(nAvg));
							SetWindowText(GETHCTL(IDC_PSPLOT_VARIANCE),
								szBuffer);

							// Show the # of FFT points
							if(sPSPlot.win==MULTITAPER_WIN)
							{
								_snprintf(szBuffer, sizeof(szBuffer), "%d",
									sPSPlot.nfft);
							}
							else // Periodogram
							{
								// The # FFT points is independent of af
								// It is simply the # of zero-padded
								// phase or frequency data points
								// used to calculate the FFT
								_snprintf(szBuffer, sizeof(szBuffer), "%d",
									sPSPlot.nfft);
							}
							SetWindowText(GETHCTL(IDC_PSPLOT_NFFT), szBuffer);

							// Show the # of PSD points
							if(sPSPlot.win==MULTITAPER_WIN)
							{
								// Note: nFFT not half nFFT
								_snprintf(szBuffer, sizeof(szBuffer), "%d",
									sPSPlot.nfft);
							}
							else // Periodogram
							{
								_snprintf(szBuffer, sizeof(szBuffer), "%d",
									sPSPlot.nfft/(2*nAvg));
							}
							SetWindowText(GETHCTL(IDC_PSPLOT_NPSD), szBuffer);

							// Display the Fourier interval
							if(sPSPlot.win==MULTITAPER_WIN)
							{
								// Fourier Interval (Hz) = fBin =
								// nAvg/(2*nFFT*fTau)
								// But we ignore the variation with AF
								// Note factor of 2 compared with periodogram
								fBin=nAvg/(2*sPSPlot.nfft*fTau);
								_snprintf(szBuffer, sizeof(szBuffer),
									"%8.4e", fBin);
								ShortenExp(szBuffer);
							}
							else // Periodogram
							{
								// Fourier Interval (Hz) = fBin =
								// nAvg/(nFFT*fTau)
								// But we ignore the variation with AF
								fBin=nAvg/(sPSPlot.nfft*fTau);
								_snprintf(szBuffer, sizeof(szBuffer),
									"%8.4e", fBin);
								ShortenExp(szBuffer);
							}
							SetWindowText(GETHCTL(IDC_PSPLOT_FBIN), szBuffer);
							
							// Display Max AF
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nAvg);
							SetWindowText(GETHCTL(IDC_PSPLOT_MAXAF), szBuffer);
						}
					}
					else // nAvg==0 (Auto AF)
					{
						// Auto AF produces PSD data that starts
						// at AF=1+PSDLFSkip
						// It has one PSD data point at each AF up to Max AF
						// and as many AF=Max AF points as the data size allows
						// The procedure starts at the low freq end, skipping
						// PSDLFSkip points, and produces one PSD point
						// at each successive octave AF up to Max AF
						// set by the PSDAvgSize or PSDAvgMax parameters
						// It is good for observing the LF end with the most
						// averaging possible
						// It cannot be smoothed

						// Turn off smoothing
						bSmooth=FALSE;
						Button_SetCheck(GETHCTL(IDC_PSPLOT_SMOOTH), bSmooth);

						// This test not necessary
						if(bSmooth)
						{
							// This message should never be displayed	
							TRACE_STR("Auto AF, Smoothed Not Allowed");
						}
						else // Unsmoothed
						{
							// Calc max af for Auto AF
							i=(int)pow(2.0,
								(double)(ceil(log(sPSPlot.nfft)/log(2))));
							_snprintf(szBuffer, sizeof(szBuffer), "%d",
								min(i/nPSDAvgSize, nPSDAvgMax));
							nMaxAF=min(i/nPSDAvgSize, nPSDAvgMax);

							// Calc # PSD points for Auto AF
							a=0; // # data points used for psd points
							     //below max af
							b=0; // # psd points below max af
							for(i=nPSDLFSkip+1; i<nMaxAF; i*=2)
							{
								a+=2*i;
								b++;
							}
							// # Auto AF PSD points
							c=b+(sPSPlot.nfft-a)/(2*nMaxAF); 
							
							// Show std dev %
							SetWindowText(GETHCTL(IDC_PSPLOT_VARIANCE),
								"Auto");

							// Show the # of FFT points
							if(sPSPlot.win==MULTITAPER_WIN)
							{
								// This case doesn't actually exist
								// AF set to 1 for multitaper 
								TRACE_STR("Auto AF, Multitaper Not Allowed");
							}
							else // Periodogram
							{
								_snprintf(szBuffer, sizeof(szBuffer), "%d",
									sPSPlot.nfft);
							}
							SetWindowText(GETHCTL(IDC_PSPLOT_NFFT), szBuffer);

							// Show the # of PSD points
							if(sPSPlot.win==MULTITAPER_WIN)
							{
								_snprintf(szBuffer, sizeof(szBuffer), "%d",
									sPSPlot.nfft/2);
							}
							else // Periodogram
							{
								_snprintf(szBuffer, sizeof(szBuffer), "%d", c);

								if(!bZeroPad)
								{
									// Auto AF w/o zero padding
									_snprintf(szBuffer, sizeof(szBuffer), "Variable");
								}
							}
							SetWindowText(GETHCTL(IDC_PSPLOT_NPSD), szBuffer);

							// Display the Fourier interval
							// Fourier Interval (Hz) = fBin = 1/(nFFT*fTau)
							fBin=1.0/(sPSPlot.nfft*fTau);
							_snprintf(szBuffer, sizeof(szBuffer),
								"%8.4e", fBin);
							ShortenExp(szBuffer);

							if(!bZeroPad)
							{
								// Auto AF w/o zero padding
								_snprintf(szBuffer, sizeof(szBuffer), "Variable");
							}

							SetWindowText(GETHCTL(IDC_PSPLOT_FBIN), szBuffer);

								// Display Max AF
							i=(int)pow(2.0,
								(double)(ceil(log(sPSPlot.nfft)/log(2))));
							_snprintf(szBuffer, sizeof(szBuffer), "%d",
								min(i/nPSDAvgSize, nPSDAvgMax));
							SetWindowText(GETHCTL(IDC_PSPLOT_MAXAF), szBuffer);
						}
					}

					// Display the max Fourier freq
					// Max Fourier Freq (Hz) = fMax = 1/(2*fTau));
					fMax=1.0/(2.0*fTau);
					_snprintf(szBuffer, sizeof(szBuffer), "%8.4e", fMax);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_PSPLOT_FMAX), szBuffer);

					// Put ENBW (Hz) into message box
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDC_PSPLOT_ENBW,
						NULL, 0));
				}
				break;

				// Subroutine to compose & display ENBW message
				case IDC_PSPLOT_ENBW:
				{
					// If nAvg=0, need to clear ENBW info because it varies
					if(nAvg==0)
					{
						// Erase any existing ENBW string
						i=ComboBox_FindString(GETHCTL(IDC_PSPLOT_MESSAGE), -1,
							"ENBW (Hz) =");
						nDummy=
							ComboBox_DeleteString(GETHCTL(IDC_PSPLOT_MESSAGE), i);
						break;
					}

					// Note: Latest ENBW is put into message box list but not
					// displayed on plot unless it is selected
					// This reduces clutter when it isn't needed, and allows
					// another user-entered message to be displayed normally

					// Put ENBW (Hz) into message box
					// It is product of Fourier freq resolution (Hz/bin)
					// from IDC_PSPLOT_FBIN
					// and ENBW (bins) from enbw[][] for selected
					// window type and number
					// This applies to all except multitaper method
					if(sPSPlot.win!=MULTITAPER_WIN)
					{
						GetWindowText(GETHCTL(IDC_PSPLOT_FBIN), szBuffer,
							sizeof(szBuffer));
						fENBW=(float)atof(szBuffer);
						fENBW*=enbw[sPSPlot.win][sPSPlot.num];
					}

					#if(0) // Obsolete
					// 05/17/08
					// ENBW wasn't working for multitaper case
					// because there was no enbw[][] array row for it
					// That was added, with nominal values of 1.0
					// Apparently the multitaper BW is given by 2*J/N*t
					// where J is fPi and 1/2*N*t is Fourier interval
					// Fourier Interval (Hz) = fBin =
					// nAvg/(2*nFFT*fTau)
					// But we ignore the variation with AF
					// Note factor of 2 compared with periodogram
					// So, for multitaper case
					// we need to multiply the ENBW by 4*fPi
					// THIS APPLIES TO MAX # WINDOWS ONLY
					if(sPSPlot.win==MULTITAPER_WIN)
					{
						fENBW*=4*fPi;
					}
					#endif

					// 05/18/08
					// The above multitaper ENBW estimate
					// applies only to the case of the maximum # of windows
					// 2*J-1 for the particular BW factor J
					// More info re multitaper BW is given in the paper:
					// A.T Walden, Ej> McCoy and D.B. Percival,
					// "The Effective Bandwidth of a Multitaper Spectral Estimator",
					// Biometrika, Vol. 82, No. 1, pp. 201-214, 1995.
					// Fig. 5 therein gives a plot of effective bandwidth versus
					// the # of tapers, which is nearly independent of J
					// This led me to devise an approximation formula
					// for the BW = (1 + #) / (N * tau)
					// where BW is the ENBW in Hz, # is the # of windows
					// N is the number of data points
					// and tau is the sampling interval
					// The ENBW goes into fEBBW, # comes from nWin
					// and N comes from sPSPlot.nfft, and tau comes from fTau
					// Note: This code superseeds that above, but it left in
					// for now for test purposes
					if(sPSPlot.win==MULTITAPER_WIN)
					{
						 // TRACE_INT(nWin);
						 // TRACE_INT(sPSPlot.nfft);
						 // TRACE_EXP(fTau);
						fENBW=(float)((1.0+nWin)/(sPSPlot.nfft*fTau));
						// TRACE_EXP(fENBW); // From my approximation formula
					}

					if((fENBW>0.1)&&(fENBW<10.0)) // Use decimal format
					{
						if(sPSPlot.plotype==2) // L(f)
						{
							_snprintf(szBuffer, sizeof(szBuffer),
								"ENBW (Hz) = %1.3f, NB Corr = %1.2f dB",
								fENBW, 10*log10(fENBW));
						}
						else // Sx(f), So(f), or Sy(f)
						{
							_snprintf(szBuffer, sizeof(szBuffer),
								"ENBW (Hz) = %1.3f, Log NB Corr = %1.2f",
								fENBW, log10(fENBW));
						}
					}
					else // Use exponential format
					{
						if(sPSPlot.plotype==2) // L(f)
						{
							_snprintf(szBuffer, sizeof(szBuffer),
								"ENBW (Hz) = %1.3e, NB Corr = %1.2f dB",
								fENBW, 10*log10(fENBW));
						}
						else // Sx(f), So(f), or Sy(f)
						{
							_snprintf(szBuffer, sizeof(szBuffer),
								"ENBW (Hz) = %1.3e, Log NB Corr = %1.2f",
								fENBW, log10(fENBW));
						}
						ShortenExp(szBuffer);
					}

					// Read currently selected message in edit box
					GetWindowText(GETHCTL(IDC_PSPLOT_MESSAGE), szTemp,
						12);

					// Check it for ENBW message
					if((strcmp(szTemp, "ENBW (Hz) ="))==0)
					{
						bENBW=TRUE;
					}
					else // Not an ENBW message
					{
						bENBW=FALSE;
					}
					
					// Erase any existing ENBW string
					i=ComboBox_FindString(GETHCTL(IDC_PSPLOT_MESSAGE), -1,
						"ENBW (Hz) =");
					nDummy=
						ComboBox_DeleteString(GETHCTL(IDC_PSPLOT_MESSAGE), i);

					// Store new ENBW in message box
					nDummy=
						ComboBox_InsertString(GETHCTL(IDC_PSPLOT_MESSAGE), -1,
						szBuffer);

					// Update ENBW message if it was selected
					if(bENBW)
					{
						// Update message
						i=ComboBox_FindString(GETHCTL(IDC_PSPLOT_MESSAGE), -1,
						"ENBW (Hz) =");
						nDummy=
							ComboBox_SetCurSel(GETHCTL(IDC_PSPLOT_MESSAGE),
							i);
						GetWindowText(GETHCTL(IDC_PSPLOT_MESSAGE), sPSPlot.message_str,
							sizeof(szBuffer));
					}

					// New code 05/14/08
					// Put NB Corr into PSD spur struct
					sSpur.corr=(float)log10(fENBW);
				}
				break;

				// Respond to plot button
				case IDC_PSPLOT_PLOT:
				{
					// Put # averages into plot structure
					sPSPlot.af=nAvg;
					
					// Put window type annotation into right_y_label string
					if(sPSPlot.num>0)
					{
						if(nAvg)
						{
							_snprintf(sPSPlot.right_y_label, YLABELSIZE,
								"Avg Factor:%d, ",nAvg);
						}
						else // nAvg=0 is flag for auto af
						{
							_snprintf(sPSPlot.right_y_label, YLABELSIZE,
								"Avg Factor:Auto, ");
						}
						_snprintf(szBuffer, YLABELSIZE,"Window:%d ",
							sPSPlot.num);
						strlcat(sPSPlot.right_y_label, szBuffer, YLABELSIZE);
						LoadString(hInst, IDS_WINTYPE_0+sPSPlot.win, szBuffer,
								BUFFER_SIZE);
						strlcat(sPSPlot.right_y_label, szBuffer, YLABELSIZE);
					}
					else
					{
						if(nAvg)
						{
							_snprintf(sPSPlot.right_y_label, YLABELSIZE,
								"Avg Factor:%d, ",nAvg);
						}
						else // nAvg=0 is flag for auto af
						{
							_snprintf(sPSPlot.right_y_label, YLABELSIZE,
								"Avg Factor:Auto, ");
						}
						_snprintf(szBuffer, sizeof(szBuffer), "Window: None ");
						strlcat(sPSPlot.right_y_label, szBuffer, YLABELSIZE);
					}

					// Special case for multitaper PSD plot
					if(sPSPlot.win==MULTITAPER_WIN)
					{
						_snprintf(sPSPlot.right_y_label, YLABELSIZE,
							"Multitaper: J=%2.1f, @#=%d", fPi, nWin);
					}

					// Also show carrier freq for S(f) & L(f) phase data
					if(bDataType==PHASE_DATA && sPSPlot.plotype!=0)
					{
						_snprintf(szBuffer, sizeof(szBuffer),
							", Carrier Freq=%-6.3e",
							sPSPlot.carrier);
						strlcat(sPSPlot.right_y_label, szBuffer, YLABELSIZE);
					}

					ShortenExp(sPSPlot.right_y_label);

					// Set correction factor
					switch(sPSPlot.plotype)
					{
						case 0: // Sx(f)
						{
							fCF=1.0;
						}
						break;

						case 1: // So(f)
						{
							fCF=(float)
								(2*PI*sPSPlot.carrier*2*PI*sPSPlot.carrier);
						}
						break;

						case 2: // L(f)
						{
							fCF=(float)
								(PI*sPSPlot.carrier*2*PI*sPSPlot.carrier);
						}
						break;

						case 3: // Sy(f)
						{
							fCF=1.0;
						}
						break;
					}

					// Set line thickness
					if(sPSPlot.do_wide)
					{
						sPSPlot.thick=WIDELINESIZE;
					}
					else
					{
						sPSPlot.thick=0;
					}	

					// Get # analysis points
					nData=(int)(fData[2]-fData[1]+1);

					// Set # FFT points to actual # of data points
					sPSPlot.nfft=nData;

					// Allocate memory for next higher power-of-2
					nAlloc=(int)pow(2.0, (double)ceil(log(nData)/log(2)));

					// Reallocate memory for FFT points
					// These are floats for compatibility with
					// PowerSpectrumPlot()'s GraphiC calls
					if((fFreq=(float*)
						realloc(fFreq, (nAlloc)*sizeof(float)))==NULL)
					{
						// Nothing useful can be done, so announce error
						// and post a messgae to close dialog box
						AllocErrorMessage();
						PostMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDCANCEL, NULL, 0));
						return TRUE;
					}

					// The fPSD array has additional space for std data header
					if((fPSD=(float*)
						realloc(fPSD, (nAlloc+ARRAY_OFFSET)*sizeof(float)))==
						NULL)
					{
						// Nothing useful can be done, so announce error,
						// clean up and post a message to close dialog box
						AllocErrorMessage();
						free(fFreq);
						PostMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDCANCEL, NULL, 0));
						return TRUE;
					}

					// Reallocate space for PSD averaging factor
					if((fAF=(float*)
						realloc(fAF, (nAlloc)*sizeof(float)))==NULL)
					{
						// Nothing useful can be done, so announce error
						// and post a messgae to close dialog box
						AllocErrorMessage();
						PostMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDCANCEL, NULL, 0));
						return TRUE;
					}

					// Zero out the fAF array
					// in case it isn't filled by auto af method
					// Note: This is probably not required
					for(i=0; i<nAlloc; i++)
					{
						fAF[i]=0.0;
					}

					// Display wait cursor
					SetCursor(hWait);

					// Clear message string if previous one for auto af
					if((strncmp(sPSPlot.message_str, "Max AF=", 7))==0)
					{
						strlcpy(sPSPlot.message_str, "", MESSAGESIZE);
					}
					
					// PSD calc is done with float arrays
					// It gives wrong results for data having a large offset
					// In that case, the data must first be "normalized"
					// i.e., its average value must be removed
					// We want to preserve and restore the original data
					// by copying it to temporary array before normalization
					// and back to main array after PSD calc
					// nNum is the full data array size
					// and fTempData is a pointer to temporary data array
					// that holds original data

					// Get total size of data array (not including header)
					nNum=(int)fData[0];

					// Allocate memory to save original data array
					// (including header)
					if((fTempData=
						(F_TYPE*)malloc((nNum+ARRAY_OFFSET+EXTRA_MEM)*
						sizeof(F_TYPE)))==NULL)
					{
						// Display error message
						#ifdef MEM_DEBUG
						AllocErrorMessageEx(__FILE__, __LINE__,
								(nNumm+ARRAY_OFFSET+EXTRA_MEM)*sizeof(F_TYPE));
						#else
						AllocErrorMessage();
						#endif

						// Close Power dialog box
						EndDialog(hDlg, 0);
					}
					else // Allocation OK
					{
						// Save full data array in temporary array
						for(i=0; i<nNum+ARRAY_OFFSET; i++)
						{
							fTempData[i]=fData[i];
						}
					}

					// Normalization is done with the following function calls
					// fData is our F_TYPE data array and bDataType is its type
					// fAvg is local double variable
					// for average value to be removed
					// Find the average value
					CalcMean(fData, &fAvg, bDataType);

					// Normalize data
					NormalizeData(fData, fAvg, bDataType);
					
					// Calc PSD
					if(sPSPlot.win==MULTITAPER_WIN)
					{
						// Calc multi-taper power spectrum
						// Note re param #8 = kind:
						// 2 (adaptive) recommended for colored noise,
						// and seems to agree best with periodogram
						nFreq=MultiTaperSpectrumCalc(fData, fPSD, fFreq,
							(float)fTau, sPSPlot.nfft, fPi, nWin, 2, 1,
							2*sPSPlot.win, sPSPlot.plotype, fCF, bDataType);
						
						// Smooth PSD if requested
						if(bSmooth)
						{
							// nFreq here is value returned
							// by MultiTaperSpectrumCalc()
							// Adjust nFreq
							// to get right # points for SmoothPSD()
							nFreq-=2;

							// Smooth PSD
							SmoothPSD(fFreq, fPSD, fAF, &nFreq, nPPO, &nMaxAF);

							// nFreq here is value returned by SmoothPSD()
							// Adjust # plot points after smoothing
							sPSPlot.nfft=nFreq;

							// Put new string into message list showing max AF
							// if message string is empty
							if((strlen(sPSPlot.message_str))==0)
							{
								// Don't store string if it is same as before
								_snprintf(sPSPlot.message_str, MESSAGESIZE,
									"Max AF=%d",
									nMaxAF);

								if(ComboBox_FindString(GETHCTL(
									IDC_PSPLOT_MESSAGE),
									-1, sPSPlot.message_str)==CB_ERR)
								{
									// Don't store blank message either
									if(strlen(sPSPlot.message_str))
									{
										nDummy=ComboBox_InsertString(GETHCTL(
											IDC_PSPLOT_MESSAGE), 0,
											sPSPlot.message_str);
									}
								}
							}
						}
						else // Unsmoothed
						{
							// Clear message string if previous one for auto af
							if((strncmp(sPSPlot.message_str, "Max AF=", 7))==0)
							{
								strlcpy(sPSPlot.message_str, "", MESSAGESIZE);
							}
						}

						// Save PSD data for multitaper spectrum
						if(bSmooth)
						{
							// nFreq here is value returned by SmoothPSD()
							PSDWrite(szPSDFile, fFreq, fPSD, fAF, nFreq-1,
								bSmooth);
						}
						else // Unsmoothed
						{
							// nFreq here is value returned
							// by MultiTaperSpectrumCalc()
							PSDWrite(szPSDFile, fFreq, fPSD, fAF, nFreq-2,
								bSmooth);
						}

						// Set the # FFT points for the multitaper case
						sPSPlot.nfft=nAlloc;
					}
					else // Periodogram
					{
						if(nAvg==0) // Automatic af method
						{
							// Note: No smooth option for Auto AF
							
							// Set nfft arg to unpadded # data points
							nfft=nData;

							// Note: nMaxAF arg is output only
							// Calc auto periodogram power spectrum
							nFreq=AutoSpectrumCalc(fData, fPSD, fFreq, fAF,
								(float)fTau,
								&nfft, sPSPlot.num, 2*sPSPlot.win,
								sPSPlot.plotype, fCF, &nMaxAF, bDataType);
							
							// We'd like to eliminate some of the LF points
							
							// Set # FFT points according to function return
							// The return value is # PSD data points
							sPSPlot.nfft=nFreq;

							// Adjust nFreq so get right # points
							// in PSD.dat file
							nFreq/=2;

							// Set nAvg to maxaf of auto spectrum calc
							nAvg=nMaxAF;

							// Put # averages into plot structure
							// This is for message on plot
							// but doesn't seem necessary
							sPSPlot.af=nAvg;

							// This forces another calc when Plot pressed again
							// Otherwise plot is wrong - like fixed AF=nMaxAF
							nAvg=0;

							// Put new string into message list showing max AF
							// if message string is empty
							if((strlen(sPSPlot.message_str))==0)
							{
								// Don't store string if it is same as before
								_snprintf(sPSPlot.message_str, MESSAGESIZE,
									"Max AF=%d",
									nMaxAF);

								if(ComboBox_FindString(GETHCTL(
									IDC_PSPLOT_MESSAGE),
									-1, sPSPlot.message_str)==CB_ERR)
								{
									// Don't store blank message either
									if(strlen(sPSPlot.message_str))
									{
										nDummy=ComboBox_InsertString(GETHCTL(
											IDC_PSPLOT_MESSAGE), 0,
											sPSPlot.message_str);
									}
								}
							}
						}
						else // Fixed af method
						{
							#ifdef A7PSD // For testing of A7PSD DLL
							// Call A7PSD DLL function driver
							nFreq=A7PSDSpectrumCalc(fData, fPSD, fFreq, (float)fTau,
								sPSPlot.nfft, sPSPlot.num, 2*sPSPlot.win,
								sPSPlot.plotype, fCF, nAvg, bDataType);

							#else // Normal code
							// Calc periodogram power spectrum
							nFreq=SpectrumCalc(fData, fPSD, fFreq, (float)fTau,
								sPSPlot.nfft, sPSPlot.num, 2*sPSPlot.win,
								sPSPlot.plotype, fCF, nAvg, bDataType);

							// Smooth PSD if requested
							if(bSmooth)
							{
								// Set # FFT points according to avg factor
								sPSPlot.nfft=nAlloc/nAvg;

								// Adjust nFreq
								nFreq-=2;

								// Smooth PSD
								SmoothPSD(fFreq, fPSD, fAF, &nFreq, nPPO,
									&nMaxAF);

								// Set # plot points
								sPSPlot.nfft=2*nFreq;
								
								// Put new string into message list
								// showing max AF
								// if message string is empty
								if((strlen(sPSPlot.message_str))==0)
								{
									// Don't store string
									// if it is same as before
									_snprintf(sPSPlot.message_str, MESSAGESIZE,
										"Max AF=%d", nMaxAF);

									if(ComboBox_FindString(GETHCTL(
										IDC_PSPLOT_MESSAGE),
										-1, sPSPlot.message_str)==CB_ERR)
									{
										// Don't store blank message either
										if(strlen(sPSPlot.message_str))
										{
											nDummy=
												ComboBox_InsertString(GETHCTL(
												IDC_PSPLOT_MESSAGE), 0,
												sPSPlot.message_str);
										}
									}
								}
							}
							else
							{
								// Fill fAF[] array with AF values
								for(i=0; i<sPSPlot.nfft; i++)
								{
									fAF[i]=(float)nAvg;
								}

								// Clear message string
								// if previous one for auto af
								if((strncmp(sPSPlot.message_str, "Max AF=",
									7))==0)
								{
									strlcpy(sPSPlot.message_str, "",
										MESSAGESIZE);
								}
							}
							#endif
						}

						// Note: 5th arg of PSDWrite is # points
						// nFreq best for non-Auto AF
						// Get all points - no bad ones either
						// But need to use nFreq-1 to avoid bad last point
						// Because DC term is dropped from spectrum
						
						// Save PSD data for periodogram
						if(nAvg)
						{
							PSDWrite(szPSDFile, fFreq, fPSD, fAF, nFreq-1,
								bSmooth);
						}
						else // nAvg=0 (Auto AF)
						{
							PSDWrite(szPSDFile, fFreq, fPSD, fAF, nFreq-1,
								bSmooth);
						}
					}

					// PSD calculation done					
					// Display normal cursor
					SetCursor(hArrow);

					// Restore original data array
					for(i=0; i<nNum+ARRAY_OFFSET; i++)
					{
						fData[i]=fTempData[i];
					}

					// Free temporary data array
					free(fTempData);

					// Display PSD parameters
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_PSPLOT_DISPLAY, NULL, 0));

					// Find maximum & minumum of PSD data
					// Question: Is divide by 2 right for auto af case?
					minmax(&fPSDMin, &fPSDMax, fPSD, (sPSPlot.nfft/2)-1);

					// Display data maximum
					_snprintf(szBuffer, sizeof(szBuffer), "%4.2f", fPSDMax);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_PSPLOT_DATAMAX), szBuffer);

					// Display data minimun
					_snprintf(szBuffer, sizeof(szBuffer), "%4.2f", fPSDMin);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_PSPLOT_DATAMIN), szBuffer);

					// Set plot type
					nPlotType=SPECT_PLOT;

					// There are several types of power spectrum plot:
					// Periodogram or Multitaper
					// Periodogram can be fixed or automatic averaging factor
					// All types except Auto AF can be smoothed or unsmoothed
					// Auto AF is unsmoothed only
					// There are several ways to set the # of plot points =
					// sPSPlot.nfft which is passed as (sPSPlot.nfft/2)-1 to
					// the plotting function PowerSpectrumPlot()
					// by GPCWINCreate():
					// nData is the # analysis points
					// (unpadded phase or freq data)
					// nFreq is the # PSD points
					// returned from SmoothPSD()
					// One factor is that the DC term is dropped
					// from the PSD plot

					// Set # plot points
					if(sPSPlot.win==MULTITAPER_WIN)
					{
						if(bSmooth)
						{
							// This needed to get full PSD plot 
							sPSPlot.nfft=2*nFreq;
						}
						else
						{
							// This needed to get full PSD plot
							// Question: Should it be raised
							// to next power-of-2?
							sPSPlot.nfft=2*nData;
						}
					}
					else // Periodogram
					{
						if(nAvg)
						{
							if(bSmooth)
							{
								// This needed to get full PSD plot 
								sPSPlot.nfft=2*nFreq;
							}
							else // Unsmoothed
							{
								sPSPlot.nfft/=nAvg;
							}
						}
						else // Auto AF
						{
							if(bSmooth) // Note: This case is not allowed
							{
								// This needed to get full PSD plot 
								sPSPlot.nfft=2*nFreq;
							}
							else // Unsmoothed
							{
								sPSPlot.nfft=2*nFreq;
							}
						}
					}
					
					// Set the plotdata smoothing flag
					sPSPlot.smooth=bSmooth;

					// Set the line fit weighting flag
					// This applies to the smoothed LS semilog fit only
					// The octave band unsmoothed fit is always weighted
					// This one is weighted by default
					sPSPlot.weight=GetPrivateProfileInt("Preferences",
						"PSDLineWeight", 1, szIniFile);

					// Here's where the actually plotting is done
					// Create child window for plot
					// Note: GPCWINCreate() passes (sPSPlot.nfft/2)-1
					// as # points to PowerSpectrumPlot()
					GPCWINCreate(hChildWnd, hInst, hDlg, SW_SHOWNORMAL,
						&hChildAccel, NULL);

					// This insures that plot is done before continuing here
					YieldControl();

					// Enable y scale boxes
					EnableWindow(GETHCTL(IDC_PSPLOT_YMAX), TRUE);
					EnableWindow(GETHCTL(IDC_PSPLOT_YMIN), TRUE);
					EnableWindow(GETHCTL(IDC_PSPLOT_YTIC), TRUE);

					// Display plot scale max & min
					// Display scale maximum
					_snprintf(szBuffer, sizeof(szBuffer), "%4.2f",
						sPSPlot.y_max);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_PSPLOT_YMAX), szBuffer);

					// Display scale minimun
					_snprintf(szBuffer, sizeof(szBuffer), "%4.2f",
						sPSPlot.y_min);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_PSPLOT_YMIN), szBuffer);

					// Display # scale tics
					_snprintf(szBuffer, sizeof(szBuffer), "%d",
						sPSPlot.y_tic);
					SetWindowText(GETHCTL(IDC_PSPLOT_YTIC), szBuffer);
				}
				break;

				// Reset all plot params to defaults
				case IDC_PSPLOT_RESET:
				{
					// Set initialization flag
					bFirstTime=TRUE;

					// Put message into PSD & scale max & min displays
					SetWindowText(GETHCTL(IDC_PSPLOT_DATAMAX), "Press Plot");
					SetWindowText(GETHCTL(IDC_PSPLOT_DATAMIN), "To Calc");
					SetWindowText(GETHCTL(IDC_PSPLOT_YMAX), "");
					SetWindowText(GETHCTL(IDC_PSPLOT_YMIN), "");
					SetWindowText(GETHCTL(IDC_PSPLOT_YTIC), "");

					// Set # y-axis scale tics to zero as code to calc scale
					sPSPlot.y_tic=0;

					// Set y-axis scale values to zero as code to calc scale
					sPSPlot.y_min=0.0;
					sPSPlot.y_max=0.0;

					// Clear the message list box
					nDummy=ComboBox_ResetContent(GETHCTL(IDC_PSPLOT_MESSAGE));
					nUserMessages=0;

					// Do initialization
					nAvg=1;
					sPSPlot.af=1;
					bSave=bUseSpectPlotIni;
					bUseSpectPlotIni=FALSE;
					SendMessage(hDlg, WM_INITDIALOG, (WPARAM)0, (LPARAM)0);
					bUseSpectPlotIni=bSave;

					// Disable y scale boxes so crazy values can't be entered
					EnableWindow(GETHCTL(IDC_PSPLOT_YMAX), FALSE);
					EnableWindow(GETHCTL(IDC_PSPLOT_YMIN), FALSE);
					EnableWindow(GETHCTL(IDC_PSPLOT_YTIC), FALSE);
				}
				break;

				// Respond to esc key or close button
				case IDCANCEL:
				case IDC_PSPLOT_CANCEL:
				{
					// Save # user-entered title strings
					nUserTitles=ComboBox_GetCount(GETHCTL(IDC_PSPLOT_TITLE))
						-NUM_PSPLOT_TITLES;

					// Limit # user titles
					nUserTitles=min(nUserTitles, NUM_TITLES);

					// Save user titles
					if(nUserTitles)
					{
						for(i=0; i<nUserTitles; i++)
						{
							// Get size of title string
							nLength=ComboBox_GetLBTextLen(GETHCTL(
								IDC_PSPLOT_TITLE), i);

							// Realloc title array
							if((szPlotTitle[i]=
								(LPSTR)realloc(szPlotTitle[i],
								(nLength+1)*sizeof(char)))==NULL)
							{
								// Just dsp err msg & skip saving string
								// We are closing dlg box anyway
								AllocErrorMessage();
							}
							else
							{
								// Save title string
								nDummy=
									ComboBox_GetLBText(GETHCTL(
									IDC_PSPLOT_TITLE),
									i, szPlotTitle[i]);
							}
						}
					}

					// Save # user-entered subtitle strings
					nUserSubtitles=
						ComboBox_GetCount(GETHCTL(IDC_PSPLOT_SUBTITLE))-
						NUM_PSPLOT_SUBTITLES;

					// Limit # user subtitles
					nUserSubtitles=min(nUserSubtitles, NUM_SUBTITLES);

					// Save user subtitles
					if(nUserSubtitles)
					{
						for(i=0; i<nUserSubtitles; i++)
						{
							// Get size of subtitle string
							nLength=ComboBox_GetLBTextLen(GETHCTL(
								IDC_PSPLOT_SUBTITLE), i);

							// Realloc subtitle array
							if((szPlotSubtitle[i]=
								(LPSTR)realloc(szPlotSubtitle[i],
								(nLength+1)*sizeof(char)))==NULL)
							{
								// Just dsp err msg & skip saving string
								// We are closing dlg box anyway
								AllocErrorMessage();
							}
							else
							{
								// Save subtitle string
								nDummy=ComboBox_GetLBText(GETHCTL(
									IDC_PSPLOT_SUBTITLE), i,
									szPlotSubtitle[i]);
							}
						}
					}

					// Save # user-entered message strings
					nUserMessages=
						ComboBox_GetCount(GETHCTL(IDC_PSPLOT_MESSAGE))-
						NUM_PSPLOT_MESSAGES;

					// Limit # user messages
					nUserMessages=min(nUserMessages, NUM_MESSAGES);

					// Save user messages
					if(nUserMessages)
					{
						for(i=0; i<nUserMessages; i++)
						{
							// Get size of messsage string
							nLength=ComboBox_GetLBTextLen(GETHCTL(
								IDC_PSPLOT_MESSAGE), i);

							// Realloc message array
							if((szPlotMessage[i]=
								(LPSTR)realloc(szPlotMessage[i],
								(nLength+1)*sizeof(char)))==NULL)
							{
								// Just dsp err msg & skip saving string
								// We are closing dlg box anyway
								AllocErrorMessage();
							}
							else
							{
								// Save message string
								nDummy=ComboBox_GetLBText(GETHCTL(
									IDC_PSPLOT_MESSAGE), i, szPlotMessage[i]);
							}
						}
					}

					// Free FFT arrays
					free(fFreq);
					free(fPSD);
					free(fAF);

					// Set dead pointers to null so subsequent realloc is OK
					fFreq=0;
					fPSD=0;
					fAF=0;

					// Close dialog box
					EndDialog (hDlg, 0);
				}
				return TRUE;
			}
		}
		break;
	 }
	 return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*               Histogram Plot Dialog Procedure                             */
/*                                                                           */
/* 		Revision record:                                                     */
/*			12/28/96	Adapted from SpectrumPlotDlgProc()                   */
/*			12/29/96	Up and running                                       */
/*			01/23/97	Added INI file initialization option                 */
/*			01/25/97	Added code to push user-entered titles, subtitles &  */
/*						messages into combo listboxes with CR                */
/*			03/25/97	Tightened normalization threshold and added code to  */
/*						de-normalize when Normalize checkbox unchecked       */
/*			05/17/00	Added use of sHPlot.do_errbar as flag to control     */
/*						filling of histogram bars                            */
/*			11/22/06	Changed initialization code                          */
/*			07/22/10	Added new controls, scaling and other new festures   */
/*			07/23/10	Added histo data file writing                        */
/*			09/19/11	Added full path to histo file                        */ 
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK HistoPlotDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	// Handles
	HWND hChildWnd=NULL;
	HANDLE hChildAccel=NULL;
	// Chars
	char szBuffer[BUFFER_SIZE+1]; 		// Text buffer
	char szBigBuffer[BIG_BUFFER_SIZE+1];// Big text buffer
	char cScaleFormat[8];				// For roundq() call
	// Temporary filename buffers
	char szTempFile[FILENAMESIZE+1];	// Temp full filename buffer
	char szTempTitle[FILENAMESIZE+1];	// Temp file title buffer
	char szTempPath[FILENAMESIZE+1];	// Temp file path buffer
	char szTempName[FILENAMESIZE+1];    // Temp file name buffer
	char szTempExt[BUFFER_SIZE+1];		// Temp file extension buffer
	// Unsigned Ints
	static unsigned uTitle;				// HWND of Title combo control
	static unsigned uSubtitle;	  		// HWND of Subtitle combo control
	static unsigned uMessage;	  		// HWND of Message combo control
	// Ints
	int i;								// Index
	int nLength;						// String length
	static int nData;					// # data analysis points
	static int nBins=1;			 		// # histogram bins
	static int nEntry;					// User entry
	// BOOLs
	BOOL bSave;							// BOOL to save state of ini flag
	static BOOL bErrorTrap=FALSE;		// Flag for entry error
	static BOOL bAlloc=FALSE;			// Flag for memory allocation
	static BOOL bFirstTime=TRUE;		// Flag for initial opening
	static BOOL bNorm=FALSE;			// Flag to normalize data
	static BOOL bMustNorm=FALSE;		// Flag that normalization is req'd
	// Floats
	// Note: fBins and fHist are global float array pointers
	static float fScaleMin, fScaleMax;	// Plot scale limits
	static float fRange;				// Plot range
	static float fStep;					// For roundq() call
	// F_TYPEs
	F_TYPE fDev;						// Std dev of data
	F_TYPE fYMax;						// Max histo y value
	static F_TYPE *fHistoData;   		// Pointer to working data array
	static F_TYPE fMin;					// Min data value
	static F_TYPE fMax;					// Max data value
	static F_TYPE fAvg;					// Mean value of data
	static F_TYPE fOffset=0.0;			// Data offset
	static F_TYPE fMult=1.0;			// Data multiplier
	// File handle
	FILE *fFile;           				// DOS file handle for histo data


	// Note: Histogram plot structs, sHPlot & sHPrev, are defined globally

	// Put plot dialog box handle into global
	hPlotBox=hDlg;

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Put dialog box handle into global variable
			// Used at end of GraphiC plotting to assure safe return here
			hDialog=hDlg;

			// Full initialization
			if(bFirstTime)
			{
				if(bUseHistoPlotIni)
				{
					ReadIni(INI_HISTO);
				}
				else
				{
					// Initialize histogram plot parameters to defaults
					strlcpy(sHPlot.title, "HISTOGRAM", TITLESIZE);
					strlcpy(sHPlot.subtitle, szFileTitle, SUBTITLESIZE);
					strlcpy(sHPlot.message_str, "", MESSAGESIZE);

					// Full filename inc drive & directory where prgm started
					strlcpy(sHPlot.plot_filename, szDrive, FILENAMESIZE);
					strlcat(sHPlot.plot_filename, szDirectory, FILENAMESIZE);
					strlcat(sHPlot.plot_filename, "HISTO.TKF", FILENAMESIZE);

					sHPlot.do_date=TRUE;
					sHPlot.do_box=TRUE;
					sHPlot.do_mouse=FALSE;
					sHPlot.do_line=TRUE;
					sHPlot.do_errbar=TRUE; // bar fill flag
					sHPlot.position=0;
					bNorm=FALSE;
				}
				bFirstTime=FALSE;
			}

			// Always start without scaling
			fOffset=0.0;
			fMult=1.0;

			// Check if data changed
			if(bDataType==PHASE_DATA && (bPhaseDataChanged ||
				bAutoPhaseDataRead))
			{
				// Make sure subtitle is correct
				strlcpy(sHPlot.subtitle, szFileTitle, SUBTITLESIZE);
				SetWindowText(GETHCTL(IDC_HPLOT_SUBTITLE),
					sHPlot.subtitle);

				// Clear message
				strlcpy(sHPlot.message_str, "", MESSAGESIZE);
				SetWindowText(GETHCTL(IDC_HPLOT_MESSAGE), "");

				// Reset plot scale
				sHPlot.y_tic=0;

				// Clear data changed flag
				bPhaseDataChanged=FALSE;
				bAutoPhaseDataRead=FALSE;
			}

			if(bDataType==FREQ_DATA && (bFreqDataChanged ||
				bAutoFreqDataRead))
			{
				// Make sure subtitle is correct
				strlcpy(sHPlot.subtitle, szFileTitle, SUBTITLESIZE);
				SetWindowText(GETHCTL(IDC_HPLOT_SUBTITLE),
					sHPlot.subtitle);

				// Clear message
				strlcpy(sHPlot.message_str, "", MESSAGESIZE);
				SetWindowText(GETHCTL(IDC_HPLOT_MESSAGE), "");

				// Reset plot scale
				sHPlot.y_tic=0;

				// Clear data changed flag
				bFreqDataChanged=FALSE;
				bAutoFreqDataRead=FALSE;
			}
			
			// Allocate memory for histogram plot
			if(!bAlloc) // Do allocation only once
			{
				// Allocate working memory for data
				if((fHistoData=(F_TYPE*)malloc(
					((int)fData[0]+ARRAY_OFFSET+EXTRA_MEM)*
					sizeof(F_TYPE)))==NULL)
				{
					// Can't continue - dsp msg & bail out
					// bAlloc remains FALSE
					AllocErrorMessage();
					PostMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDCANCEL,
						NULL, 0));
					return TRUE;
				}

				// For testing
				// fMult=1e6;

				#if(0) // Original code
				// Copy complete data array to working memory
				for(i=0; i<(int)(fData[0]+ARRAY_OFFSET); i++)
				{
					fHistoData[i]=fData[i];
				}
				#endif

				#if(1) // New code 07/23/10
				// Copy complete data array to working memory
				// ARRAY_OFFSET=3
				// Header items are 0=size, 1=start & 2=end
				// Copy header
				for(i=0; i<ARRAY_OFFSET; i++)
				{
					fHistoData[i]=fData[i];
				}

				// Copy scaled values
				for(i=ARRAY_OFFSET; i<(int)(fData[0]+ARRAY_OFFSET); i++)
				{
					fHistoData[i]=(fData[i]+fOffset)*fMult;
				}
				#endif

				// Allocate memory for histogram bins
				if((fBins=(float*)malloc(nBins*sizeof(float)))==NULL)
				{
					// Can't continue - dsp msg, free mem & bail out
					// bAlloc remains FALSE
					AllocErrorMessage();
					free(fHistoData);
					PostMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDCANCEL,
						NULL, 0));
					return TRUE;
				}

				// Allocate memory for histogram counts
				if((fHist=(float*)malloc(nBins*sizeof(float)))==NULL)
				{
					// Can't continue - dsp msg, free mem & bail out
					// bAlloc remains FALSE
					AllocErrorMessage();
					free(fHistoData);
					free(fBins);
					PostMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDCANCEL,
						NULL, 0));
					return TRUE;
				}

				bAlloc=TRUE;
			}

			// Find and check data range
			FindMinMax(fHistoData, &fMin, &fMax, bDataType);
			CalcMean(fHistoData, &fAvg, bDataType);

			// Check for too small histogram range
			if( (fAvg) && ((fabs((fMax-fMin)/fAvg))<1e-3) )
			{
				// Must normalize histogram data
				bNorm=TRUE;
				bMustNorm=TRUE;

			}
			else
			{
				bMustNorm=FALSE;
			}

			// Normalize?
			if(bNorm)
			{
				// Find avg
				CalcMean(fHistoData, &fAvg, bDataType);

				// Normalize data
				NormalizeData(fHistoData, fAvg, bDataType);

				// Display mean value removed
				_snprintf(szBuffer, sizeof(szBuffer), "Mean Removed = %10.6e",
					fAvg);
				ShortenExp(szBuffer);
				SetWindowText(GETHCTL(IDC_HPLOT_AVG), szBuffer);

				// Recalc min & max
				FindMinMax(fHistoData, &fMin, &fMax, bDataType);
			}

			// Disable scaling if normalize
			EnableWindow(GETHCTL(IDC_HPLOT_OFFSET), !bNorm);
			EnableWindow(GETHCTL(IDC_HPLOT_MULT), !bNorm);

			// Load x label
			LoadString(hInst, IDS_HPLOT_XLABEL_0+bNorm, szBuffer, BUFFER_SIZE);
			SetWindowText(GETHCTL(IDC_HPLOT_XLABEL), szBuffer);
			LoadString(hInst, IDS_HPLOT_XLABEL_2+bNorm, szBuffer, BUFFER_SIZE);
			strlcpy(sHPlot.x_label, szBuffer, XLABELSIZE);

			// Load y label
			LoadString(hInst, IDS_HPLOT_YLABEL_0, szBuffer, BUFFER_SIZE);
			SetWindowText(GETHCTL(IDC_HPLOT_YLABEL), szBuffer);
			LoadString(hInst, IDS_HPLOT_YLABEL_1, szBuffer, BUFFER_SIZE);
			strlcpy(sHPlot.left_y_label, szBuffer, YLABELSIZE);

			// Fill up message position list box using string table
			// Note usage of DPLOT rather than PSPLOT strings
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_HPLOT_POSITION));
			nDummy=ComboBox_InsertString(GETHCTL(IDC_HPLOT_POSITION),
				0, "None");
			for(i=0; i<NUM_DPLOT_POSITIONS; i++)
			{
				LoadString(hInst, IDS_DPLOT_POSITION_0+i, szBuffer,
					BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_HPLOT_POSITION),
					i, szBuffer);
			}

			// Show position
			nDummy=ComboBox_SetCurSel(GETHCTL(IDC_HPLOT_POSITION),
				sHPlot.position);

			// Clear the title list box
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_HPLOT_TITLE));

			// Load previous user-entered title strings into list box
			if(nUserTitles)
			{
				for(i=0; i<nUserTitles; i++)
				{
					// Load title string
					nDummy=ComboBox_InsertString(GETHCTL(IDC_HPLOT_TITLE),
						i, szPlotTitle[i]);
				}
			}

			// Load the current title
			nDummy=ComboBox_AddString(GETHCTL(IDC_HPLOT_TITLE), sHPlot.title);
			SetWindowText(GETHCTL(IDC_HPLOT_TITLE),
				sHPlot.title);

			// Clear the subtitle list box
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_HPLOT_SUBTITLE));

			// Load the filenames into the subtitle list box
			nDummy=ComboBox_AddString(GETHCTL(IDC_HPLOT_SUBTITLE),
				szFileTitle);
			nDummy=ComboBox_AddString(GETHCTL(IDC_HPLOT_SUBTITLE), szFile);

			// Load previous user-entered subtitle strings into list box
			if(nUserSubtitles)
			{
				for(i=0; i<nUserSubtitles; i++)
				{
					// Load subtitle string
					nDummy=ComboBox_InsertString(GETHCTL(IDC_HPLOT_SUBTITLE),
						i, szPlotSubtitle[i]);
				}
			}

			// Load the current subtitle
			SetWindowText(GETHCTL(IDC_HPLOT_SUBTITLE),
				sHPlot.subtitle);

			// Clear the message list box
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_HPLOT_MESSAGE));

			if(bNorm)
			{
				// Put mean removed message into top of list box
				_snprintf(szBuffer, sizeof(szBuffer), "Mean Removed = %10.6e",
					fAvg);
				ShortenExp(szBuffer);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_HPLOT_MESSAGE),
					0, szBuffer);
				strlcpy(sHPlot.message_str, szBuffer, MESSAGESIZE);
			}

			// Load previous user-entered message strings into list box
			if(nUserMessages)
			{
				for(i=0; i<nUserMessages; i++)
				{
					// Load message string
					nDummy=ComboBox_InsertString(GETHCTL(IDC_HPLOT_MESSAGE),
						i, szPlotMessage[i]);
				}
			}

			// Load the current message
			nDummy=ComboBox_AddString(GETHCTL(IDC_HPLOT_MESSAGE),
				sHPlot.message_str);
			SetWindowText(GETHCTL(IDC_HPLOT_MESSAGE),
				sHPlot.message_str);

			// Load the plot filename
			SetWindowText(GETHCTL(IDC_HPLOT_FILENAME),
				sHPlot.plot_filename);

			// Restore the date checkbox state
			Button_SetCheck(GETHCTL(IDC_HPLOT_DATE), sHPlot.do_date);

			// Restore the box checkbox state
			Button_SetCheck(GETHCTL(IDC_HPLOT_BOX), sHPlot.do_box);

			// Restore the cursor checkbox state
			Button_SetCheck(GETHCTL(IDC_HPLOT_CURSOR), sHPlot.do_mouse);

			// Restore the fit checkbox state
			Button_SetCheck(GETHCTL(IDC_HPLOT_FIT), sHPlot.do_line);

			// Restore the fill checkbox state
			Button_SetCheck(GETHCTL(IDC_HPLOT_FILL), sHPlot.do_errbar);

			// Restore the norm checkbox state
			Button_SetCheck(GETHCTL(IDC_HPLOT_NORM), bNorm);

			// Disable the norm checkbox if normalization is required
			EnableWindow(GETHCTL(IDC_HPLOT_NORM), !bMustNorm);

			// Update plot scales
			SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDC_HPLOT_UPDATE,
				NULL, 0));

			// Display data scaling values
			_snprintf(szBuffer, sizeof(szBuffer), "%e", fOffset);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_HPLOT_OFFSET), szBuffer);
			_snprintf(szBuffer, sizeof(szBuffer), "%e", fMult);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_HPLOT_MULT), szBuffer);

			// Get & save HWNDs returned by GetFocus() for Title, Subtitle &
			// Message combo boxes
			SetFocus(GETHCTL(IDC_HPLOT_TITLE));
			uTitle=(UINT)GetFocus();
			SetFocus(GETHCTL(IDC_HPLOT_SUBTITLE));
			uSubtitle=(UINT)GetFocus();
			SetFocus(GETHCTL(IDC_HPLOT_MESSAGE));
			uMessage=(UINT)GetFocus();

			// This code produces histogram plot automatically
			if(bAutoHistoPlot)
			{
				// Automatically produce histogram plot
				SendMessage(hDlg, WM_COMMAND,
					GET_WM_COMMAND_MPS(IDC_HPLOT_PLOT, NULL, 0));

				// Turn off auto histogram plot flag
				// Have to turn on this flag each time it is used
				bAutoHistoPlot=FALSE;
			}

			return TRUE;
		}

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::HISTOGRAM_FUNCTION.HTM",
						HH_DISPLAY_TOPIC,
                        0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::HISTOGRAM_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "HISTOGRAM_FUNCTION");
					#endif
				}
				break;

				// Detect parameter changes
				// Title change
				case IDC_HPLOT_TITLE:
				{
					// Respond to focus lost
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_KILLFOCUS)
					{
						GetWindowText(GETHCTL(IDC_HPLOT_TITLE),
						sHPlot.title, TITLESIZE-1);

						// Redisplay title - perhaps shortened
						SetWindowText(GETHCTL(IDC_HPLOT_TITLE),
							sHPlot.title);

						// Put new string into list
						// Don't store string if it is same as before
						if(ComboBox_FindString(GETHCTL(IDC_HPLOT_TITLE),
							-1, sHPlot.title)==CB_ERR)
						{
							// Don't store blank title either
							if(strlen(sHPlot.title))
							{
								nDummy=ComboBox_InsertString(GETHCTL(
									IDC_HPLOT_TITLE), 0, sHPlot.title);
							}
						}
					}
				}
				break;

				// Subtitle change
				case IDC_HPLOT_SUBTITLE:
				{
					// Respond to focus lost
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_KILLFOCUS)
					{
						GetWindowText(GETHCTL(IDC_HPLOT_SUBTITLE),
						sHPlot.subtitle, SUBTITLESIZE-1);

						// Redisplay subtitle - perhaps shortened
						SetWindowText(GETHCTL(IDC_HPLOT_SUBTITLE),
							sHPlot.subtitle);

						// Put new string into list
						// Don't store string if it is same as before
						if(ComboBox_FindString(GETHCTL(IDC_HPLOT_SUBTITLE),
							-1, sHPlot.subtitle)==CB_ERR)
						{
							// Don't store blank subtitle either
							if(strlen(sHPlot.subtitle))
							{
								nDummy=ComboBox_InsertString(GETHCTL(
									IDC_HPLOT_SUBTITLE), 0, sHPlot.subtitle);
							}
						}
					}
				}
				break;

				// Message change
				case IDC_HPLOT_MESSAGE:
				{
					// Respond to focus lost
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_KILLFOCUS)
					{
						GetWindowText(GETHCTL(IDC_HPLOT_MESSAGE),
						sHPlot.message_str, MESSAGESIZE-1);

						// Redisplay message - perhaps shortened
						SetWindowText(GETHCTL(IDC_HPLOT_MESSAGE),
							sHPlot.message_str);

						// Put new string into list
						// Don't store string if it is same as before
						if(ComboBox_FindString(GETHCTL(IDC_HPLOT_MESSAGE),
							-1, sHPlot.message_str)==CB_ERR)
						{
							// Don't store blank message either
							if(strlen(sHPlot.message_str))
							{
								nDummy=ComboBox_InsertString(GETHCTL(
									IDC_HPLOT_MESSAGE), 0, sHPlot.message_str);
							}
						}
					}
				}
				break;

				// Plot Filename change
				case IDC_HPLOT_FILENAME:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_HPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// The default *.TKF filename includes full drive/path
						// where program started to avoid writing to floppy
						// or non-writable media.  The edit window AutoHScrolls.
						GetWindowText(GETHCTL(IDC_HPLOT_FILENAME),
							szTempFile, FILENAMESIZE-1);

						// Validate new filename
						if(CheckFilename(szTempFile, szTempTitle, szTempPath,
							szTempName, szTempExt, hDlg,
							"Histo Plot Filename"))
						{
							// Filename OK
							strlcpy(sHPlot.plot_filename, szTempFile,
								FILENAMESIZE);

							// Reload the plot filename
							SetWindowText(GETHCTL(IDC_HPLOT_FILENAME),
								sHPlot.plot_filename);
						}
						else // Filename NG
						{
							// Restore original filename
							SetWindowText(GETHCTL(IDC_HPLOT_FILENAME),
								sHPlot.plot_filename);
							SetFocus(GETHCTL(IDC_HPLOT_FILENAME));
							break;
						}
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// # Bins change
				case IDC_HPLOT_NUMBINS:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_HPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get new # bins
						GetWindowText(GETHCTL(IDC_HPLOT_NUMBINS),
							szBuffer, BUFFER_SIZE+1);
						nEntry=abs(atoi(szBuffer));

						// Validate new # bins
						// ## bins must be between 10 and nData/2
						if(ValidateInteger(hDlg, nEntry, 10, nData/2))
						{
							// # bins OK
							nBins=nEntry;

							// Redisplay the # bins
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nBins);
							SetWindowText(GETHCTL(IDC_HPLOT_NUMBINS), szBuffer);
						}
						else // # bins NG
						{
							// Restore original # bins
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nBins);
							SetWindowText(GETHCTL(IDC_HPLOT_NUMBINS), szBuffer);
							SetFocus(GETHCTL(IDC_HPLOT_FILENAME));
							break;
						}

						// Redisplay bin size
						_snprintf(szBuffer, sizeof(szBuffer), "%e", fRange/nBins);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_HPLOT_BINSIZE), szBuffer);

						// Update y-axis plot scale for next plot
						sHPlot.y_min=0;
						sHPlot.y_max=0;
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// X-axis label change
				case IDC_HPLOT_XLABEL:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_HPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get new x-axis label
						GetWindowText(GETHCTL(IDC_HPLOT_XLABEL),
						sHPlot.x_label, XLABELSIZE);

						// Redisplay x label - perhaps shortened
						SetWindowText(GETHCTL(IDC_HPLOT_XLABEL),
							sHPlot.x_label);
						break;
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Y-axis label change
				case IDC_HPLOT_YLABEL:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_HPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get new y-axis label
						GetWindowText(GETHCTL(IDC_HPLOT_YLABEL),
						sHPlot.left_y_label, XLABELSIZE);

						// Redisplay y label - perhaps shortened
						SetWindowText(GETHCTL(IDC_HPLOT_YLABEL),
							sHPlot.left_y_label);
							break;
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// X-axis plot scale maximum change
				case IDC_HPLOT_XMAX:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_HPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get new x-axis scale maximum
						GetWindowText(GETHCTL(IDC_HPLOT_XMAX), szBuffer,
							BUFFER_SIZE);
						sHPlot.x_max=(float)atof(szBuffer);

						// Redisplay x-axis scale maximun
						_snprintf(szBuffer, sizeof(szBuffer), "%e", sHPlot.x_max);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_HPLOT_XMAX), szBuffer);
						break;
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// X-axis plot scale minimum change
				case IDC_HPLOT_XMIN:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_HPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get new x-axis scale minimum
						GetWindowText(GETHCTL(IDC_HPLOT_XMIN), szBuffer,
							BUFFER_SIZE);
						sHPlot.x_min=(float)atof(szBuffer);

						// Redisplay x-axis scale minimun
						_snprintf(szBuffer, sizeof(szBuffer), "%e", sHPlot.x_min);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_HPLOT_XMIN), szBuffer);
						break;
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// X-axis plot scale step change
				case IDC_HPLOT_XSTEP:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_HPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get new y-axis scale maximum
						GetWindowText(GETHCTL(IDC_HPLOT_XSTEP), szBuffer,
							BUFFER_SIZE);
						sHPlot.x_step=(float)atof(szBuffer);

						// Redisplay y scale maximun
						_snprintf(szBuffer, sizeof(szBuffer), "%e", sHPlot.x_step);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_HPLOT_XSTEP), szBuffer);
						break;
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Y-axis plot scale maximum change
				case IDC_HPLOT_YMAX:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_HPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get new y-axis scale maximum
						GetWindowText(GETHCTL(IDC_HPLOT_YMAX), szBuffer,
							BUFFER_SIZE);
						sHPlot.y_max=(float)atof(szBuffer);

						// Redisplay y scale maximun
						_snprintf(szBuffer, sizeof(szBuffer), "%e", sHPlot.y_max);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_HPLOT_YMAX), szBuffer);
						break;
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Y-axis plot scale minimum change
				case IDC_HPLOT_YMIN:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_HPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get new y-axis scale maximum
						GetWindowText(GETHCTL(IDC_HPLOT_YMIN), szBuffer,
							BUFFER_SIZE);
						sHPlot.y_min=(float)atof(szBuffer);

						// Redisplay y scale maximun
						_snprintf(szBuffer, sizeof(szBuffer), "%e", sHPlot.y_min);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_HPLOT_YMIN), szBuffer);
						break;
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Y-axis plot scale step change
				case IDC_HPLOT_YSTEP:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_HPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get new y-axis scale maximum
						GetWindowText(GETHCTL(IDC_HPLOT_YSTEP), szBuffer,
							BUFFER_SIZE);
						sHPlot.y_step=(float)atof(szBuffer);

						// Redisplay y scale maximun
						_snprintf(szBuffer, sizeof(szBuffer), "%e", sHPlot.y_step);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_HPLOT_YSTEP), szBuffer);
						break;
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Offset change
				case IDC_HPLOT_OFFSET:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_HPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get new offset
						GetWindowText(GETHCTL(IDC_HPLOT_OFFSET), szBuffer,
							BUFFER_SIZE);
						fOffset=atof(szBuffer);

						// Redisplay offset
						_snprintf(szBuffer, sizeof(szBuffer), "%e", fOffset);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_HPLOT_OFFSET), szBuffer);
						break;
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}

					// Copy complete data array to working memory
					// ARRAY_OFFSET=3
					// Header items are 0=size, 1=start & 2=end
					// Copy header
					for(i=0; i<ARRAY_OFFSET; i++)
					{
						fHistoData[i]=fData[i];
					}

					// Copy scaled values
					for(i=ARRAY_OFFSET; i<(int)(fData[0]+ARRAY_OFFSET); i++)
					{
						fHistoData[i]=(fData[i]+fOffset)*fMult;
					}

					// Update plot scales
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDC_HPLOT_UPDATE,
						NULL, 0));
				}
				break;

				// Multiplier change
				case IDC_HPLOT_MULT:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_HPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get new multiplier
						GetWindowText(GETHCTL(IDC_HPLOT_MULT), szBuffer,
							BUFFER_SIZE);
						fMult=atof(szBuffer);

						// Redisplay multiplier
						_snprintf(szBuffer, sizeof(szBuffer), "%e", fMult);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_HPLOT_MULT), szBuffer);
						break;
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}

					// Copy complete data array to working memory
					// ARRAY_OFFSET=3
					// Header items are 0=size, 1=start & 2=end
					// Copy header
					for(i=0; i<ARRAY_OFFSET; i++)
					{
						fHistoData[i]=fData[i];
					}

					// Copy scaled values
					for(i=ARRAY_OFFSET; i<(int)(fData[0]+ARRAY_OFFSET); i++)
					{
						fHistoData[i]=(fData[i]+fOffset)*fMult;
					}

					// Update plot scales
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDC_HPLOT_UPDATE,
						NULL, 0));
				}
				break;

				// Position change
				case IDC_HPLOT_POSITION:
				{
					sHPlot.position=
						ComboBox_GetCurSel(GETHCTL(IDC_HPLOT_POSITION));
				}
				break;

				// Date flag change
				case IDC_HPLOT_DATE:
				{
					sHPlot.do_date=Button_GetCheck(GETHCTL(IDC_HPLOT_DATE));
				}
				break;

				// Box flag change
				case IDC_HPLOT_BOX:
				{
					sHPlot.do_box=Button_GetCheck(GETHCTL(IDC_HPLOT_BOX));
				}
				break;

				// Cursor flag change
				case IDC_HPLOT_CURSOR:
				{
					sHPlot.do_mouse=Button_GetCheck(GETHCTL(IDC_HPLOT_CURSOR));
				}
				break;

				// Read config button
				case IDC_HPLOT_READ:
				{
					bSave=bUseHistoPlotIni;
					bUseHistoPlotIni=TRUE;
					ReadIni(INI_HISTO);
					bUseHistoPlotIni=bSave;
					SendMessage(hDlg, WM_INITDIALOG, (WPARAM)0, (LPARAM)0);
				}
				break;

				// Save config button
				case IDC_HPLOT_WRITE:
				{
					bSave=bUseHistoPlotIni;
					bUseHistoPlotIni=TRUE;
					WriteIni(INI_HISTO);
					bUseHistoPlotIni=bSave;
				}
				break;

				// Fit flag change
				case IDC_HPLOT_FIT:
				{
					sHPlot.do_line=Button_GetCheck(GETHCTL(IDC_HPLOT_FIT));
				}
				break;

				// Fill flag change
				case IDC_HPLOT_FILL:
				{
					sHPlot.do_errbar=Button_GetCheck(GETHCTL(IDC_HPLOT_FILL));
				}
				break;

				// Norm flag change
				case IDC_HPLOT_NORM:
				{
					// Get normalization flag
					bNorm=Button_GetCheck(GETHCTL(IDC_HPLOT_NORM));

					// Load x label
					LoadString(hInst, IDS_HPLOT_XLABEL_0+bNorm, szBuffer,
						BUFFER_SIZE);
					SetWindowText(GETHCTL(IDC_HPLOT_XLABEL), szBuffer);
					LoadString(hInst, IDS_HPLOT_XLABEL_2+bNorm, szBuffer,
						BUFFER_SIZE);
					strlcpy(sHPlot.x_label, szBuffer, XLABELSIZE);

					if(bNorm)
					{
						// No scaling if normalize
						// Set offset=0 and multiplier=1
						// and disable their controls
						fOffset=0.0;
						fMult=1.0;

						// Display data scaling values
						_snprintf(szBuffer, sizeof(szBuffer), "%e", fOffset);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_HPLOT_OFFSET), szBuffer);
						_snprintf(szBuffer, sizeof(szBuffer), "%e", fMult);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_HPLOT_MULT), szBuffer);

						// Disable scaling
						EnableWindow(GETHCTL(IDC_HPLOT_OFFSET), !bNorm);
						EnableWindow(GETHCTL(IDC_HPLOT_MULT), !bNorm);

						// Find avg
						CalcMean(fHistoData, &fAvg, bDataType);

						// Normalize data
						NormalizeData(fHistoData, fAvg, bDataType);

						// Display mean value removed
						_snprintf(szBuffer, sizeof(szBuffer),
							"Mean Removed = %10.6e", fAvg);
						ShortenExp(szBuffer);
						strlcpy(sHPlot.message_str, szBuffer, MESSAGESIZE);

						// Put mean removed message into list box
						nDummy=
							ComboBox_InsertString(GETHCTL(IDC_HPLOT_MESSAGE),
							0, szBuffer);

						// Find new avg
						CalcMean(fHistoData, &fAvg, bDataType);

						// Display new mean value
						_snprintf(szBuffer, sizeof(szBuffer),
							"%10.6e", fAvg);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_HPLOT_AVG),
							szBuffer);

						// Recalc min & max
						FindMinMax(fHistoData, &fMin, &fMax, bDataType);
					}
					else // Not normalized
					{
						// Enable scaling
						EnableWindow(GETHCTL(IDC_HPLOT_OFFSET), !bNorm);
						EnableWindow(GETHCTL(IDC_HPLOT_MULT), !bNorm);

						// Display blank field
						SetWindowText(GETHCTL(IDC_HPLOT_AVG), "");
						strlcpy(sHPlot.message_str, "", MESSAGESIZE);

						// Remove list box "Mean Removed" message
						i=ComboBox_SelectString(GETHCTL(IDC_HPLOT_MESSAGE), -1,
							"Mean Removed");
						if(i!=CB_ERR)
						{
							nDummy=ComboBox_DeleteString(GETHCTL(
							IDC_HPLOT_MESSAGE), i);
						}

						// De-normalize working data
						// Copy complete data array to working memory
						for(i=0; i<fData[0]+ARRAY_OFFSET; i++)
						{
							fHistoData[i]=fData[i];
						}

						// Find new avg
						CalcMean(fHistoData, &fAvg, bDataType);

						// Display new mean value
						_snprintf(szBuffer, sizeof(szBuffer),
							"%10.6e", fAvg);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_HPLOT_AVG),
							szBuffer);

						// Recalc min & max
						FindMinMax(fHistoData, &fMin, &fMax, bDataType);
					}

					// Update plot scales
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDC_HPLOT_UPDATE,
						NULL, 0));

					// Show message
					nDummy=ComboBox_SetCurSel(GETHCTL(IDC_HPLOT_MESSAGE), 0);
				}
				break;

				// Respond to CR in an edit control
				// Note: No button is a DEFPUSHBUTTON
				case IDOK:
				{
					// The HWND returned by GetFocus() is not the same as the
					// one returned by GetDlgItem(), so the uTitle, etc
					// variables are used in these tests
					if((UINT)GetFocus()==uTitle)
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_HPLOT_TITLE, NULL, CBN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to SUBTITLE edit control
					if((UINT)GetFocus()==uSubtitle)
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_HPLOT_SUBTITLE, NULL, CBN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to MESSAGE edit control
					if((UINT)GetFocus()==uMessage)
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_HPLOT_MESSAGE, NULL, CBN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to FILENAME edit control
					if(GetFocus()==GETHCTL(IDC_HPLOT_FILENAME))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_HPLOT_FILENAME, NULL, EN_KILLFOCUS));
					}
					// Send EN_KILLFOCUS message to NUMBINS edit control
					if(GetFocus()==GETHCTL(IDC_HPLOT_NUMBINS))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_HPLOT_NUMBINS, NULL, EN_KILLFOCUS));
					}
					// Send EN_KILLFOCUS message to XLABEL edit control
					if(GetFocus()==GETHCTL(IDC_HPLOT_XLABEL))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_HPLOT_XLABEL, NULL, EN_KILLFOCUS));
					}
					// Send EN_KILLFOCUS message to YLABEL edit control
					if(GetFocus()==GETHCTL(IDC_HPLOT_YLABEL))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_HPLOT_YLABEL, NULL, EN_KILLFOCUS));
					}
					// Send EN_KILLFOCUS message to XMAX edit control
					if(GetFocus()==GETHCTL(IDC_HPLOT_XMAX))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_HPLOT_XMAX, NULL, EN_KILLFOCUS));
					}
					// Send EN_KILLFOCUS message to YMAX edit control
					if(GetFocus()==GETHCTL(IDC_HPLOT_YMAX))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_HPLOT_YMAX, NULL, EN_KILLFOCUS));
					}
					// Send EN_KILLFOCUS message to XMIN edit control
					if(GetFocus()==GETHCTL(IDC_HPLOT_XMIN))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_HPLOT_XMIN, NULL, EN_KILLFOCUS));
					}
					// Send EN_KILLFOCUS message to YMIN edit control
					if(GetFocus()==GETHCTL(IDC_HPLOT_YMIN))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_HPLOT_YMIN, NULL, EN_KILLFOCUS));
					}
					// Send EN_KILLFOCUS message to XSTEP edit control
					if(GetFocus()==GETHCTL(IDC_HPLOT_XSTEP))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_HPLOT_XSTEP, NULL, EN_KILLFOCUS));
					}
					// Send EN_KILLFOCUS message to YSTEP edit control
					if(GetFocus()==GETHCTL(IDC_HPLOT_YSTEP))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_HPLOT_YSTEP, NULL, EN_KILLFOCUS));
					}
					// Send EN_KILLFOCUS message to OFFSET edit control
					if(GetFocus()==GETHCTL(IDC_HPLOT_OFFSET))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_HPLOT_OFFSET, NULL, EN_KILLFOCUS));
					}
					// Send EN_KILLFOCUS message to MULT edit control
					if(GetFocus()==GETHCTL(IDC_HPLOT_MULT))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_HPLOT_MULT, NULL, EN_KILLFOCUS));
					}
				}
				break;

				// Respond to plot button
				case IDC_HPLOT_PLOT:
				{
					// Reallocate memory for histogram bins
					// +1 is for scale factor
					if((fBins=(float*)realloc((void*)fBins,
						(nBins+1)*sizeof(float)))==NULL)
					{
						// Just abandon plot
						AllocErrorMessage();
						break;
					}

					// Reallocate memory for histogram counts
					if((fHist=(float*)realloc((void*)fHist,
						nBins*sizeof(float)))==NULL)
					{
						// Just abandon plot
						AllocErrorMessage();
						break;
					}

					// Clear histogram arrays
					for(i=0; i<nBins; i++)
					{
						fBins[i]=0.0;
						fHist[i]=0.0;
					}

					for(i=0; i<nBins; i++)
					{
						fBins[i]=fScaleMin+i*(fRange/nBins);
					}

					fBins[nBins]=fScaleMax;

					// Save nBins in plot structure
					sHPlot.num=nBins;

					// Calc histogram
					// HistoCalc() moved to FrequenC DLL 03/20/03
					HistoCalc(fHistoData, fBins, fHist, &fYMax, nBins,
						bDataType);

					#if(0) // Original code
					// Write histo data file
					fFile=fopen("Histo.dat", "w");
					#endif

					#if(1) // New code 09/19/11 Full path added
					// 10/03/11 Changed to safe string functions
					// Don't want to write this file where data read from
					// because may not have write permission to that folder
					// especially if it is on a network drive
					// Compose histo data filename
					strlcpy(szBigBuffer, szPath, BIG_BUFFER_SIZE);
					strlcat(szBigBuffer, "Histo.dat", BIG_BUFFER_SIZE);
					
					// Open histo data file
					fFile=fopen(szBigBuffer, "w");
					#endif
	
					// Write histo data file
					for(i=0; i<nBins; i++)
					{
						_snprintf(szBuffer, sizeof(szBuffer), "%e %e\n",
							fBins[i], fHist[i]);

						// Write data file
						fputs(szBuffer, fFile);
					}

					// Close file
					fclose(fFile);

					// Get message text
					GetWindowText(GETHCTL(IDC_HPLOT_MESSAGE),
							(LPSTR)szBuffer, BUFFER_SIZE);
					strlcpy(sHPlot.message_str, szBuffer, MESSAGESIZE);

					// Set plot type
					nPlotType=HISTO_PLOT;

					// Create child window for plot
					GPCWINCreate(hChildWnd, hInst, hDlg, SW_SHOWNORMAL,
						&hChildAccel, NULL);
					
					// This appears necessary to get plotdata strut items
					// after histogram plot is closed
					YieldControl();
					
					// Display max, min & step x & y axis scale values
					// Y scale maximum
					_snprintf(szBuffer, sizeof(szBuffer),
							"%10.6e", sHPlot.y_max);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_HPLOT_YMAX), szBuffer );
					// Y scale minimum
					_snprintf(szBuffer, sizeof(szBuffer),
							"%10.6e", sHPlot.y_min);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_HPLOT_YMIN), szBuffer );
					// Y scale step
					_snprintf(szBuffer, sizeof(szBuffer),
							"%10.6e", sHPlot.y_step);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_HPLOT_YSTEP), szBuffer );
					// X scale maximum
					_snprintf(szBuffer, sizeof(szBuffer),
							"%10.6e", sHPlot.x_max);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_HPLOT_XMAX), szBuffer );
					// X scale minimum
					_snprintf(szBuffer, sizeof(szBuffer),
							"%10.6e", sHPlot.x_min);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_HPLOT_XMIN), szBuffer );
					// X scale step
					_snprintf(szBuffer, sizeof(szBuffer),
							"%10.6e", sHPlot.x_step);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_HPLOT_XSTEP), szBuffer );

					// Display max & min x & y data values
					_snprintf(szBuffer, sizeof(szBuffer),
							"%10.6e", fMax);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_HPLOT_BINMAX), szBuffer );
					_snprintf(szBuffer, sizeof(szBuffer),
							"%10.6e", fMin);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_HPLOT_BINMIN), szBuffer );
					_snprintf(szBuffer, sizeof(szBuffer),
							"%10.6e", fYMax);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_HPLOT_DATAMAX), szBuffer );
					_snprintf(szBuffer, sizeof(szBuffer),
							"%d", 0);
					SetWindowText(GETHCTL(IDC_HPLOT_DATAMIN), szBuffer );
				}
				break;

				// Reset all plot params to defaults
				case IDC_HPLOT_RESET:
				{
					// Display blank field
					SetWindowText(GETHCTL(IDC_HPLOT_AVG), "");
					strlcpy(sHPlot.message_str, "", MESSAGESIZE);

					// Set initialization flag
					bFirstTime=TRUE;

					// Do initialization
					bSave=bUseHistoPlotIni;
					bUseHistoPlotIni=FALSE;
					SendMessage(hDlg, WM_INITDIALOG, (WPARAM)0, (LPARAM)0);
					bUseHistoPlotIni=bSave;
				}
				break;

				// Update plot scales
				case IDC_HPLOT_UPDATE:
				{
					// Update plot scales
					// Add controls for bin size and X & Y scales
					// Find data range
					FindMinMax(fHistoData, &fMin, &fMax, bDataType);
					CalcMean(fHistoData, &fAvg, bDataType);

					// Set up plot scales
					// Double range to give more room for "tail" of bell curve
					fScaleMax=(float)(fMax +(fMax-fMin)/2);
					fScaleMin=(float)(fMin -(fMax-fMin)/2);
					roundq(5, &fScaleMin, &fStep, &fScaleMax, cScaleFormat);
					CalcFreqStdDev(fHistoData, &fDev);       /* calc std dev */

					// Set up scales
					sHPlot.y_mult=(float)fDev;           /* y_mult = std dev */
					sHPlot.y_offset=(float)fAvg;     /* y_offset = avg value */
					sHPlot.x_min=fScaleMin;
					sHPlot.x_max=fScaleMax;
					sHPlot.y_min=0;
					sHPlot.y_max=0;

					// Set up bins
					fRange=fScaleMax-fScaleMin;           /* plot data range */
					nData=(int)(fHistoData[2]-fHistoData[1]+1);     /* # pts */
					nBins=(int)sqrt(nData);      /* seems like a good choice */
					nBins/=2;                 /* but a bit smaller is better */
					if(nBins<10)        /* make sure # bins is not too small */
					{
						nBins=10;                         /* min # bins = 10 */
					}
					// Find "nice" # bins: 10,15,20,25,30,40,50,60,75 or 100
					i=0;
					while(nBins>100)
					{
						nBins/=10;
						i++;
					}
					// Now nBins is between 10 and 100
					if(nBins<15)
					{
						nBins=10;
					}
					else if(nBins<20)
					{
						nBins=15;
					}
					else if(nBins<25)
					{
						nBins=20;
					}
					else if(nBins<30)
					{
						nBins=25;
					}
					else if(nBins<35)
					{
						nBins=30;
					}
					else if(nBins<50)
					{
						nBins=40;
					}
					else if(nBins<60)
					{
						nBins=50;
					}
					else if(nBins<70)
					{
						nBins=60;
					}
					else if(nBins<85)
					{
						nBins=75;
					}
					else
					{
						nBins=100;
					}
					// Restore factors of 10
					while(i>0)
					{
						nBins*=10;
						i--;
					}

					// Display mean value
					_snprintf(szBuffer, sizeof(szBuffer), "%e", fAvg);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_HPLOT_AVG), szBuffer);

					// Display # bins
					_snprintf(szBuffer, sizeof(szBuffer), "%d", nBins);
					SetWindowText(GETHCTL(IDC_HPLOT_NUMBINS), szBuffer);

					// Display bin size
					_snprintf(szBuffer, sizeof(szBuffer), "%e", fRange/nBins);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_HPLOT_BINSIZE), szBuffer);

					// Display axis labels
					SetWindowText(GETHCTL(IDC_HPLOT_XLABEL), sHPlot.x_label);
					SetWindowText(GETHCTL(IDC_HPLOT_YLABEL), sHPlot.left_y_label);

					// Display x-axis bin values
					// Need to choose whether to display bin centers or limits
					#if(0)
					// Center of min bin is at data min + bin size/2
					_snprintf(szBuffer, sizeof(szBuffer), "%e", fMin+(fRange/(2*nBins)));
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_HPLOT_BINMIN), szBuffer);
					#endif
					// Bottom of min bin is at data min
					_snprintf(szBuffer, sizeof(szBuffer), "%e", fMin);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_HPLOT_BINMIN), szBuffer);
					#if(0)
					// Center of max bin is at data max - bin size/2
					_snprintf(szBuffer, sizeof(szBuffer), "%e", fMax-(fRange/(2*nBins)));
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_HPLOT_BINMAX), szBuffer);
					#endif
					// Top of max bin is at data max
					_snprintf(szBuffer, sizeof(szBuffer), "%e", fMax);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_HPLOT_BINMAX), szBuffer);

					// Display y-axis frequency values
					// Have to calc histogram to show these
					// At initialization, just show message
					SetWindowText(GETHCTL(IDC_HPLOT_DATAMAX), "Press Plot to calc");
					SetWindowText(GETHCTL(IDC_HPLOT_DATAMIN), "Press Plot to calc");
					SetWindowText(GETHCTL(IDC_HPLOT_YMAX), "Press Plot to calc");
					SetWindowText(GETHCTL(IDC_HPLOT_YMIN), "Press Plot to calc");
					SetWindowText(GETHCTL(IDC_HPLOT_YSTEP), "Press Plot to calc");

					// Display x-axis bin max and min values
					// Have to calc histogram to show these
					// At initialization, just show message
					SetWindowText(GETHCTL(IDC_HPLOT_XMAX), "Press Plot to calc");
					SetWindowText(GETHCTL(IDC_HPLOT_XMIN), "Press Plot to calc");
					SetWindowText(GETHCTL(IDC_HPLOT_XSTEP), "Press Plot to calc");

					// Initialize y-axis scale factors to zero as flag to calc them
					sHPlot.y_min=0;
					sHPlot.y_max=0;
				}
				break;

				// Respond to esc key or close button
				case IDCANCEL:
				case IDC_HPLOT_CANCEL:
				{
					// Save # user-entered title strings
					nUserTitles=ComboBox_GetCount(GETHCTL(IDC_HPLOT_TITLE))-
						NUM_HPLOT_TITLES;

					// Limit # user titles
					nUserTitles=min(nUserTitles, NUM_TITLES);

					// Save user titles
					if(nUserTitles)
					{
						for(i=0; i<nUserTitles; i++)
						{
							// Get size of title string
							nLength=ComboBox_GetLBTextLen(GETHCTL(
								IDC_HPLOT_TITLE), i);

							// Realloc title array
							if((szPlotTitle[i]=
								(LPSTR)realloc(szPlotTitle[i],
								(nLength+1)*sizeof(char)))==NULL)
							{
								// Just dsp err msg & skip saving string
								// We are closing dlg box anyway
								AllocErrorMessage();
							}
							else
							{
								// Save title string
								nDummy=
									ComboBox_GetLBText(GETHCTL(
									IDC_HPLOT_TITLE),
									i, szPlotTitle[i]);
							}
						}
					}

					// Save # user-entered subtitle strings
					nUserSubtitles=
						ComboBox_GetCount(GETHCTL(IDC_HPLOT_SUBTITLE))-
						NUM_HPLOT_SUBTITLES;

					// Limit # user subtitles
					nUserSubtitles=min(nUserSubtitles, NUM_SUBTITLES);

					// Save user subtitles
					if(nUserSubtitles)
					{
						for(i=0; i<nUserSubtitles; i++)
						{
							// Get size of subtitle string
							nLength=ComboBox_GetLBTextLen(GETHCTL(
								IDC_HPLOT_SUBTITLE), i);

							// Realloc subtitle array
							if((szPlotSubtitle[i]=
								(LPSTR)realloc(szPlotSubtitle[i],
								(nLength+1)*sizeof(char)))==NULL)
							{
								// Just dsp err msg & skip saving string
								// We are closing dlg box anyway
								AllocErrorMessage();
							}
							else
							{
								// Save subtitle string
								nDummy=ComboBox_GetLBText(GETHCTL(
									IDC_HPLOT_SUBTITLE), i, szPlotSubtitle[i]);
							}
						}
					}

					// Save # user-entered message strings
					nUserMessages=
						ComboBox_GetCount(GETHCTL(IDC_HPLOT_MESSAGE))-
						NUM_HPLOT_MESSAGES;

					// Limit # user messages
					nUserMessages=min(nUserMessages, NUM_MESSAGES);

					// Save user messages
					if(nUserMessages)
					{
						for(i=0; i<nUserMessages; i++)
						{
							// Get size of message string
							nLength=ComboBox_GetLBTextLen(GETHCTL(
								IDC_HPLOT_MESSAGE), i);

							// Realloc message array
							if((szPlotMessage[i]=
								(LPSTR)realloc(szPlotMessage[i],
								(nLength+1)*sizeof(char)))==NULL)
							{
								// Just dsp err msg & skip saving string
								// We are closing dlg box anyway
								AllocErrorMessage();
							}
							else
							{
								// Save message string
								nDummy=ComboBox_GetLBText(GETHCTL(
									IDC_HPLOT_MESSAGE), i, szPlotMessage[i]);
							}
						}
					}

					if(bAlloc)
					{
					
						// Free histogram data arrays
						free(fHistoData);
						free(fBins);
						free(fHist);

						// Set dead pointers to 0
						fHistoData=0;
						fBins=0;
						fHist=0;

						bAlloc=FALSE;
					}

					// Close dialog box
					EndDialog (hDlg, 0);
				}
				return TRUE;
			}
		}
		break;
	 }
	 return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*                Read Plot Parameter Entry Dialog Procedure                 */
/*                                                                           */
/* 	Dialog box controls (Save template as for sigma plot options):           */
/*			ID					Description		Variable or struct member    */
/*	IDC_SPLOT_TITLE		 		Plot Title              .title{}             */
/*	IDC_SPLOT_SUBTITLE	 		Plot Subtitle           .sub_title{}         */
/*	IDC_SPLOT_MESSAGE	 		Plot Message            .message_str[]       */
/*	IDC_SPLOT_DATE		 		Date Flag               .do_date             */
/*	IDC_SPLOT_BOX		 		Box Flag                .do_box              */
/*	IDC_SPLOT_ERRBAR		 	Error Bar Flag          .do_errbar           */
/*	IDC_SPLOT_TABLE		 		Table Flag              .do_table            */
/*	IDC_SPLOT_FILENAME	 		Plot Filename           .plot_filename[]     */
/*	IDC_SPLOT_YMAX		 		Y Scale Maximum         .y_max               */
/*	IDC_SPLOT_YMIN		 		Y Scale Minimum         .y_min               */
/*	IDC_SPLOT_XMAX		 		X Scale Maximum                              */
/*	IDC_SPLOT_XMIN		 		X Scale Minimum                              */
/*	IDC_SPLOT_POSITION			Message position		.position            */
/*	IDC_SPLOT_RESET		 		Reset Param Flag                             */
/*	IDC_SPLOT_SIGMAMAX	 		Sigma Maximum                                */
/*	IDC_SPLOT_SIGMAMIN	 		Sigma Minimum                                */
/*	IDC_SPLOT_YMULTLABEL 		Y Multiplier Label                           */
/*	IDC_SPLOT_YOFFLABEL         Y Offset Label                               */
/*	IDC_SPLOT_YLABLABEL         Y Label Label                                */
/*	IDC_SPLOT_XMULTLABEL        X Multiplier Label                           */
/*	IDC_SPLOT_XOFFLABEL         X Offset Label                               */
/*	IDC_SPLOT_XLABLABEL         X Label Label                                */
/*                                                                           */
/*	struct plotdata             structure template for plot data             */
/*	{                                                                        */
/*		float x_offset;                                             not used */
/*		float x_mult;                                               not used */
/*		float y_offset;                                             not used */
/*		float y_mult;                                               not used */
/*		float x_min;                                     x-axis plot minimum */
/*		float x_max;                                     x-axis plot maximum */
/*		float y_min;                                     y-axis plot minimum */
/*		float y_max;                                     y-axis plot maximum */
/*		char title[TITLESIZE];                                    plot title */
/*		char subtitle[SUBTITLESIZE];                           plot subtitle */
/*		char x_label[XLABELSIZE];                          plot x-axis label */
/*		char left_y_label[YLABELSIZE];           plot y-axis left side label */
/*		char right_y_label[YLABELSIZE];         plot y-axis right side label */
/*		char plot_filename[FILENAMESIZE];                 plot .TKF filename */
/*		char message_str[MESSAGESIZE];                   plot message string */
/*		int do_date;                               flag to draw date on plot */
/*		int do_box;                             flag to draw box around plot */
/*		int do_errbar;                    flag to include error bars on plot */
/*		int do_line;                code to control drawing of lines on plot */
/*		int do_mouse;                                               not used */
/*		int do_table;        flag to write sigma-tau table on stability plot */
/*		int new_file;                  flag that plot is for a new data file */
/*		int new_name;             flag that plot is for a new basic filename */
/*		int plotype;                       code to identify the type of plot */
/*		int position;        code to control position of message box on plot */
/*		int x_div;                                                  not used */
/*		int x_tic;                                                  not used */
/*		int y_div;                                                  not used */
/*		int y_tic;                                                  not used */
/*		int config;                       flag for active configuration file */
/*	}                                                                        */
/*                                                                           */
/*		Run (Sigma) Types    nSigmaPlotType                                  */
/*		NORMAL_RUN             0                                             */
/*		OVERLAPPING_RUN        1                                             */
/*		MODIFIED_RUN           2                                             */
/*		TIME_RUN               3                                             */
/*		HADAMARD_RUN           4                                             */
/*		OVERLAPHAD_RUN		   5                                             */
/*		TOTAL_RUN              6                                             */
/*		MODTOTAL_RUN		   7                                             */
/*		TIMETOTAL_RUN		   8                                             */
/*		HADTOTAL_RUN		   9                                             */
/*		BOTH_RUN              10                                             */
/*		TIERMS_RUN            11                                             */
/*		MTIE_RUN              12                                             */
/*		THEO1_RUN			  13                                             */
/*		FULL_RUN              14                                             */
/*		CROSS_RUN			  15                                             */
/*                                                                           */
/*		X-label x-axis (tau) strings                                         */
/*		IDS_SPLOT_XLABEL_n                                                   */
/*                                                                           */
/*		Y-label y-axis (sigma) strings                                       */
/*		IDS_SPLOT_YLABEL_n                                                   */
/*                                                                           */
/* 		Revision record:                                                     */
/*			10/17/96	Adapted from SigmaPlotDlgProc()                      */
/*			06/05/98	Added provisions for TIE rms and MTIE                */
/*			08/31/98	Added do_fit usage                                   */
/*			05/21/00	Added missing table position code                    */
/*			02/16/10	Added cross sigma support                            */
/*                                                                           */
/*****************************************************************************/

#ifndef _MSC_VER
	#pragma argsused
#endif

BOOL CALLBACK ReadPlotDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	// Chars
	char szBuffer[BUFFER_SIZE+1]; 	// Text buffer
	char szTemp[BUFFER_SIZE+1];	    // Temp buffer
	// Temporary filename buffers
	char szTempFile[FILENAMESIZE+1];	// Temp full filename buffer
	char szTempTitle[FILENAMESIZE+1];	// Temp file title buffer
	char szTempPath[FILENAMESIZE+1];	// Temp file path buffer
	char szTempName[FILENAMESIZE+1];    // Temp file name buffer
	char szTempExt[BUFFER_SIZE+1];		// Temp file extension buffer
	// Ints
	int i;							// Index
	static int nPoints;         	// # sigma data points
	int nLength;					// String length
	static int nMessageCount;		// # non-user messages entered into list
	// BOOLs
	BOOL bSave;						// BOOL to save state of ini flag
	static BOOL bErrorTrap=FALSE;   // Flag for entry error
	// Floats
	static float fTauMax;      		// Tau data maximum
	static float fTauMin;       	// Tau data minimum
	static float fSigmaMax;     	// Sigma data maximum
	static float fSigmaMin;     	// Sigma data minimum
	static float fEntry;        	// Entry to be validated

	// Note: The sigma plot data structs, sSPlot & sSPrev, are defined globally

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Set dialog box title
			LoadString(hInst, IDS_TITLE_READOPT, szBuffer,	BUFFER_SIZE);
			SetWindowText(hDlg, szBuffer);

			// Hide the stability plot filename edit control
			// Can't choose name of stability plot here
			ShowWindow(GETHCTL(IDC_SPLOT_STABFILE), SW_HIDE);

			// Display stability filename
			strlcpy(szBuffer, "Stability File: ", sizeof(szBuffer));
			strlcat(szBuffer, szStabFileTitle, sizeof(szBuffer));
			SetWindowText(GETHCTL(IDC_SPLOT_SLABEL),
				szBuffer);

			// Get sigma & tau min & max
			SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDC_SPLOT_MINMAX,
				NULL, 0));

			// Load selectable x-axis tau label label - not wanted 09/24/98
			// SetWindowText(GETHCTL(IDC_SPLOT_XLABLABEL), "Label:");

			// Fill up x-axis label list box using string table
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_SPLOT_XLABEL));
			for(i=0; i<NUM_SPLOT_XLABELS; i++)
			{
				LoadString(hInst, IDS_SPLOT_XLABEL_0+i, szBuffer, BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_SPLOT_XLABEL), i,
					szBuffer);
			}

			// Load the x-axis label
			SetWindowText(GETHCTL(IDC_SPLOT_XLABEL), sSPlot.x_label);

			// Load selectable y-axis sigma label - not wanted 09/24/98
			// SetWindowText(GETHCTL(IDC_SPLOT_YLABLABEL), "Label:");

			// Fill up y-axis label list box using string table
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_SPLOT_YLABEL));

			// Have NUM_SPLOT_YLABELS sigma types
			// Allow NUM_SPLOT_YNAMES for each sigma type
			// Strings are organized in NUM_SPLOT_YNAMES=3 groups of
			// NUM_SPLOT_YLABELS=8
			for(i=0; i<NUM_SPLOT_YNAMES; i++)
			{
				LoadString(hInst,
					IDS_SPLOT_YLABEL_0+(i*NUM_SPLOT_YLABELS)+nSigmaPlotType,
					szBuffer, BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_SPLOT_YLABEL), i,
					szBuffer);
			}

			// Load the y-axis label
			SetWindowText(GETHCTL(IDC_SPLOT_YLABEL), sSPlot.left_y_label);

			// Save previous sigma plot parameters
			strlcpy(sSPrev.title, sSPlot.title, TITLESIZE);
			strlcpy(sSPrev.subtitle, sSPlot.subtitle, SUBTITLESIZE);
			strlcpy(sSPrev.message_str, sSPlot.message_str, MESSAGESIZE);
			strlcpy(sSPrev.plot_filename, sSPlot.plot_filename, FILENAMESIZE);
			sSPrev.x_max=sSPlot.x_max;
			sSPrev.x_min=sSPlot.x_min;
			sSPrev.y_max=sSPlot.y_max;
			sSPrev.y_min=sSPlot.y_min;
			sSPrev.do_date=sSPlot.do_date;
			sSPrev.do_box=sSPlot.do_box;
			sSPrev.do_fit=sSPlot.do_fit;
			sSPrev.do_mouse=sSPlot.do_mouse;
			sSPrev.do_table=sSPlot.do_table;
			sSPrev.position=sSPlot.position;
			sSPrev.table_position=sSPlot.table_position;
			strlcpy(sSPrev.x_label, sSPlot.x_label, XLABELSIZE);
			strlcpy(sSPrev.left_y_label, sSPlot.left_y_label, YLABELSIZE);

			// Fill up message position list box using string table
			// Note usage of DPLOT rather than SPLOT strings
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_SPLOT_POSITION));
			nDummy=ComboBox_InsertString(GETHCTL(IDC_SPLOT_POSITION),
				0, "None");
			for(i=0; i<NUM_DPLOT_POSITIONS; i++)
			{
				LoadString(hInst, IDS_DPLOT_POSITION_0+i, szBuffer,
					BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_SPLOT_POSITION),
					i, szBuffer);
			}

			// Show position
			nDummy=ComboBox_SetCurSel(GETHCTL(IDC_SPLOT_POSITION),
				sSPlot.position);

			// Fill up table position list box using string table
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_SPLOT_TABPOS));
			for(i=0; i<NUM_TABLE_POSITIONS; i++)
			{
				LoadString(hInst, IDS_TABLE_POSITION_0+i, szBuffer,
					BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_SPLOT_TABPOS),
					i, szBuffer);
			}

			// Show position
			nDummy=ComboBox_SetCurSel(GETHCTL(IDC_SPLOT_TABPOS),
				sSPlot.table_position);

			// Disable table position control if table is not checked
			EnableWindow(GETHCTL(IDC_SPLOT_TABPOS), sSPlot.do_table);

			// Load the title
			SetWindowText(GETHCTL(IDC_SPLOT_TITLE), sSPlot.title);

			// Load the subtitle
			SetWindowText(GETHCTL(IDC_SPLOT_SUBTITLE), sSPlot.subtitle);

			// Clear the message list box
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_SPLOT_MESSAGE));
			nMessageCount=0;

			// Load line parameter messages
			for(i=0; i<SLINE_NUMLINES; i++)
			{
				switch(sSLine[i].nLineType)
				{
					case SLINE_NOISE:
					{
						// Compose noise line parameter message
						// Example: Line 1: W FM Sigma(1)=1.234e-12
						// nSlope	Noise
						// 0		W PM
						// 1		F PM
						// 2		W FM
						// 3       F FM
						// 4       RW FM
						// 5       Aging
						LoadString(hInst, IDS_FORMAT_LINE_0+sSLine[i].nSlope,
							szTemp, BUFFER_SIZE);
						_snprintf(szBuffer, sizeof(szBuffer), szTemp, i+1,
							sSLine[i].fSigma1);
						ShortenExp(szBuffer);
						nDummy=ComboBox_AddString(GETHCTL(IDC_SPLOT_MESSAGE),
							szBuffer);
						nMessageCount++;
					}
					break;
				}
			}

			// Load previous user-entered message strings into list box
			if(nUserMessages)
			{
				for(i=0; i<nUserMessages; i++)
				{
					// Load message string
					nDummy=ComboBox_InsertString(GETHCTL(IDC_SPLOT_MESSAGE),
						i, szPlotMessage[i]);
				}
			}

			// Load the current message
			SetWindowText(GETHCTL(IDC_SPLOT_MESSAGE),
				sSPlot.message_str);

			// Load the plot filename
			SetWindowText(GETHCTL(IDC_SPLOT_FILENAME), sSPlot.plot_filename);

			// Load the fTauMax value
			_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fTauMax);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_SPLOT_TAUMAX), szBuffer);

			// Load the fSigmaMax value
			_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fSigmaMax);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_SPLOT_SIGMAMAX), szBuffer);

			// Load the x_max value
			_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", sSPlot.x_max);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_SPLOT_XMAX), szBuffer);

			// Load the y_max value
			_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", sSPlot.y_max);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_SPLOT_YMAX), szBuffer);

			// Load the fTauMin value
			_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fTauMin);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_SPLOT_TAUMIN), szBuffer);

			// Load the fSigmaMin value
			_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fSigmaMin);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_SPLOT_SIGMAMIN), szBuffer);

			// Load the x_min value
			_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", sSPlot.x_min);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_SPLOT_XMIN), szBuffer);

			// Load the y_min value
			_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", sSPlot.y_min);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_SPLOT_YMIN), szBuffer);

			// Restore the date checkbox state
			Button_SetCheck(GETHCTL(IDC_SPLOT_DATE), sSPlot.do_date);

			// Restore the box checkbox state
			Button_SetCheck(GETHCTL(IDC_SPLOT_BOX), sSPlot.do_box);

			// Restore the fit checkbox state
			Button_SetCheck(GETHCTL(IDC_SPLOT_FIT), sSPlot.do_fit);

			// Activate only if there are noise or TDEV lines
			EnableWindow(GETHCTL(IDC_SPLOT_FIT), FALSE);

			for(i=0; i<SLINE_NUMLINES; i++)
			{
				if( (sSLine[i].nLineType==SLINE_NOISE) ||
					(sSLine[i].nLineType==SLINE_TDEV) )
				{
					EnableWindow(GETHCTL(IDC_SPLOT_FIT), TRUE);
				}
			}

			// Set errorbar checkbox state
			if( (!bAllTau) && (nSigmaPlotType!=TIERMS_RUN) &&
				(nSigmaPlotType!=MTIE_RUN) && nSigmaPlotType!=BOTH_RUN)
			{
				// Restore the errorbar checkbox state
				Button_SetCheck(GETHCTL(IDC_SPLOT_ERRBAR), sSPlot.do_errbar);
				EnableWindow(GETHCTL(IDC_SPLOT_ERRBAR), TRUE);
			}
			else // All tau sigma or TIE rms or MTIE or both ADEV & MDEV
			{
				// Disable error bars
				sSPlot.do_errbar=FALSE;
				Button_SetCheck(GETHCTL(IDC_SPLOT_ERRBAR), sSPlot.do_errbar);
				EnableWindow(GETHCTL(IDC_SPLOT_ERRBAR), FALSE);
			}

			// Set the table checkbox state
			if(bAllTau)
			{
				// Disable table
				Button_SetCheck(GETHCTL(IDC_SPLOT_TABLE), FALSE);
				// EnableWindow(GETHCTL(IDC_SPLOT_TABLE), FALSE);
				// Allow new all tau table
				EnableWindow(GETHCTL(IDC_SPLOT_TABLE), TRUE);
			}
			else
			{
				// Restore the box checkbox state
				Button_SetCheck(GETHCTL(IDC_SPLOT_TABLE), sSPlot.do_table);
				EnableWindow(GETHCTL(IDC_SPLOT_TABLE), TRUE);
			}

			// Set the errorbar checkbox state
			if(bAllTau)
			{
				// Disable errorbars
				Button_SetCheck(GETHCTL(IDC_SPLOT_ERRBAR), FALSE);
				EnableWindow(GETHCTL(IDC_SPLOT_ERRBAR), FALSE);
			}
			else
			{
				// Restore the errorbar checkbox state
				Button_SetCheck(GETHCTL(IDC_SPLOT_ERRBAR), sSPlot.do_errbar);
			}

			return TRUE;
		}

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::READ_OPTIONS_FUNCTION.HTM",
						HH_DISPLAY_TOPIC,
                        0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::READ_OPTIONS_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "READ_OPTIONS_FUNCTION");
					#endif
				}
				break;

				// Detect parameter changes
				// Title change
				case IDC_SPLOT_TITLE:
				{
					GetWindowText(GETHCTL(IDC_SPLOT_TITLE),
						sSPlot.title, TITLESIZE-1);
				}
				break;

				// Subtitle change
				case IDC_SPLOT_SUBTITLE:
				{
					GetWindowText(GETHCTL(IDC_SPLOT_SUBTITLE),
						sSPlot.subtitle, SUBTITLESIZE-1);
				}
				break;

				// X-Axis label change
				case IDC_SPLOT_XLABEL:
				{
					GetWindowText(GETHCTL(IDC_SPLOT_XLABEL),
						sSPlot.x_label, XLABELSIZE-1);
				}
				break;

				// Y-Axis label change
				case IDC_SPLOT_YLABEL:
				{
					GetWindowText(GETHCTL(IDC_SPLOT_YLABEL),
						sSPlot.left_y_label, YLABELSIZE-1);
				}
				break;

				// Message change
				case IDC_SPLOT_MESSAGE:
				{
					// Respond to focus lost
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_KILLFOCUS)
					{
						GetWindowText(GETHCTL(IDC_SPLOT_MESSAGE),
						sSPlot.message_str, MESSAGESIZE-1);

						// Redisplay message - perhaps shortened
						SetWindowText(GETHCTL(IDC_SPLOT_MESSAGE),
							sSPlot.message_str);

						// Put new string into list
						// Don't store string if it is same as before
						if(ComboBox_FindString(GETHCTL(IDC_SPLOT_MESSAGE),
							-1, sSPlot.message_str)==CB_ERR)
						{
							// Don't store blank message either
							if(strlen(sSPlot.message_str))
							{
								nDummy=ComboBox_InsertString(GETHCTL(
									IDC_SPLOT_MESSAGE), 0, sSPlot.message_str);
							}
						}
					}
				}
				break;

				// Plot Filename change
				case IDC_SPLOT_FILENAME:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_SPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						GetWindowText(GETHCTL(IDC_SPLOT_FILENAME),
							szTempFile, FILENAMESIZE-1);

						// Validate new filename
						if(CheckFilename(szTempFile, szTempTitle, szTempPath,
							szTempName, szTempExt, hDlg,
							"Sigma Plot Filename"))
						{
							// Filename OK
							strlcpy(sSPlot.plot_filename, szTempFile,
								FILENAMESIZE);
						}
						else // Filename NG
						{
							// Restore original filename
							SetWindowText(GETHCTL(IDC_SPLOT_FILENAME),
								sSPlot.plot_filename);
							SetFocus(GETHCTL(IDC_SPLOT_FILENAME));
							break;
						}
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Stability filename change
				case IDC_SPLOT_STABFILE:
				{
					GetWindowText(GETHCTL(IDC_SPLOT_STABFILE),
						szStabFile, FILENAMESIZE-1);
				}
				break;

				// Message position change
				case IDC_SPLOT_POSITION:
				{
					sSPlot.position=
						ComboBox_GetCurSel(GETHCTL(IDC_SPLOT_POSITION));
				}
				break;

				// Table position change
				case IDC_SPLOT_TABPOS:
				{
					sSPlot.table_position=
						ComboBox_GetCurSel(GETHCTL(IDC_SPLOT_TABPOS));
				}
				break;

				// Date flag change
				case IDC_SPLOT_DATE:
				{
					sSPlot.do_date=Button_GetCheck(GETHCTL(IDC_SPLOT_DATE));
				}
				break;

				// Box flag change
				case IDC_SPLOT_BOX:
				{
					sSPlot.do_box=Button_GetCheck(GETHCTL(IDC_SPLOT_BOX));
				}
				break;

				// Errorbar flag change
				case IDC_SPLOT_ERRBAR:
				{
					sSPlot.do_errbar=
						Button_GetCheck(GETHCTL(IDC_SPLOT_ERRBAR));
				}
				break;

				// Fit label flag change
				case IDC_SPLOT_FIT:
				{
					sSPlot.do_fit=Button_GetCheck(GETHCTL(IDC_SPLOT_FIT));
				}
				break;

				// Table flag change
				case IDC_SPLOT_TABLE:
				{
					sSPlot.do_table=
						Button_GetCheck(GETHCTL(IDC_SPLOT_TABLE));

					// Disable table position control if table is not checked
					EnableWindow(GETHCTL(IDC_SPLOT_TABPOS), sSPlot.do_table);
				}
				break;

				// Read config button
				// Note: Read & Run share same plot info
				case IDC_SPLOT_READ:
				{
					bSave=bUseSigmaPlotIni;
					bUseSigmaPlotIni=TRUE;
					ReadIni(INI_SIGMA);
					bUseSigmaPlotIni=bSave;
					SendMessage(hDlg, WM_INITDIALOG, (WPARAM)0, (LPARAM)0);
				}
				break;

				// Save config button
				// Note: Read & Run share same plot info
				case IDC_SPLOT_WRITE:
				{
					bSave=bUseSigmaPlotIni;
					bUseSigmaPlotIni=TRUE;
					WriteIni(INI_SIGMA);
					bUseSigmaPlotIni=bSave;
				}
				break;
				
				// Y-axis plot scale max change
				case IDC_SPLOT_YMAX:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_SPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new y_max value
						GetWindowText(GETHCTL(IDC_SPLOT_YMAX),
							szBuffer, BUFFER_SIZE);
						fEntry=(float)fabs(atof(szBuffer));

						// Validate new y_max value
						// Can't be less than or equal to y_min
						if(fEntry>sSPlot.y_min)
						{
							// New value OK
							sSPlot.y_max=fEntry;
						}
						else
						{
							MessageBeep(0);
							LoadString(hInst, IDS_FORMAT_GT, szTemp,
								BUFFER_SIZE);
							_snprintf(szBuffer, sizeof(szBuffer), szTemp,
								fEntry,
								sSPlot.y_min);

							MessageBox(hDlg, szBuffer, "Invalid Entry",
								MB_ICONEXCLAMATION);
							SetFocus(GETHCTL(IDC_SPLOT_YMAX));
						}

						// Redisplay y_max value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							sSPlot.y_max);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_SPLOT_YMAX),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Y-axis plot scale min change
				case IDC_SPLOT_YMIN:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_SPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new y_min value
						GetWindowText(GETHCTL(IDC_SPLOT_YMIN),
							szBuffer, BUFFER_SIZE);
						fEntry=(float)fabs(atof(szBuffer));

						// Validate new y_min value
						// Can't be greater than or equal to y_max
						if(fEntry<sSPlot.y_max)
						{
							// New value OK
							sSPlot.y_min=fEntry;
						}
						else
						{
							MessageBeep(0);
							LoadString(hInst, IDS_FORMAT_LT, szTemp,
								BUFFER_SIZE);
							_snprintf(szBuffer, sizeof(szBuffer), szTemp,
								fEntry,
								sSPlot.y_max);

							MessageBox(hDlg, szBuffer, "Invalid Entry",
								MB_ICONEXCLAMATION);
							SetFocus(GETHCTL(IDC_SPLOT_YMIN));
						}

						// Redisplay y_min value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							sSPlot.y_min);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_SPLOT_YMIN),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// X-axis plot scale max change
				case IDC_SPLOT_XMAX:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_SPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new x_max value
						GetWindowText(GETHCTL(IDC_SPLOT_XMAX),
							szBuffer, BUFFER_SIZE);
						fEntry=(float)fabs(atof(szBuffer));

						// Validate new x_max value
						// Can't be less than or equal to x_min
						if(fEntry>sSPlot.x_min)
						{
							// New value OK
							sSPlot.x_max=fEntry;
						}
						else
						{
							MessageBeep(0);
							LoadString(hInst, IDS_FORMAT_GT, szTemp,
								BUFFER_SIZE);
							_snprintf(szBuffer, sizeof(szBuffer), szTemp,
								fEntry,	sSPlot.x_min);

							MessageBox(hDlg, szBuffer, "Invalid Entry",
								MB_ICONEXCLAMATION);
							SetFocus(GETHCTL(IDC_SPLOT_XMAX));
						}

						// Redisplay x_max value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							sSPlot.x_max);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_SPLOT_XMAX),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// X-axis plot scale min change
				case IDC_SPLOT_XMIN:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_SPLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new x_min value
						GetWindowText(GETHCTL(IDC_SPLOT_XMIN),
							szBuffer, BUFFER_SIZE);
						fEntry=(float)fabs(atof(szBuffer));

						// Validate new x_min value
						// Can't be greater than or equal to x_max
						if(fEntry<sSPlot.x_max)
						{
							// New value OK
							sSPlot.x_min=fEntry;
						}
						else
						{
							MessageBeep(0);
							LoadString(hInst, IDS_FORMAT_LT, szTemp,
								BUFFER_SIZE);
							_snprintf(szBuffer, sizeof(szBuffer), szTemp,
								fEntry,	sSPlot.x_max);

							MessageBox(hDlg, szBuffer, "Invalid Entry",
								MB_ICONEXCLAMATION);
							SetFocus(GETHCTL(IDC_SPLOT_XMIN));
						}

						// Redisplay x_min value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							sSPlot.x_min);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_SPLOT_XMIN),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Respond to CR in an edit control
				// Note: No button is a DEFPUSHBUTTON
				case IDOK:
				{
					// Send EN_KILLFOCUS message to XMIN edit control
					if(GetFocus()==GETHCTL(IDC_SPLOT_XMIN))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_SPLOT_XMIN, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to XMAX edit control
					if(GetFocus()==GETHCTL(IDC_SPLOT_XMAX))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_SPLOT_XMAX, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to YMIN edit control
					if(GetFocus()==GETHCTL(IDC_SPLOT_YMIN))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_SPLOT_YMIN, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to YMAX edit control
					if(GetFocus()==GETHCTL(IDC_SPLOT_YMAX))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_SPLOT_YMAX, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to FILENAME edit control
					if(GetFocus()==GETHCTL(IDC_SPLOT_FILENAME))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_SPLOT_FILENAME, NULL, EN_KILLFOCUS));
					}
				}
				break;

				// Get sigma & tau min & max
				case IDC_SPLOT_MINMAX:
				{
					if( (nSigmaPlotType==MODIFIED_RUN) ||
						(nSigmaPlotType==MODTOTAL_RUN) ||
						(nSigmaPlotType==TIME_RUN)     ||
						(nSigmaPlotType==TIMETOTAL_RUN) )
					{
						nPoints=sModSigData.points;
						minmax(&fTauMin, &fTauMax, sModSigData.tau,
							nPoints);
						minmax(&fSigmaMin, &fSigmaMax, sModSigData.sigma,
							nPoints);
					}
					else // ADEV, etc
					{
						nPoints=sNormSigData.points;
						minmax(&fTauMin, &fTauMax, sNormSigData.tau,
							nPoints);
						minmax(&fSigmaMin, &fSigmaMax, sNormSigData.sigma,
							nPoints);
					}
				}
				break;

				// Reset all plot params to defaults
				case IDC_SPLOT_RESET:
				{
					// Initialize read plot parameters
					InitReadPlotParams();
					CalcSigmaPlotScale();
					bSave=bUseSigmaPlotIni;
					bUseSigmaPlotIni=FALSE;
					SendMessage(hDlg, WM_INITDIALOG, (WPARAM)0, (LPARAM)0);
					bUseSigmaPlotIni=bSave;
				}
				break;

				// Respond to esc key or cancel button
				case IDCANCEL:
				case IDC_SPLOT_CANCEL:
				{
					// Restore previous sigma plot parameters
					strlcpy(sSPlot.title, sSPrev.title, TITLESIZE);
					strlcpy(sSPlot.subtitle, sSPrev.subtitle, SUBTITLESIZE);
					strlcpy(sSPlot.message_str, sSPrev.message_str,
						MESSAGESIZE);
					strlcpy(sSPlot.plot_filename, sSPrev.plot_filename,
						FILENAMESIZE);
					sSPlot.x_max=sSPrev.x_max;
					sSPlot.x_min=sSPrev.x_min;
					sSPlot.y_max=sSPrev.y_max;
					sSPlot.y_min=sSPrev.y_min;
					sSPlot.do_date=sSPrev.do_date;
					sSPlot.do_box=sSPrev.do_box;
					sSPlot.do_fit=sSPrev.do_fit;
					sSPlot.do_mouse=sSPrev.do_mouse;
					sSPlot.do_table=sSPrev.do_table;
					sSPlot.position=sSPrev.position;
					sSPlot.table_position=sSPrev.table_position;
					strlcpy(sSPlot.x_label, sSPrev.x_label, XLABELSIZE);
					strlcpy(sSPlot.left_y_label, sSPrev.left_y_label,
						YLABELSIZE);

					// Close dialog box
					EndDialog (hDlg, 0);
				}
				return TRUE;

				case IDC_SPLOT_ACCEPT:
				{
					// Save # user-entered title strings
					nUserTitles=
						ComboBox_GetCount(GETHCTL(IDC_SPLOT_TITLE))-
						NUM_SPLOT_TITLES;

					// Limit # user titles
					nUserTitles=min(nUserTitles, NUM_TITLES);

					// Save user titles
					if(nUserTitles)
					{
						for(i=0; i<nUserTitles; i++)
						{
							// Get size of title string
							nLength=ComboBox_GetLBTextLen(GETHCTL(
								IDC_SPLOT_TITLE), i);

							// Realloc title array
							if((szPlotTitle[i]=
								(LPSTR)realloc(szPlotTitle[i],
								(nLength+1)*sizeof(char)))==NULL)
							{
								// Just dsp err msg & skip saving string
								// We are closing dlg box anyway
								AllocErrorMessage();
							}
							else
							{
								// Save title string
								nDummy=
									ComboBox_GetLBText(GETHCTL(
									IDC_SPLOT_TITLE),
									i, szPlotTitle[i]);
							}
						}
					}

					// Save # user-entered subtitle strings
					nUserSubtitles=
						ComboBox_GetCount(GETHCTL(IDC_SPLOT_SUBTITLE))-
						NUM_SPLOT_SUBTITLES;

					// Limit # user subtitles
					nUserSubtitles=min(nUserSubtitles, NUM_SUBTITLES);

					// Save user subtitles
					if(nUserSubtitles)
					{
						for(i=0; i<nUserSubtitles; i++)
						{
							// Get size of subtitle string
							nLength=ComboBox_GetLBTextLen(GETHCTL(
								IDC_SPLOT_SUBTITLE), i);

							// Realloc subtitle array
							if((szPlotSubtitle[i]=
								(LPSTR)realloc(szPlotSubtitle[i],
								(nLength+1)*sizeof(char)))==NULL)
							{
								// Just dsp err msg & skip saving string
								// We are closing dlg box anyway
								AllocErrorMessage();
							}
							else
							{
								// Save subtitle string
								nDummy=ComboBox_GetLBText(GETHCTL(
									IDC_SPLOT_SUBTITLE), i,	szPlotSubtitle[i]);
							}
						}
					}

					// Save # user-entered message strings
					nUserMessages=
						ComboBox_GetCount(GETHCTL(IDC_SPLOT_MESSAGE))-
						nMessageCount;

					// Limit # user messages
					nUserMessages=min(nUserMessages, NUM_MESSAGES);

					// Save user messages
					if(nUserMessages)
					{
						for(i=0; i<nUserMessages; i++)
						{
							// Get size of message string
							nLength=ComboBox_GetLBTextLen(GETHCTL(
								IDC_SPLOT_MESSAGE), i);

							// Realloc message array
							if((szPlotMessage[i]=
								(LPSTR)realloc(szPlotMessage[i],
								(nLength+1)*sizeof(char)))==NULL)
							{
								// Just dsp err msg & skip saving string
								// We are closing dlg box anyway
								AllocErrorMessage();
							}
							else
							{
								// Save message string
								nDummy=ComboBox_GetLBText(GETHCTL(
									IDC_SPLOT_MESSAGE), i, szPlotMessage[i]);
							}
						}
					}

					// Close dialog box
					EndDialog (hDlg, 0);
				}
				return TRUE;
			}
		}
		break;
	 }
	 return FALSE;
}
#endif

/*****************************************************************************/
/*                                                                           */
/*                   Freq Plot Line Dialog Procedure                         */
/*                                                                           */
/*      Dialog box procedure to enter parameters for lines to be added to    */
/*      the frequency data plot.                                             */
/*                                                                           */
/* 		The lines are defined by a linetype structure with these items:      */
/* 			int		nLineType	type of line (see FLINE macros)              */
/*          F_TYPE  fXStart     x-axis starting point                        */
/*          F_TYPE	fXEnd       x-axis ending point                          */
/*          F_TYPE	fYStart     y-axis starting point                        */
/*          F_TYPE	fYEnd       y-axis ending point                          */
/*                                                                           */
/*      There is a global array of FLINE_NUMLINES of these linetype structs  */
/*      called sFLine[] with index nLine.  The elements are accessed as:     */
/*          sFLine[nLine].nLineType, etc.                                    */
/*                                                                           */
/*     	The following WM_COMMAND message wParams are used:                   */
/*		Note: Revire for WIN32 compatibility
/*      	Dialog box controls:                                             */
/*				IDC_DLINE_RESET	 	 Button                                  */
/*				IDC_DLINE_NUM		 Edit                                    */
/*				IDC_DLINE_TYPE		 Combo                                   */
/*				IDC_DLINE_XSTART	 Edit                                    */
/*				IDC_DLINE_XEND		 Edit                                    */
/*				IDC_DLINE_UP		 Button                                  */
/*				IDC_DLINE_DOWN		 Button                                  */
/*				IDC_DLINE_YSTART	 Edit                                    */
/*				IDC_DLINE_YEND		 Edit                                    */
/*				IDC_DLINE_PARAM		 Text                                    */
/*			Internal processing routines:                                    */
/*				IDC_DLINE_UPDATE                                             */
/*              IDC_DLINE_CLEAR		                                         */
/*              IDC_DLINE_COUNT                                              */
/*                                                                           */
/*	Revision record:                                                         */
/*  	10/20/96	Line # entry changed to combo box                        */
/*      11/12/96	Changed reset code                                       */
/*		06/04/97	Added line count at initialization                       */
/*		12/20/97	Added line parameter read & save buttons                 */
/*		01/01/98	Fixed line parameter code to use actual line limits      */
/*					Added code to validate line limit entries                */
/*		01/02/97	Added up and down buttons                                */
/*		08/29/98	Added line parameter printout                            */
/*		03/10/00	Fixed line default logic error                           */
/*		03/26/02	Changed initialization defaults to fix problem           */
/*		10/13/02	Added copy feature                                       */
/*		10/03/08	Fixed clipboard string size in copy                      */
/*                                                                           */
/*****************************************************************************/

#ifndef _MSC_VER
	#pragma argsused
#endif

BOOL CALLBACK FreqLineDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local macro
	#define CLIPBOARD_SIZE	14*80	// Size of clipboard string

	// Local variables
	// Structs
	static struct linedata sFSave[FLINE_NUMLINES];
									// To preserve original plot line data
	// Chars
	char szBuffer[BUFFER_SIZE+1]; 	// General text buffer
	char szTemp[BUFFER_SIZE+1];		// Temporary text buffer
	// Ints
	int i;							// General index
	int k;							// Secondary index
	int nPrintLine;					// Line # of printout
	static int nOldLineType;		// Original line type
	static int nCount;				// # active lines
	static int nLine=0;				// nLine (goes from 0 to FLINE_NUMLINES-1)
									// Line # displayed is nLine+1
	static int nEntry;        		// Entry to be validated
	static int nSpace;				// Min spacing between line ends
	// BOOLs
	static BOOL bStart=TRUE;  	 	// Start flag for initializations
	static BOOL bUpdate=TRUE;    	// Update flag to avoid infinite looping
	static BOOL bErrorTrap=FALSE;   // Flag for entry error
	static BOOL bLineNG=FALSE;		// Flag for bad line parameter
	// F_TYPES
	static F_TYPE fA;  				// Intercept of linear regression fit
	static F_TYPE fB;               // Slope of linear regression fit
	static F_TYPE fV;               // Variance of linear regression fit
	static F_TYPE fAvg;             // Average value
	static F_TYPE fAnalysisStart;   // Saved analysis start point
	static F_TYPE fAnalysisEnd;     // Saved analysis end point
	// Printing variables
	char szFormat[BUFFER_SIZE+1];           // Format string
	static HDC hdcPrn;              // Handle to printer device context
	TEXTMETRIC tm;                  // Text metrics structure
	static int xChar, yChar;        // Text character sizes
	static int nRows;               // # rows of results
	static short xPage, yPage;      // Graphic page dims in pixels
	// Printer font
	LOGFONT logfont;                // Printer logical font structure
	HFONT hPrnFont;                 // Printer font handle
	// Win32 API printing structs
	PRINTDLG pd;
	DOCINFO di;
	// Clipboard variables
	HGLOBAL hClipboard;			// Handle to clipboard text buffer
	LPSTR	szClipboard;		// Ptr to clipboard text string

	// Start of code

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Check line start & end parameter values
			SendMessage(hDlg, WM_COMMAND,
				GET_WM_COMMAND_MPS(IDC_DLINE_CHECK, NULL, 0));

			// Clear start flag if freq line data was read from INI file
			if(bUseFreqPlotIni)
			{
				bStart=FALSE;
			}

			// Count # active lines
			// Note: Can't do this with "call" to DLINE_COUNT because that
			// doesn't necessarily happen immediately
			nCount=0;
			for(i=0; i<FLINE_NUMLINES; i++)
			{
				if(sFLine[i].nLineType!=FLINE_NONE)
				{
					nCount++;
				}
			}

			// These initializations are done only at start
			if(bStart || nCount==0)
			{
				// Initialize the line #
				nLine=0;

				// Initialize scale if null
				if( ((sFPlot.y_min==0.0) && (sFPlot.y_max==0.0)) ||
					((sFPlot.x_min==0.0) && (sFPlot.x_max==0.0)) )
				{
					// Initialize freq plot parameters
					InitFreqPlotParams(1);
				}

				// Initialize the sFLine elements
				for(i=0; i<FLINE_NUMLINES; i++)
				{
					sFLine[i].nLineType=FLINE_NONE;		// No line
					sFLine[i].fXStart=fFreqData[1];     // Analysis min
					sFLine[i].fXEnd=fFreqData[2];       // Analysis max
					k=(int)fFreqData[1]+2;				// First index
					sFLine[i].fYStart=fFreqData[k];     // First analy pt
					k=(int)fFreqData[2]+2;				// Last index
					sFLine[i].fYEnd=fFreqData[k];       // Last analy pt
				}

				// Reset start flag
				bStart=FALSE;
			}

			// Other initializations done every time dialog box is opened

			// Load integers into line # box
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_DLINE_NUM));
			for(i=0; i<FLINE_NUMLINES; i++)
			{
				_snprintf(szBuffer, sizeof(szBuffer), "%d", i+1);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_DLINE_NUM),
					i, szBuffer);
			}

			// Set dialog box title
			LoadString(hInst, IDS_TITLE_FREQLINE, szBuffer, BUFFER_SIZE);
			SetWindowText(hDlg, szBuffer);

			// Save the original line data
			for(i=0; i<FLINE_NUMLINES; i++)
			{
				sFSave[i].nLineType=sFLine[i].nLineType;
				sFSave[i].fXStart=sFLine[i].fXStart;
				sFSave[i].fXEnd=sFLine[i].fXEnd;
				sFSave[i].fYStart=sFLine[i].fYStart;
				sFSave[i].fYEnd=sFLine[i].fYEnd;
			}

			// Fill up the line options list box
			// Note: The NULL case allows the display of a blank list box

			// Fill up line options list box using string table
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_DLINE_TYPE));
			for(i=0; i<NUM_DLINE_TYPES; i++)
			{
				LoadString(hInst, IDS_DLINE_TYPE_0+i, szBuffer, BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_DLINE_TYPE),
					i, szBuffer);
			}

			// Update display for all parameter values
			SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDC_DLINE_UPDATE,
				NULL, 0));

			return TRUE;
		}

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				// Help button presses
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::PLOT_LINES_FUNCTION.HTM",
						HH_DISPLAY_TOPIC,
                        0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::PLOT_LINES_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "PLOT_LINES_FUNCTION");
					#endif
				}
				break;

				// Check for OK line limits
				case IDC_DLINE_CHECK:
				{
					// Loop thru all lines
					for(i=0; i<FLINE_NUMLINES; i++)
					{
						// Ignore empty lines
						if(sFLine[i].nLineType!=FLINE_NONE)
						{
							// Set the space value
							switch(sFLine[i].nLineType)
							{
								case FLINE_LIN:
								{
									nSpace=1;
								}
								break;

								case FLINE_AVG:
								case FLINE_END:
								case FLINE_MARK:
								{
									nSpace=0;
								}
								break;
							}

							// Reset the error flag
							bLineNG=FALSE;

							// Check that line start is >= analysis start
							if(sFLine[i].fXStart<fFreqData[1])
							{
								bLineNG=TRUE;
							}

							// Check that line end is <= analysis end
							if(sFLine[i].fXEnd>fFreqData[2])
							{
								bLineNG=TRUE;
							}

							// Check that line range is >= space
							if(sFLine[i].fXEnd-sFLine[i].fXStart<nSpace)
							{
								bLineNG=TRUE;
							}

							// NG line parameter?
							if(bLineNG)
							{
								// Display error message
								MessageBeep(0);
								LoadString(hInst, IDS_FORMAT_20, szTemp,
									BUFFER_SIZE);
								_snprintf(szBuffer, sizeof(szBuffer), szTemp,
									i+1);
								LoadString(hInst, IDS_MESSAGE_LINENG, szTemp,
									BUFFER_SIZE);
								strlcat(szBuffer, szTemp, FILE_NAME_SIZE);
								LoadString(hInst, IDS_TITLE_LINENG, szTemp,
									BUFFER_SIZE);
								MessageBox(hDlg, szBuffer, szTemp,
									MB_ICONEXCLAMATION);

								// Use defaults
								sFLine[i].fXStart=fFreqData[1];
								sFLine[i].fXEnd=fFreqData[2];
							}
						}
					}
				}
				break;

				// Clear display
				// Note: Used to clear display for case of invalid line #
				// Therefore the line # display is not changed
				case IDC_DLINE_CLEAR:
				{
					// Inhibit value changed processing
					bUpdate=FALSE;

					// Show line type
					nDummy=ComboBox_SetCurSel(GETHCTL(IDC_DLINE_TYPE),
						FLINE_NULL);

					// Load the x-axis start value
					SetWindowText(GETHCTL(IDC_DLINE_XSTART), "");

					// Load the x-axis end value
					SetWindowText(GETHCTL(IDC_DLINE_XEND), "");

					// Load the y-axis start value
					SetWindowText(GETHCTL(IDC_DLINE_YSTART), "");

					// Load the y-axis end value
					SetWindowText(GETHCTL(IDC_DLINE_YEND), "");

					// Update line count
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DLINE_COUNT, NULL, 0));

					// Enable value changed processing
					bUpdate=TRUE;
				}
				break;

				// Update display
				case IDC_DLINE_UPDATE:
				{
					// Inhibit value changed processing
					bUpdate=FALSE;

					// Select line #
					nDummy=ComboBox_SetCurSel(GETHCTL(IDC_DLINE_NUM), nLine);

					// Show line type
					nDummy=ComboBox_SetCurSel(GETHCTL(IDC_DLINE_TYPE),
						sFLine[nLine].nLineType);

					//  Enable/disable parameter label
					if( (sFLine[nLine].nLineType==FLINE_LIN) ||
						(sFLine[nLine].nLineType==FLINE_AVG) )
					{
						EnableWindow(GETHCTL(IDC_DLINE_PARAMLAB),
							TRUE);
					}
					else
					{
						EnableWindow(GETHCTL(IDC_DLINE_PARAMLAB),
							FALSE);
					}

					// Load the x-axis start value
					switch(sFLine[nLine].nLineType)
					{
						case FLINE_NONE:
						{
							nSpace=0;
							SetWindowText(GETHCTL(IDC_DLINE_XSTART),
								"");
							EnableWindow(GETHCTL(IDC_DLINE_XSTARTLAB),
								FALSE);
							ShowWindow(GETHCTL(IDC_DLINE_XSTART),
								SW_HIDE);
						}
						break;

						case FLINE_LIN:
						{
							nSpace=1;
							_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
								sFLine[nLine].fXStart);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_DLINE_XSTART),
								szBuffer);
							EnableWindow(GETHCTL(IDC_DLINE_XSTARTLAB),
								TRUE);
							ShowWindow(GETHCTL(IDC_DLINE_XSTART),
								SW_SHOWNORMAL);
						}
						break;

						case FLINE_AVG:
						case FLINE_END:
						case FLINE_MARK:
						{
							nSpace=0;
							_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
								sFLine[nLine].fXStart);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_DLINE_XSTART),
								szBuffer);
							EnableWindow(GETHCTL(IDC_DLINE_XSTARTLAB),
								TRUE);
							ShowWindow(GETHCTL(IDC_DLINE_XSTART),
								SW_SHOWNORMAL);
						}
						break;
					}

					// Load the x-axis end value
					switch(sFLine[nLine].nLineType)
					{
						case FLINE_NONE:
						case FLINE_MARK:
						{
							SetWindowText(GETHCTL(IDC_DLINE_XEND),
								"");
							EnableWindow(GETHCTL(IDC_DLINE_XENDLAB),
								FALSE);
							ShowWindow(GETHCTL(IDC_DLINE_XEND),
								SW_HIDE);
						}
						break;

						case FLINE_END:
						case FLINE_LIN:
						case FLINE_AVG:
						{
							_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
								sFLine[nLine].fXEnd);
							ShortenExp(szBuffer);

							SetWindowText(GETHCTL(IDC_DLINE_XEND),
								szBuffer);
							EnableWindow(GETHCTL(IDC_DLINE_XENDLAB),
								TRUE);
							ShowWindow(GETHCTL(IDC_DLINE_XEND),
								SW_SHOWNORMAL);
						}
						break;
					}

					// Load the y-axis start value
					switch(sFLine[nLine].nLineType)
					{
						case FLINE_NONE:
						case FLINE_LIN:
						case FLINE_AVG:
						case FLINE_MARK:
						{
							SetWindowText(GETHCTL(IDC_DLINE_YSTART),
								"");
							EnableWindow(GETHCTL(IDC_DLINE_YSTARTLAB),
								FALSE);
							ShowWindow(GETHCTL(IDC_DLINE_YSTART),
								SW_HIDE);
						}
						break;

						case FLINE_END:
						{
							_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
								sFLine[nLine].fYStart);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_DLINE_YSTART),
								szBuffer);
							EnableWindow(GETHCTL(IDC_DLINE_YSTARTLAB),
								TRUE);
							ShowWindow(GETHCTL(IDC_DLINE_YSTART),
								SW_SHOWNORMAL);
						}
						break;
					}

					// Load the y-axis end value
					switch(sFLine[nLine].nLineType)
					{
						case FLINE_NONE:
						case FLINE_LIN:
						case FLINE_AVG:
						case FLINE_MARK:
						{
							SetWindowText(GETHCTL(IDC_DLINE_YEND),
								"");
							EnableWindow(GETHCTL(IDC_DLINE_YENDLAB),
								FALSE);
							ShowWindow(GETHCTL(IDC_DLINE_YEND),
								SW_HIDE);
						}
						break;

						case FLINE_END:
						{
							_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
								sFLine[nLine].fYEnd);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_DLINE_YEND),
								szBuffer);
							EnableWindow(GETHCTL(IDC_DLINE_YENDLAB),
								TRUE);
							ShowWindow(GETHCTL(IDC_DLINE_YEND),
								SW_SHOWNORMAL);
						}
						break;
					}

					// Update parameter display
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DLINE_PARAM, NULL, 0));

					// Update line count
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DLINE_COUNT, NULL, 0));

					// Enable value changed processing
					bUpdate=TRUE;

					// Activate print & copy buttons if any lines
					if(nCount)
					{
						EnableWindow(GETHCTL(IDC_DLINE_PRINT), TRUE);
						EnableWindow(GETHCTL(IDC_DLINE_COPY), TRUE);
					}
					else
					{
						EnableWindow(GETHCTL(IDC_DLINE_PRINT), FALSE);
						EnableWindow(GETHCTL(IDC_DLINE_COPY), FALSE);
					}
				}
				break;

				// Count and display # active lines
				case IDC_DLINE_COUNT:
				{
					nCount=0;
					for(i=0; i<FLINE_NUMLINES; i++)
					{
						if(sFLine[i].nLineType!=FLINE_NONE)
						{
							nCount++;
						}
					}

					// Load the # active lines display
					_snprintf(szBuffer, sizeof(szBuffer), "# Lines = %d",
						nCount);
					SetWindowText(GETHCTL(IDC_DLINE_LINES),
						szBuffer);
				}
				break;

				// Calc and display the parameter values
				case IDC_DLINE_PARAM:
				{
					// Save original analysis limits
					fAnalysisStart=fFreqData[1];
					fAnalysisEnd=fFreqData[2];

					// Substitute line limits
					fFreqData[1]=sFLine[nLine].fXStart;
					fFreqData[2]=sFLine[nLine].fXEnd;

					switch(sFLine[nLine].nLineType)
					{
						case FLINE_LIN:
						{
							// Calc linear fit
							CalcLinFreqDrift(fFreqData, &fA, &fB, &fV);

							// Show parameter value
							_snprintf(szBuffer, sizeof(szBuffer),
								"Slope = %10.5e", fB);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_DLINE_PARAM),
								szBuffer);
							// Save parameter value in linedata structure
							sFLine[nLine].fSlope=(float)fB;
						}
						break;

						case FLINE_AVG:
						{
							// Calc average
							CalcMean(fFreqData, &fAvg, FREQ_DATA);

							// Show parameter value
							_snprintf(szBuffer, sizeof(szBuffer),
								"Average = %10.5e", fAvg);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_DLINE_PARAM),
								szBuffer);
							// Save parameter value in linedata structure
							sFLine[nLine].fAverage=(float)fAvg;
						}
						break;

						default:
						{
							// Show parameter value
							SetWindowText(GETHCTL(IDC_DLINE_PARAM),
								"");
						}
						break;
					}

					// Restore original analysis limits
					fFreqData[1]=fAnalysisStart;
					fFreqData[2]=fAnalysisEnd;
				}
				break;

				// Line # changed
				case IDC_DLINE_NUM:
				{
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_SELCHANGE)
					{
						// Read new line #
						nLine=ComboBox_GetCurSel(GETHCTL(IDC_DLINE_NUM));

						// Update display for all parameter values
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
							IDC_DLINE_UPDATE, NULL, 0));

						// Update the ENBW message
					}
				}
				break;

				// Line # up button pressed
				case IDC_DLINE_UP:
				{
					// Increment line # (with wrap-around)
					if(nLine<FLINE_NUMLINES-1)
					{
						nLine++;
					}
					else
					{
						nLine=0;
					}

					// Update display for all values
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DLINE_UPDATE, NULL, 0));
				}
				break;

				// Line # down button pressed
				case IDC_DLINE_DOWN:
				{
					// Decrement line # (with wrap=around)
					if(nLine>0)
					{
						nLine--;
					}
					else
					{
						nLine=FLINE_NUMLINES-1;
					}

					// Update display for all values
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DLINE_UPDATE, NULL, 0));
				}
				break;

				// Line type changed
				case IDC_DLINE_TYPE:
				{
					if(bUpdate)
					{
						// Save original line type
						nOldLineType=sFLine[nLine].nLineType;

						// Read new line type
						sFLine[nLine].nLineType=
							ComboBox_GetCurSel(GETHCTL(IDC_DLINE_TYPE));

						// Bypass NULL type
						if(sFLine[nLine].nLineType==FLINE_NULL)
						{
							sFLine[nLine].nLineType=FLINE_NONE;
						}

						// Reset selected line to defaults if its type changed
						if(sFLine[nLine].nLineType!=nOldLineType)
						{
							sFLine[nLine].fXStart=fFreqData[1]; // Anal min
							sFLine[nLine].fXEnd=fFreqData[2];   // Anal max
							k=(int)fFreqData[1]+2;				// First index
							sFLine[nLine].fYStart=fFreqData[k]; // 1st anal pt
							k=(int)fFreqData[2]+2;				// Last index
							sFLine[nLine].fYEnd=fFreqData[k];   // Last anal pt
						}

						// Update display for all parameter values
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
							IDC_DLINE_UPDATE, NULL, 0));
					}
				}
				break;

				// X-Start value changed
				case IDC_DLINE_XSTART:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DLINE_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new x-start value
						GetWindowText(GETHCTL(IDC_DLINE_XSTART),
							szBuffer, BUFFER_SIZE);

						nEntry=(int)fabs(atof(szBuffer));

						// Validate new line start value
						// Must be between analysis start and line end-space
						if(ValidateInteger(hDlg, nEntry, (int)(fFreqData[1]),
							(int)(sFLine[nLine].fXEnd-nSpace))==TRUE)
						{
							// Valid entry - change line start value
							sFLine[nLine].fXStart=(F_TYPE)nEntry;
						}
						else
						{
							// Invalid entry - ignore new value
							SetFocus(GETHCTL(IDC_DLINE_XSTART));
						}

						// Redisplay x-start value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							sFLine[nLine].fXStart);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_DLINE_XSTART),
							szBuffer);

						// Update display for all parameter values
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
							IDC_DLINE_UPDATE, NULL, 0));
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// X-End value changed
				case IDC_DLINE_XEND:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DLINE_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new x-end value
						GetWindowText(GETHCTL(IDC_DLINE_XEND),
							szBuffer, BUFFER_SIZE);

						nEntry=(int)fabs(atof(szBuffer));

						// Validate new line end value
						// Must be between line start+space and analysis end
						if(ValidateInteger(hDlg, nEntry,
							(int)(sFLine[nLine].fXStart+nSpace),
							(int)(fFreqData[2]))==TRUE)
						{
							// Valid entry - change line start value
							sFLine[nLine].fXEnd=(F_TYPE)nEntry;
						}
						else
						{
							// Invalid entry - ignore new value
							SetFocus(GETHCTL(IDC_DLINE_XEND));
						}

						// Redisplay x-end value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							sFLine[nLine].fXEnd);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_DLINE_XEND),
							szBuffer);

						// Update display for all parameter values
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
							IDC_DLINE_UPDATE, NULL, 0));
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Y-Start value changed
				case IDC_DLINE_YSTART:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DLINE_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new y-start value
						GetWindowText(GETHCTL(IDC_DLINE_YSTART),
							szBuffer, BUFFER_SIZE);
						sFLine[nLine].fYStart=atof(szBuffer);

						// Redisplay y-start value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							sFLine[nLine].fYStart);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_DLINE_YSTART),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Y-End value changed
				case IDC_DLINE_YEND:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DLINE_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new y-end value
						GetWindowText(GETHCTL(IDC_DLINE_YEND),
							szBuffer, BUFFER_SIZE);
						sFLine[nLine].fYEnd=atof(szBuffer);

						// Redisplay y-end value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							sFLine[nLine].fYEnd);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_DLINE_YEND),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Read button pressed
				case IDC_DLINE_READ:
				{
					ReadIni(INI_FLINE);

					// Check line start & end parameter values
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_DLINE_CHECK, NULL, 0));

					// Update display for all parameter values
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DLINE_UPDATE, NULL, 0));
				}
				break;

				// Write button pressed
				case IDC_DLINE_WRITE:
				{
					WriteIni(INI_FLINE);
				}
				break;

				// Reset button pressed - restore defaults
				case IDC_DLINE_RESET:
				{
					#if(1) // New code 03/20/08
					for(i=0; i<FLINE_NUMLINES; i++)
					{
						sFLine[i].nLineType=FLINE_NONE;
					}
					#endif

					// Reinitialize line data
					bStart=TRUE;
					SendMessage(hDlg, WM_INITDIALOG, (WPARAM)0, (LPARAM)0);
				}
				break;

				// Respond to CR in an edit control
				// Note: No button is a DEFPUSHBUTTON
				case IDOK:
				{
					// Send EN_KILLFOCUS message to XSTART edit control
					if(GetFocus()==GETHCTL(IDC_DLINE_XSTART))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
							IDC_DLINE_XSTART, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to XEND edit control
					if(GetFocus()==GETHCTL(IDC_DLINE_XEND))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
							IDC_DLINE_XEND, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to YSTART edit control
					if(GetFocus()==GETHCTL(IDC_DLINE_YSTART))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
							IDC_DLINE_YSTART, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to YEND edit control
					if(GetFocus()==GETHCTL(IDC_DLINE_YEND))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
							IDC_DLINE_YEND, NULL, EN_KILLFOCUS));
					}
				}
				break;

				// Print line info on printer using Win32 API
				// Note: Bare-bones printing code: no error trapping, no font
				// selection, no abort proc, 1 page only
				// Printer must use fixed-space font
				// User can choose printer in PrintDlg

				// Struct linedata items for plot line data:
				// int nLineType	Line type
				// int nSlope		Power law slope for noise line
				// int nXStart		
				// int nXEnd		
				// float fSlope		Linear slope for regression fit
				// float fSigma1	Sigma(1) value for power law noise fit
				// float fAverage	Average line value
			    // F_TYPE fXStart	 
				// F_TYPE fXEnd
				// F_TYPE fYStart
				// F_TYPE fYEnd

				// Freq Plot Line # & Types
				// FLINE_NUMLINES	# possible lines
				// FLINE_NONE       No line
				// FLINE_END        Line between endpoints
				// FLINE_LIN        Linear fit
				// FLINE_AVG        Horiz line at avg value
				// FLINE_MARK       Vert marker line

				case IDC_DLINE_PRINT:
				{
					// Initialize PRINTDLG structure
					memset(&pd, 0, sizeof(PRINTDLG));
					pd.lStructSize=sizeof(PRINTDLG);
					pd.Flags=PD_RETURNDEFAULT; // Don't show dialog box

					// 1st (hidden) call to PrintDlg()
					// To set up hDevNames & hDevMode
 					if(!PrintDlg(&pd))
					{
						// PrintDlg() called failed
						MessageBox(hwndMain, "Printer Not Found", "Line Print",
						MB_ICONEXCLAMATION);
						break;
					}

					// Reinitialize PRINTDLG structure
					// Get DC & no choice of page #s & no text selection
					pd.Flags=PD_RETURNDC | PD_NOPAGENUMS | PD_NOSELECTION;

					// 2nd (visible) call to PrintDlg()
					if(PrintDlg(&pd))
					{
						// Get printer device context
						hdcPrn=pd.hDC;
					}
					else
					{
						if(CommDlgExtendedError())
						{
							// Printer error
							MessageBox(hwndMain, "Printer Error", "Line Print",
							MB_ICONEXCLAMATION);
						}
						else // Error code 0
						{
							// User hit cancel button
							break;
						}
					}
					
					// Determine logfont.lfHeight from point size = nPointSize
					// where nPointSize is global variable that user can enter
					// in General page of Configure property sheet
					// Win32 documentation gives the formula:
					// lfHeight = -MulDiv(PointSize,
					//   GetDeviceCaps(hDC, LOGPIXELSY), 72);
					// which becomes the following for our variables:
					// nFontHeight = -MulDiv(nPointSize, GetDeviceCaps(hdcPrn,
					//  LOGPIXELSY), 72);
					// Both nPointSize and nFontHeight are global variables
					// A couple of typical values are nPointSize=9,
					//  nFontHeight=-75
					// and nPointSize=10, nFontHeight=-83
					// The abs value of nFontHeight is used
					nFontHeight = -MulDiv(nPointSize, GetDeviceCaps(hdcPrn,
						LOGPIXELSY), 72);
					
					// Set font attributes
					// Assumes 8.5"x11" portrait page
					// Text size set to fit nicely across std page
					// Fixed pitch for easy alignment
					logfont.lfHeight=nFontHeight;
					logfont.lfWidth=0;
					logfont.lfEscapement=0;
					logfont.lfOrientation=0;
					logfont.lfWeight=0;
					logfont.lfItalic=0;
					logfont.lfUnderline=0;
					logfont.lfStrikeOut=0;
					logfont.lfCharSet=OEM_CHARSET;
					logfont.lfOutPrecision=OUT_DEFAULT_PRECIS;
					logfont.lfClipPrecision=CLIP_DEFAULT_PRECIS;
					logfont.lfQuality=PROOF_QUALITY;
					logfont.lfPitchAndFamily=FIXED_PITCH | FF_DONTCARE;
					strlcpy(logfont.lfFaceName,"", LF_FACESIZE);

					// Create printer font
					hPrnFont=CreateFontIndirect(&logfont);

					// Select font into printer device
					SelectObject(hdcPrn, hPrnFont);

					// Get text metrics
					GetTextMetrics(hdcPrn, &tm);
					yChar=tm.tmHeight + tm.tmExternalLeading;
					xChar=tm.tmAveCharWidth;

					// Get page dimensions
					xPage=(short)GetDeviceCaps(hdcPrn, HORZRES);
					yPage=(short)GetDeviceCaps(hdcPrn, VERTRES);

					// Compose Print Manager message
					LoadString(hInst, IDS_MESSAGE_REPORT, szPrnMsg,
							BUFFER_SIZE);

					// Set up DOCINFO structure
					memset(&di, 0, sizeof(DOCINFO));
					di.cbSize=sizeof(DOCINFO);
					di.lpszDocName=szPrnMsg;
					
					// Start printing
					if(hdcPrn != NULL)
					{
						if(StartDoc(hdcPrn, &di) != SP_ERROR)
						{
							// Actual printing code starts here
							StartPage(hdcPrn);

							nPrintLine=0; // Page heading
							SetTextAlign(hdcPrn, TA_LEFT || TA_TOP);
							LoadString(hInst, IDS_FORMAT_FLINE_PH, szFormat,
								BUFFER_SIZE);
							_snprintf(szBuffer, sizeof(szBuffer), szFormat,
								szFreqFileTitle);
							TextOut(hdcPrn, xChar/2, (int)((nPrintLine+0.5)*
								yChar),	szBuffer, strlen(szBuffer));
							
							nPrintLine=2; // Column headings
							SetTextAlign(hdcPrn, TA_LEFT || TA_TOP);
							LoadString(hInst, IDS_FORMAT_FLINE_CH, szFormat,
								BUFFER_SIZE);
							_snprintf(szBuffer, sizeof(szBuffer), szFormat);
							TextOut(hdcPrn, xChar/2, (int)((nPrintLine+0.5)*
								yChar),	szBuffer, strlen(szBuffer));

							nPrintLine++;

							for(i=0; i<FLINE_NUMLINES; i++)
							{
								nPrintLine++;
								switch(sFLine[i].nLineType)
								{
									case FLINE_NONE:
									{
										LoadString(hInst, IDS_FORMAT_FLINE_0,
											szFormat, BUFFER_SIZE);
										_snprintf(szBuffer, sizeof(szBuffer),
											szFormat,	i+1);
									}
									break;

									case FLINE_END:
									{
										LoadString(hInst, IDS_FORMAT_FLINE_1,
											szFormat, BUFFER_SIZE);
										_snprintf(szBuffer, sizeof(szBuffer),
											szFormat, i+1,
											sFLine[i].fXStart,
											sFLine[i].fXEnd,
											sFLine[i].fYStart,
											sFLine[i].fYEnd);
									}
									break;

									case FLINE_LIN:
									{
										LoadString(hInst, IDS_FORMAT_FLINE_2,
											szFormat, BUFFER_SIZE);
										_snprintf(szBuffer, sizeof(szBuffer),
											szFormat,	i+1,
											sFLine[i].fXStart,
											sFLine[i].fXEnd,
											sFLine[i].fSlope);
									}
									break;
						
									case FLINE_AVG:
									{
										LoadString(hInst, IDS_FORMAT_FLINE_3,
											szFormat, BUFFER_SIZE);
										_snprintf(szBuffer, sizeof(szBuffer),
											szFormat, i+1,
											sFLine[i].fXStart,
											sFLine[i].fXEnd,
											sFLine[i].fAverage);
									}
									break;

									case FLINE_MARK:
									{
										LoadString(hInst, IDS_FORMAT_FLINE_4,
											szFormat, BUFFER_SIZE);
										_snprintf(szBuffer, sizeof(szBuffer),
											szFormat, i+1,
											sFLine[i].fXStart,
											sFLine[i].fXEnd);
									}
									break;
								}

								ShortenExp(szBuffer);
								TextOut(hdcPrn, (int)(xChar/2),
									(int)((nPrintLine+0.4)*yChar), szBuffer,
									strlen(szBuffer));
							}

							// End (single) page
							EndPage(hdcPrn);

							// End printing
							EndDoc(hdcPrn);
						}
						else // Error or print to file cancelled
						{
							;
						}

						// Release device context
						DeleteDC(hdcPrn) ;
					}
					else // hdcPrn==NULL
					{
						;
					}

					// Delete printer logical font
					DeleteObject(hPrnFont);
				}
				break;

				// Respond to copy button
				case IDC_DLINE_COPY:
				{
					#if(1) // New code 10/03/08
					// Allocate global memory for 14 lines of info
					// Top & column headings plus 12 lines
					hClipboard=GlobalAlloc(GMEM_DDESHARE, (DWORD)(14*80));
					szClipboard=GlobalLock(hClipboard);

					// Main heading
					LoadString(hInst, IDS_FORMAT_FLINE_PH, szFormat,
						BUFFER_SIZE);
					_snprintf(szClipboard, CLIPBOARD_SIZE, szFormat,
						szFreqFileTitle);
					strlcat(szClipboard, "\r\n", CLIPBOARD_SIZE);

					// Column heading
					LoadString(hInst, IDS_FORMAT_FLINE_CH, szFormat,
						BUFFER_SIZE);
					_snprintf(szBuffer, sizeof(szBuffer), szFormat);
					strlcat(szClipboard, szBuffer, CLIPBOARD_SIZE);
					strlcat(szClipboard, "\r\n", CLIPBOARD_SIZE);

					for(i=0; i<FLINE_NUMLINES; i++)
					{
						switch(sFLine[i].nLineType)
						{
							case FLINE_NONE:
							{
								LoadString(hInst, IDS_FORMAT_FLINE_0,
									szFormat, BUFFER_SIZE);
								_snprintf(szBuffer, sizeof(szBuffer),
									szFormat,	i+1);
							}
							break;

							case FLINE_END:
							{
								LoadString(hInst, IDS_FORMAT_FLINE_1,
									szFormat, BUFFER_SIZE);
								_snprintf(szBuffer, sizeof(szBuffer),
									szFormat, i+1,
									sFLine[i].fXStart,
									sFLine[i].fXEnd,
									sFLine[i].fYStart,
									sFLine[i].fYEnd);
							}
							break;

							case FLINE_LIN:
							{
								LoadString(hInst, IDS_FORMAT_FLINE_2,
									szFormat, BUFFER_SIZE);
								_snprintf(szBuffer, sizeof(szBuffer),
									szFormat,	i+1,
									sFLine[i].fXStart,
									sFLine[i].fXEnd,
									sFLine[i].fSlope);
							}
							break;
						
							case FLINE_AVG:
							{
								LoadString(hInst, IDS_FORMAT_FLINE_3,
									szFormat, BUFFER_SIZE);
								_snprintf(szBuffer, sizeof(szBuffer),
									szFormat, i+1,
									sFLine[i].fXStart,
									sFLine[i].fXEnd,
									sFLine[i].fAverage);
							}
							break;

							case FLINE_MARK:
							{
								LoadString(hInst, IDS_FORMAT_FLINE_4,
									szFormat, BUFFER_SIZE);
								_snprintf(szBuffer, sizeof(szBuffer),
									szFormat, i+1,
									sFLine[i].fXStart,
									sFLine[i].fXEnd);
							}
							break;
						}

						ShortenExp(szBuffer);
						strlcat(szClipboard, szBuffer, CLIPBOARD_SIZE);
						strlcat(szClipboard, "\r\n", CLIPBOARD_SIZE);
					}

					// Write info to clipboard
					GlobalUnlock(hClipboard);
					OpenClipboard(NULL);
					EmptyClipboard();
					SetClipboardData(CF_TEXT, hClipboard);
					CloseClipboard();
					#endif
				}

				// OK button pressed - accept inputs
				case IDC_DLINE_ACCEPT:
				{
					// Close dialog box
					EndDialog (hDlg, 0);
				}
				return TRUE;

				// Cancel button pressed - restore previous inputs before end
				// Respond to esc key or cancel button
				case IDCANCEL:
				case IDC_DLINE_CANCEL:
				{
					// Save the original line data
					for(i=0; i<FLINE_NUMLINES; i++)
					{
						sFLine[i].nLineType=sFSave[i].nLineType;
						sFLine[i].fXStart=sFSave[i].fXStart;
						sFLine[i].fXEnd=sFSave[i].fXEnd;
						sFLine[i].fYStart=sFSave[i].fYStart;
						sFLine[i].fYEnd=sFSave[i].fYEnd;
					}

					// Close dialog box
					EndDialog (hDlg, 0);
				}
				return TRUE;
			}
		}
		break;
	 }
	 return FALSE;
}


/*****************************************************************************/
/*                                                                           */
/*                   Phase Plot Line Dialog Procedure                        */
/*                                                                           */
/*	Revision record:                                                         */
/*  	10/20/96	Line # entry changed to combo box                        */
/*      11/12/96	Changed reset code                                       */
/*		06/04/97	Added line count at initialization                       */
/*		12/20/97	Added line parameter read & save buttons                 */
/*		01/01/98	Fixed line parameter code to use actual line limits      */
/*					Added code to validate line limit entries                */
/*		01/02/97	Added up and down buttons                                */
/*		08/28/98	Added print function                                     */
/*		03/10/00	Fixed line default logic error                           */
/*		03/26/02	Changed initialization defaults to fix problem           */
/*		10/13/02	Added copy feature                                       */
/*		10/03/08	Fixed clipboard string size in copy                      */
/*                                                                           */
/*****************************************************************************/

#ifndef _MSC_VER
	#pragma argsused
#endif

BOOL CALLBACK PhaseLineDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local macro
	#define CLIPBOARD_SIZE	14*80	// Size of clipboard string

	// Local variables
	// Structs
	static struct linedata sPSave[PLINE_NUMLINES];
									// To preserve original plot line data
	// Chars
	char szBuffer[BUFFER_SIZE+1];		// General text buffer
	char szTemp[BUFFER_SIZE+1];		// Temporary text buffer
	// Ints
	int i;							// General index
	int k;							// Secondary index
	int nPrintLine;					// Line # of printout
	static int nOldLineType;		// Original line type
	static int nCount; 				// # active lines
	static int nLine=0;				// nLine (goes from 0 to PLINE_NUMLINES-1)
									// Line # displayed is nLine+1
	static int nEntry;        		// Entry to be validated
	static int nSpace;				// Min spacing between line ends
	// BOOLs
	static BOOL bStart=TRUE;  	 	// Start flag for initializations
	static BOOL bUpdate=TRUE;    	// Update flag to avoid infinite looping
	static BOOL bErrorTrap=FALSE;   // Flag for entry error
	static BOOL bLineNG=FALSE;		// Flag for bad line parameter
	// F_TYPEs
	static F_TYPE fTau;				// Averaging time of phase data
	static F_TYPE fA;  				// Constant term of quadratic fit
	static F_TYPE fB;               // Linear term of quadratic fit
	static F_TYPE fC;               // Quadratic term of quadratic fit
	static F_TYPE fV;               // Variance of quadratic fit
	static F_TYPE fAvg;             // Average phase value
	static F_TYPE fAnalysisStart;   // Saved analysis start point
	static F_TYPE fAnalysisEnd;     // Saved analysis end point
	// Printing variables
	char szFormat[BUFFER_SIZE+1];           // Format string
	static HDC hdcPrn;              // Handle to printer device context
	TEXTMETRIC tm;                  // Text metrics structure
	static int xChar, yChar;        // Text character sizes
	static int nRows;               // # rows of results
	static short xPage, yPage;      // Graphic page dims in pixels
	// Printer font
	LOGFONT logfont;                // Printer logical font structure
	HFONT hPrnFont;                 // Printer font handle
	// Win32 API printing structs
	PRINTDLG pd;
	DOCINFO di;
	// Clipboard variables
	HGLOBAL hClipboard;			// Handle to clipboard text buffer
	LPSTR	szClipboard;		// Ptr to clipboard text string

	// Start of code
	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Check line start & end parameter values
			SendMessage(hDlg, WM_COMMAND,
				GET_WM_COMMAND_MPS(IDC_DLINE_CHECK, NULL, 0));

			// Clear start flag if phase line data was read from INI file
			if(bUsePhasePlotIni)
			{
				bStart=FALSE;
			}

			// Count # active lines
			// Note: Can't do this with "call" to DLINE_COUNT because that
			// doesn't necessarily happen immediately
			nCount=0;
			for(i=0; i<PLINE_NUMLINES; i++)
			{
				if(sPLine[i].nLineType!=PLINE_NONE)
				{
					nCount++;
				}
			}

			// These initializations are done only at start
			if(bStart || nCount==0)
			{
				// Initialize the line #
				nLine=0;

				// Initialize scale if null
				if( ((sPPlot.y_min==0.0) && (sPPlot.y_max==0.0)) ||
					((sPPlot.x_min==0.0) && (sPPlot.x_max==0.0)) )
				{
					// Initialize phase plot parameters
					InitPhasePlotParams(1);
				}

				// Initialize the sPLine elements
				for(i=0; i<PLINE_NUMLINES; i++)
				{
					sPLine[i].fXStart=fPhaseData[1];    // Analysis min
					sPLine[i].fXEnd=fPhaseData[2];      // Analysis max
					k=(int)fPhaseData[1]+2;				// First index
					sPLine[i].fYStart=fPhaseData[k];    // First analy pt
					k=(int)fPhaseData[2]+2;				// Last index
					sPLine[i].fYEnd=fPhaseData[k];      // Last analy pt
				}

				// Reset start flag
				bStart=FALSE;
			}

			// Other initializations done every time dialog box is opened

			// Load integers into line # box
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_DLINE_NUM));
			for(i=0; i<PLINE_NUMLINES; i++)
			{
				_snprintf(szBuffer, sizeof(szBuffer), "%d", i+1);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_DLINE_NUM),
					i, szBuffer);
			}

			// Set dialog box title
			LoadString(hInst, IDS_TITLE_PHASELINE, szBuffer, BUFFER_SIZE);
			SetWindowText(hDlg, szBuffer);

			// Save the original line data
			for(i=0; i<PLINE_NUMLINES; i++)
			{
				sPSave[i].nLineType=sPLine[i].nLineType;
				sPSave[i].fXStart=sPLine[i].fXStart;
				sPSave[i].fXEnd=sPLine[i].fXEnd;
				sPSave[i].fYStart=sPLine[i].fYStart;
				sPSave[i].fYEnd=sPLine[i].fYEnd;
			}

			// Fill up line options list box using string table
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_DLINE_TYPE));

			#if(0) // Original code
			for(i=0; i<NUM_DLINE_TYPES; i++)
			#endif

			#if(1) // New code 07/24/10 to add Freq Offset choice
			// NUM_DLINE_TYPES is not changed so as not to break other code
			for(i=0; i<NUM_DLINE_TYPES+1; i++)
			#endif
			{
				LoadString(hInst, IDS_DLINE_TYPE_0+i, szBuffer, BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_DLINE_TYPE),
					i, szBuffer);
			}

			// Update display for all parameter values
			SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDC_DLINE_UPDATE,
				NULL, 0));

			return TRUE;
		}

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				// Help button presses
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::PLOT_LINES_FUNCTION.HTM",
						HH_DISPLAY_TOPIC,
                        0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::PLOT_LINES_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "PLOT_LINES_FUNCTION");
					#endif
				}
				break;

				// Check for OK line limits
				case IDC_DLINE_CHECK:
				{
					// Loop thru all lines
					for(i=0; i<PLINE_NUMLINES; i++)
					{
						// Ignore empty lines
						if(sPLine[i].nLineType!=PLINE_NONE)
						{
							// Set the space value
							switch(sPLine[i].nLineType)
							{
								case PLINE_QUAD:
								{
									nSpace=3;
								}
								break;

								// Note: This case doesn't exist
								case PLINE_LIN:
								{
									nSpace=1;
								}
								break;

								case PLINE_AVG:
								case PLINE_END:
								case PLINE_MARK:
								{
									nSpace=0;
								}
								break;
							}

							// Reset the error flag
							bLineNG=FALSE;

							// Check that line start is >= analysis start
							if(sPLine[i].fXStart<fPhaseData[1])
							{
								bLineNG=TRUE;
							}

							// Check that line end is <= analysis end
							if(sPLine[i].fXEnd>fPhaseData[2])
							{
								bLineNG=TRUE;
							}

							// Check that line range is >= space
							if(sPLine[i].fXEnd-sPLine[i].fXStart<nSpace)
							{
								bLineNG=TRUE;
							}

							// NG line parameter?
							if(bLineNG)
							{
								// Display error message
								MessageBeep(0);
								LoadString(hInst, IDS_FORMAT_20, szTemp,
									BUFFER_SIZE);
								_snprintf(szBuffer, sizeof(szBuffer), szTemp,
									i+1);
								LoadString(hInst, IDS_MESSAGE_LINENG, szTemp,
									BUFFER_SIZE);
								strlcat(szBuffer, szTemp, sizeof(szBuffer));
								LoadString(hInst, IDS_TITLE_LINENG, szTemp,
									BUFFER_SIZE);
								MessageBox(hDlg, szBuffer, szTemp,
									MB_ICONEXCLAMATION);

								// Use defaults
								sPLine[i].fXStart=fPhaseData[1];
								sPLine[i].fXEnd=fPhaseData[2];
							}
						}
					}
				}
				break;

				// Clear display
				// Note: Used to clear display for case of invalid line #
				// Therefore the line # display is not changed
				case IDC_DLINE_CLEAR:
				{
					// Inhibit value changed processing
					bUpdate=FALSE;

					// Show line type
					nDummy=ComboBox_SetCurSel(GETHCTL(IDC_DLINE_TYPE),
						PLINE_NULL);

					// Load the x-axis start value
					SetWindowText(GETHCTL(IDC_DLINE_XSTART), "");

					// Load the x-axis end value
					SetWindowText(GETHCTL(IDC_DLINE_XEND), "");

					// Load the y-axis start value
					SetWindowText(GETHCTL(IDC_DLINE_YSTART), "");

					// Load the y-axis end value
					SetWindowText(GETHCTL(IDC_DLINE_YEND), "");

					// Update line count
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DLINE_COUNT, NULL, 0));

					// Enable value changed processing
					bUpdate=TRUE;
				}
				break;

				// Update display
				case IDC_DLINE_UPDATE:
				{
					// Inhibit value changed processing
					bUpdate=FALSE;

					// Select line #
					nDummy=ComboBox_SetCurSel(GETHCTL(IDC_DLINE_NUM), nLine);

					// Show line type
					nDummy=ComboBox_SetCurSel(GETHCTL(IDC_DLINE_TYPE),
						sPLine[nLine].nLineType);

					//  Enable/disable parameter label
					if( (sPLine[nLine].nLineType==PLINE_QUAD) ||
						(sPLine[nLine].nLineType==PLINE_LIN)  ||
						(sPLine[nLine].nLineType==PLINE_AVG) )
					{
						EnableWindow(GETHCTL(IDC_DLINE_PARAMLAB),
							TRUE);
					}
					else
					{
						EnableWindow(GETHCTL(IDC_DLINE_PARAMLAB),
							FALSE);
					}

					// Load the x-axis start value
					switch(sPLine[nLine].nLineType)
					{
						case PLINE_NONE:
						{
							nSpace=0;
							SetWindowText(GETHCTL(IDC_DLINE_XSTART),
								"");
							EnableWindow(GETHCTL(IDC_DLINE_XSTARTLAB),
								FALSE);
							ShowWindow(GETHCTL(IDC_DLINE_XSTART),
								SW_HIDE);
						}
						break;

						case PLINE_QUAD:
						{
							// Note: This is 3 rather than 2 because need at
							// least 4 points to calc variance of quad fit
							nSpace=3;
							_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
								sPLine[nLine].fXStart);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_DLINE_XSTART),
								szBuffer);
							EnableWindow(GETHCTL(IDC_DLINE_XSTARTLAB),
								TRUE);
							ShowWindow(GETHCTL(IDC_DLINE_XSTART),
								SW_SHOWNORMAL);
						}
						break;

						// Note: This case doesn't exist
						case PLINE_LIN:
						{
							nSpace=1;
							_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
								sPLine[nLine].fXStart);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_DLINE_XSTART),
								szBuffer);
							EnableWindow(GETHCTL(IDC_DLINE_XSTARTLAB),
								TRUE);
							ShowWindow(GETHCTL(IDC_DLINE_XSTART),
								SW_SHOWNORMAL);
						}
						break;

						case PLINE_AVG:
						case PLINE_END:
						case PLINE_MARK:
						{
							nSpace=0;
							_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
								sPLine[nLine].fXStart);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_DLINE_XSTART),
								szBuffer);
							EnableWindow(GETHCTL(IDC_DLINE_XSTARTLAB),
								TRUE);
							ShowWindow(GETHCTL(IDC_DLINE_XSTART),
								SW_SHOWNORMAL);
						}
						break;
					}

					// Load the x-axis end value
					switch(sPLine[nLine].nLineType)
					{
						case PLINE_NONE:
						case PLINE_MARK:
						{
							SetWindowText(GETHCTL(IDC_DLINE_XEND),
								"");
							EnableWindow(GETHCTL(IDC_DLINE_XENDLAB),
								FALSE);
							ShowWindow(GETHCTL(IDC_DLINE_XEND),
								SW_HIDE);
						}
						break;

						case PLINE_END:
						case PLINE_QUAD:
						case PLINE_LIN:
						case PLINE_AVG:
						{
							_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
								sPLine[nLine].fXEnd);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_DLINE_XEND),
								szBuffer);
							EnableWindow(GETHCTL(IDC_DLINE_XENDLAB),
								TRUE);
							ShowWindow(GETHCTL(IDC_DLINE_XEND),
								SW_SHOWNORMAL);
						}
						break;
					}

					// Load the y-axis start value
					switch(sPLine[nLine].nLineType)
					{
						case PLINE_NONE:
						case PLINE_QUAD:
						case PLINE_LIN:
						case PLINE_AVG:
						case PLINE_MARK:
						{
							SetWindowText(GETHCTL(IDC_DLINE_YSTART),
								"");
							EnableWindow(GETHCTL(IDC_DLINE_YSTARTLAB),
								FALSE);
							ShowWindow(GETHCTL(IDC_DLINE_YSTART),
								SW_HIDE);
						}
						break;

						case PLINE_END:
						{
							_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
								sPLine[nLine].fYStart);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_DLINE_YSTART),
								szBuffer);
							EnableWindow(GETHCTL(IDC_DLINE_YSTARTLAB),
								TRUE);
							ShowWindow(GETHCTL(IDC_DLINE_YSTART),
								SW_SHOWNORMAL);
						}
						break;
					}

					// Load the y-axis end value
					switch(sPLine[nLine].nLineType)
					{
						case PLINE_NONE:
						case PLINE_QUAD:
						case PLINE_LIN:
						case PLINE_AVG:
						case PLINE_MARK:
						{
							SetWindowText(GETHCTL(IDC_DLINE_YEND),
								"");
							EnableWindow(GETHCTL(IDC_DLINE_YENDLAB),
								FALSE);
							ShowWindow(GETHCTL(IDC_DLINE_YEND),
								SW_HIDE);
						}
						break;

						case PLINE_END:
						{
							_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
								sPLine[nLine].fYEnd);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_DLINE_YEND),
								szBuffer);
							EnableWindow(GETHCTL(IDC_DLINE_YENDLAB),
								TRUE);
							ShowWindow(GETHCTL(IDC_DLINE_YEND),
								SW_SHOWNORMAL);
						}
						break;
					}

					// Update parameter display
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DLINE_PARAM, NULL, 0));

					// Update line count
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DLINE_COUNT, NULL, 0));

					// Enable value changed processing
					bUpdate=TRUE;

					// Activate print & copy buttons if any lines
					if(nCount)
					{
						EnableWindow(GETHCTL(IDC_DLINE_PRINT), TRUE);
						EnableWindow(GETHCTL(IDC_DLINE_COPY), TRUE);
					}
					else
					{
						EnableWindow(GETHCTL(IDC_DLINE_PRINT), FALSE);
						EnableWindow(GETHCTL(IDC_DLINE_COPY), FALSE);
					}
				}
				break;

				// Count and display # active lines
				case IDC_DLINE_COUNT:
				{
					nCount=0;
					for(i=0; i<PLINE_NUMLINES; i++)
					{
						if(sPLine[i].nLineType!=PLINE_NONE)
						{
							nCount++;
						}
					}

					// Load the # active lines display
					_snprintf(szBuffer, sizeof(szBuffer),
						"# Lines = %d", nCount);
					SetWindowText(GETHCTL(IDC_DLINE_LINES),
						szBuffer);
				}
				break;

				// Calc and display the parameter values
				case IDC_DLINE_PARAM:
				{
					// Save original analysis limits
					fAnalysisStart=fPhaseData[1];
					fAnalysisEnd=fPhaseData[2];

					// Substitute line limits
					fPhaseData[1]=sPLine[nLine].fXStart;
					fPhaseData[2]=sPLine[nLine].fXEnd;

					switch(sPLine[nLine].nLineType)
					{
						case PLINE_QUAD:
						{
							// Get tau of phase data
							GetWindowText(hwndPhaseTau, (LPSTR)szBuffer,
								BUFFER_SIZE);
							fTau=(F_TYPE)atof(szBuffer);

							// Calc quadratic fit: y=a+bt+ct^2
							// Use tau=1.0 because slope is per tau interval
							CalcQuadraticDrift(fPhaseData, 1.0, &fA, &fB, &fC,
								&fV);

							// Show parameter value
							// Freq slope = 2c (per tau interval)
							_snprintf(szBuffer, sizeof(szBuffer),
								"Freq Slope = %10.5e", 2*fC/fTau);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_DLINE_PARAM),
								szBuffer);
							// Save parameter value in linedata structure
							sPLine[nLine].fSlope=(float)(2*fC/fTau);
						}
						break;

						// Note: This case doesn't exist
						case PLINE_LIN:
						{
							// This line option uses CalcLinFreqDrift() to
							// calc linear fit to phase data.  That function
							// is normally used with freq data.  It S/B OK
							// with phase data, except ALL 0s will be gaps.
							// Phase slope is freq offset.
							CalcLinFreqDrift(fPhaseData, &fA, &fB, &fV);

							// Show parameter value
							_snprintf(szBuffer, sizeof(szBuffer),
								"Slope = %10.5e", fB);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_DLINE_PARAM),
								szBuffer);
							// Save parameter value in linedata structure
							sPLine[nLine].fSlope=(float)fB;
						}
						break;

						case PLINE_AVG:
						{
							// Calc average
							CalcMean(fPhaseData, &fAvg, PHASE_DATA);

							// Show parameter value
							_snprintf(szBuffer, sizeof(szBuffer),
								"Average = %10.5e", fAvg);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_DLINE_PARAM),
								szBuffer);
							// Save parameter value in linedata structure
							sPLine[nLine].fAverage=(float)fAvg;
						}
						break;

						default:
						{
							// Show parameter value
							SetWindowText(GETHCTL(IDC_DLINE_PARAM),
								"");
						}
						break;
					}

					// Restore original analysis limits
					fPhaseData[1]=fAnalysisStart;
					fPhaseData[2]=fAnalysisEnd;
				}
				break;

				// Line # changed
				case IDC_DLINE_NUM:
				{
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_SELCHANGE)
					{
						// Read new line #
						nLine=ComboBox_GetCurSel(GETHCTL(IDC_DLINE_NUM));

						// Update display for all parameter values
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
							IDC_DLINE_UPDATE, NULL, 0));
					}
				}
				break;

				// Line # up button pressed
				case IDC_DLINE_UP:
				{
					// Increment line # (with wrap-around)
					if(nLine<PLINE_NUMLINES-1)
					{
						nLine++;
					}
					else
					{
						nLine=0;
					}

					// Update display for all values
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DLINE_UPDATE, NULL, 0));
				}
				break;

				// Line # down button pressed
				case IDC_DLINE_DOWN:
				{
					// Decrement line # (with wrap=around)
					if(nLine>0)
					{
						nLine--;
					}
					else
					{
						nLine=PLINE_NUMLINES-1;
					}

					// Update display for all values
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DLINE_UPDATE, NULL, 0));
				}
				break;

				// Line type changed
				case IDC_DLINE_TYPE:
				{
					if(bUpdate)
					{
						// Save original line type
						nOldLineType=sPLine[nLine].nLineType;

						// Read new line type
						sPLine[nLine].nLineType=
							ComboBox_GetCurSel(GETHCTL(IDC_DLINE_TYPE));

						// Bypass NULL type
						if(sPLine[nLine].nLineType==PLINE_NULL)
						{
							sPLine[nLine].nLineType=PLINE_NONE;
						}

						// Reset selected line to defaults if its type changed
						if(sPLine[nLine].nLineType!=nOldLineType)
						{
							sPLine[nLine].fXStart=fPhaseData[1];// Anal min
							sPLine[nLine].fXEnd=fPhaseData[2];  // Anal max
							k=(int)fPhaseData[1]+2;				// First index
							sPLine[nLine].fYStart=fPhaseData[k];// 1st anal pt
							k=(int)fPhaseData[2]+2;				// Last index
							sPLine[nLine].fYEnd=fPhaseData[k];  // Last anal pt
						}

						// Update display for all parameter values
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
							IDC_DLINE_UPDATE, NULL, 0));
					}
				}
				break;

				// X-Start value changed
				case IDC_DLINE_XSTART:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DLINE_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new x-start value
						GetWindowText(GETHCTL(IDC_DLINE_XSTART),
							szBuffer, BUFFER_SIZE);

						nEntry=(int)fabs(atof(szBuffer));

						// Validate new line start value
						// Must be between analysis start and line end-space
						if(ValidateInteger(hDlg, nEntry, (int)(fPhaseData[1]),
							(int)(sPLine[nLine].fXEnd-nSpace))==TRUE)
						{
							// Valid entry - change line start value
							sPLine[nLine].fXStart=(F_TYPE)nEntry;
						}
						else
						{
							// Invalid entry - ignore new value
							SetFocus(GETHCTL(IDC_DLINE_XSTART));
						}

						// Redisplay x-start value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							sPLine[nLine].fXStart);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_DLINE_XSTART),
							szBuffer);

						// Update display for all parameter values
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
							IDC_DLINE_UPDATE, NULL, 0));
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// X-End value changed
				case IDC_DLINE_XEND:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DLINE_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new x-end value
						GetWindowText(GETHCTL(IDC_DLINE_XEND),
							szBuffer, BUFFER_SIZE);

						nEntry=(int)fabs(atof(szBuffer));

						// Validate new line end value
						// Must be between line start+space and analysis end
						if(ValidateInteger(hDlg, nEntry,
							(int)(sPLine[nLine].fXStart+nSpace),
							(int)(fPhaseData[2]))==TRUE)
						{
							// Valid entry - change line start value
							sPLine[nLine].fXEnd=(F_TYPE)nEntry;
						}
						else
						{
							// Invalid entry - ignore new value
							SetFocus(GETHCTL(IDC_DLINE_XEND));
						}

						// Redisplay x-end value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							sPLine[nLine].fXEnd);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_DLINE_XEND),
							szBuffer);

						// Update display for all parameter values
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
							IDC_DLINE_UPDATE, NULL, 0));
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Y-Start value changed
				case IDC_DLINE_YSTART:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DLINE_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new y-start value
						GetWindowText(GETHCTL(IDC_DLINE_YSTART),
							szBuffer, BUFFER_SIZE);
						sPLine[nLine].fYStart=atof(szBuffer);

						// Redisplay y-start value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							sPLine[nLine].fYStart);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_DLINE_YSTART),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Y-End value changed
				case IDC_DLINE_YEND:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DLINE_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Read new y-end value
						GetWindowText(GETHCTL(IDC_DLINE_YEND),
							szBuffer, BUFFER_SIZE);
						sPLine[nLine].fYEnd=atof(szBuffer);

						// Redisplay y-end value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							sPLine[nLine].fYEnd);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_DLINE_YEND),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Read button pressed
				case IDC_DLINE_READ:
				{
					ReadIni(INI_PLINE);

					// Check line start & end parameter values
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_DLINE_CHECK, NULL, 0));

					// Update display for all parameter values
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DLINE_UPDATE, NULL, 0));
				}
				break;

				// Write button pressed
				case IDC_DLINE_WRITE:
				{
					WriteIni(INI_PLINE);
				}
				break;

				// Reset button pressed - restore defaults
				case IDC_DLINE_RESET:
				{
					#if(1) // New code 03/20/08
					for(i=0; i<PLINE_NUMLINES; i++)
					{
						sPLine[i].nLineType=PLINE_NONE;
					}
					#endif

					// Reinitialize line data
					bStart=TRUE;
					SendMessage(hDlg, WM_INITDIALOG, (WPARAM)0, (LPARAM)0);
				}
				break;

				// Respond to CR in an edit control
				// Note: No button is a DEFPUSHBUTTON
				case IDOK:
				{
					// Send EN_KILLFOCUS message to XSTART edit control
					if(GetFocus()==GETHCTL(IDC_DLINE_XSTART))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
							IDC_DLINE_XSTART, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to XEND edit control
					if(GetFocus()==GETHCTL(IDC_DLINE_XEND))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
							IDC_DLINE_XEND, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to YSTART edit control
					if(GetFocus()==GETHCTL(IDC_DLINE_YSTART))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
							IDC_DLINE_YSTART, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to YEND edit control
					if(GetFocus()==GETHCTL(IDC_DLINE_YEND))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
							IDC_DLINE_YEND, NULL, EN_KILLFOCUS));
					}
				}
				break;

				// Print line info on printer using Win32 API
				// Note: Bare-bones printing code: no error trapping, no font
				// selection, no abort proc, 1 page only
				// Printer must use fixed-space font
				// User can choose printer in PrintDlg

				// Struct linedata items for plot line data:
				// int nLineType	Line type
				// int nSlope		Power law slope for noise line
				// int nXStart		
				// int nXEnd		
				// float fSlope		Linear slope for regression fit
				// float fSigma1	Sigma(1) value for power law noise fit
				// float fAverage	Average line value
			    // F_TYPE fXStart	 
				// F_TYPE fXEnd
				// F_TYPE fYStart
				// F_TYPE fYEnd

				// Phase Plot Line # & Types
				// PLINE_NUMLINES	# possible lines
				// PLINE_NONE       No line
				// PLINE_END        Line between endpoints
				// PLINE_QUAD       Quadratic fit
				// PLINE_AVG        Horiz line at avg value
				// PLINE_MARK       Vert marker line

				case IDC_DLINE_PRINT:
				{
					// Initialize PRINTDLG structure
					memset(&pd, 0, sizeof(PRINTDLG));
					pd.lStructSize=sizeof(PRINTDLG);
					pd.Flags=PD_RETURNDEFAULT; // Don't show dialog box

					// 1st (hidden) call to PrintDlg()
					// To set up hDevNames & hDevMode
 					if(!PrintDlg(&pd))
					{
						// PrintDlg() called failed
						MessageBox(hwndMain, "Printer Not Found", "Line Print",
						MB_ICONEXCLAMATION);
						break;
					}

					// Reinitialize PRINTDLG structure
					// Get DC & no choice of page #s & no text selection
					pd.Flags=PD_RETURNDC | PD_NOPAGENUMS | PD_NOSELECTION;

					// 2nd (visible) call to PrintDlg()
					if(PrintDlg(&pd))
					{
						// Get printer device context
						hdcPrn=pd.hDC;
					}
					else
					{
						if(CommDlgExtendedError())
						{
							// Printer error
							MessageBox(hwndMain, "Printer Error", "Line Print",
							MB_ICONEXCLAMATION);
						}
						else // Error code 0
						{
							// User hit cancel button
							break;
						}
					}
					
					// Determine logfont.lfHeight from point size = nPointSize
					// where nPointSize is global variable that user can enter
					// in General page of Configure property sheet
					// Win32 documentation gives the formula:
					// lfHeight = -MulDiv(PointSize,
					//    GetDeviceCaps(hDC, LOGPIXELSY), 72);
					// which becomes the following for our variables:
					// nFontHeight = -MulDiv(nPointSize, GetDeviceCaps(hdcPrn,
					//    LOGPIXELSY), 72);
					// Both nPointSize and nFontHeight are global variables
					// A couple of typical values are nPointSize=9,
					//    nFontHeight=-75
					// and nPointSize=10, nFontHeight=-83
					// The abs value of nFontHeight is used
					nFontHeight = -MulDiv(nPointSize, GetDeviceCaps(hdcPrn,
						LOGPIXELSY), 72);
					
					// Set font attributes
					// Assumes 8.5"x11" portrait page
					// Text size set to fit nicely across std page
					// Fixed pitch for easy alignment
					logfont.lfHeight=nFontHeight;
					logfont.lfWidth=0;
					logfont.lfEscapement=0;
					logfont.lfOrientation=0;
					logfont.lfWeight=0;
					logfont.lfItalic=0;
					logfont.lfUnderline=0;
					logfont.lfStrikeOut=0;
					logfont.lfCharSet=OEM_CHARSET;
					logfont.lfOutPrecision=OUT_DEFAULT_PRECIS;
					logfont.lfClipPrecision=CLIP_DEFAULT_PRECIS;
					logfont.lfQuality=PROOF_QUALITY;
					logfont.lfPitchAndFamily=FIXED_PITCH | FF_DONTCARE;
					strlcpy(logfont.lfFaceName,"", LF_FACESIZE);

					// Create printer font
					hPrnFont=CreateFontIndirect(&logfont);

					// Select font into printer device
					SelectObject(hdcPrn, hPrnFont);

					// Get text metrics
					GetTextMetrics(hdcPrn, &tm);
					yChar=tm.tmHeight + tm.tmExternalLeading;
					xChar=tm.tmAveCharWidth;

					// Get page dimensions
					xPage=(short)GetDeviceCaps(hdcPrn, HORZRES);
					yPage=(short)GetDeviceCaps(hdcPrn, VERTRES);

					// Compose Print Manager message
					LoadString(hInst, IDS_MESSAGE_REPORT, szPrnMsg,
							BUFFER_SIZE);

					// Set up DOCINFO structure
					memset(&di, 0, sizeof(DOCINFO));
					di.cbSize=sizeof(DOCINFO);
					di.lpszDocName=szPrnMsg;
					
					// Start printing
					if(hdcPrn != NULL)
					{
						if(StartDoc(hdcPrn, &di) != SP_ERROR)
						{
							// Actual printing code starts here
							StartPage(hdcPrn);

							nPrintLine=0; // Page heading
							SetTextAlign(hdcPrn, TA_LEFT || TA_TOP);
							LoadString(hInst, IDS_FORMAT_PLINE_PH, szFormat,
								BUFFER_SIZE);
							_snprintf(szBuffer, sizeof(szBuffer), szFormat,
								szPhaseFileTitle);
							TextOut(hdcPrn, xChar/2, (int)((nPrintLine+0.5)*
								yChar),	szBuffer, strlen(szBuffer));
							
							nPrintLine=2; // Column headings
							SetTextAlign(hdcPrn, TA_LEFT || TA_TOP);
							LoadString(hInst, IDS_FORMAT_PLINE_CH, szFormat,
								BUFFER_SIZE);
							_snprintf(szBuffer, sizeof(szBuffer), szFormat);
							TextOut(hdcPrn, xChar/2, (int)((nPrintLine+0.5)*
								yChar),	szBuffer, strlen(szBuffer));

							nPrintLine++;

							for(i=0; i<PLINE_NUMLINES; i++)
							{
								nPrintLine++;
								switch(sPLine[i].nLineType)
								{
									case PLINE_NONE:
									{
										LoadString(hInst, IDS_FORMAT_PLINE_0,
											szFormat, BUFFER_SIZE);
										_snprintf(szBuffer, sizeof(szBuffer),
											szFormat,	i+1);
									}
									break;

									case PLINE_END:
									{
										LoadString(hInst, IDS_FORMAT_PLINE_1,
											szFormat, BUFFER_SIZE);
										_snprintf(szBuffer, sizeof(szBuffer),
											szFormat, i+1,
											sPLine[i].fXStart,
											sPLine[i].fXEnd,
											sPLine[i].fYStart,
											sPLine[i].fYEnd);
									}
									break;

									case PLINE_QUAD:
									{
										LoadString(hInst, IDS_FORMAT_PLINE_2,
											szFormat, BUFFER_SIZE);
										_snprintf(szBuffer, sizeof(szBuffer),
											szFormat,	i+1,
											sPLine[i].fXStart,
											sPLine[i].fXEnd,
											sPLine[i].fSlope);
									}
									break;
						
									case PLINE_AVG:
									{
										LoadString(hInst, IDS_FORMAT_PLINE_3,
											szFormat, BUFFER_SIZE);
										_snprintf(szBuffer, sizeof(szBuffer),
											szFormat, i+1,
											sPLine[i].fXStart,
											sPLine[i].fXEnd,
											sPLine[i].fAverage);
									}
									break;

									case PLINE_MARK:
									{
										LoadString(hInst, IDS_FORMAT_PLINE_4,
											szFormat, BUFFER_SIZE);
										_snprintf(szBuffer, sizeof(szBuffer),
											szFormat, i+1,
											sPLine[i].fXStart,
											sPLine[i].fXEnd);
									}
									break;

									#if(1) // New code 07/24/10
									case PLINE_LIN:
									{
										LoadString(hInst, IDS_FORMAT_PLINE_5,
											szFormat, BUFFER_SIZE);
										_snprintf(szBuffer, sizeof(szBuffer),
											szFormat,	i+1,
											sPLine[i].fXStart,
											sPLine[i].fXEnd,
											sPLine[i].fSlope);
									}
									break;
									#endif
								}

								ShortenExp(szBuffer);
								TextOut(hdcPrn, (int)(xChar/2),
									(int)((nPrintLine+0.4)*yChar), szBuffer,
									strlen(szBuffer));
							}

							// End (single) page
							EndPage(hdcPrn);

							// End printing
							EndDoc(hdcPrn);
						}
						else // Error or print to file cancelled
						{
							;
						}

						// Release device context
						DeleteDC(hdcPrn) ;
					}
					else // hdcPrn==NULL
					{
						;
					}

					// Delete printer logical font
					DeleteObject(hPrnFont);
				}
				break;

				// Respond to copy button
				case IDC_DLINE_COPY:
				{
					#if(1) // New code 10/03/08
					// Allocate global memory for 14 lines of info
					// Top & column headings plus 12 lines
					hClipboard=GlobalAlloc(GMEM_DDESHARE, (DWORD)(CLIPBOARD_SIZE));
					szClipboard=GlobalLock(hClipboard);

					// Main heading
					LoadString(hInst, IDS_FORMAT_PLINE_PH, szFormat,
						BUFFER_SIZE);
					
					_snprintf(szClipboard, CLIPBOARD_SIZE, szFormat,
						szPhaseFileTitle);
					strlcat(szClipboard, "\r\n", CLIPBOARD_SIZE);

					// Column heading
					LoadString(hInst, IDS_FORMAT_PLINE_CH, szFormat,
						BUFFER_SIZE);
					_snprintf(szBuffer, sizeof(szBuffer), szFormat);
					strlcat(szClipboard, szBuffer, CLIPBOARD_SIZE);
					strlcat(szClipboard, "\r\n", CLIPBOARD_SIZE);

					for(i=0; i<PLINE_NUMLINES; i++)
					{
						switch(sPLine[i].nLineType)
						{
							case PLINE_NONE:
							{
								LoadString(hInst, IDS_FORMAT_PLINE_0,
									szFormat, BUFFER_SIZE);
								_snprintf(szBuffer, sizeof(szBuffer),
									szFormat,	i+1);
							}
							break;

							case PLINE_END:
							{
								LoadString(hInst, IDS_FORMAT_PLINE_1,
									szFormat, BUFFER_SIZE);
								_snprintf(szBuffer, sizeof(szBuffer),
									szFormat, i+1,
									sPLine[i].fXStart,
									sPLine[i].fXEnd,
									sPLine[i].fYStart,
									sPLine[i].fYEnd);
							}
							break;

							case PLINE_QUAD:
							{
								LoadString(hInst, IDS_FORMAT_PLINE_2,
									szFormat, BUFFER_SIZE);
								_snprintf(szBuffer, sizeof(szBuffer),
									szFormat,	i+1,
									sPLine[i].fXStart,
									sPLine[i].fXEnd,
									sPLine[i].fSlope);
							}
							break;
						
							case PLINE_AVG:
							{
								LoadString(hInst, IDS_FORMAT_PLINE_3,
									szFormat, BUFFER_SIZE);
								_snprintf(szBuffer, sizeof(szBuffer),
									szFormat, i+1,
									sPLine[i].fXStart,
									sPLine[i].fXEnd,
									sPLine[i].fAverage);
							}
							break;

							case PLINE_MARK:
							{
								LoadString(hInst, IDS_FORMAT_PLINE_4,
									szFormat, BUFFER_SIZE);
								_snprintf(szBuffer, sizeof(szBuffer),
									szFormat, i+1,
									sPLine[i].fXStart,
									sPLine[i].fXEnd);
							}
							break;

							#if(1) // New code 07/24/10
							case PLINE_LIN:
							{
								LoadString(hInst, IDS_FORMAT_PLINE_5,
									szFormat, BUFFER_SIZE);
								_snprintf(szBuffer, sizeof(szBuffer),
									szFormat,	i+1,
									sPLine[i].fXStart,
									sPLine[i].fXEnd,
									sPLine[i].fSlope);
							}
							break;
							#endif
						}

						ShortenExp(szBuffer);
						strlcat(szClipboard, szBuffer, CLIPBOARD_SIZE);
						strlcat(szClipboard, "\r\n", CLIPBOARD_SIZE);
					}

					// Write info to clipboard
					GlobalUnlock(hClipboard);
					OpenClipboard(NULL);
					EmptyClipboard();
					SetClipboardData(CF_TEXT, hClipboard);
					CloseClipboard();
					#endif
				}

				// OK button pressed - accept inputs
				case IDC_DLINE_ACCEPT:
				{
					// Close dialog box
					EndDialog (hDlg, 0);
				}
				return TRUE;

				// Cancel button pressed - restore previous inputs before end
				// Respond to esc key or cancel button
				case IDCANCEL:
				case IDC_DLINE_CANCEL:
				{
					// Save the original line data
					for(i=0; i<PLINE_NUMLINES; i++)
					{
						sPLine[i].nLineType=sPSave[i].nLineType;
						sPLine[i].fXStart=sPSave[i].fXStart;
						sPLine[i].fXEnd=sPSave[i].fXEnd;
						sPLine[i].fYStart=sPSave[i].fYStart;
						sPLine[i].fYEnd=sPSave[i].fYEnd;
					}

					// Close dialog box
					EndDialog (hDlg, 0);
				}
				return TRUE;
			}
		}
		break;
	 }
	 return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*                   Sigma Plot Line Dialog Procedure                        */
/*                                                                           */
/*	Sigmadata structures:                                                    */
/*	struct sigmadata sNormSigData	Normal & overlapping sigma data struct   */
/*	struct sigmadata sModSigData	Modified & time sigma data struct        */
/*                                                                           */
/*	Struct for sigma data:                                                   */
/*	struct sigmadata		Structure template for sigma data                */
/*	{                                                                        */
/*		int points;         Number of sigma data points                      */
/*		float *tau;         Pointer to averaging time data array             */
/*		float *num;         Pointer to number of data points array           */
/*		float *sigma;       Pointer to sigma data array                      */
/*		float *ci;          Pointer to conf interval from SIGMA.TAU file     */
/*		float *sig_min;     Pointer to lower sigma error bar array           */
/*		float *sig_max;     Pointer to upper sigma error bar array           */
/*		float *std_dev;		Pointer to standard deviation array              */
/*		int *alpha;         Pointer to power-law noise type exponent array   */
/*	}                                                                        */
/*                                                                           */
/*  Stability plot mask file format:                                         */
/*                                                                           */
/*		1.	No line shall exceed 80 characters.                              */
/*		2.	An optional first line beginning with # as the first character   */
/*			can contain a comment (such as information about the name,       */
/*          origin & purpose of the mask) for documentation purposes only.   */
/*		3.	A mandatory header line with four fields: n x y l, where:        */
/*				int n = # mask data points                                   */
/*              double x = label x position in stability plot units          */
/*				double y = label y position in stability plot units          */
/*	            char *l = mask label string, which must be enclosed in       */
/*				double quotes.  This label becomes a plot note and can be    */
/*				edited as a note before it appears on the plot.  The intent  */
/*				is for the label to automatically identify the mask on the   */
/*				plot.                                                        */
/*      4.	An arbitrary number of following lines containg x-y data in      */
/*          stability plot units defining the mask.  These tau-sigma points  */
/*          must be in exactly n rows of two space-delimited columns.  Plot  */
/*          lines will connect these points on the plot, so they need only   */
/*          define the corners of the mask on log-log axes.  Otherwise, the  */
/*          points can be dense enough to draw a general smooth curve.       */
/*		5.	The mask filename shall have a *.msk extension, and its name     */
/*          should relate in an obvious way to the mask label because it is  */
/*          the means that the user will use to select it.                   */
/*      6.	The mask file(s) must reside in the same directory as the        */
/*          Stable32.exe executable file that launched the program.  Any     */
/*			number of such files can exist and are available for selection   */
/*          in the Run Plot Lines dialog.                                    */
/*                                                                           */
/*          Example of mask file "test.msk":                                 */
/*                                                                           */
/*			# Test mask to use with phase.dat test data ADEV plot			 */
/*			3 10 0.55 "Test Mask"											 */
/*			1 .05															 */
/*			10 .5															 */
/*			100 .5                                                           */
/*                                                                           */
/*	Revision record:                                                         */
/*  	10/20/96	Running quite nicely                                     */
/*					Line # entry changed to combo box                        */
/*		10/21/96	Fixed incorrect noise tau start & end values             */
/*		10/23/96	Revised line initialization code                         */
/*		03/27/97 	Fixed noise line initialization code problem             */
/*		05/25/97	Added code to reinitialize after tau increment change    */
/*		06/04/97	Added line count at initialization                       */
/*		12/20/97	Added line parameter read & save buttons                 */
/*		01/02/97	Added up and down buttons                                */
/*		01/20/98	Fixed error in noise fits for +1.5 & +2.0 slopes         */
/*		08/29/98	Added print function                                     */
/*		12/27/99	Added Mod Totvar                                         */
/*		05/15/00	Added TTOT                                               */
/*					Added provisions for updating tau choices after resume   */
/*		05/30/00	Eliminated noise lines if multiple data sets             */
/*		10/29/00	Added HTOT                                               */
/*		11/02/05	Added provisions for masks                               */
/*		12/22/06	Added weighted noise fits                                */
/*		12/22/06	Added Weight= INI file [Preferences] item (read only)    */
/*		03/11/07	Avoid noise line weighting if bAllTau set                */
/*					Omit noise line type for MTIE and TIErms sigma types     */
/*					Handle weighted ThoH noise line                         */
/*		10/08/08	Use fully-qualified mask filename                        */
/*                                                                           */
/*****************************************************************************/

#ifndef _MSC_VER
	#pragma argsused
#endif

BOOL CALLBACK SigmaLineDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local macro
	#define SLOPE_DEF 2             // Default slope

	// Local variables
	// Structs
	static struct linedata sPSave[SLINE_NUMLINES];
									// To preserve original plot line data
	// Chars
	char szBuffer[BUFFER_SIZE+1];	// General text buffer
	char szText[BUFFER_SIZE+1];		// Text buffer
	char szMaskFilename[FILENAMESIZE+1];	// General text buffer
	// Ints
	int i;							// General index
	int j;							// Secondary array index;
	int k;							// Secondary index
	int nStart, nEnd;				// Line fit start & end indices
	int	nPrevLineType;              // Previous line type
	int nPrintLine;					// Line # of printout
	int nSize;						// String size
	static int nCount=0; 		   	// # active lines
	static int nPoints;				// # sigma data points
	static int nLine=0;				// Line # = 0 to SLINE_NUMLINES-1
									// Line # displayed is nLine+1
	static int nSlope=SLOPE_DEF;    // Slope # goes from 0 to NUM_RUN_NOISES-1
	static int nPrevSigmaType=NORMAL_RUN;	// Previous sigma plot type
	static int nPrevTauIncrement=TAU_OCTAVE;// Previous tau increment type
	// BOOLs
	static BOOL bStart=TRUE;  	 	// Start flag for initializations
	static BOOL bUpdate=TRUE;    	// Update flag to avoid infinite looping
	static BOOL bErrorTrap=FALSE;   // Flag for entry error
	static BOOL bNewNoiseLine=TRUE;	// Flag for new noise line
	static BOOL	bMultiple=FALSE;	// Flag for multiple data sets

	// Flag for weighted noise fit
	// Note: Set below by reading Weight=  INI file [Preferences] item
	static BOOL bWeight=TRUE;		// 0=No weighting, 1=Weighting

	// Floats
	float fEntry;                   // Entry value to be validated
	static float fTauStart;         // X-start value
	static float fTauEnd;           // X-end value
	static float fSigmaStart;       // Y-start value
	static float fSigmaEnd;         // Y-end value
	static float fSlope;			// Numerical noise slope
	static float fSigma1;			// Sigma(1) value for noise fit
	static float fMinTau;           // Min tau value
	static float fMaxTau;           // Max tau value
	static float fMinSigma;         // Min sigma value
	static float fMaxSigma;         // Max sigma value
	static float fWeight;			// Noise fit point weighting factor
	static float fWeightSum;		// Noise fit weighting sum

	// Printing variables
	char szFormat[BUFFER_SIZE+1];           // Format string
	static HDC hdcPrn;              // Handle to printer device context
	TEXTMETRIC tm;                  // Text metrics structure
	static int xChar, yChar;        // Text character sizes
	static int nRows;               // # rows of results
	static short xPage, yPage;      // Graphic page dims in pixels
	// Printer font
	LOGFONT logfont;                // Printer logical font structure
	HFONT hPrnFont;                 // Printer font handle
	// Win32 API printing structs
	PRINTDLG pd;
	DOCINFO di;
	// File handle
	FILE *fFile;           			// DOS file handle for mask file reading

	// Start of code

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Initializations done only at start

			// Clear start flag if sigma line data was read from INI file
			if(bUseSigmaPlotIni)
			{
				bStart=FALSE;
			}

			// Count # active lines
			nCount=0;
			for(i=0; i<SLINE_NUMLINES; i++)
			{
				if(sSLine[i].nLineType!=SLINE_NONE)
				{
					nCount++;
				}
			}

			// Update end tau values in case we are resuming a run
			for (i=0; i<nCount; i++)
			{
				// Update end tau choices
				SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
					IDC_SLINE_TAUUPDATE, NULL, 0));
			}
			
			if((bStart) || (nPrevSigmaType!=nSigmaPlotType) ||
			   (nPrevTauIncrement!=nTauIncrement) || (nCount==0))
			{
				// Initialize line params
				SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
					IDC_SLINE_INITIALIZE, NULL, 0));

				// Reset start flag
				bStart=FALSE;

				// Set new noise line flag
				bNewNoiseLine=TRUE;

				// Save sigma type
				// Used to force full initialization if sigma type changes
				nPrevSigmaType=nSigmaPlotType;

				// Save tau increment type
				// Used to force full initialization if increment type changes
				nPrevTauIncrement=nTauIncrement;
			}

			// Other initializations done every time dialog box is opened
			if(nPlotType==READ_PLOT)
			{
				// Change dialog box title
				LoadString(hInst, IDS_TITLE_READLINE, szBuffer,	BUFFER_SIZE);
			}
			else if(nPlotType==SIGMA_PLOT)
			{
				// Change dialog box title
				LoadString(hInst, IDS_TITLE_SIGMALINE, szBuffer, BUFFER_SIZE);
			}
			SetWindowText(hDlg, szBuffer);

			// Load integers into line # box
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_SLINE_NUM));
			for(i=0; i<SLINE_NUMLINES; i++)
			{
				_snprintf(szBuffer, sizeof(szBuffer), "%d", i+1);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_SLINE_NUM),
					i, szBuffer);
			}

			// Save the original line data
			for(i=0; i<SLINE_NUMLINES; i++)
			{
				sPSave[i].nLineType=sSLine[i].nLineType;
				sPSave[i].nSlope=sSLine[i].nSlope;
				sPSave[i].fXStart=sSLine[i].fXStart;
				sPSave[i].fXEnd=sSLine[i].fXEnd;
				sPSave[i].fYStart=sSLine[i].fYStart;
				sPSave[i].fYEnd=sSLine[i].fYEnd;
			}

			// Fill up line options list box using string table
			// nSigmaPlotType choices are:
			// NORMAL_RUN             0
			// OVERLAPPING_RUN        1
			// MODIFIED_RUN           2
			// TIME_RUN               3
			// HADAMARD_RUN           4
			// OVERLAPHAD_RUN		  5
			// TOTAL_RUN              6
			// MODTOTAL_RUN			  7
			// TIMETOTAL_RUN		  8
			// HADTOTAL_RUN			  9
			// BOTH_RUN              10
			// TIERMS_RUN            11
			// MTIE_RUN              12
			// THEO1_RUN			 13
			// FULL_RUN              14
			// CROSS_RUN			 15

			// The NUM_RUN_LINETYPES nLineType choices are:
			// 		SLINE_NONE		IDS_RUN_LINE_0		"None"
			//		SLINE_END		IDS_RUN_LINE_1		"Endpoints"
			//		SLINE_HORIZ		IDS_RUN_LINE_2		"Horizontal"
			//		SLINE_VERT		IDS_RUN_LINE_3		"Vertical"
			//		SLINE_NOISE		IDS_RUN_LINE_4		"Noise"
			//		SLINE_MASK		IDS_RUN_LINE_5		"Mask"
			//		SLINE_TDEV		IDS_RUN_LINE_6		"TDEV"

			// Noise lines are allowed only for the first 10 _RUN types
			// Plus Tho1
			// TDEV lines are allowed only for MODIFIED_RUN & MODTOTAL_RUN

			if( (nSigmaPlotType==MODIFIED_RUN) ||
				(nSigmaPlotType==MODTOTAL_RUN))
			{
				nDummy=ComboBox_ResetContent(GETHCTL(IDC_SLINE_TYPE));
				for(i=0; i<NUM_RUN_LINETYPES; i++)
				{
					LoadString(hInst, IDS_RUN_LINE_0+i, szBuffer, BUFFER_SIZE);
					nDummy=ComboBox_InsertString(GETHCTL(IDC_SLINE_TYPE),
						i, szBuffer);
				}
			}
			else if((nSigmaPlotType<=HADTOTAL_RUN) ||
				(nSigmaPlotType==THEO1_RUN))
			{
				nDummy=ComboBox_ResetContent(GETHCTL(IDC_SLINE_TYPE));
				for(i=0; i<NUM_RUN_LINETYPES-1; i++)
				{
					LoadString(hInst, IDS_RUN_LINE_0+i, szBuffer, BUFFER_SIZE);
					nDummy=ComboBox_InsertString(GETHCTL(IDC_SLINE_TYPE),
						i, szBuffer);
				}
			}
			else if((nSigmaPlotType==MTIE_RUN) || (nSigmaPlotType==TIERMS_RUN))
			// MTIE_RUN & TIERMS_RUN don't support noise lines
			{
				nDummy=ComboBox_ResetContent(GETHCTL(IDC_SLINE_TYPE));
				j=0;
				for(i=0; i<NUM_RUN_LINETYPES-1; i++)
				{
					// Omit noise line
					if(i!=SLINE_NOISE)
					{
						LoadString(hInst, IDS_RUN_LINE_0+i, szBuffer,
							BUFFER_SIZE);
						nDummy=ComboBox_InsertString(GETHCTL(IDC_SLINE_TYPE),
							j, szBuffer);
						j++;
					}
				}
			}
			else // Everything else
			{
				nDummy=ComboBox_ResetContent(GETHCTL(IDC_SLINE_TYPE));
				for(i=0; i<NUM_RUN_LINETYPES-2; i++)
				{
					LoadString(hInst, IDS_RUN_LINE_0+i, szBuffer, BUFFER_SIZE);
					nDummy=ComboBox_InsertString(GETHCTL(IDC_SLINE_TYPE),
						i, szBuffer);
				}
			}

			// Disable noise lines if have more than one data set
			// Reset multiple data set flag
			bMultiple=FALSE;

			// Scan through all sigma points, looking for tau reversal
			for(i=0; i<nPoints-1; i++)
			{
				if( (nSigmaPlotType==MODIFIED_RUN) ||
					(nSigmaPlotType==MODTOTAL_RUN) ||
					(nSigmaPlotType==TIME_RUN)     ||
					(nSigmaPlotType==TIMETOTAL_RUN) )
				{
					if(sModSigData.tau[i+1]<=sModSigData.tau[i])
					{
						bMultiple=TRUE;
					}
				}
				else // Normal sigma type
				{
					if(sNormSigData.tau[i+1]<=sNormSigData.tau[i])
					{
						bMultiple=TRUE;
					}
				}
			}

			// Eliminate noise lines if multiple data sets
			if(bMultiple)
			{
				nDummy=ComboBox_ResetContent(GETHCTL(IDC_SLINE_TYPE));
				for(i=0; i<NUM_RUN_LINETYPES-2; i++)
				{
					LoadString(hInst, IDS_RUN_LINE_0+i, szBuffer, BUFFER_SIZE);
					nDummy=ComboBox_InsertString(GETHCTL(IDC_SLINE_TYPE),
						i, szBuffer);
				}
			}
			
			// Fill up noise slope options list box using string table
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_SLINE_SLOPE));
			if(nSigmaPlotType!=TIME_RUN && nSigmaPlotType!=TIMETOTAL_RUN)
			{
				// Change W PM slope to -1.5 for mod sigmas
				if( (nSigmaPlotType==MODIFIED_RUN) ||
					(nSigmaPlotType==MODTOTAL_RUN) )
				{
					LoadString(hInst, IDS_RUN_MDEV_0, szBuffer, BUFFER_SIZE);
					nDummy=ComboBox_InsertString(GETHCTL(IDC_SLINE_SLOPE),
						0, szBuffer);
				}
				else // All other ADEVs
				{
					LoadString(hInst, IDS_RUN_ADEV_0, szBuffer, BUFFER_SIZE);
					nDummy=ComboBox_InsertString(GETHCTL(IDC_SLINE_SLOPE),
						0, szBuffer);
				}

				for(i=1; i<NUM_RUN_NOISES; i++)
				{
					LoadString(hInst, IDS_RUN_ADEV_0+i, szBuffer, BUFFER_SIZE);
					nDummy=ComboBox_InsertString(GETHCTL(IDC_SLINE_SLOPE),
						i, szBuffer);
				}

				// Add FW and RR FM noises for Hadamard variances
				if(nSigmaPlotType==HADAMARD_RUN ||
				   nSigmaPlotType==OVERLAPHAD_RUN ||
				   nSigmaPlotType==HADTOTAL_RUN)
				{
					for(i=NUM_RUN_NOISES; i<NUM_RUN_NOISES+2; i++)
					{
						LoadString(hInst, IDS_RUN_ADEV_0+i, szBuffer,
							BUFFER_SIZE);
						nDummy=ComboBox_InsertString(GETHCTL(IDC_SLINE_SLOPE),
							i, szBuffer);
					}
				}
			}

			// Use other strings for time sigma
			if(nSigmaPlotType==TIME_RUN || nSigmaPlotType==TIMETOTAL_RUN)
			{
				for(i=0; i<NUM_RUN_NOISES; i++)
				{
					LoadString(hInst, IDS_RUN_TDEV_0+i, szBuffer, BUFFER_SIZE);
					nDummy=ComboBox_InsertString(GETHCTL(IDC_SLINE_SLOPE),
						i, szBuffer);
				}
			}

			// Update display for all parameter values
			SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDC_SLINE_UPDATE,
				NULL, 0));

			return TRUE;
		}

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				// Help button presses
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::RUN_LINES_FUNCTION.HTM",
						HH_DISPLAY_TOPIC,
                        0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::RUN_LINES_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "RUN_LINES_FUNCTION");
					#endif
				}
				break;


				case IDC_SLINE_INITIALIZE:
				{
					if( (nSigmaPlotType==MODIFIED_RUN) ||
						(nSigmaPlotType==MODTOTAL_RUN) ||
						(nSigmaPlotType==TIME_RUN)     ||
						(nSigmaPlotType==TIMETOTAL_RUN) )
					{
						nPoints=sModSigData.points;
					}
					else
					{
						nPoints=sNormSigData.points;
					}

					// Initialize the sSLine elements to the sigma plot
					// scale limits
					for(i=0; i<SLINE_NUMLINES; i++)
					{
						sSLine[i].nLineType=SLINE_NONE;
						sSLine[i].fXStart=sSPlot.x_min;
						sSLine[i].fXEnd=sSPlot.x_max;
						sSLine[i].fYStart=sSPlot.y_min;
						sSLine[i].fYEnd=sSPlot.y_max;
						sSLine[i].nSlope=SLOPE_DEF;
					}
				}
				break;

				// Clear display
				// Note: Used to clear display for case of invalid line #
				// Therefore the line # display is not changed
				case IDC_SLINE_CLEAR:
				{
					// Inhibit value changed processing
					bUpdate=FALSE;

					// Show line type
					nDummy=ComboBox_SetCurSel(GETHCTL(IDC_SLINE_TYPE),
						SLINE_NULL);

					// Show noise type
					nDummy=ComboBox_SetCurSel(GETHCTL(IDC_SLINE_SLOPE),
						SLOPE_DEF);

					// Load the x-axis start value
					SetWindowText(GETHCTL(IDC_SLINE_XSTART), "");

					// Load the x-axis end value
					SetWindowText(GETHCTL(IDC_SLINE_XEND), "");

					// Load the y-axis start value
					SetWindowText(GETHCTL(IDC_SLINE_YSTART), "");

					// Load the y-axis end value
					SetWindowText(GETHCTL(IDC_SLINE_YEND), "");

					// Update line count
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_SLINE_COUNT, NULL, 0));

					// Enable value changed processing
					bUpdate=TRUE;
				}
				break;

				// Update noise line end tau choices
				case IDC_SLINE_TAUUPDATE:
				{
					// Get current # sigma points
					if( (nSigmaPlotType==MODIFIED_RUN) ||
						(nSigmaPlotType==MODTOTAL_RUN) ||
						(nSigmaPlotType==TIME_RUN)     ||
						(nSigmaPlotType==TIMETOTAL_RUN) )
					{
						nPoints=sModSigData.points;
					}
					else
					{
						nPoints=sNormSigData.points;
					}

					// Check if noise line
					if(sSLine[nLine].nLineType==SLINE_NOISE)
					{
						// Load tau end values into list box
						nDummy=ComboBox_ResetContent(GETHCTL(IDC_SLINE_XLAST));
						for(k=0; k<nPoints; k++)
						{
							if( (nSigmaPlotType==MODIFIED_RUN) ||
								(nSigmaPlotType==MODTOTAL_RUN) ||
								(nSigmaPlotType==TIME_RUN)     ||
								(nSigmaPlotType==TIMETOTAL_RUN) )
							{
								_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
									sModSigData.tau[k]);
								ShortenExp(szBuffer);
							}
							else
							{
								_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
									sNormSigData.tau[k]);
								ShortenExp(szBuffer);
							}
							nDummy=ComboBox_InsertString(GETHCTL(
								IDC_SLINE_XLAST), k, szBuffer);
						}
					}
				}
				break;

				// Update display
				case IDC_SLINE_UPDATE:
				{
					// Inhibit value changed processing
					bUpdate=FALSE;

					// Set Noise Line groupbox label
					SetWindowText(GETHCTL(IDC_SLINE_NOISE), "Noise Line");

					// Set Slope label to Slope:
					SetWindowText(GETHCTL(IDC_SLINE_SLOPELAB), "Slo&pe:");

					// Show all Noise Line groupbox controls
					ShowWindow(GETHCTL(IDC_SLINE_SLOPE), SW_SHOWNORMAL);
					ShowWindow(GETHCTL(IDC_SLINE_SLOPELAB), SW_SHOWNORMAL);
					ShowWindow(GETHCTL(IDC_SLINE_SIGMALAB), SW_SHOWNORMAL);
					ShowWindow(GETHCTL(IDC_SLINE_PARAM), SW_SHOWNORMAL);

					// Hide masks combo box
					ShowWindow(GETHCTL(IDC_SLINE_MASKS), SW_HIDE);

					// Select line #
					nDummy=ComboBox_SetCurSel(GETHCTL(IDC_SLINE_NUM), nLine);

					// Show line type
					nDummy=ComboBox_SetCurSel(GETHCTL(IDC_SLINE_TYPE),
						sSLine[nLine].nLineType);

					// Disable noise type params
					nDummy=ComboBox_SetCurSel(GETHCTL(IDC_SLINE_SLOPE),
						nSlope);
					ShowWindow(GETHCTL(IDC_SLINE_SLOPE),SW_HIDE);
					EnableWindow(GETHCTL(IDC_SLINE_SLOPELAB), FALSE);
					EnableWindow(GETHCTL(IDC_SLINE_SIGMALAB), FALSE);

					// Disable all line params
					ShowWindow(GETHCTL(IDC_SLINE_XFIRST), SW_HIDE);
					ShowWindow(GETHCTL(IDC_SLINE_XLAST), SW_HIDE);
					ShowWindow(GETHCTL(IDC_SLINE_XSTART), SW_HIDE);
					ShowWindow(GETHCTL(IDC_SLINE_XEND), SW_HIDE);
					ShowWindow(GETHCTL(IDC_SLINE_YSTART), SW_HIDE);
					ShowWindow(GETHCTL(IDC_SLINE_YEND), SW_HIDE);
					EnableWindow(GETHCTL(IDC_SLINE_XSTARTLAB), FALSE);
					EnableWindow(GETHCTL(IDC_SLINE_XENDLAB), FALSE);
					EnableWindow(GETHCTL(IDC_SLINE_YSTARTLAB), FALSE);
					EnableWindow(GETHCTL(IDC_SLINE_YENDLAB), FALSE);

					// Clear tau start & end list boxes
					nDummy=ComboBox_ResetContent(GETHCTL(IDC_SLINE_XFIRST));
					nDummy=ComboBox_ResetContent(GETHCTL(IDC_SLINE_XLAST));

					// Clear parameter display
					SetWindowText(GETHCTL(IDC_SLINE_PARAM), "");

					// Setup controls for mask
					// Load mask names into separate combo box IDC_SLINE_MASKS
					// Change IDC_SLINE_NOISE Noise Line groupbox label
					// to Masks
					// Hide all its normal contents
					// Show a separate Mask: label and combobox in it
					if((sSLine[nLine].nLineType)==SLINE_MASK)
					{
						// Change Noise Line groupbox label to Masks
						SetWindowText(GETHCTL(IDC_SLINE_NOISE), "Masks");

						// Change Slope label to File:
						SetWindowText(GETHCTL(IDC_SLINE_SLOPELAB), "&File:");
						EnableWindow(GETHCTL(IDC_SLINE_SLOPELAB), TRUE);

						// Hide unwanted Noise Line groupbox controls
						ShowWindow(GETHCTL(IDC_SLINE_SLOPE), SW_HIDE);
						ShowWindow(GETHCTL(IDC_SLINE_SIGMALAB), SW_HIDE);
						ShowWindow(GETHCTL(IDC_SLINE_PARAM), SW_HIDE);

						// Show mask combo box
						ShowWindow(GETHCTL(IDC_SLINE_MASKS), SW_SHOWNORMAL);

						// Load mask combo box with names of available
						// mask files
						// Masks are stored as disk files with *.msk extension
						// First line of file has mask x-y position & label
						// Label is generally same as filename,
						// but not necessarily
						// Combobox has special CB_DIR message
						// for listing files
						nDummy=ComboBox_ResetContent(GETHCTL(IDC_SLINE_MASKS));

						#if(0) // Original code
						SendMessage(GETHCTL(IDC_SLINE_MASKS), CB_DIR,
							DDL_READWRITE, (LPARAM) "*.msk");
						#endif

						#if(1) // New code 10/08/08
						// Compose fully-qualified general mask filename
						strlcpy(szMaskFilename, szPath, FILE_NAME_SIZE);
						strlcat(szMaskFilename, "*.msk", FILE_NAME_SIZE);
						SendMessage(GETHCTL(IDC_SLINE_MASKS), CB_DIR,
							DDL_READWRITE, (LPARAM) szMaskFilename);
						#endif

						// Select first mask file
						nDummy=ComboBox_SetCurSel(GETHCTL(IDC_SLINE_MASKS),
							0);
					}
					
					// Load the x-axis start value
					switch(sSLine[nLine].nLineType)
					{
						case SLINE_NONE:
						case SLINE_TDEV:
						case SLINE_MASK:
						{
							SetWindowText(GETHCTL(IDC_SLINE_XSTART),
								"");
						}
						break;

						case SLINE_END:
						case SLINE_VERT:
						case SLINE_HORIZ:
						{
							ShowWindow(GETHCTL(IDC_SLINE_XSTART),
								SW_SHOWNORMAL);
							EnableWindow(GETHCTL(IDC_SLINE_XSTARTLAB),
								TRUE);
							_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
								sSLine[nLine].fXStart);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_SLINE_XSTART),
								szBuffer);
						}
						break;

						case SLINE_NOISE:
						{
							ShowWindow(GETHCTL(IDC_SLINE_XFIRST),
								SW_SHOWNORMAL);
							EnableWindow(GETHCTL(IDC_SLINE_XSTARTLAB),
								TRUE);
							EnableWindow(GETHCTL(IDC_SLINE_SLOPELAB),
								TRUE);
							EnableWindow(GETHCTL(IDC_SLINE_SIGMALAB),
								TRUE);
							ShowWindow(GETHCTL(IDC_SLINE_SLOPE),
								SW_SHOWNORMAL);

							// Load tau values into list box
							nDummy=ComboBox_ResetContent
								(GETHCTL(IDC_SLINE_XFIRST));
							for(i=0; i<nPoints; i++)
							{
								if( (nSigmaPlotType==MODIFIED_RUN) ||
									(nSigmaPlotType==MODTOTAL_RUN) ||
									(nSigmaPlotType==TIME_RUN)     ||
									(nSigmaPlotType==TIMETOTAL_RUN) )
								{
									_snprintf(szBuffer, sizeof(szBuffer),
										"%10.5e", sModSigData.tau[i]);
									ShortenExp(szBuffer);

									// Set fTauStart to 1st tau point
									fTauStart=sModSigData.tau[0];
								}
								else
								{
									_snprintf(szBuffer, sizeof(szBuffer),
										"%10.5e", sNormSigData.tau[i]);
									ShortenExp(szBuffer);

									// Set fTauStart to 1st tau point
									fTauStart=sNormSigData.tau[0];
								}

								nDummy=ComboBox_InsertString(GETHCTL(
									IDC_SLINE_XFIRST), i, szBuffer);
							}

							if(!bNewNoiseLine)
							{
								// Set fTauStart to current x-start value
								fTauStart=(float)sSLine[nLine].fXStart;
							}
							else // New noise line
							{
								// Set current x-start value to 1st tau point
								sSLine[nLine].fXStart=fTauStart;
							}

							// Select the current x-first value
							_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
								fTauStart);
							ShortenExp(szBuffer);
							nDummy=ComboBox_SelectString(GETHCTL(
								IDC_SLINE_XFIRST), -1, szBuffer);

							// Select the slope value
							nDummy=ComboBox_SetCurSel(GETHCTL(IDC_SLINE_SLOPE),
								sSLine[nLine].nSlope);
						}
						break;
					}

					// Load the x-axis end value
					switch(sSLine[nLine].nLineType)
					{
						case SLINE_NONE:
						case SLINE_TDEV:
						case SLINE_VERT:
						case SLINE_MASK:
						{
							SetWindowText(GETHCTL(IDC_SLINE_XEND),
								"");
						}
						break;

						case SLINE_END:
						case SLINE_HORIZ:
						{
							ShowWindow(GETHCTL(IDC_SLINE_XEND),
								SW_SHOWNORMAL);
							EnableWindow(GETHCTL(IDC_SLINE_XENDLAB),
								TRUE);
							_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
								sSLine[nLine].fXEnd);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_SLINE_XEND),
								szBuffer);
						}
						break;

						case SLINE_NOISE:
						{
							ShowWindow(GETHCTL(IDC_SLINE_XLAST),
								SW_SHOWNORMAL);
							EnableWindow(GETHCTL(IDC_SLINE_XENDLAB),
								TRUE);

							// Load tau values into list box
							nDummy=ComboBox_ResetContent
								(GETHCTL(IDC_SLINE_XLAST));
							for(i=0; i<nPoints; i++)
							{
								if( (nSigmaPlotType==MODIFIED_RUN) ||
									(nSigmaPlotType==MODTOTAL_RUN) ||
									(nSigmaPlotType==TIME_RUN)     ||
									(nSigmaPlotType==TIMETOTAL_RUN) )
								{
									_snprintf(szBuffer, sizeof(szBuffer),
										"%10.5e",
										sModSigData.tau[i]);
									ShortenExp(szBuffer);

									// Set x-end to last tau point
									fTauEnd=sModSigData.tau[nPoints-1];
								}
								else
								{
									_snprintf(szBuffer, sizeof(szBuffer),
										"%10.5e",
										sNormSigData.tau[i]);
									ShortenExp(szBuffer);

									// Set x-end to last tau point
									fTauEnd=sNormSigData.tau[nPoints-1];
								}
								nDummy=ComboBox_InsertString(GETHCTL(
									IDC_SLINE_XLAST), i, szBuffer);
							}

							if(!bNewNoiseLine)
							{
								// Set fTauEnd to current x-end value
								fTauEnd=(float)sSLine[nLine].fXEnd;
							}
							else // New noise line
							{
								// Set current x-end value to last tau point
								sSLine[nLine].fXEnd=fTauEnd;
							}

							// Select the current x-last value
							_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
								fTauEnd);
							ShortenExp(szBuffer);
							nDummy=ComboBox_SelectString(GETHCTL(
								IDC_SLINE_XLAST), -1, szBuffer);

							// Calc sigma(1)
							SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
								IDC_SLINE_SIGMA1, NULL, 0));

							// Display sigma(1) parameter value
							_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
								fSigma1);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_SLINE_PARAM),
							szBuffer);

							bNewNoiseLine=FALSE;
						}
						break;
					}

					// Load the y-axis start value
					switch(sSLine[nLine].nLineType)
					{
						case SLINE_NONE:
						case SLINE_NOISE:
						case SLINE_TDEV:
						case SLINE_MASK:
						{
							SetWindowText(GETHCTL(IDC_SLINE_YSTART),
								"");
						}
						break;

						case SLINE_END:
						case SLINE_HORIZ:
						case SLINE_VERT:
						{
							ShowWindow(GETHCTL(IDC_SLINE_YSTART),
								SW_SHOWNORMAL);
							EnableWindow(GETHCTL(IDC_SLINE_YSTARTLAB),
								TRUE);
							_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
								sSLine[nLine].fYStart);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_SLINE_YSTART),
								szBuffer);
						}
						break;
					}

					// Load the y-axis end value
					switch(sSLine[nLine].nLineType)
					{
						case SLINE_NONE:
						case SLINE_NOISE:
						case SLINE_HORIZ:
						case SLINE_TDEV:
						case SLINE_MASK:
						{
							SetWindowText(GETHCTL(IDC_SLINE_YEND),
								"");
						}
						break;

						case SLINE_END:
						case SLINE_VERT:
						{
							ShowWindow(GETHCTL(IDC_SLINE_YEND),
								SW_SHOWNORMAL);
							EnableWindow(GETHCTL(IDC_SLINE_YENDLAB),
								TRUE);
							_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
								sSLine[nLine].fYEnd);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_SLINE_YEND),
								szBuffer);
						}
						break;
					}

					// Update line count
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_SLINE_COUNT, NULL, 0));

					// Enable value changed processing
					bUpdate=TRUE;

					// Activate print button if any lines
					if(nCount)
					{
						EnableWindow(GETHCTL(IDC_SLINE_PRINT), TRUE);
					}
					else
					{
						EnableWindow(GETHCTL(IDC_SLINE_PRINT), FALSE);
					}
				}
				break;

				// Count and display # active lines
				case IDC_SLINE_COUNT:
				{
					nCount=0;
					for(i=0; i<SLINE_NUMLINES; i++)
					{
						if(sSLine[i].nLineType!=SLINE_NONE)
						{
							nCount++;
						}
					}

					// Load the # active lines display
					_snprintf(szBuffer, sizeof(szBuffer), "# Lines = %d",
						nCount);
					SetWindowText(GETHCTL(IDC_SLINE_LINES),
						szBuffer);
				}
				break;

				// Line # changed
				case IDC_SLINE_NUM:
				{
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_SELCHANGE)
					{
						// Read new line #
						nLine=ComboBox_GetCurSel(GETHCTL(IDC_SLINE_NUM));

						// Update display for all parameter values
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
							IDC_SLINE_UPDATE, NULL, 0));
					}
				}
				break;

				// Line # up button pressed
				case IDC_SLINE_UP:
				{
					// Increment line # (with wrap-around)
					if(nLine<SLINE_NUMLINES-1)
					{
						nLine++;
					}
					else
					{
						nLine=0;
					}

					// Update display for all values
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_SLINE_UPDATE, NULL, 0));
				}
				break;

				// Line # down button pressed
				case IDC_SLINE_DOWN:
				{
					// Decrement line # (with wrap=around)
					if(nLine>0)
					{
						nLine--;
					}
					else
					{
						nLine=SLINE_NUMLINES-1;
					}

					// Update display for all values
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_SLINE_UPDATE, NULL, 0));
				}
				break;

				// Line type changed
				case IDC_SLINE_TYPE:
				{
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_SELCHANGE)
					{
						// Save previous line type
						nPrevLineType=sSLine[nLine].nLineType;

						// Read new line type
						sSLine[nLine].nLineType=
							ComboBox_GetCurSel(GETHCTL(IDC_SLINE_TYPE));

						// Bypass NULL type
						if(sSLine[nLine].nLineType==SLINE_NULL)
						{
							sSLine[nLine].nLineType=SLINE_NONE;
						}

						// Mask line type index must be incremented
						// for MTIE and TIErms that skip noise line type
						if((nSigmaPlotType==MTIE_RUN) ||
							(nSigmaPlotType==TIERMS_RUN))
						{
							if(sSLine[nLine].nLineType==SLINE_NOISE)
							{
								sSLine[nLine].nLineType=SLINE_MASK;
							}
						}
							
						// Reinit x_start & x_end if they were for noise line
						if(nPrevLineType==SLINE_NOISE)
						{
							sSLine[nLine].fXStart=sSPlot.x_min;
							_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
								sSPlot.x_min);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_SLINE_XSTART),
								szBuffer);
							sSLine[nLine].fXEnd=sSPlot.x_max;
							_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
								sSPlot.x_max);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_SLINE_XEND),
								szBuffer);
						}

						if(sSLine[nLine].nLineType==SLINE_NOISE)
						{
							bNewNoiseLine=TRUE;
						}

						// Update display for all parameter values
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
							IDC_SLINE_UPDATE, NULL, 0));
					}
				}
				break;

				// Mask file changed
				case IDC_SLINE_MASKS:
				{
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_SELCHANGE)
					{
						// Read new mask filename
						i=ComboBox_GetCurSel(GETHCTL(IDC_SLINE_MASKS));
						nDummy=ComboBox_GetLBText(GETHCTL(IDC_SLINE_MASKS),
								i, szBuffer);
						strlcpy(sSLine[nLine].szMaskFile, szBuffer,
							FILE_NAME_SIZE);

						// Set bUseSigmaPlotIni flag to avoid initialization
						// if SigmaNoteDlgProc() is opened?
						// To preserve mask label and allow it to be edited
						// Doesn't seem to be needed
						// bUseSigmaPlotIni=TRUE;
					}
				}
				break;

				// X-Start value changed
				case IDC_SLINE_XSTART:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_SLINE_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get current x values
						fTauStart=(float)sSLine[nLine].fXStart;
						fTauEnd=(float)sSLine[nLine].fXEnd;

						// Set fMinTau for validity check
						fMinTau=sSPlot.x_min;

						// Read new x-start value
						GetWindowText(GETHCTL(IDC_SLINE_XSTART),
							szBuffer, BUFFER_SIZE);
						fEntry=(float)atof(szBuffer);

						// Note: Consider opening up limits to full plot area
						// so start & end don't have to go from low to high
						// Or: Change labels from Start & End to Min & Max
						// But:  OK as is & same as Stable/DOS

						// Validate new x-start value
						if(ValidateFloat(hDlg, fEntry, fMinTau, fTauEnd)==
							TRUE)
						{
							// New value OK
							fTauStart=fEntry;

							// Store new x-start value
							sSLine[nLine].fXStart=fTauStart;
						}
						else
						{
							SetFocus(GETHCTL(IDC_SLINE_XSTART));
						}

						// Redisplay x-start value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							sSLine[nLine].fXStart);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_SLINE_XSTART),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// X-End value changed
				case IDC_SLINE_XEND:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_SLINE_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get current x values
						fTauStart=(float)sSLine[nLine].fXStart;
						fTauEnd=(float)sSLine[nLine].fXEnd;

						// Set fMaxTau for validity check
						fMaxTau=sSPlot.x_max;

						// Read new x-end value
						GetWindowText(GETHCTL(IDC_SLINE_XEND),
							szBuffer, BUFFER_SIZE);
						fEntry=(float)atof(szBuffer);

						// Validate new x-end value
						if(ValidateFloat(hDlg, fEntry, fTauStart, fMaxTau)==
							TRUE)
						{
							// New value OK
							fTauEnd=fEntry;

							// Store new x-end value
							sSLine[nLine].fXEnd=fTauEnd;
						}
						else
						{
							SetFocus(GETHCTL(IDC_SLINE_XEND));
						}

						// Redisplay x-end value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							sSLine[nLine].fXEnd);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_SLINE_XEND),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Y-Start value changed
				case IDC_SLINE_YSTART:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_SLINE_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get current y values
						fSigmaStart=(float)sSLine[nLine].fYStart;
						fSigmaEnd=(float)sSLine[nLine].fYEnd;

						// Set scale limits for validity check
						fMinSigma=sSPlot.y_min;
						fMaxSigma=sSPlot.y_max;

						// Read new y-start value
						GetWindowText(GETHCTL(IDC_SLINE_YSTART),
							szBuffer, BUFFER_SIZE);
						fEntry=(float)atof(szBuffer);

						// Validate new y-start value
						// Note: Limits are full plot area
						// so line slope can be upward or downward
						if(ValidateFloat(hDlg, fEntry, fMinSigma, fMaxSigma)==
							TRUE)
						{
							// New value OK
							fSigmaStart=fEntry;

							// Store new y-start value
							sSLine[nLine].fYStart=fSigmaStart;
						}
						else
						{
							SetFocus(GETHCTL(IDC_SLINE_YSTART));
						}

						// Redisplay y-start value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							sSLine[nLine].fYStart);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_SLINE_YSTART),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Y-End value changed
				case IDC_SLINE_YEND:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_SLINE_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get current y values
						fSigmaStart=(float)sSLine[nLine].fYStart;
						fSigmaEnd=(float)sSLine[nLine].fYEnd;

						// Set scale limits for validity check
						fMinSigma=sSPlot.y_min;
						fMaxSigma=sSPlot.y_max;

						// Read new y-end value
						GetWindowText(GETHCTL(IDC_SLINE_YEND),
							szBuffer, BUFFER_SIZE);
						fEntry=(float)atof(szBuffer);

						// Validate new y-end value
						// Note: Limits are full plot area
						// so line slope can be upward or downward
						if(ValidateFloat(hDlg, fEntry, fMinSigma, fMaxSigma)==
							TRUE)
						{
							// New value OK
							fSigmaEnd=fEntry;

							// Store new y-end value
							sSLine[nLine].fYEnd=fSigmaEnd;
						}
						else
						{
							SetFocus(GETHCTL(IDC_SLINE_YEND));
						}

						// Redisplay parameter value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							sSLine[nLine].fYEnd);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_SLINE_YEND),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// X-First value changed
				case IDC_SLINE_XFIRST:
				{
					// Respond to combo control selection change
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_SELCHANGE)
					{
						// Get current x values
						fTauStart=(float)sSLine[nLine].fXStart;
						fTauEnd=(float)sSLine[nLine].fXEnd;

						// Set fMinTau for validity check
						if( (nSigmaPlotType==MODIFIED_RUN) ||
							(nSigmaPlotType==MODTOTAL_RUN) ||
							(nSigmaPlotType==TIME_RUN)     ||
							(nSigmaPlotType==TIMETOTAL_RUN) )
						{
							fMinTau=sModSigData.tau[0];
						}
						else
						{
							fMinTau=sNormSigData.tau[0];
						}

						// Read new x-first value
						i=ComboBox_GetCurSel(GETHCTL(IDC_SLINE_XFIRST));
						nDummy=ComboBox_GetLBText(GETHCTL(IDC_SLINE_XFIRST),
								i, szBuffer);
						fEntry=(float)atof(szBuffer);

						// Validate new x-first value
						if(ValidateFloat(hDlg, fEntry, fMinTau, fTauEnd)==
							TRUE)
						{
							// New value OK
							fTauStart=fEntry;

							// Store new x-first value
							sSLine[nLine].fXStart=fTauStart;
						}
						else
						{
							SetFocus(GETHCTL(IDC_SLINE_XFIRST));
						}

						// Redisplay x-first value
						fTauStart=(float)sSLine[nLine].fXStart;
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							fTauStart);
						ShortenExp(szBuffer);
						nDummy=ComboBox_SelectString(GETHCTL(IDC_SLINE_XFIRST),
							-1, szBuffer);

						// Calc sigma(1)
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
							IDC_SLINE_SIGMA1, NULL, 0));

						// Display sigma(1) parameter value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							fSigma1);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_SLINE_PARAM),
							szBuffer);
					}
				}
				break;

				// X-Last value changed
				case IDC_SLINE_XLAST:
				{
					// Respond to combo control selection change
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_SELCHANGE)
					{
						// Get current x values
						fTauStart=(float)sSLine[nLine].fXStart;
						fTauEnd=(float)sSLine[nLine].fXEnd;

						// Set fMaxTau for validity check
						if( (nSigmaPlotType==MODIFIED_RUN) ||
							(nSigmaPlotType==MODTOTAL_RUN) ||
							(nSigmaPlotType==TIME_RUN)     ||
							(nSigmaPlotType==TIMETOTAL_RUN) )
						{
							fMaxTau=sModSigData.tau[nPoints-1];
						}
						else
						{
							fMaxTau=sNormSigData.tau[nPoints-1];
						}

						// Read new x-last value
						i=ComboBox_GetCurSel(GETHCTL(IDC_SLINE_XLAST));
						nDummy=ComboBox_GetLBText(GETHCTL(IDC_SLINE_XLAST),
								i, szBuffer);
						fEntry=(float)atof(szBuffer);

						// Validate new x-last value
						if(ValidateFloat(hDlg, fEntry, fTauStart, fMaxTau)==
							TRUE)
						{
							// New value OK
							fTauEnd=fEntry;

							// Store new x-last value
							sSLine[nLine].fXEnd=fTauEnd;
						}
						else
						{
							SetFocus(GETHCTL(IDC_SLINE_XLAST));
						}

						// Redisplay x-last value
						fTauEnd=(float)sSLine[nLine].fXEnd;
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							fTauEnd);
						ShortenExp(szBuffer);
						nDummy=ComboBox_SelectString(GETHCTL(IDC_SLINE_XLAST),
							-1, szBuffer);

						// Calc sigma(1)
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
							IDC_SLINE_SIGMA1, NULL, 0));

						// Display sigma(1) parameter value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							fSigma1);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_SLINE_PARAM),
							szBuffer);
					}
				}
				break;

				// Noise line slope changed
				case IDC_SLINE_SLOPE:
				{
					// Respond to combo control selection change
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_SELCHANGE)
					{
						// Read new slope type
						sSLine[nLine].nSlope=
							ComboBox_GetCurSel(GETHCTL(IDC_SLINE_SLOPE));

						// Calc sigma(1)
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
							IDC_SLINE_SIGMA1, NULL, 0));

						// Display sigma(1) parameter value
						_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							fSigma1);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_SLINE_PARAM),
							szBuffer);
					}
				}
				break;

				// Calculate Sigma(1) of noise fit
				case IDC_SLINE_SIGMA1:
				{
					// Initialize fSigma1
					fSigma1=0.0;

					// Initialize weighting sum
					fWeightSum=0.0;

					// Get start index
					nStart=ComboBox_GetCurSel(GETHCTL(IDC_SLINE_XFIRST));

					// Get end index
					nEnd=ComboBox_GetCurSel(GETHCTL(IDC_SLINE_XLAST));

					// Find fSlope
					// Note: Relationship between slope params as follows:
					//		nSlope	Noise	ADEV Slope	MDEV Slope	TDEV Slope
					//		0		W PM	-1.0		-1.5		-0.5
					//		1		F PM	-1.0		-1.0		+0.0
					//		2		W FM	-0.5		-0.5		+0.5
					//		3       F FM	+0.0		+0.0		+1.0
					//		4       RW FM	+0.5		+0.5		+1.5
					//		5       Aging	+1.0		+1.0		+2.0
					// For ADEV, fSlope=-1.5+(nSlope/2)+0.5 if nSlope=0
					// For MDEV, fSlope=-1.5+(nSlope/2)
					// For TDEV, fSlope=-0.5+(nSlope/2)
					if(nSigmaPlotType!=TIME_RUN &&
						nSigmaPlotType!=TIMETOTAL_RUN)
					// ADEV or MDEV
					{
						fSlope=(float)(-1.5+(sSLine[nLine].nSlope/2.0));
						if( (nSigmaPlotType!=MODIFIED_RUN) &&
							(nSigmaPlotType!=MODTOTAL_RUN) &&
							(sSLine[nLine].nSlope==0) )
						{
							fSlope+=0.5;
						}

						// Take care of Hadamard cases with FW & RR FM
						if( (sSLine[nLine].nSlope==6) ||
							(sSLine[nLine].nSlope==7) )
						{
							fSlope-=0.5;
						}
					}
					else // TDEV or TTOT
					{
						fSlope=(float)(-0.5+(sSLine[nLine].nSlope/2.0));
					}

					sSLine[nLine].fSlope=fSlope;

					// Calc linear fit to power law noise characteristic
					// Slope is fixed at that of selected noise type
					// Sigma(1) intercept is found as average or
					// weighted average of stability data points
					// Weighhting uses reciprocal of error bar range

					// Get bWeight setting from INI file (default=TRUE)
					bWeight=GetPrivateProfileInt("Preferences", "Weight", 1,
						szIniFile);

					// Calc fit
					for(i=nStart; i<=nEnd; i++)
					{
						if( (nSigmaPlotType==MODIFIED_RUN) ||
							(nSigmaPlotType==MODTOTAL_RUN) ||
							(nSigmaPlotType==TIME_RUN)     ||
							(nSigmaPlotType==TIMETOTAL_RUN) )
						{
							// Set weighting factor based on reciprocal
							// of % error bar range,
							// the error bar range divided by the nominal sigma
							// Used only if bWeight is TRUE and bAllTau is FALSE
							// The factor of 100 makes no difference in results
							fWeight=
								100*(sModSigData.sig_max[i]-
								sModSigData.sig_min[i])/
								sModSigData.sigma[i];
							fWeightSum+=(float)1.0/fWeight;

							// Find sigma(1) for particular noise slope
							if(fSlope==-1.5) // W PM
							{
								if(bWeight && !bAllTau)
								{
									fSigma1+=(float)((sModSigData.sigma[i]*
										sModSigData.tau[i]*
										sqrt(sModSigData.tau[i]))/fWeight);
								}
								else // No weighting
								{
									fSigma1+=(float)(sModSigData.sigma[i]*
										sModSigData.tau[i]*
										sqrt(sModSigData.tau[i]));
								}
							}
							else if(fSlope==-1.0) // F PM
							{
								if(bWeight && !bAllTau)
								{
									fSigma1+=(float)((sModSigData.sigma[i]*
										sModSigData.tau[i])/fWeight);
								}
								else // No weighting
								{
									fSigma1+=(float)(sModSigData.sigma[i]*
										sModSigData.tau[i]);
								}
							}
							else if(fSlope==-0.5) // W FM
							{
								if(bWeight && !bAllTau)
								{
									fSigma1+=(float)((sModSigData.sigma[i]*
										sqrt(sModSigData.tau[i]))/fWeight);
								}
								else // No weighting
								{
									fSigma1+=(float)(sModSigData.sigma[i]*
										sqrt(sModSigData.tau[i]));
								}
							}
							else if(fSlope==0.0) // F FM
							{
								if(bWeight && !bAllTau)
								{
									fSigma1+=(float)
										((sModSigData.sigma[i])/fWeight);
								}
								else // No weighting
								{
									fSigma1+=(float)(sModSigData.sigma[i]);
								}
							}
							else if(fSlope==0.5) // RW FM
							{
								if(bWeight && !bAllTau)
								{
									fSigma1+=(float)((sModSigData.sigma[i]/
										sqrt(sModSigData.tau[i]))/fWeight);
								}
								else // No weighting
								{
									fSigma1+=(float)(sModSigData.sigma[i]/
										sqrt(sModSigData.tau[i]));
								}
							}
							else if(fSlope==1.0) // Aging
							{
								if(bWeight && !bAllTau)
								{
									fSigma1+=(float)((sModSigData.sigma[i]/
										sModSigData.tau[i])/fWeight);
								}
								else // No weighting
								{
									fSigma1+=(float)(sModSigData.sigma[i]/
										sModSigData.tau[i]);
								}
							}
							else if(fSlope==1.5) // Not a normal noise slope
							{
								if(bWeight && !bAllTau)
								{
									fSigma1+=(float)((sModSigData.sigma[i]/
										(sModSigData.tau[i]*
										sqrt(sModSigData.tau[i])))/fWeight);
								}
								else // No weighting
								{
									fSigma1+=(float)(sModSigData.sigma[i]/
										(sModSigData.tau[i]*
										sqrt(sModSigData.tau[i])));
								}
							}
							else if(fSlope==2.0) // Not a normal noise slope
							{
								if(bWeight && !bAllTau)
								{
									fSigma1+=(float)((sModSigData.sigma[i]/
										(sModSigData.tau[i]*
										(sModSigData.tau[i])))/fWeight);
								}
								else // No weighting
								{
									fSigma1+=(float)(sModSigData.sigma[i]/
										(sModSigData.tau[i]*
										(sModSigData.tau[i])));
								}
							}
						}
						else // ADEV
						{
							// Set weighting factor based on reciprocal of
							// % error bar range,
							// the error bar range divided by the nominal sigma
							// Used only if bWeight is TRUE
							// and bAllTau is false
							fWeight=
								100*(sNormSigData.sig_max[i]-
								sNormSigData.sig_min[i])/
								sNormSigData.sigma[i];

							// Code to handle special case of ThoH
							// where mod sigma array
							// is also used for some Tho1 points
							if(fWeight==0.0)
							{
								fWeight=
									100*(sModSigData.sig_max[i]-
									sModSigData.sig_min[i])/
									sModSigData.sigma[i];
							}

							#if(1) // New code 04/09/10
							// Handle special case of cross ADEV
							// where there are no error bars
							if(nSigmaPlotType==CROSS_RUN)
							{
								fWeight=1.0;
							}
							#endif

							// Add weight value to sum
							fWeightSum+=(float)1.0/fWeight;

							// Find sigma(1) for particular noise slope
							if(fSlope==-1.5) // Not normal pwr law noise slope
							{
								if(bWeight && !bAllTau)
								{
									fSigma1+=(float)(sNormSigData.sigma[i]*
										sNormSigData.tau[i]*
										sqrt(sNormSigData.tau[i])/fWeight);
								}
								else // No weighting
								{
									fSigma1+=(float)(sNormSigData.sigma[i]*
										sNormSigData.tau[i]*
										sqrt(sNormSigData.tau[i]));
								}
							}
							else if(fSlope==-1.0) // W or F PM
							{
								if(bWeight && !bAllTau)
								{
									fSigma1+=(float)((sNormSigData.sigma[i]*
										sNormSigData.tau[i])/fWeight);
								}
								else // No weighting
								{
									fSigma1+=(float)(sNormSigData.sigma[i]*
										sNormSigData.tau[i]);
								}
							}
							else if(fSlope==-0.5) // W FM
							{
								if(bWeight && !bAllTau)
								{
									fSigma1+=(float)((sNormSigData.sigma[i]*
										sqrt(sNormSigData.tau[i]))/fWeight);
								}
								else // No weighting
								{
									fSigma1+=(float)(sNormSigData.sigma[i]*
										sqrt(sNormSigData.tau[i]));
								}
							}
							else if(fSlope==0.0) // F FM
							{
								if(bWeight && !bAllTau)
								{
									fSigma1+=(float)
										((sNormSigData.sigma[i])/fWeight);
								}
								else // No weighting
								{
									fSigma1+=(float)(sNormSigData.sigma[i]);
								}
							}
							else if(fSlope==0.5) // RW FM
							{
								if(bWeight && !bAllTau)
								{
									fSigma1+=(float)((sNormSigData.sigma[i]/
										sqrt(sNormSigData.tau[i]))/fWeight);
								}
								else // No weighting
								{
									fSigma1+=(float)(sNormSigData.sigma[i]/
										sqrt(sNormSigData.tau[i]));
								}
							}
							else if(fSlope==1.0) // Aging
							{
								if(bWeight && !bAllTau)
								{
									fSigma1+=(float)((sNormSigData.sigma[i]/
										sNormSigData.tau[i])/fWeight);
								}
								else // No weighting
								{
									fSigma1+=(float)(sNormSigData.sigma[i]/
										sNormSigData.tau[i]);
								}
							}
							else if(fSlope==1.5) // Not a normal noise slope
							{
								if(bWeight && !bAllTau)
								{
									fSigma1+=(float)((sNormSigData.sigma[i]/
										(sNormSigData.tau[i]*
										sqrt(sNormSigData.tau[i])))/fWeight);
								}
								else // No weighting
								{
									fSigma1+=(float)(sNormSigData.sigma[i]/
										(sNormSigData.tau[i]*
										sqrt(sNormSigData.tau[i])));
								}
							}
							else if(fSlope==2.0) // Not a normal noise slope
							{
								if(bWeight && !bAllTau)
								{
									fSigma1+=(float)((sNormSigData.sigma[i]/
										(sNormSigData.tau[i]*
										(sNormSigData.tau[i])))/fWeight);
								}
								else // No weighting
								{
									fSigma1+=(float)(sNormSigData.sigma[i]/
										(sNormSigData.tau[i]*
										(sNormSigData.tau[i])));
								}
							}
						}
					}

					// Correct sigma(1) for weightings or average
					if(bWeight && !bAllTau)
					{
						fSigma1/=fWeightSum;
					}
					else // No weighting
					{
						fSigma1/=(nEnd-nStart+1);
					}
					
					sSLine[nLine].fSigma1=fSigma1;
					sSLine[nLine].nXStart=nStart;
					sSLine[nLine].nXEnd=nEnd;
				}
				break;

				// Read button pressed
				case IDC_SLINE_READ:
				{
					// Read sigma line info from ini file
					ReadIni(INI_SLINE);

					// Clear new noise line flag so tau start & end values
					// from ini file are used
					bNewNoiseLine=FALSE;

					// Update display for all parameter values
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_SLINE_UPDATE, NULL, 0));
				}
				break;

				// Write button pressed
				case IDC_SLINE_WRITE:
				{
					WriteIni(INI_SLINE);
				}
				break;

				// Reset button pressed - restore defaults
				case IDC_SLINE_RESET:
				{
					// Initialize line params
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_SLINE_INITIALIZE, NULL, 0));

					// Go to 1st line
					nLine=0;

					// Update display for all parameter values
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_SLINE_UPDATE, NULL, 0));
				}
				break;

				// Respond to CR in an edit control
				// Note: No button is a DEFPUSHBUTTON
				case IDOK:
				{
					// Send EN_KILLFOCUS message to XSTART edit control
					if(GetFocus()==GETHCTL(IDC_SLINE_XSTART))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
							IDC_SLINE_XSTART, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to XEND edit control
					if(GetFocus()==GETHCTL(IDC_SLINE_XEND))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
							IDC_SLINE_XEND, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to YSTART edit control
					if(GetFocus()==GETHCTL(IDC_SLINE_YSTART))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
							IDC_SLINE_YSTART, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to YEND edit control
					if(GetFocus()==GETHCTL(IDC_SLINE_YEND))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
							IDC_SLINE_YEND, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to XFIRST edit control
					if(GetFocus()==GETHCTL(IDC_SLINE_XFIRST))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
							IDC_SLINE_XFIRST, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to XLAST edit control
					if(GetFocus()==GETHCTL(IDC_SLINE_XLAST))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
							IDC_SLINE_XLAST, NULL, EN_KILLFOCUS));
					}
				}
				break;

				// Print line info on printer using Win32 API
				// Note: Bare-bones printing code:
				// no error trapping, no font
				// selection, no abort proc, 1 page only
				// Printer must use fixed-space font
				// User can choose printer in PrintDlg

				// Struct linedata items for plot line data:
				// int nLineType	Line type
				// int nSlope		Power law slope for noise line
				// int nXStart		
				// int nXEnd		
				// float fSlope		Linear slope for regression fit
				// float fSigma1	Sigma(1) value for power law noise fit
				// float fAverage	Average line value
			    // F_TYPE fXStart	 
				// F_TYPE fXEnd
				// F_TYPE fYStart
				// F_TYPE fYEnd

				// Sigma Plot Line # & Types
				// SLINE_NUMLINES	# possible lines
				// SLINE_NONE       No line
				// SLINE_HORIZ      Horizontal line
				// SLINE_VERT       Vertical line
				// SLINE_NOISE      Power-law noise fit w/ Sigma(1) param
				// SLINE_TDEV       TDEV loci

				case IDC_SLINE_PRINT:
				{
					// Initialize PRINTDLG structure
					memset(&pd, 0, sizeof(PRINTDLG));
					pd.lStructSize=sizeof(PRINTDLG);
					pd.Flags=PD_RETURNDEFAULT; // Don't show dialog box

					// 1st (hidden) call to PrintDlg()
					// To set up hDevNames & hDevMode
 					if(!PrintDlg(&pd))
					{
						// PrintDlg() called failed
						MessageBox(hwndMain, "Printer Not Found", "Line Print",
						MB_ICONEXCLAMATION);
						break;
					}

					// Reinitialize PRINTDLG structure
					// Get DC & no choice of page #s & no text selection
					pd.Flags=PD_RETURNDC | PD_NOPAGENUMS | PD_NOSELECTION;

					// 2nd (visible) call to PrintDlg()
					if(PrintDlg(&pd))
					{
						// Get printer device context
						hdcPrn=pd.hDC;
					}
					else
					{
						if(CommDlgExtendedError())
						{
							// Printer error
							MessageBox(hwndMain, "Printer Error", "Line Print",
							MB_ICONEXCLAMATION);
						}
						else // Error code 0
						{
							// User hit cancel button
							break;
						}
					}
					
					// Determine logfont.lfHeight from point size = nPointSize
					// where nPointSize is global variable that user can enter
					// in General page of Configure property sheet
					// Win32 documentation gives the formula:
					// lfHeight = -MulDiv(PointSize, GetDeviceCaps(hDC,
					//  LOGPIXELSY), 72);
					// which becomes the following for our variables:
					// nFontHeight = -MulDiv(nPointSize, GetDeviceCaps(hdcPrn,
					//  LOGPIXELSY), 72);
					// Both nPointSize and nFontHeight are global variables
					// A couple of typical values are nPointSize=9,
					//  nFontHeight=-75
					// and nPointSize=10, nFontHeight=-83
					// The abs value of nFontHeight is used
					nFontHeight = -MulDiv(nPointSize, GetDeviceCaps(hdcPrn,
						LOGPIXELSY), 72);
					
					// Set font attributes
					// Assumes 8.5"x11" portrait page
					// Text size set to fit nicely across std page
					// Fixed pitch for easy alignment
					logfont.lfHeight=nFontHeight;
					logfont.lfWidth=0;
					logfont.lfEscapement=0;
					logfont.lfOrientation=0;
					logfont.lfWeight=0;
					logfont.lfItalic=0;
					logfont.lfUnderline=0;
					logfont.lfStrikeOut=0;
					logfont.lfCharSet=OEM_CHARSET;
					logfont.lfOutPrecision=OUT_DEFAULT_PRECIS;
					logfont.lfClipPrecision=CLIP_DEFAULT_PRECIS;
					logfont.lfQuality=PROOF_QUALITY;
					logfont.lfPitchAndFamily=FIXED_PITCH | FF_DONTCARE;
					strlcpy(logfont.lfFaceName,"", LF_FACESIZE);

					// Create printer font
					hPrnFont=CreateFontIndirect(&logfont);

					// Select font into printer device
					SelectObject(hdcPrn, hPrnFont);

					// Get text metrics
					GetTextMetrics(hdcPrn, &tm);
					yChar=tm.tmHeight + tm.tmExternalLeading;
					xChar=tm.tmAveCharWidth;

					// Get page dimensions
					xPage=(short)GetDeviceCaps(hdcPrn, HORZRES);
					yPage=(short)GetDeviceCaps(hdcPrn, VERTRES);

					// Compose Print Manager message
					LoadString(hInst, IDS_MESSAGE_REPORT, szPrnMsg,
							BUFFER_SIZE);

					// Set up DOCINFO structure
					memset(&di, 0, sizeof(DOCINFO));
					di.cbSize=sizeof(DOCINFO);
					di.lpszDocName=szPrnMsg;
					
					// Start printing
					if(hdcPrn != NULL)
					{
						if(StartDoc(hdcPrn, &di) != SP_ERROR)
						{
							// Actual printing code starts here
							StartPage(hdcPrn);

							nPrintLine=0; // Page heading
							SetTextAlign(hdcPrn, TA_LEFT || TA_TOP);
							LoadString(hInst, IDS_FORMAT_SLINE_PH, szFormat,
								BUFFER_SIZE);

							if(nPlotType==READ_PLOT)
							{
								_snprintf(szBuffer, sizeof(szBuffer), szFormat,
									szStabFileTitle);
							}
							else
							{
								_snprintf(szBuffer, sizeof(szBuffer), szFormat,
									szFileTitle);
							}

							TextOut(hdcPrn, xChar/2, (int)((nPrintLine+0.5)*
								yChar),	szBuffer, strlen(szBuffer));
							
							nPrintLine=2; // Column headings
							SetTextAlign(hdcPrn, TA_LEFT || TA_TOP);
							LoadString(hInst, IDS_FORMAT_SLINE_CH, szFormat,
								BUFFER_SIZE);
							_snprintf(szBuffer, sizeof(szBuffer), szFormat);
							TextOut(hdcPrn, xChar/2, (int)((nPrintLine+0.5)*
								yChar),	szBuffer, strlen(szBuffer));

							nPrintLine++;

							for(i=0; i<SLINE_NUMLINES; i++)
							{
								nPrintLine++;
								switch(sSLine[i].nLineType)
								{
									case SLINE_NONE:
									{
										LoadString(hInst, IDS_FORMAT_SLINE_0,
											szFormat, BUFFER_SIZE);
										_snprintf(szBuffer, sizeof(szBuffer),
											szFormat,	i+1);
									}
									break;

									case SLINE_END:
									{
										LoadString(hInst, IDS_FORMAT_SLINE_1,
											szFormat, BUFFER_SIZE);
										_snprintf(szBuffer, sizeof(szBuffer),
											szFormat, i+1,
											sSLine[i].fXStart,
											sSLine[i].fXEnd,
											sSLine[i].fYStart,
											sSLine[i].fYEnd);
									}
									break;

									case SLINE_HORIZ:
									{
										LoadString(hInst, IDS_FORMAT_SLINE_2,
											szFormat, BUFFER_SIZE);
										_snprintf(szBuffer, sizeof(szBuffer),
											szFormat,	i+1,
											sSLine[i].fXStart,
											sSLine[i].fXEnd,
											sSLine[i].fYStart);
									}
									break;
						
									case SLINE_VERT:
									{
										LoadString(hInst, IDS_FORMAT_SLINE_3,
											szFormat, BUFFER_SIZE);
										_snprintf(szBuffer, sizeof(szBuffer),
											szFormat, i+1,
											sSLine[i].fXStart,
											sSLine[i].fYStart,
											sSLine[i].fYEnd);
									}
									break;

									case SLINE_NOISE:
									{
										LoadString(hInst, IDS_FORMAT_SLINE_4,
											szFormat, BUFFER_SIZE);
										_snprintf(szBuffer, sizeof(szBuffer),
											szFormat, i+1,
											sSLine[i].fXStart,
											sSLine[i].fXEnd,
											sSLine[i].fSigma1);
									}
									break;

									case SLINE_TDEV:
									{
										LoadString(hInst, IDS_FORMAT_SLINE_5,
											szFormat, BUFFER_SIZE);
										_snprintf(szBuffer, sizeof(szBuffer),
											szFormat, i+1);
									}
									break;

									case SLINE_MASK:
									{
										LoadString(hInst, IDS_FORMAT_SLINE_6,
											szFormat, BUFFER_SIZE);
										_snprintf(szBuffer, sizeof(szBuffer),
											szFormat, i+1,
											sSLine[i].szMaskFile);
									}
									break;
								}

								ShortenExp(szBuffer);
								TextOut(hdcPrn, (int)(xChar/2),
									(int)((nPrintLine+0.4)*yChar), szBuffer,
									strlen(szBuffer));
							}

							// End (single) page
							EndPage(hdcPrn);

							// End printing
							EndDoc(hdcPrn);
						}
						else // Error or print to file cancelled
						{
							;
						}

						// Release device context
						DeleteDC(hdcPrn) ;
					}
					else // hdcPrn==NULL
					{
						;
					}

					// Delete printer logical font
					DeleteObject(hPrnFont);
				}
				break;

				// OK button pressed - accept inputs
				case IDC_SLINE_ACCEPT:
				{
					// Close dialog box
					EndDialog (hDlg, 0);

					// Loop through line choices looking for masks
					for(i=0; i<SLINE_NUMLINES; i++)
					{
						if((sSLine[i].nLineType)==SLINE_MASK)
						{
							// Read mask points from disk
							// Get filename
							// Note 10/08/08: As is, mask file must be in whatever folder
							// the system last used, which may not be the
							// Stable32.exe folder if a data file has been stored elsewhere
							// Should use a fully-qualified filename
							// Stable32.exe launch folder is in szPath
							#if(0) // Original code
							strlcpy(szMaskFilename, sSLine[i].szMaskFile,
								FILE_NAME_SIZE);
							#endif

							#if(1) // New code 10/08/08
							strlcpy(szMaskFilename, szPath, FILE_NAME_SIZE);
							strlcat(szMaskFilename, sSLine[i].szMaskFile,
								FILE_NAME_SIZE);
							#endif

							// For testing
							// TRACE_STR(szMaskFilename);

							// Open file
							if((fFile=fopen(szMaskFilename, "r"))==NULL)
							{
								// Error
								_snprintf(szBuffer, sizeof(szBuffer),
									"Couldn't open mask file %s",
									szMaskFilename);
								MessageBox(hDlg, szBuffer, "Mask File Error",
									MB_ICONEXCLAMATION);

								// Scrub mask line
								sSLine[i].nLineType=SLINE_NONE;
								break;
							}

							// Read mask data
							// Initialize line counter
							j=0;

							// Read file line-by-line
							while((fgets(szBuffer,
								BUFFER_SIZE, fFile) != NULL))
							{
								// Ignore optional 1st comment line
								// that starts with #
								if(szBuffer[0]=='#')
								{
									continue; // Note that j is not incremented
								}

								// Parse lines
								// First line (after optional comment line)
								// contains special information
								if(j==0)
								{
									// Parse 1st line
									// (# points, position & label)
									// Format is n x y l,
									// where int n=# mask points,
									// double x=label x position,
									// double y = label
									// y position, and char *label =
									// mask label string
									// Use n=nMaskPoints to reallocate memory
									// for the particular set of n mask points

									// Parse the header line
									// The usual %s string specification
									// is replaced by %*[\"]
									// to ignore a leading "
									// character, and %[^\"]
									// to treat a trailing "
									// as a delimiter,
									// so as to specify a string
									// delinited by double quotes ("")
									sscanf(szBuffer,
										"%d %le %le %*[\"] %[^\"]",
										&nMaskRows[i], &sSNote[i].fX,
										&sSNote[i].fY, szText);
									
									// Reallocate the mask array
									// We are reallocating the size of
									// only the ith pair of mask arrays
									fMaskSigma[i]=
										(float*)realloc(fMaskSigma[i],
										(nMaskRows[i])*sizeof(float));
									fMaskTau[i]=(float*)realloc(fMaskTau[i],
										(nMaskRows[i])*sizeof(float));

									// Find the length of the label
									nSize=strlen(szText);

									// Realloc note text array
									if((sSNote[i].szText=
										(LPSTR)realloc(sSNote[i].szText,
										(nSize+2)*sizeof(char)))==NULL)
									{
										// Just dsp msg & avoid changing array
										AllocErrorMessage();
									}
									else // OK
									{
										// Save new text
										strlcpy(sSNote[i].szText, szText,
											(nSize+2)*sizeof(char));
									}
								}
								else // Data lines
								{
									// Parse data line (tau & sigma)
									// j starts at 1 when reading data lines
									// So we offset the array index
									sscanf(szBuffer,
										"%e %e", &fMaskTau[i][j-1],
										&fMaskSigma[i][j-1]);
								}


								// Increment line count
								j++;

								// Done?
								if(j>nMaskRows[i])
								{
									break;
								}
							}

							// Set note parameters
							sSNote[i].nSize=8;
							sSNote[i].bBorder=0;
							sSNote[i].bOpaque=1;
						}
					}
				}
				return TRUE;

				// Cancel button pressed - restore previous inputs before end
				// Respond to esc key or cancel button
				case IDCANCEL:
				case IDC_SLINE_CANCEL:
				{
					// Save the original line data
					for(i=0; i<SLINE_NUMLINES; i++)
					{
						sSLine[i].nLineType=sPSave[i].nLineType;
						sSLine[i].nSlope=sPSave[i].nSlope;
						sSLine[i].fXStart=sPSave[i].fXStart;
						sSLine[i].fXEnd=sPSave[i].fXEnd;
						sSLine[i].fYStart=sPSave[i].fYStart;
						sSLine[i].fYEnd=sPSave[i].fYEnd;
					}

					// Close dialog box
					EndDialog (hDlg, 0);
				}
				return TRUE;
			}
		}
		break;
	 }
	 return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*                   Freq Plot Annotation Dialog Procedure                   */
/*                                                                           */
/*      Dialog box procedure to enter annotations to be added to             */
/*      the frequency data plot.                                             */
/*                                                                           */
/* 		The annotations are defined by a notetype struct with these items:   */
/* 			char*	szNote		annotation text                              */
/*          F_TYPE  fX     		x-axis position                              */
/*          F_TYPE	fY       	y-axis position                              */
/*          int		nSize     	type point size                              */
/*          BOOL	bBorder     border flag                                  */
/*                                                                           */
/*      There is a global array of FNOTE_NUMNOTES of these notetype structs  */
/*      called sFNote[] with index nNote.  The elements are accessed as:     */
/*          sFNote[nNote].szNote, etc.                                       */
/*                                                                           */
/*     	The following WM_COMMAND message wParams are used:                   */
/*      	Dialog box controls:                                             */
/*				IDC_DNOTE_CLR	 	 Button		Clear all notes              */
/*				IDC_DNOTE_NUM		 Edit       Current note #               */
/*				IDC_DNOTE_SIZE		 Edit       Point size of note text      */
/*				IDC_DNOTE_X			 Edit       X-axis position              */
/*				IDC_DNOTE_Y			 Edit       Y-axis position              */
/*				IDC_DNOTE_UP		 Button     Increment note #             */
/*				IDC_DNOTE_DOWN		 Button     Decrement note #             */
/*				IDC_DNOTE_EDIT		 Edit       Note text                    */
/*				IDC_DNOTE_BORDER	 Check      Border flag                  */
/*				IDC_DNOTE_OPAQUE	 Check      Opaque flag                  */
/*				IDC_DNOTE_NOTES		 Text       # active notes               */
/*			Internal processing routines:                                    */
/*				IDC_DNOTE_UPDATE                Update screen displays       */
/*              IDC_DNOTE_CLEAR		            Clear screen displays        */
/*              IDC_DNOTE_COUNT                 Count # active notes         */
/*                                                                           */
/*      Programming notes:                                                   */
/*			1.	Multiline text edit box uses ES_WANTRETURN.                  */
/*              Don't want CR to activate selected command button.           */
/*          2.	Don't update screen after every edit box change message.     */
/*              Not only is that unnecessary, but it also puts cursor at     */
/*              beginning, which messes up the editing process.              */
/*          3.  The text memory has an extra character (in addition to the   */
/*              normal EOS).  The edit control seems to want this.           */
/*          4.  The sFNote[i].szText memory is allocated & freed in Winmain. */
/*                                                                           */
/*                                                                           */
/* 		Revision record:                                                     */
/*			07/09/96	Drafted                                              */
/*			07/10/96	Debugged                                             */
/*			07/11/96	More debugging                                       */
/*			07/12/96	Completed                                            */
/*			07/14/97	Fixed memory leak from sFSave[]                      */
/*			12/20/97	Added note parameter read & save buttons             */
/*			01/02/98	Added up and down note # buttons                     */
/*						Changed note # control to a drop down list combobox  */
/*			08/02/03	Added opaque note feature                            */
/*                                                                           */
/*****************************************************************************/

#ifndef _MSC_VER
	#pragma argsused
#endif

BOOL CALLBACK FreqNoteDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	// Structs
	static struct notedata sFSave[FNOTE_NUMNOTES];
									// To preserve original plot note data
	// Chars
	char szBuffer[BUFFER_SIZE+1];		// General text buffer
	// Ints
	int i;							// General index
	int nCount;						// # active lines
	int nSize;						// Text array size (not inc EOS)
	static int nNote=0;				// nNote (goes from 0 to FNOTE_NUMNOTES-1)
									// Line # displayed is nNote+1
	// BOOLs
	static BOOL bStart=TRUE;  	 	// Start flag for initializations
	static BOOL bUpdate=TRUE;    	// Update flag to avoid infinite looping

	// Start of code
	switch(message)
	{
		case WM_INITDIALOG:
		{
			// These initializations are done only at start

			// Clear start flag if freq note data was read from INI file
			if(bUseFreqPlotIni)
			{
				bStart=FALSE;
			}

			if(bStart)
			{
				// Initialize the line #
				nNote=0;

				// Initialize the sFNote elements
				for(i=0; i<FNOTE_NUMNOTES; i++)
				{
					strlcpy(sFNote[i].szText, "", 2);
					sFNote[i].fX=0.0;
					sFNote[i].fY=0.0;
					sFNote[i].nSize=8;
					sFNote[i].bBorder=TRUE;
					sFNote[i].bOpaque=TRUE;
				}

				// Reset start flag
				bStart=FALSE;
			}

			// The rest is done every time the dialog box is opened/reopened
			// Set dialog box title

			LoadString(hInst, IDS_TITLE_FREQNOTE, szBuffer, BUFFER_SIZE);
			SetWindowText(hDlg, szBuffer);

			// Save the original note data
			for(i=0; i<FNOTE_NUMNOTES; i++)
			{
				// Find the length of the original text array
				// Note: nSize does not include the EOS
				nSize=strlen(sFNote[i].szText);

				// Allocate the save text array to the original size
				if((sFSave[i].szText=
					(LPSTR)malloc((nSize+2)*sizeof(char)))==NULL)
				{
					// Can't continue - dsp msg & bail out
					AllocErrorMessage();
					PostMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDCANCEL,
						NULL, 0));
					return TRUE;
				}

				// Save the original note data
				strlcpy(sFSave[i].szText, sFNote[i].szText,
					(nSize+2)*sizeof(char));
				sFSave[i].fX=sFNote[i].fX;
				sFSave[i].fY=sFNote[i].fY;
				sFSave[i].nSize=sFNote[i].nSize;
				sFSave[i].bBorder=sFNote[i].bBorder;
				sFSave[i].bOpaque=sFNote[i].bOpaque;
			}

			// Load integers into note # box
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_DNOTE_NUM));
			for(i=0; i<FNOTE_NUMNOTES; i++)
			{
				_snprintf(szBuffer, sizeof(szBuffer), "%d", i+1);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_DNOTE_NUM),
					i, szBuffer);
			}
 
			// Update display for all parameter values
			SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
				IDC_DNOTE_UPDATE, NULL, 0));

			return TRUE;
		}

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				// Help button presses
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::PLOT_NOTES_FUNCTION.HTM",
						HH_DISPLAY_TOPIC,
                        0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::PLOT_NOTES_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "PLOT_NOTES_FUNCTION");
					#endif
				}
				break;

				// Clear display
				// Note: Used to clear display for case of invalid note #
				// Therefore the line # display is not changed
				// And the array memory allocation is unchanged
				case IDC_DNOTE_CLEAR:
				{
					// Inhibit value changed processing
					bUpdate=FALSE;

					// Clear the size value
					SetWindowText(GETHCTL(IDC_DNOTE_SIZE), "");

					// Clear the text string
					SetWindowText(GETHCTL(IDC_DNOTE_EDIT), "");

					// Clear the x position value
					SetWindowText(GETHCTL(IDC_DNOTE_X), "");

					// Clear the y position value
					SetWindowText(GETHCTL(IDC_DNOTE_Y), "");

					// Set the border flag
					Button_SetCheck(GETHCTL(IDC_DNOTE_BORDER), TRUE);

					// Set the opaque flag
					Button_SetCheck(GETHCTL(IDC_DNOTE_OPAQUE), TRUE);

					// Update note count
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DNOTE_COUNT, NULL, 0));

					// Enable value changed processing
					bUpdate=TRUE;
				}
				break;

				// Update display
				case IDC_DNOTE_UPDATE:
				{
					// Inhibit value changed processing
					bUpdate=FALSE;
					// Select line #
					nDummy=ComboBox_SetCurSel(GETHCTL(IDC_DNOTE_NUM), nNote);

					// Load size value
					_snprintf(szBuffer, sizeof(szBuffer), "%d",
						sFNote[nNote].nSize);
					SetWindowText(GETHCTL(IDC_DNOTE_SIZE),
						szBuffer);

					// Load the note text string
					SetWindowText(GETHCTL(IDC_DNOTE_EDIT),
						sFNote[nNote].szText);

					// Load the x position value
					_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
						sFNote[nNote].fX);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_DNOTE_X),
						szBuffer);

					// Load the y position value
					_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
						sFNote[nNote].fY);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_DNOTE_Y),
						szBuffer);

					// Load the border flag
					Button_SetCheck(GETHCTL(IDC_DNOTE_BORDER),
						sFNote[nNote].bBorder);

					// Load the opaque flag
					Button_SetCheck(GETHCTL(IDC_DNOTE_OPAQUE),
						sFNote[nNote].bOpaque);

					// Update note count
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DNOTE_COUNT, NULL, 0));

					// Enable value changed processing
					bUpdate=TRUE;
				}
				break;

				// Count and display # active notes
				case IDC_DNOTE_COUNT:
				{
					nCount=0;
					for(i=0; i<FNOTE_NUMNOTES; i++)
					{
						if(strlen(sFNote[i].szText))
						{
							nCount++;
						}
					}

					// Load the # active notes display
					_snprintf(szBuffer, sizeof(szBuffer), "# Notes = %d",
						nCount);
					SetWindowText(GETHCTL(IDC_DNOTE_NOTES),
						szBuffer);
				}
				break;

				// Note # changed
				case IDC_DNOTE_NUM:
				{
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_SELCHANGE)
					{
						// Read new line #
						nNote=ComboBox_GetCurSel(GETHCTL(IDC_DNOTE_NUM));

						// Update display for all parameter values
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
							IDC_DNOTE_UPDATE, NULL, 0));
					}
				}
				break;

				case IDC_DNOTE_UP:
				{
					// Increment note # (with wrap-around)
					if(nNote<FNOTE_NUMNOTES-1)
					{
						nNote++;
					}
					else
					{
						nNote=0;
					}

					// Update display for all values
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DNOTE_UPDATE, NULL, 0));
				}
				break;

				// Note # down button pressed
				case IDC_DNOTE_DOWN:
				{
					// Decrement note # (with wrap=around)
					if(nNote>0)
					{
						nNote--;
					}
					else
					{
						nNote=FNOTE_NUMNOTES-1;
					}

					// Update display for all values
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DNOTE_UPDATE, NULL, 0));
				}
				break;

				// Font point size changed
				case IDC_DNOTE_SIZE:
				{
					if(bUpdate)
					{
						// Read new size
						GetWindowText(GETHCTL(IDC_DNOTE_SIZE),
							szBuffer, BUFFER_SIZE);
						sFNote[nNote].nSize=abs(atoi(szBuffer));
					}
				}
				break;

				// X position changed
				case IDC_DNOTE_X:
				{
					if(bUpdate)
					{
						// Read new x position value
						GetWindowText(GETHCTL(IDC_DNOTE_X),
							szBuffer, BUFFER_SIZE);
						sFNote[nNote].fX=atof(szBuffer);
					}
				}
				break;

				// Y position changed
				case IDC_DNOTE_Y:
				{
					if(bUpdate)
					{
						// Read new y position value
						GetWindowText(GETHCTL(IDC_DNOTE_Y),
							szBuffer, BUFFER_SIZE);
						sFNote[nNote].fY=atof(szBuffer);
					}
				}
				break;

				// Text changed
				case IDC_DNOTE_EDIT:
				{
					if(bUpdate)
					{
						// Get new text array size (not inc EOS)
						nSize=GetWindowTextLength(GETHCTL(
							IDC_DNOTE_EDIT));

						// Realloc text arrays
						if((sFNote[nNote].szText=
							(LPSTR)realloc(sFNote[nNote].szText,
							(nSize+2)*sizeof(char)))==NULL)
						{
							// I suppose it is OK just to break out
							// But some other realloc() failure will follow
							AllocErrorMessage();
							break;
						}

						// Read new text
						GetWindowText(GETHCTL(IDC_DNOTE_EDIT),
							sFNote[nNote].szText, nSize+1);

						// Update note count
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
							IDC_DNOTE_COUNT, NULL, 0));
					}
				}
				break;

				// Border flag changed
				case IDC_DNOTE_BORDER:
				{
					if(bUpdate)
					{
						// Get new border flag state
						sFNote[nNote].bBorder=
							Button_GetCheck(GETHCTL(IDC_DNOTE_BORDER));
					}
				}
				break;

				// Opaque flag changed
				case IDC_DNOTE_OPAQUE:
				{
					if(bUpdate)
					{
						// Get new opaque flag state
						sFNote[nNote].bOpaque=
							Button_GetCheck(GETHCTL(IDC_DNOTE_OPAQUE));
					}
				}
				break;

				// Clear button pressed - restore defaults
				// Do not clear saved data - may want to cancel
				case IDC_DNOTE_CLR:
				{
					// Restore the default note data
					for(i=0; i<FNOTE_NUMNOTES; i++)
					{
						// Reallocate text array to minimum size
						if((sFNote[i].szText=
							(LPSTR)realloc(sFNote[i].szText,
							(2)*sizeof(char)))==NULL)
						{
							// This really shouldn't happen
							AllocErrorMessage();
							break;
						}

						// Load defualts
						strlcpy(sFNote[i].szText, "", 2);
						sFNote[i].fX=0.0;
						sFNote[i].fY=0.0;
						sFNote[i].nSize=8;
						sFNote[i].bBorder=TRUE;
						sFNote[i].bOpaque=TRUE;
					}

					// Go to 1st note
					nNote=0;

					// Update display for all values
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DNOTE_UPDATE, NULL, 0));
				}
				break;

				// OK button pressed - accept inputs
				case IDC_DNOTE_ACCEPT:
				{
					// Free memory used to save text strings
					for(i=0; i<FNOTE_NUMNOTES; i++)
					{
						free(sFSave[i].szText);
					}

					// Close dialog box
					EndDialog (hDlg, 0);
				}
				return TRUE;

				// Read button pressed
				case IDC_DNOTE_READ:
				{
					ReadIni(INI_FNOTE);

					// Update display for all parameter values
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DNOTE_UPDATE, NULL, 0));
				}
				break;

				// Write button pressed
				case IDC_DNOTE_WRITE:
				{
					WriteIni(INI_FNOTE);
				}
				break;

				// Cancel button pressed - restore previous inputs before end
				// Respond to esc key or cancel button
				case IDCANCEL:
				case IDC_DNOTE_CANCEL:
				{
					// Restore the saved note data
					for(i=0; i<FNOTE_NUMNOTES; i++)
					{
						// Find the length of the saved text array
						nSize=strlen(sFSave[i].szText);

						// Reallocate the note text array to the saved size
						if((sFNote[i].szText=
							(LPSTR)realloc(sFNote[i].szText,
							(nSize+2)*sizeof(char)))==NULL)
						{
							// Dsp msg, avoid using this array & hang in
							// The end is near!
							AllocErrorMessage();
						}
						else
						{
							// Restore the saved data
							strlcpy(sFNote[i].szText, sFSave[i].szText,
								(nSize+2)*sizeof(char));
							sFNote[i].fX=sFSave[i].fX;
							sFNote[i].fY=sFSave[i].fY;
							sFNote[i].nSize=sFSave[i].nSize;
							sFNote[i].bBorder=sFSave[i].bBorder;
							sFNote[i].bOpaque=sFSave[i].bOpaque;
						}

						// Free memory used to save text strings
						free(sFSave[i].szText);
					}

					// Close dialog box
					EndDialog (hDlg, 0);
				}
				return TRUE;
			}
		}
		break;
	 }
	 return FALSE;
}


/*****************************************************************************/
/*                                                                           */
/*                   Phase Plot Annotation Dialog Procedure                  */
/*                                                                           */
/*      Dialog box procedure to enter annotations to be added to             */
/*      the phase data plot.                                                 */
/*                                                                           */
/* 		The annotations are defined by a notetype struct with these items:   */
/* 			char*	szNote		annotation text                              */
/*          F_TYPE  fX     		x-axis position                              */
/*          F_TYPE	fY       	y-axis position                              */
/*          int		nSize     	type point size                              */
/*          BOOL	bBorder     border flag                                  */
/*                                                                           */
/*      There is a global array of PNOTE_NUMNOTES of these notetype structs  */
/*      called sPNote[] with index nNote.  The elements are accessed as:     */
/*          sPNote[nNote].szNote, etc.                                       */
/*                                                                           */
/*     	The following WM_COMMAND message wParams are used:                   */
/*      	Dialog box controls:                                             */
/*				IDC_DNOTE_CLR	 	 Button		Clear all notes              */
/*				IDC_DNOTE_NUM		 Edit       Current note #               */
/*				IDC_DNOTE_SIZE		 Edit       Point size of note text      */
/*				IDC_DNOTE_X			 Edit       X-axis position              */
/*				IDC_DNOTE_Y			 Edit       Y-axis position              */
/*				IDC_DNOTE_UP		 Button     Increment note #             */
/*				IDC_DNOTE_DOWN		 Button     Decrement note #             */
/*				IDC_DNOTE_EDIT		 Edit       Note text                    */
/*				IDC_DNOTE_BORDER	 Check      Border flag                  */
/*				IDC_DNOTE_OPAQUE	 Check      Opaque flag                  */
/*				IDC_DNOTE_NOTES		 Text       # active notes               */
/*			Internal processing routines:                                    */
/*				IDC_DNOTE_UPDATE                Update screen displays       */
/*              IDC_DNOTE_CLEAR		            Clear screen displays        */
/*              IDC_DNOTE_COUNT                 Count # active notes         */
/*                                                                           */
/*      Programming notes:                                                   */
/*			1.	Multiline text edit box uses ES_WANTRETURN.                  */
/*              Don't want CR to activate selected command button.           */
/*          2.	Don't update screen after every edit box change message.     */
/*              Not only is that unnecessary, but it also puts cursor at     */
/*              beginning, which messes up the editing process.              */
/*          3.  The text memory has an extra character (in addition to the   */
/*              normal EOS).  The edit control seems to want this.           */
/*          4.  The sPNote[i].szText memory is allocated & freed in Winmain. */
/*                                                                           */
/*                                                                           */
/* 		Revision record:                                                     */
/*			07/09/96	Drafted                                              */
/*			07/10/96	Debugged                                             */
/*			07/11/96	More debugging                                       */
/*			07/12/96	Completed                                            */
/*			07/14/97	Fixed memory leak from sPSave[]                      */
/*			12/20/97	Added note parameter read & save buttons             */
/*			01/02/98	Added up and down note # buttons                     */
/*						Changed note # control to a drop down list combobox  */
/*			08/02/03	Added opaque note feature                            */
/*                                                                           */
/*****************************************************************************/

#ifndef _MSC_VER
	#pragma argsused
#endif

BOOL CALLBACK PhaseNoteDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	// Chars
	char szBuffer[BUFFER_SIZE+1];	// General text buffer
	// Ints
	int i;							// General index
	int nCount;						// # active lines
	int nSize;						// Text array size (not inc EOS)
	static int nNote=0;				// nNote (goes from 0 to PNOTE_NUMNOTES-1)
									// Line # displayed is nNote+1
	// BOOLs
	static BOOL bStart=TRUE;  	 	// Start flag for initializations
	static BOOL bUpdate=TRUE;    	// Update flag to avoid infinite looping
	// Misc
	static struct notedata sPSave[PNOTE_NUMNOTES];
									// To preserve original plot note data

	// Start of code

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// These initializations are done only at start

			// Clear start flag if phase note data was read from INI file
			if(bUsePhasePlotIni)
			{
				bStart=FALSE;
			}

			if(bStart)
			{
				// Initialize the line #
				nNote=0;

				// Initialize the sPNote elements
				for(i=0; i<PNOTE_NUMNOTES; i++)
				{
					strlcpy(sPNote[i].szText, "", 2);
					sPNote[i].fX=0.0;
					sPNote[i].fY=0.0;
					sPNote[i].nSize=8;
					sPNote[i].bBorder=TRUE;
					sPNote[i].bOpaque=TRUE;
				}

				// Reset start flag
				bStart=FALSE;
			}

			// The rest is done every time the dialog box is opened/reopened

			// Set dialog box title
			LoadString(hInst, IDS_TITLE_PHASENOTE, szBuffer, BUFFER_SIZE);
			SetWindowText(hDlg, szBuffer);

			// Save the original note data
			for(i=0; i<PNOTE_NUMNOTES; i++)
			{
				// Find the length of the original text array
				// Note: nSize does not include the EOS
				nSize=strlen(sPNote[i].szText);

				// Allocate the save text array to the original size
				if((sPSave[i].szText=
					(LPSTR)malloc((nSize+2)*sizeof(char)))==NULL)
				{
					// Dsp msg & bail out
					AllocErrorMessage();
					PostMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDCANCEL,
						NULL, 0));
					return TRUE;
				}

				// Save the original note data
				strlcpy(sPSave[i].szText, sPNote[i].szText,
					(nSize+2)*sizeof(char));
				sPSave[i].fX=sPNote[i].fX;
				sPSave[i].fY=sPNote[i].fY;
				sPSave[i].nSize=sPNote[i].nSize;
				sPSave[i].bBorder=sPNote[i].bBorder;
				sPSave[i].bOpaque=sPNote[i].bOpaque;
			}

			// Load integers into note # box
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_DNOTE_NUM));
			for(i=0; i<PNOTE_NUMNOTES; i++)
			{
				_snprintf(szBuffer, sizeof(szBuffer), "%d", i+1);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_DNOTE_NUM),
					i, szBuffer);
			}

			// Update display for all parameter values
			SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDC_DNOTE_UPDATE,
				NULL, 0));
			return TRUE;
		}

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				// Help button presses
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::PLOT_NOTES_FUNCTION.HTM",
						HH_DISPLAY_TOPIC,
                        0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::PLOT_NOTES_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "PLOT_NOTES_FUNCTION");
					#endif
				}
				break;

				// Clear display
				// Note: Used to clear display for case of invalid note #
				// Therefore the line # display is not changed
				// And the array memory allocation is unchanged
				case IDC_DNOTE_CLEAR:
				{
					// Inhibit value changed processing
					bUpdate=FALSE;

					// Clear the size value
					SetWindowText(GETHCTL(IDC_DNOTE_SIZE), "");

					// Clear the text string
					SetWindowText(GETHCTL(IDC_DNOTE_EDIT), "");

					// Clear the x position value
					SetWindowText(GETHCTL(IDC_DNOTE_X), "");

					// Clear the y position value
					SetWindowText(GETHCTL(IDC_DNOTE_Y), "");

					// Set the border flag
					Button_SetCheck(GETHCTL(IDC_DNOTE_BORDER), TRUE);

					// Set the opaque flag
					Button_SetCheck(GETHCTL(IDC_DNOTE_OPAQUE), TRUE);

					// Update note count
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DNOTE_COUNT, NULL, 0));

					// Enable value changed processing
					bUpdate=TRUE;
				}
				break;

				// Update display
				case IDC_DNOTE_UPDATE:
				{
					// Inhibit value changed processing
					bUpdate=FALSE;

					// Select line #
					nDummy=ComboBox_SetCurSel(GETHCTL(IDC_DNOTE_NUM), nNote);

					// Load size value
					_snprintf(szBuffer, sizeof(szBuffer), "%d",
						sPNote[nNote].nSize);
					SetWindowText(GETHCTL(IDC_DNOTE_SIZE),
						szBuffer);

					// Load the note text string
					SetWindowText(GETHCTL(IDC_DNOTE_EDIT),
						sPNote[nNote].szText);

					// Load the x position value
					_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
						sPNote[nNote].fX);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_DNOTE_X),
						szBuffer);

					// Load the y position value
					_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
						sPNote[nNote].fY);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_DNOTE_Y),
						szBuffer);

					// Load the border flag
					Button_SetCheck(GETHCTL(IDC_DNOTE_BORDER),
						sPNote[nNote].bBorder);

					// Load the opaque flag
					Button_SetCheck(GETHCTL(IDC_DNOTE_OPAQUE),
						sPNote[nNote].bOpaque);

					// Update note count
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DNOTE_COUNT, NULL, 0));

					// Enable value changed processing
					bUpdate=TRUE;
				}
				break;

				// Count and display # active notes
				case IDC_DNOTE_COUNT:
				{
					nCount=0;
					for(i=0; i<PNOTE_NUMNOTES; i++)
					{
						if(strlen(sPNote[i].szText))
						{
							nCount++;
						}
					}

					// Load the # active notes display
					_snprintf(szBuffer, sizeof(szBuffer), "# Notes = %d",
						nCount);
					SetWindowText(GETHCTL(IDC_DNOTE_NOTES),
						szBuffer);
				}
				break;

				// Note # changed
				case IDC_DNOTE_NUM:
				{
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_SELCHANGE)
					{
						// Read new line #
						nNote=ComboBox_GetCurSel(GETHCTL(IDC_DNOTE_NUM));

						// Update display for all parameter values
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
							IDC_DNOTE_UPDATE, NULL, 0));
					}
				}
				break;

				// Note # up button pressed
				case IDC_DNOTE_UP:
				{
					// Increment note # (with wrap-around)
					if(nNote<PNOTE_NUMNOTES-1)
					{
						nNote++;
					}
					else
					{
						nNote=0;
					}

					// Update display for all values
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DNOTE_UPDATE, NULL, 0));
				}
				break;

				// Note # down button pressed
				case IDC_DNOTE_DOWN:
				{
					// Decrement note # (with wrap=around)
					if(nNote>0)
					{
						nNote--;
					}
					else
					{
						nNote=PNOTE_NUMNOTES-1;
					}

					// Update display for all values
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DNOTE_UPDATE, NULL, 0));
				}
				break;

				// Font point size changed
				case IDC_DNOTE_SIZE:
				{
					if(bUpdate)
					{
						// Read new size
						GetWindowText(GETHCTL(IDC_DNOTE_SIZE),
							szBuffer, BUFFER_SIZE);
						sPNote[nNote].nSize=abs(atoi(szBuffer));
					}
				}
				break;

				// X position changed
				case IDC_DNOTE_X:
				{
					if(bUpdate)
					{
						// Read new x position value
						GetWindowText(GETHCTL(IDC_DNOTE_X),
							szBuffer, BUFFER_SIZE);
						sPNote[nNote].fX=atof(szBuffer);
					}
				}
				break;

				// Y position changed
				case IDC_DNOTE_Y:
				{
					if(bUpdate)
					{
						// Read new y position value
						GetWindowText(GETHCTL(IDC_DNOTE_Y),
							szBuffer, BUFFER_SIZE);
						sPNote[nNote].fY=atof(szBuffer);
					}
				}
				break;

				// Text changed
				case IDC_DNOTE_EDIT:
				{
					if(bUpdate)
					{
						// Get new text array size (not inc EOS)
						nSize=GetWindowTextLength(GETHCTL(
							IDC_DNOTE_EDIT));

						// Realloc text arrays
						if((sPNote[nNote].szText=
							(LPSTR)realloc(sPNote[nNote].szText,
							(nSize+2)*sizeof(char)))==NULL)
						{
							// Just break out - more trouble will prob follow
							AllocErrorMessage();
							break;
						}
						else
						{
							// Read new text
							GetWindowText(GETHCTL(IDC_DNOTE_EDIT),
								sPNote[nNote].szText, nSize+1);

							// Update note count
							SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
								IDC_DNOTE_COUNT, NULL, 0));
						}
					}
				}
				break;

				// Border flag changed
				case IDC_DNOTE_BORDER:
				{
					if(bUpdate)
					{
						// Get new border flag state
						sPNote[nNote].bBorder=
							Button_GetCheck(GETHCTL(IDC_DNOTE_BORDER));
					}
				}
				break;

				// Opaque flag changed
				case IDC_DNOTE_OPAQUE:
				{
					if(bUpdate)
					{
						// Get new opaque flag state
						sPNote[nNote].bOpaque=
							Button_GetCheck(GETHCTL(IDC_DNOTE_OPAQUE));
					}
				}
				break;

				// Clear button pressed - restore defaults
				// Do not clear saved data - may want to cancel
				case IDC_DNOTE_CLR:
				{
					// Restore the default note data
					for(i=0; i<PNOTE_NUMNOTES; i++)
					{
						// Reallocate text array to minimum size
						if((sPNote[i].szText=
							(LPSTR)realloc(sPNote[i].szText,
							(2)*sizeof(char)))==NULL)
						{
							// This really shouldn't happen
							AllocErrorMessage();
							break;
						}

						// Load defualts
						strlcpy(sPNote[i].szText, "", 2);
						sPNote[i].fX=0.0;
						sPNote[i].fY=0.0;
						sPNote[i].nSize=8;
						sPNote[i].bBorder=TRUE;
						sPNote[i].bOpaque=TRUE;
					}

					// Go to 1st note
					nNote=0;

					// Update display for all values
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DNOTE_UPDATE, NULL, 0));
				}
				break;

				// OK button pressed - accept inputs
				case IDC_DNOTE_ACCEPT:
				{
					// Free memory used to save text strings
					for(i=0; i<PNOTE_NUMNOTES; i++)
					{
						free(sPSave[i].szText);
					}

					// Close dialog box
					EndDialog (hDlg, 0);
				}
				return TRUE;

				// Read button pressed
				case IDC_DNOTE_READ:
				{
					ReadIni(INI_PNOTE);

					// Update display for all parameter values
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DNOTE_UPDATE, NULL, 0));
				}
				break;

				// Write button pressed
				case IDC_DNOTE_WRITE:
				{
					WriteIni(INI_PNOTE);
				}
				break;

				// Cancel button pressed - restore previous inputs before end
				// Respond to esc key or cancel button
				case IDCANCEL:
				case IDC_DNOTE_CANCEL:
				{
					// Restore the saved note data
					for(i=0; i<PNOTE_NUMNOTES; i++)
					{
						// Find the length of the saved text array
						nSize=strlen(sPSave[i].szText);

						// Reallocate the note text array to the saved size
						if((sPNote[i].szText=
							(LPSTR)realloc(sPNote[i].szText,
							(nSize+2)*sizeof(char)))==NULL)
						{
							// Dsp msg & hang in till end
							AllocErrorMessage();
						}
						else
						{
							// Restore the saved data
							strlcpy(sPNote[i].szText, sPSave[i].szText,
								(nSize+2)*sizeof(char));
							sPNote[i].fX=sPSave[i].fX;
							sPNote[i].fY=sPSave[i].fY;
							sPNote[i].nSize=sPSave[i].nSize;
							sPNote[i].bBorder=sPSave[i].bBorder;
							sPNote[i].bOpaque=sPSave[i].bOpaque;
						}

						// Free memory used to save text strings
						free(sPSave[i].szText);
					}

					// Close dialog box
					EndDialog (hDlg, 0);
				}
				return TRUE;
			}
		}
		break;
	 }
	 return FALSE;
}


/*****************************************************************************/
/*                                                                           */
/*                 Stability Plot Annotation Dialog Procedure                */
/*                                                                           */
/*      Dialog box procedure to enter annotations to be added to             */
/*      the stability data plot.                                             */
/*                                                                           */
/* 		The annotations are defined by a notetype struct with these items:   */
/* 			char*	szNote		annotation text                              */
/*          F_TYPE  fX     		x-axis position                              */
/*          F_TYPE	fY       	y-axis position                              */
/*          int		nSize     	type point size                              */
/*          BOOL	bBorder     border flag                                  */
/*                                                                           */
/*      There is a global array of SNOTE_NUMNOTES of these notetype structs  */
/*      called sSNote[] with index nNote.  The elements are accessed as:     */
/*          sSNote[nNote].szNote, etc.                                       */
/*                                                                           */
/*     	The following WM_COMMAND message wParams are used:                   */
/*      	Dialog box controls:                                             */
/*				IDC_DNOTE_CLR	 	 Button		Clear all notes              */
/*				IDC_DNOTE_NUM		 Edit       Current note #               */
/*				IDC_DNOTE_SIZE		 Edit       Point size of note text      */
/*				IDC_DNOTE_X			 Edit       X-axis position              */
/*				IDC_DNOTE_Y			 Edit       Y-axis position              */
/*				IDC_DNOTE_UP		 Button     Increment note #             */
/*				IDC_DNOTE_DOWN		 Button     Decrement note #             */
/*				IDC_DNOTE_EDIT		 Edit       Note text                    */
/*				IDC_DNOTE_BORDER	 Check      Border flag                  */
/*				IDC_DNOTE_OPAQUE	 Check      Opaque flag                  */
/*				IDC_DNOTE_NOTES		 Text       # active notes               */
/*			Internal processing routines:                                    */
/*				IDC_DNOTE_UPDATE                Update screen displays       */
/*              IDC_DNOTE_CLEAR		            Clear screen displays        */
/*              IDC_DNOTE_COUNT                 Count # active notes         */
/*                                                                           */
/*      Programming notes:                                                   */
/*			1.	Multiline text edit box uses ES_WANTRETURN.                  */
/*              Don't want CR to activate selected command button.           */
/*          2.	Don't update screen after every edit box change message.     */
/*              Not only is that unnecessary, but it also puts cursor at     */
/*              beginning, which messes up the editing process.              */
/*          3.  The text memory has an extra character (in addition to the   */
/*              normal EOS).  The edit control seems to want this.           */
/*          4.  The sSNote[i].szText memory is allocated & freed in Winmain. */
/*                                                                           */
/*                                                                           */
/* 		Revision record:                                                     */
/*			07/18/96	Drafted                                              */
/*			07/14/97	Fixed memory leak from sSSave[]                      */
/*			12/20/97	Added note parameter read & save buttons             */
/*			01/02/98	Added up and down note # buttons                     */
/*						Changed note # control to a drop down list combobox  */
/*			08/01/03	Added opaque note feature                            */
/*                                                                           */
/*****************************************************************************/

#ifndef _MSC_VER
	#pragma argsused
#endif

BOOL CALLBACK SigmaNoteDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	// Structs
	static struct notedata sSSave[SNOTE_NUMNOTES];
									// To preserve original plot note data
	// Chars
	char szBuffer[BUFFER_SIZE+1];		// General text buffer
	// Ints
	int i;							// General index
	int nCount;						// # active lines
	int nSize;						// Text array size (not inc EOS)
	static int nNote=0;				// nNote (goes from 0 to SNOTE_NUMNOTES-1)
									// Line # displayed is nNote+1
	// BOOLs
	static BOOL bStart=TRUE;  	 	// Start flag for initializations
	static BOOL bUpdate=TRUE;    	// Update flag to avoid infinite looping

	// Start of code

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// These initializations are done only at start
			// Clear start flag if sigma note data was read from INI file
			if(bUseSigmaPlotIni)
			{
				bStart=FALSE;
			}

			if(bStart)
			{
				// Initialize the line #
				nNote=0;

				// Initialize the sFNote elements
				for(i=0; i<SNOTE_NUMNOTES; i++)
				{
					strlcpy(sSNote[i].szText, "", 2);
					sSNote[i].fX=0.0;
					sSNote[i].fY=0.0;
					sSNote[i].nSize=8;
					sSNote[i].bBorder=TRUE;
					sSNote[i].bOpaque=TRUE;
				}

				// Reset start flag
				bStart=FALSE;
			}

			// The rest is done every time the dialog box is opened/reopened
			if(nPlotType==READ_PLOT)
			{
				// Change dialog box title
				LoadString(hInst, IDS_TITLE_READNOTE, szBuffer,	BUFFER_SIZE);
			}
			else if(nPlotType==SIGMA_PLOT)
			{
				// Change dialog box title
				LoadString(hInst, IDS_TITLE_SIGMANOTE, szBuffer, BUFFER_SIZE);
			}
			SetWindowText(hDlg, szBuffer);

			// Save the original note data
			for(i=0; i<SNOTE_NUMNOTES; i++)
			{
				// Find the length of the original text array
				// Note: nSize does not include the EOS
				nSize=strlen(sSNote[i].szText);

				// Allocate the save text string array to the original size
				if((sSSave[i].szText=(LPSTR)malloc((nSize+2)*sizeof(char)))==
					NULL)
				{
					// Dsl msg & bail out
					AllocErrorMessage();
					PostMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDCANCEL,
						NULL, 0));
					return TRUE;
				}

				// Save the original note data
				strlcpy(sSSave[i].szText, sSNote[i].szText,
					(nSize+2)*sizeof(char));
				sSSave[i].fX=sSNote[i].fX;
				sSSave[i].fY=sSNote[i].fY;
				sSSave[i].nSize=sSNote[i].nSize;
				sSSave[i].bBorder=sSNote[i].bBorder;
				sSSave[i].bOpaque=sSNote[i].bOpaque;
			}

			// Load integers into note # box
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_DNOTE_NUM));
			for(i=0; i<SNOTE_NUMNOTES; i++)
			{
				_snprintf(szBuffer, sizeof(szBuffer), "%d", i+1);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_DNOTE_NUM),
					i, szBuffer);
			}

			// Update display for all parameter values
			SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDC_DNOTE_UPDATE,
				NULL, 0));
			return TRUE;
		}

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				// Help button presses
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::RUN_NOTES_FUNCTION.HTM",
						HH_DISPLAY_TOPIC,
                        0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::RUN_NOTES_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "RUN_NOTES_FUNCTION");
					#endif
				}
				break;

				// Clear display
				// Note: Used to clear display for case of invalid note #
				// Therefore the line # display is not changed
				// And the array memory allocation is unchanged
				case IDC_DNOTE_CLEAR:
				{
					// Inhibit value changed processing
					bUpdate=FALSE;

					// Clear the size value
					SetWindowText(GETHCTL(IDC_DNOTE_SIZE), "");

					// Clear the text string
					SetWindowText(GETHCTL(IDC_DNOTE_EDIT), "");

					// Clear the x position value
					SetWindowText(GETHCTL(IDC_DNOTE_X), "");

					// Clear the y position value
					SetWindowText(GETHCTL(IDC_DNOTE_Y), "");

					// Set the border flag
					Button_SetCheck(GETHCTL(IDC_DNOTE_BORDER), TRUE);

					// Set the opaque flag
					Button_SetCheck(GETHCTL(IDC_DNOTE_OPAQUE), TRUE);

					// Update note count
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DNOTE_COUNT, NULL, 0));

					// Enable value changed processing
					bUpdate=TRUE;
				}
				break;

				// Update display
				case IDC_DNOTE_UPDATE:
				{
					// Inhibit value changed processing
					bUpdate=FALSE;

					// Select line #
					nDummy=ComboBox_SetCurSel(GETHCTL(IDC_DNOTE_NUM), nNote);

					// Load size value
					_snprintf(szBuffer, sizeof(szBuffer), "%d",
						sSNote[nNote].nSize);
					SetWindowText(GETHCTL(IDC_DNOTE_SIZE),
						szBuffer);

					// Load the note text string
					SetWindowText(GETHCTL(IDC_DNOTE_EDIT),
						sSNote[nNote].szText);

					// Load the x position value
					_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
						sSNote[nNote].fX);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_DNOTE_X),
						szBuffer);

					// Load the y position value
					_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
						sSNote[nNote].fY);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_DNOTE_Y),
						szBuffer);

					// Load the border flag
					Button_SetCheck(GETHCTL(IDC_DNOTE_BORDER),
						sSNote[nNote].bBorder);

					// Load the opaque flag
					Button_SetCheck(GETHCTL(IDC_DNOTE_OPAQUE),
						sSNote[nNote].bOpaque);

					// Update note count
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DNOTE_COUNT, NULL, 0));

					// Enable value changed processing
					bUpdate=TRUE;
				}
				break;

				// Count and display # active notes
				case IDC_DNOTE_COUNT:
				{
					nCount=0;
					for(i=0; i<SNOTE_NUMNOTES; i++)
					{
						if(strlen(sSNote[i].szText))
						{
							nCount++;
						}
					}

					// Load the # active notes display
					_snprintf(szBuffer, sizeof(szBuffer), "# Notes = %d",
						nCount);
					SetWindowText(GETHCTL(IDC_DNOTE_NOTES),
						szBuffer);
				}
				break;

				// Note # changed
				case IDC_DNOTE_NUM:
				{
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_SELCHANGE)
					{
						// Read new line #
						nNote=ComboBox_GetCurSel(GETHCTL(IDC_DNOTE_NUM));

						// Update display for all parameter values
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
							IDC_DNOTE_UPDATE, NULL, 0));
					}
				}
				break;

				// Note # up button pressed
				case IDC_DNOTE_UP:
				{
					// Increment note # (with wrap-around)
					if(nNote<SNOTE_NUMNOTES-1)
					{
						nNote++;
					}
					else
					{
						nNote=0;
					}

					// Update display for all values
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DNOTE_UPDATE, NULL, 0));
				}
				break;

				// Note # down button pressed
				case IDC_DNOTE_DOWN:
				{
					// Decrement note # (with wrap=around)
					if(nNote>0)
					{
						nNote--;
					}
					else
					{
						nNote=SNOTE_NUMNOTES-1;
					}

					// Update display for all values
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DNOTE_UPDATE, NULL, 0));
				}
				break;

				// Font point size changed
				case IDC_DNOTE_SIZE:
				{
					if(bUpdate)
					{
						// Read new size
						GetWindowText(GETHCTL(IDC_DNOTE_SIZE),
							szBuffer, BUFFER_SIZE);
						sSNote[nNote].nSize=abs(atoi(szBuffer));
					}
				}
				break;

				// X position changed
				case IDC_DNOTE_X:
				{
					if(bUpdate)
					{
						// Read new x position value
						GetWindowText(GETHCTL(IDC_DNOTE_X),
							szBuffer, BUFFER_SIZE);
						sSNote[nNote].fX=atof(szBuffer);
					}
				}
				break;

				// Y position changed
				case IDC_DNOTE_Y:
				{
					if(bUpdate)
					{
						// Read new y position value
						GetWindowText(GETHCTL(IDC_DNOTE_Y),
							szBuffer, BUFFER_SIZE);
						sSNote[nNote].fY=atof(szBuffer);
					}
				}
				break;

				// Text changed
				case IDC_DNOTE_EDIT:
				{
					if(bUpdate)
					{
						// Get new text array size (not inc EOS)
						nSize=GetWindowTextLength(GETHCTL(
							IDC_DNOTE_EDIT));

						// Realloc text arrays
						if((sSNote[nNote].szText=
							(LPSTR)realloc(sSNote[nNote].szText,
							(nSize+2)*sizeof(char)))==NULL)
						{
							// Just dsp msg & avoid changing array
							AllocErrorMessage();
						}
						else
						{
							// Read new text
							GetWindowText(GETHCTL(IDC_DNOTE_EDIT),
								sSNote[nNote].szText, nSize+1);

							// Update note count
							SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
								IDC_DNOTE_COUNT, NULL, 0));
						}
					}
				}
				break;

				// Border flag changed
				case IDC_DNOTE_BORDER:
				{
					if(bUpdate)
					{
						// Get new border flag state
						sSNote[nNote].bBorder=
							Button_GetCheck(GETHCTL(IDC_DNOTE_BORDER));
					}
				}
				break;

				// Opaque flag changed
				case IDC_DNOTE_OPAQUE:
				{
					if(bUpdate)
					{
						// Get new opaque flag state
						sSNote[nNote].bOpaque=
							Button_GetCheck(GETHCTL(IDC_DNOTE_OPAQUE));
					}
				}
				break;

				// Clear button pressed - restore defaults
				// Do not clear saved data - may want to cancel
				case IDC_DNOTE_CLR:
				{
					// Restore the default note data
					for(i=0; i<SNOTE_NUMNOTES; i++)
					{
						// Reallocate text array to minimum size
						if((sSNote[i].szText=
							(LPSTR)realloc(sSNote[i].szText,
							(2)*sizeof(char)))==NULL)
						{
							// This shouldn't happen
							AllocErrorMessage();
						}

						// Load defualts
						strlcpy(sSNote[i].szText, "", 2);
						sSNote[i].fX=0.0;
						sSNote[i].fY=0.0;
						sSNote[i].nSize=8;
						sSNote[i].bBorder=TRUE;
						sSNote[i].bOpaque=TRUE;
					}

					// Go to 1st note
					nNote=0;

					// Update display for all values
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DNOTE_UPDATE, NULL, 0));
				}
				break;

				// OK button pressed - accept inputs
				case IDC_DNOTE_ACCEPT:
				{
					// Free the original note data arrays
					for(i=0; i<SNOTE_NUMNOTES; i++)
					{
						free(sSSave[i].szText);
					}

					// Close dialog box
					EndDialog (hDlg, 0);
				}
				return TRUE;

				// Read button pressed
				case IDC_DNOTE_READ:
				{
					ReadIni(INI_SNOTE);

					// Update display for all parameter values
					SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DNOTE_UPDATE, NULL, 0));
				}
				break;

				// Write button pressed
				case IDC_DNOTE_WRITE:
				{
					WriteIni(INI_SNOTE);
				}
				break;

				// Cancel button pressed - restore previous inputs before end
				// Respond to esc key or cancel button
				case IDCANCEL:
				case IDC_DNOTE_CANCEL:
				{
					// Restore the saved note data
					for(i=0; i<SNOTE_NUMNOTES; i++)
					{
						// Find the length of the saved text array
						nSize=strlen(sSSave[i].szText);

						// Reallocate the note text array to the saved size
						if((sSNote[i].szText=
							(LPSTR)realloc(sSNote[i].szText,
							(nSize+2)*sizeof(char)))==NULL)
						{
							// Dsp msg & go on to end
							AllocErrorMessage();
						}
						else
						{
							// Restore the saved data
							strlcpy(sSNote[i].szText, sSSave[i].szText,
								(nSize+2)*sizeof(char));
							sSNote[i].fX=sSSave[i].fX;
							sSNote[i].fY=sSSave[i].fY;
							sSNote[i].nSize=sSSave[i].nSize;
							sSNote[i].bBorder=sSSave[i].bBorder;
							sSNote[i].bOpaque=sSSave[i].bOpaque;
						}

						// Free the original note data arrays
						free(sSSave[i].szText);
					}

					// Close dialog box
					EndDialog (hDlg, 0);
				}
				return TRUE;
			}
		}
		break;
	 }
	 return FALSE;
}

/*****************************************************************************/

#ifndef LITE_VER
/*****************************************************************************/
/*                                                                           */
/*                      Autocorrelation Plot Dialog Procedure                */
/*                                                                           */
/*                                                                           */
/*                                                                           */
/* 		Revision record:                                                     */
/*			08/05/03	Created from SpectrumPlotDlgProc()                   */
/*			08/17/03	Complete                                             */
/*			09/10/09	Added initial noise ID                               */
/*			07/31/07	Added automatic ACF plot with F11 key                */
/*			02/12/08	Changed max AF from nPoints to nPoints/2             */
/*			07/14/10	Added automatic opening of normalize dialog          */
/*                                                                           */
/*****************************************************************************/

#ifndef _MSC_VER
	#pragma argsused
#endif

BOOL CALLBACK AutocorrelationPlotDlgProc(HWND hDlg, UINT message,
	WPARAM wParam,	LPARAM lParam)
{
	// Local variables
	// Handles
	HWND hChildWnd=NULL;
	HANDLE hChildAccel=NULL;
	// Chars
	char szBuffer[BUFFER_SIZE+1]; 		// General buffer
	char szText[BUFFER_SIZE+1]; 		// Text buffer
	static char szMsg[BUFFER_SIZE+1]; 	// Message buffer
	// Temporary filename buffers
	char szTempFile[FILENAMESIZE+1];	// Temp full filename buffer
	char szTempTitle[FILENAMESIZE+1];	// Temp file title buffer
	char szTempPath[FILENAMESIZE+1];	// Temp file path buffer
	char szTempName[FILENAMESIZE+1];    // Temp file name buffer
	char szTempExt[BUFFER_SIZE+1];		// Temp file extension buffer
	// Unsigned Ints
	static unsigned uTitle;			// HWND of Title combo control
	static unsigned uSubtitle;	  	// HWND of Subtitle combo control
	static unsigned uMessage;	  	// HWND of Message combo control
	// Ints
	int i;							// Index
	static int nTest;				// Max allowable # lag points
	static int nData;               // # analysis points
	static int n2;					// Power of 2 results array size
	static int nEntry;				// # points entry
	static int nPoints;				// # lag points to show
	static int nNum;				// # data points to save/restore
	static int nN;					// # points in noise ID function
	static int nAF;					// Averaging factor
	static int nAlpha;				// Power law exponent
	int nLength;					// String length
	static int nYTic=0;				// # y scale tics
	static int nAvg=1;				// PSD averaging factor
	static int nWin=5;				// # multitaper windows
	static int nFreq;				// # MT FFT frequencies
	// BOOLs
	BOOL bSave;						// BOOL to save state of ini flag
	static BOOL bErrorTrap=FALSE;   // Flag for entry error
	static BOOL bFirstTime=TRUE;    // Flag for initial opening
	static BOOL bPrevDataType=0;	// Flag for previous data type
	static BOOL bMethod=TRUE;		// Autocorrelation calc method
	static BOOL bZero=TRUE;			// Zero lag calc flag
	static BOOL bNoiseMsg=FALSE;	// Flag that previous msg is noise msg
	// F_TYPEs
	static F_TYPE fTau;			   	// Tau value
	static F_TYPE *fTempData;		// Pointer to temporary data array
	static F_TYPE *fSaveData;		// Pointer to saved data array
	F_TYPE fAvg, fMax, fMin;		// Used for checking need to normalize
	// Noise ID variables
	static float fR1;				// Lag 1 ACF value
	static float fDelta;			// Greenhall delta
	static float fAlpha;			// Estimated alpha as decimal value
	static int nP;					// Greenhall p = alpha estimate
	static int nD;					// Greenhall d = difference order

	// Note: The autocorrelation array fAuto[] and the plot structs
	// sAPlot & sAPrev are defined globally

	// Put plot dialog box handle into global
	hPlotBox=hDlg;

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Put dialog box handle into global variable
			// Used at end of GraphiC plotting to assure safe return here
			hDialog=hDlg;

			// Reinitialize avg factor
			if( (bFirstTime) || (bDataType!=bPrevDataType) ||
				(bDataType==PHASE_DATA && (bPhaseDataChanged ||
				bAutoPhaseDataRead)) ||
				(bDataType==FREQ_DATA && (bFreqDataChanged ||
				bAutoFreqDataRead)) )
			{
				nAF=1;
				sAPlot.af=1;
				sAPlot.win=1; // Lag # for scatter plot
			}

			// Get # analysis points
			nData=(int)(fData[2]-fData[1]+1);

            // Get tau value
            if(bDataType==FREQ_DATA)
            {
                GetWindowText(hwndFreqTau, szBuffer, BUFFER_SIZE);
                fTau=(F_TYPE)atof(szBuffer);
            }
            else // Phase data
            {
                GetWindowText(hwndPhaseTau, szBuffer, BUFFER_SIZE);
				fTau=(F_TYPE)atof(szBuffer);
            }

			// Calc max # lags allowed
			if(bMethod)
			{
				nTest=nData/(2*nAF);
			}
			else
			{
				nTest=nData/nAF;
			}

			// Put max # lag points into info text
			_snprintf(szBuffer, sizeof(szBuffer), "of %d", nTest);
			SetWindowText(GETHCTL(IDC_APLOT_INFO), szBuffer);

			// Restore # points - min of previous or allowable
			// May change below if data did
			_snprintf(szBuffer, sizeof(szBuffer), "%d", min(nPoints, nTest));
			SetWindowText(GETHCTL(IDC_APLOT_POINTS), szBuffer);

			// This can happen if user makes analysis limits smaller
			if(nTest<nPoints)
			{
				// Bring #s into sync
				nPoints=nTest;
				sAPlot.num=nPoints;
			}

			// Clear the message if it is a noise type
			// Is message a noise type?
			if( ((strcmp(sAPlot.message_str, "White PM"))==0) ||
				((strcmp(sAPlot.message_str, "Flicker PM"))==0) ||
				((strcmp(sAPlot.message_str, "White FM"))==0) ||
				((strcmp(sAPlot.message_str, "Flicker FM"))==0) ||
				((strcmp(sAPlot.message_str, "Random Walk FM"))==0) ||
				((strcmp(sAPlot.message_str, "W, F or RW FM"))==0) )
			{
				// Clear the noise message
				strlcpy(sAPlot.message_str, "", MESSAGESIZE);
				SetWindowText(GETHCTL(IDC_APLOT_MESSAGE),
					sAPlot.message_str);
			}

			// Check if data type changed
			if(bDataType!=bPrevDataType)
			{
				// Make sure subtitle is correct
				strlcpy(sAPlot.subtitle, szFileTitle, SUBTITLESIZE);
				SetWindowText(GETHCTL(IDC_APLOT_SUBTITLE),
					sAPlot.subtitle);

				// Clear message (noise type)
				strlcpy(sAPlot.message_str, "", MESSAGESIZE);
				SetWindowText(GETHCTL(IDC_APLOT_MESSAGE), "");

					// Reset plot scale
				sAPlot.y_tic=0;

				// Reset AF & lag #
				nAF=1;
				sAPlot.af=1;
				sAPlot.win=1; // Lag # for scatter plot

				// Put max allowable # lag points into # points
				_snprintf(szBuffer, sizeof(szBuffer), "%d", nTest);
				SetWindowText(GETHCTL(IDC_APLOT_POINTS), szBuffer);
				nPoints=nTest;
				sAPlot.num=nPoints;
			}

			// Save new data type
			bPrevDataType=bDataType;
			
			// Check if data changed
			if(bDataType==
				PHASE_DATA && (bPhaseDataChanged || bAutoPhaseDataRead))
			{
				// Make sure subtitle is correct
				strlcpy(sAPlot.subtitle, szFileTitle, SUBTITLESIZE);
				SetWindowText(GETHCTL(IDC_APLOT_SUBTITLE),
					sAPlot.subtitle);

				// Clear message (noise type)
				strlcpy(sAPlot.message_str, "", MESSAGESIZE);
				SetWindowText(GETHCTL(IDC_APLOT_MESSAGE), "");

				// Reset plot scale
				sAPlot.y_tic=0;

				// Reset AF & lag #
				nAF=1;
				sAPlot.af=1;
				sAPlot.win=1; // Lag # for scatter plot

				// Put max allowable # lag points into # points
				_snprintf(szBuffer, sizeof(szBuffer), "%d", nTest);
				SetWindowText(GETHCTL(IDC_APLOT_POINTS), szBuffer);
				nPoints=nTest;
				sAPlot.num=nPoints;

				// Clear data changed flag
				bPhaseDataChanged=FALSE;
				bAutoPhaseDataRead=FALSE;
			}

			if(bDataType==FREQ_DATA && (bFreqDataChanged || bAutoFreqDataRead))
			{
				// Make sure subtitle is correct
				strlcpy(sAPlot.subtitle, szFileTitle, SUBTITLESIZE);
				SetWindowText(GETHCTL(IDC_APLOT_SUBTITLE),
					sAPlot.subtitle);

				// Clear message (noise type)
				strlcpy(sAPlot.message_str, "", MESSAGESIZE);
				SetWindowText(GETHCTL(IDC_APLOT_MESSAGE), "");

				// Reset plot scale
				sAPlot.y_tic=0;

				// Reset AF & lag #
				nAF=1;
				sAPlot.af=1;
				sAPlot.win=1; // Lag # for scatter plot

				// Put max allowable # lag points into # points
				_snprintf(szBuffer, sizeof(szBuffer), "%d", nTest);
				SetWindowText(GETHCTL(IDC_APLOT_POINTS), szBuffer);
				nPoints=nTest;
				sAPlot.num=nPoints;

				// Clear data changed flag
				bFreqDataChanged=FALSE;
				bAutoFreqDataRead=FALSE;
			}

			// Full initialization
			if(bFirstTime)
			{
				// Initialize plot parameters
				InitAutocorrelationPlotParams(1);
				
				// Set # y-axis tics to zero as code to calc scale
				sAPlot.y_tic=0;

				if(bUseAutoPlotIni)
				{
					ReadIni(INI_AUTO);
					nAF=sAPlot.af;
				}
				else
				{
					// Initialize autocorrelation plot parameters to defaults
					strlcpy(sAPlot.title, "AUTOCORRELATION", TITLESIZE);
					strlcpy(sAPlot.subtitle, szFileTitle, SUBTITLESIZE);
					strlcpy(sAPlot.message_str, "", MESSAGESIZE);
					sAPlot.do_date=TRUE;
					sAPlot.do_box=TRUE;
					sAPlot.do_mouse=FALSE;
					sAPlot.do_line=TRUE;
					sAPlot.do_errbar=TRUE;
					sAPlot.do_table=TRUE; // Controls lag1 scatter plot
					sAPlot.do_fit=TRUE;
					sAPlot.do_wide=FALSE;
					sAPlot.position=0;
					sAPlot.win=1;
					sAPlot.num=1;
					sAPlot.carrier=1.0e7;
					nAF=1;
					sAPlot.af=1;
					sAPlot.win=1; // Lag # for scatter plot
				}

				// Adjust settings for modern plot style
				if(nStyle==MODERN_STYLE)
				{
					sAPlot.do_date=FALSE;
					sAPlot.do_wide=TRUE;
					sAPlot.do_table=FALSE;
					sAPlot.position=NUM_DPLOT_POSITIONS; // None for no message on plot
					strlcpy(sAPlot.subtitle, "", sizeof(sAPlot.subtitle));
				}

				// Put max allowable # lag points into # points
				_snprintf(szBuffer, sizeof(szBuffer), "%d", nTest);
				SetWindowText(GETHCTL(IDC_APLOT_POINTS), szBuffer);
				nPoints=nTest;
				sAPlot.num=nPoints;
				
				bFirstTime=FALSE;
			}

			// Load x label
			SetWindowText(GETHCTL(IDC_APLOT_XLABEL), "X-Label: Lag");

			// Load y label
			SetWindowText(GETHCTL(IDC_APLOT_YLABEL),
				"Y-Label: Autocorrelation");

			// Fill up message position list box using string table
			// Note usage of DPLOT rather than APLOT strings
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_APLOT_POSITION));
			nDummy=ComboBox_InsertString(GETHCTL(IDC_APLOT_POSITION),
				0, "None");
			for(i=0; i<NUM_DPLOT_POSITIONS; i++)
			{
				LoadString(hInst, IDS_DPLOT_POSITION_0+i, szBuffer,
					BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_APLOT_POSITION),
					i, szBuffer);
			}

			// Show position
			nDummy=ComboBox_SetCurSel(GETHCTL(IDC_APLOT_POSITION),
				sAPlot.position);

			// Clear the title list box
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_APLOT_TITLE));

			// Load the title
			SetWindowText(GETHCTL(IDC_APLOT_TITLE), sAPlot.title);

			// Load previous user-entered title strings into list box
			if(nUserTitles)
			{
				for(i=0; i<nUserTitles; i++)
				{
					// Load title string
					nDummy=ComboBox_InsertString(GETHCTL(IDC_APLOT_TITLE),
						i, szPlotTitle[i]);
				}
			}

			// Load the current title
			nDummy=ComboBox_AddString(GETHCTL(IDC_APLOT_TITLE),
				sAPlot.title);
			SetWindowText(GETHCTL(IDC_APLOT_TITLE),
				sAPlot.title);

			// Clear the subtitle list box
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_APLOT_SUBTITLE));

			// Load the filenames into the subtitle list box
			nDummy=ComboBox_AddString(GETHCTL(IDC_APLOT_SUBTITLE),
				szFileTitle);
			nDummy=ComboBox_AddString(GETHCTL(IDC_APLOT_SUBTITLE), szFile);

			// Load previous user-entered subtitle strings into list box
			if(nUserSubtitles)
			{
				for(i=0; i<nUserSubtitles; i++)
				{
					// Load subtitle string
					nDummy=ComboBox_InsertString(GETHCTL(IDC_APLOT_SUBTITLE),
						i, szPlotSubtitle[i]);
				}
			}

			// Load the subtitle
			SetWindowText(GETHCTL(IDC_APLOT_SUBTITLE),
				sAPlot.subtitle);

			// Clear the message list box
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_APLOT_MESSAGE));

			// Load previous user-entered message strings into list box
			if(nUserMessages)
			{
				for(i=0; i<nUserMessages; i++)
				{
					// Load message string
					nDummy=ComboBox_InsertString(GETHCTL(IDC_APLOT_MESSAGE),
						i, szPlotMessage[i]);
				}
			}

			// Load the current message
			SetWindowText(GETHCTL(IDC_APLOT_MESSAGE),
				sAPlot.message_str);

			// Load the plot filename
			SetWindowText(GETHCTL(IDC_APLOT_FILENAME),
				sAPlot.plot_filename);

			// Load the lag #
			_snprintf(szBuffer, sizeof(szBuffer), "%d", sAPlot.win);
			SetWindowText(GETHCTL(IDC_APLOT_LAGNUM), szBuffer);

			// Load the avg factor
			_snprintf(szBuffer, sizeof(szBuffer), "%d", nAF);
			SetWindowText(GETHCTL(IDC_APLOT_AF), szBuffer);

			// Display tau
			_snprintf(szBuffer, sizeof(szBuffer), "%11.5e", fTau*nAF);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_APLOT_TAU), szBuffer);
			
			// Load the autocorrelation data filename
			SetWindowText(GETHCTL(IDC_APLOT_AUTOFILE), szAutoFile);

				// Restore the date checkbox state
			Button_SetCheck(GETHCTL(IDC_APLOT_DATE), sAPlot.do_date);

			// Restore the box checkbox state
			Button_SetCheck(GETHCTL(IDC_APLOT_BOX), sAPlot.do_box);

			// Restore the cursor checkbox state
			Button_SetCheck(GETHCTL(IDC_APLOT_CURSOR), sAPlot.do_mouse);

			// Restore the zero checkbox state - uses do_line flag
			Button_SetCheck(GETHCTL(IDC_APLOT_ZERO), sAPlot.do_line);

			// Restore the lag1 checkbox state - uses do_table flag
			Button_SetCheck(GETHCTL(IDC_APLOT_LAG1), sAPlot.do_table);

			// Restore the wide checkbox state
			Button_SetCheck(GETHCTL(IDC_APLOT_WIDE), sAPlot.do_wide);

			// Get & save HWNDs returned by GetFocus() for Title, Subtitle &
			// Message combo boxes
			SetFocus(GETHCTL(IDC_APLOT_TITLE));
			uTitle=(UINT)GetFocus();
			SetFocus(GETHCTL(IDC_APLOT_SUBTITLE));
			uSubtitle=(UINT)GetFocus();
			SetFocus(GETHCTL(IDC_APLOT_MESSAGE));
			uMessage=(UINT)GetFocus();

			// Do immediate Greenhall lag 1 noise ID
			// Call ACF noise ID function
			// No sigma type applies, so allow dmax=3

			// Has additional 2nd arg
			ACFNoiseID(fData, bDataType, nAF, &fR1, &fAlpha, &nAlpha, 3, 0);

			// Display lag 1 autocorrelation
			_snprintf(szBuffer, sizeof(szBuffer), "%1.3f", fR1);
			SetWindowText(GETHCTL(IDC_APLOT_R1), szBuffer);

			// Don't ID noise if don't have at least 30 analysis points
			if(nData/nAF>=30)
			{
				switch(nAlpha) 
				{
					case -4: // RR FM
					{
						strlcpy(szBuffer, "Random Run FM: ",
							sizeof(szBuffer));
					}
					break;

					case -3: // FW FM
					{
						strlcpy(szBuffer, "Flicker Walk FM: ",
							sizeof(szBuffer));
					}
					break;

					case -2: // RW FM
					{
						strlcpy(szBuffer, "Random Walk FM: ",
							sizeof(szBuffer));
					}
					break;

					case -1: // F FM
					{
						strlcpy(szBuffer, "Flicker FM: ",
							sizeof(szBuffer));
					}
					break;

					case -0: // W FM
					{
						strlcpy(szBuffer, "White FM: ",
							sizeof(szBuffer));
					}
					break;

					case 1: // F PM
					{
						strlcpy(szBuffer, "Flicker PM: ",
							sizeof(szBuffer));
					}
					break;

					case 2: // W PM
					{
						strlcpy(szBuffer, "White PM: ",
							sizeof(szBuffer));
					}
					break;

					default: // Noise out of normal range
					{
						_snprintf(szBuffer, sizeof(szBuffer), "");
					}
				}

				// Show estimated alpha
				_snprintf(szText, sizeof(szText), "Estimated alpha=%+1.2f",
					fAlpha);
				
				// For testing
				// _snprintf(szText,"Estimated alpha=%e", fAlpha);

				strlcat(szBuffer, szText, sizeof(szBuffer));

				// Use noise type as message if user hasn't entered one
				if((strlen(sAPlot.message_str))==0)
				{
					strlcpy(sAPlot.message_str, szBuffer, MESSAGESIZE);
				}

				// Or if previous message is a noise type
				if( ((strcmp(szMsg, "White PM:"))==0) ||
					((strcmp(szMsg, "Flicker P"))==0) ||
					((strcmp(szMsg, "White FM:"))==0) ||
					((strcmp(szMsg, "Flicker F"))==0) ||
					((strcmp(szMsg, "Random Wa"))==0) ||
					((strcmp(szMsg, "Estimated"))==0) )
				{
					// Store message
					strlcpy(sAPlot.message_str, szBuffer, MESSAGESIZE);

					// Set noise message flag
					bNoiseMsg=TRUE;
				}
				else
				{
					// Reset noise message flag
					bNoiseMsg=FALSE;
				}

				// Put noise type string into message list
				// Don't store again if already in list
				if(ComboBox_FindString(GETHCTL(IDC_APLOT_MESSAGE),
					-1, szBuffer)==CB_ERR)
				{
					if(bNoiseMsg) // Replace noise message
					{
						// Delete current noise message
						nDummy=ComboBox_DeleteString(GETHCTL(
							IDC_APLOT_MESSAGE), 0);

						// Replace it with new one
						nDummy=ComboBox_InsertString(GETHCTL(
							IDC_APLOT_MESSAGE), 0, sAPlot.message_str);
					}
					else // Add noise message
					{
						// Store noise message
						nDummy=ComboBox_InsertString(GETHCTL(
							IDC_APLOT_MESSAGE), 0, sAPlot.message_str);
					}
				}

				// Display the (possibly changed) message
				SetWindowText(GETHCTL(IDC_APLOT_MESSAGE),
					sAPlot.message_str);
			}
			else // Too few data points for noise ID
			{
				// Is previous message a noise type?
				if( ((strcmp(szMsg, "White PM:"))==0) ||
					((strcmp(szMsg, "Flicker P"))==0) ||
					((strcmp(szMsg, "White FM:"))==0) ||
					((strcmp(szMsg, "Flicker F"))==0) ||
					((strcmp(szMsg, "Random Wa"))==0) ||
					((strcmp(szMsg, "Estimated"))==0) )
				{
					// Clear the noise message
					strlcpy(sAPlot.message_str, "", MESSAGESIZE);
					SetWindowText(GETHCTL(IDC_APLOT_MESSAGE),
						sAPlot.message_str);
				}
			}

			// This code produces autocorrelation plot automatically
			// It is used only by the F11 function key run command
			// which sets this flag
			if(bAutoACFPlot)
			{
				// Automatically produce ACF plot
				SendMessage(hDlg, WM_COMMAND,
					GET_WM_COMMAND_MPS(IDC_APLOT_PLOT, NULL, 0));

				// Turn off auto ACF plot flag
				// Have to turn on this flag each time it is used
				bAutoACFPlot=FALSE;
			}

			return TRUE;
		}

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg,
						"Stable32.chm::AUTOCORRELATION_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::AUTOCORRELATION_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "AUTOCORRELATION_FUNCTION");
					#endif
				}
				break;

				// Detect parameter changes
				// Title change
				case IDC_APLOT_TITLE:
				{
					// Respond to focus lost
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_KILLFOCUS)
					{
						GetWindowText(GETHCTL(IDC_APLOT_TITLE),
						sAPlot.title, TITLESIZE-1);

						// Redisplay title - perhaps shortened
						SetWindowText(GETHCTL(IDC_APLOT_TITLE),
							sAPlot.title);

						// Put new string into list
						// Don't store string if it is same as before
						if(ComboBox_FindString(GETHCTL(IDC_APLOT_TITLE),
							-1, sAPlot.title)==CB_ERR)
						{
							// Don't store blank title either
							if(strlen(sAPlot.title))
							{
								nDummy=ComboBox_InsertString(GETHCTL(
									IDC_APLOT_TITLE), 0, sAPlot.title);
							}
						}
					}
				}
				break;

				// Subtitle change
				case IDC_APLOT_SUBTITLE:
				{
					// Respond to focus lost
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_KILLFOCUS)
					{
						GetWindowText(GETHCTL(IDC_APLOT_SUBTITLE),
						sAPlot.subtitle, SUBTITLESIZE-1);

						// Redisplay subtitle - perhaps shortened
						SetWindowText(GETHCTL(IDC_APLOT_SUBTITLE),
							sAPlot.subtitle);

						// Put new string into list
						// Don't store string if it is same as before
						if(ComboBox_FindString(GETHCTL(IDC_APLOT_SUBTITLE),
							-1, sAPlot.subtitle)==CB_ERR)
						{
							// Don't store blank subtitle either
							if(strlen(sAPlot.subtitle))
							{
								nDummy=ComboBox_InsertString(GETHCTL(
									IDC_APLOT_SUBTITLE), 0, sAPlot.subtitle);
							}
						}
					}
				}
				break;

				// Message change
				case IDC_APLOT_MESSAGE:
				{
					// Respond to focus lost
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_KILLFOCUS)
					{
						GetWindowText(GETHCTL(IDC_APLOT_MESSAGE),
						sAPlot.message_str, MESSAGESIZE-1);

						// Redisplay message - perhaps shortened
						SetWindowText(GETHCTL(IDC_APLOT_MESSAGE),
							sAPlot.message_str);

						// Put new string into list
						// Don't store string if it is same as before
						if(ComboBox_FindString(GETHCTL(IDC_APLOT_MESSAGE),
							-1, sAPlot.message_str)==CB_ERR)
						{
							// Don't store blank message either
							if(strlen(sAPlot.message_str))
							{
								nDummy=ComboBox_InsertString(GETHCTL(
									IDC_APLOT_MESSAGE),0,sAPlot.message_str);
							}
						}
					}
				}
				break;

				// Plot Filename change
				case IDC_APLOT_FILENAME:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_APLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// The default *.TKF filename includes full drive/path
						// where program started to avoid writing to floppy
						// or non-writable media.  The edit window AutoHScrolls
						GetWindowText(GETHCTL(IDC_APLOT_FILENAME),
							szTempFile, FILENAMESIZE-1);

						// Validate new filename
						if(CheckFilename(szTempFile, szTempTitle, szTempPath,
							szTempName, szTempExt, hDlg,
							"Spectrum Plot Filename"))
						{
							// Filename OK
							strlcpy(sAPlot.plot_filename, szTempFile,
								FILENAMESIZE);

							// Redisplay the new filename
							SetWindowText(GETHCTL(IDC_APLOT_FILENAME),
								szTempFile);
						}
						else // Filename NG
						{
							// Restore original filename
							SetWindowText(GETHCTL(IDC_APLOT_FILENAME),
								sAPlot.plot_filename);
							SetFocus(GETHCTL(IDC_APLOT_FILENAME));
							break;
						}
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Autocorrrelation data filename change
				case IDC_APLOT_AUTOFILE:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_APLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// The default data filename includes full drive/path
						// where program started.  The edit window AutoHScrolls.
						GetWindowText(GETHCTL(IDC_APLOT_AUTOFILE),
							szTempFile, FILENAMESIZE-1);

						// Validate new filename
						if(CheckFilename(szTempFile, szTempTitle, szTempPath,
							szTempName, szTempExt, hDlg,
							"Autocorrelation Data Filename"))
						{
							// Filename OK
							strlcpy(szAutoFile, szTempFile, FILE_NAME_SIZE);

							// Redisplay the new filename
							SetWindowText(GETHCTL(IDC_APLOT_AUTOFILE),
								szTempFile);
						}
						else // Filename NG
						{
							// Restore original filename
							SetWindowText(GETHCTL(IDC_APLOT_AUTOFILE),
								szAutoFile);
							SetFocus(GETHCTL(IDC_APLOT_AUTOFILE));
							break;
						}
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Position change
				case IDC_APLOT_POSITION:
				{
					sAPlot.position=
						ComboBox_GetCurSel(GETHCTL(IDC_APLOT_POSITION));
				}
				break;

				// Date flag change
				case IDC_APLOT_DATE:
				{
					sAPlot.do_date=Button_GetCheck(GETHCTL(IDC_APLOT_DATE));
				}
				break;

				// Box flag change
				case IDC_APLOT_BOX:
				{
					sAPlot.do_box=Button_GetCheck(GETHCTL(IDC_APLOT_BOX));
				}
				break;

				// Cursor flag change
				case IDC_APLOT_CURSOR:
				{
					sAPlot.do_mouse=
						Button_GetCheck(GETHCTL(IDC_APLOT_CURSOR));
				}
				break;

				// Lag1 flag change
				case IDC_APLOT_LAG1:
				{
					sAPlot.do_table=
						Button_GetCheck(GETHCTL(IDC_APLOT_LAG1));
				}
				break;

				// Wide flag change
				case IDC_APLOT_WIDE:
				{
					sAPlot.do_wide=
						Button_GetCheck(GETHCTL(IDC_APLOT_WIDE));
				}
				break;

				// All button
				case IDC_APLOT_ALL:
				{
					// Recalc max # lags allowed
					if(bMethod)
					{
						nTest=nData/(2*nAF);
					}
					else
					{
						nTest=nData/nAF;
					}

					// Put max # lag points into info text
					_snprintf(szBuffer, sizeof(szBuffer), "of %d", nTest);
					SetWindowText(GETHCTL(IDC_APLOT_INFO), szBuffer);

					// Refresh # points
					_snprintf(szBuffer, sizeof(szBuffer), "%d", nTest);
					SetWindowText(GETHCTL(IDC_APLOT_POINTS), szBuffer);
					nPoints=nTest;
					sAPlot.num=nPoints;
				}
				break;

				// Read config button
				case IDC_APLOT_READ:
				{
					bSave=bUseAutoPlotIni;
					bUseAutoPlotIni=TRUE;
					ReadIni(INI_AUTO);

					// Save # lags - INITDIALOG changes it to max
					nEntry=sAPlot.num;
					
					// Use af from ini file
					nAF=sAPlot.af;

					bUseAutoPlotIni=bSave;
					SendMessage(hDlg, WM_INITDIALOG, (WPARAM)0, (LPARAM)0);

					// Load the # lags
					sAPlot.num=nEntry;
					_snprintf(szBuffer, sizeof(szBuffer), "%d", nEntry);
					SetWindowText(GETHCTL(IDC_APLOT_POINTS), szBuffer);
				}
				break;

				// Save config button
				case IDC_APLOT_WRITE:
				{
					bSave=bUseAutoPlotIni;
					bUseAutoPlotIni=TRUE;
					WriteIni(INI_AUTO);
					bUseAutoPlotIni=bSave;
				}
				break;

				// Zero flag change - note that this uses do_line flag
				case IDC_APLOT_ZERO:
				{
					sAPlot.do_line=Button_GetCheck(GETHCTL(IDC_APLOT_ZERO));
				}
				break;

				// Respond to avg factor edit control message
				case IDC_APLOT_AF:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) && (GetFocus()!=GETHCTL(IDC_AVG_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get (new) avg factor
						GetWindowText(GETHCTL(IDC_APLOT_AF), szBuffer,
							BUFFER_SIZE);
						nEntry=abs(atoi(szBuffer));

						// Check entry - must be between 1 and nData/2
						if(ValidateInteger(hDlg, nEntry, 1, nData/2)==TRUE)
						{
							// New value OK
							nAF=nEntry;
							sAPlot.af=nAF;
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nAF);
							SetWindowText(GETHCTL(IDC_APLOT_AF), szBuffer);
						}
						else
						{
							// Invalid entry - restore default value
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nAF);
							SetWindowText(GETHCTL(IDC_APLOT_AF), szBuffer);
							SetFocus(GETHCTL(IDC_APLOT_AF));
						}

						// Redisplay tau
						_snprintf(szBuffer, sizeof(szBuffer), "%11.5e",
							fTau*nAF);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_APLOT_TAU), szBuffer);

						// Recalc max # lags allowed
						if(bMethod)
						{
							nTest=nData/(2*nAF);
						}
						else
						{
							nTest=nData/nAF;
						}

						// Put max # lag points into info text
						_snprintf(szBuffer, sizeof(szBuffer), "of %d", nTest);
						SetWindowText(GETHCTL(IDC_APLOT_INFO), szBuffer);

						// Refresh # points
						_snprintf(szBuffer, sizeof(szBuffer), "%d", nTest);
						SetWindowText(GETHCTL(IDC_APLOT_POINTS), szBuffer);
						nPoints=nTest;
						sAPlot.num=nPoints;

						// Set message string to force update
						strlcpy(szMsg, "White FM:", BUFFER_SIZE);

						// Reinitialize
						SendMessage(hDlg, WM_INITDIALOG, (WPARAM)0, (LPARAM)0);
					}
                    else
                    {
                        // Reset error flag
                        bErrorTrap=FALSE;
                    }
                }
                break;

				// # lag points change:
				case IDC_APLOT_POINTS:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_APLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get # points entry
						GetWindowText(GETHCTL(IDC_APLOT_POINTS),
							(LPSTR)szBuffer, BUFFER_SIZE);
						nEntry=atoi(szBuffer);
						
						// Valudate entry
						// Must be between 3 and nData for direct method
						// and nData/2 for FFT method
						if(bMethod)
						{
							nTest=nData/2;
						}
						else
						{
							nTest=nData;
						}

						if(ValidateInteger(hDlg, nEntry, 3, nTest)==TRUE)
						{
							// Valid entry
							nPoints=nEntry;
						}
						else
						{
							// Invalid entry - ignore new value
							SetFocus(GETHCTL(IDC_APLOT_POINTS));
						}

						// Redisplay # points
						_snprintf(szBuffer, sizeof(szBuffer), "%d", nPoints);
						SetWindowText(GETHCTL(IDC_APLOT_POINTS),
							szBuffer);

						// Put # points into plot struct
						sAPlot.num=nPoints;
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Lag # change:
				case IDC_APLOT_LAGNUM:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_APLOT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get lag # entry
						GetWindowText(GETHCTL(IDC_APLOT_LAGNUM),
							(LPSTR)szBuffer, BUFFER_SIZE);
						nEntry=atoi(szBuffer);
						
						// Valudate entry
						// Must be between 1 and nData-1 for direct method
						// and (nData/2)-1 for FFT method
						if(bMethod)
						{
							nTest=nData/2;
						}
						else
						{
							nTest=nData;
						}

						if(ValidateInteger(hDlg, nEntry, 1, nTest-1)==TRUE)
						{
							// Valid entry
							sAPlot.win=nEntry;
						}
						else
						{
							// Invalid entry - ignore new value
							SetFocus(GETHCTL(IDC_APLOT_LAGNUM));
						}

						// Redisplay lag #
						_snprintf(szBuffer, sizeof(szBuffer), "%d",
							sAPlot.win);
						SetWindowText(GETHCTL(IDC_APLOT_LAGNUM),
							szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Respond to CR in an edit control
				// Note: No button is a DEFPUSHBUTTON
				case IDOK:
				{
					// The HWND returned by GetFocus() is not the same as the
					// one returned by GetDlgItem(), so the uTitle, etc
					// variables are used in these tests
					if((UINT)GetFocus()==uTitle)
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_APLOT_TITLE, NULL, CBN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to SUBTITLE edit control
					if((UINT)GetFocus()==uSubtitle)
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_APLOT_SUBTITLE, NULL, CBN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to MESSAGE edit control
					if((UINT)GetFocus()==uMessage)
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_APLOT_MESSAGE, NULL, CBN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to FILENAME edit control
					if(GetFocus()==GETHCTL(IDC_APLOT_FILENAME))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_APLOT_FILENAME, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to AUTOFILE edit control
					if(GetFocus()==GETHCTL(IDC_APLOT_AUTOFILE))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_APLOT_AUTOFILE, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to # points edit control
					if(GetFocus()==GETHCTL(IDC_APLOT_POINTS))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_APLOT_POINTS, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to avg factor edit control
					if(GetFocus()==GETHCTL(IDC_APLOT_AF))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_APLOT_AF, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to lag # edit control
					if(GetFocus()==GETHCTL(IDC_APLOT_LAGNUM))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_APLOT_LAGNUM, NULL, EN_KILLFOCUS));
					}
				}
				break;

				// Respond to plot button
				case IDC_APLOT_PLOT:
				{
					// Allocate memory to save original data
					// Get size
					nNum=(int)fData[0];

					// Allocate memory
					if((fTempData=
						(F_TYPE*)malloc((nNum+ARRAY_OFFSET+EXTRA_MEM)*
						sizeof(F_TYPE)))==NULL)
					{
						// Display error message
						AllocErrorMessage();

						// Close dialog box
						EndDialog (hDlg, 0);
					}
					else
					{
						// Save data
						for(i=0; i<nNum+ARRAY_OFFSET; i++)
						{
							fTempData[i]=fData[i];
						}
					}

					// Set line thickness
					if(sAPlot.do_wide)
					{
						sAPlot.thick=WIDELINESIZE;
					}
					else
					{
						sAPlot.thick=0;
					}	

					if(!bMethod) // Direct method
					{
						// Allocate memory for autocorrelation points
						if((fAuto=(float*)
							malloc((nData)*sizeof(float)))==NULL)
						{
							// Nothing useful can be done, so announce error
							// and post a messgae to close dialog box
							AllocErrorMessage();
							PostMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDCANCEL, NULL, 0));
							return TRUE;
						}
					}
					else // FFT method
					{
						// Determine size of zero-padded integer power of 2
						// autocorrelation results array size
						n2=(int)pow(2.0, (double)ceil(log(nData)/log(2)));

						// Allocate memory for autocorrelation points
						if((fAuto=(float*)
							malloc(((2*n2)+1)*sizeof(float)))==NULL)
						{
							// Nothing useful can be done, so announce error
							// and post a messgae to close dialog box
							AllocErrorMessage();
							PostMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDCANCEL, NULL, 0));
							return TRUE;
						}
					}					
					// Display wait cursor
					SetCursor(hWait);

					// Calc autocorrelation
					// Cannot reduce analysis end because shorter max lag 
					if(bDataType==FREQ_DATA)
					{
						// Calc autocorrelation
						AutocorrelationCalc(fFreqData, fAuto, nPoints, nAF,
							FREQ_DATA, bMethod, bZero);
					}
					else // Phase data
					{
						// Calc autocorrelation
						AutocorrelationCalc(fPhaseData, fAuto, nPoints, nAF,
							PHASE_DATA, bMethod, bZero);
					}

					// Save autocorrelation data
					AutoWrite(szAutoFile, fAuto, nPoints);

					// Display lag 1 autocorrelation
					_snprintf(szBuffer, sizeof(szBuffer), "%1.3f", fAuto[1]);
					SetWindowText(GETHCTL(IDC_APLOT_R1), szBuffer);

					// Report power law noise type based on lag 1 value
					// Thresholds are adaptive to # analysis points
					// by using expression of form a+b*ln(N)
					// a=0.1 for W-F boundary, 0.6 for F-RW boundary
					// b=0.05 for both
					// e.g. Parallel curves vs. log N separated by 0.5
					// F-RW boundary value limited to 0.998
					// Nominal acf values for W PM=-0.5 & F PM=-0.33
					// are independent of N

					// Get the current message string
					strlcpy(szMsg, sAPlot.message_str, BUFFER_SIZE);

					// Truncate it to 9 characters (e.g. "White FM:")
					szMsg[9]='\0';

					// Use Greenhall noise ID method
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_APLOT_NOISEID, NULL, 0));
				
					// Display lag 1 autocorrelation
					_snprintf(szBuffer, sizeof(szBuffer), "%1.3f", fR1);
					SetWindowText(GETHCTL(IDC_APLOT_R1), szBuffer);

					// Don't ID noise if don't have at least 30 analysis points
					if(nData/nAF>=30)
					{
						switch(nAlpha) 
						{
							case -4: // RR FM
							{
								strlcpy(szBuffer, "Random Run FM: ",
									sizeof(szBuffer));
							}
							break;

							case -3: // FW FM
							{
								strlcpy(szBuffer, "Flicker Walk FM: ",
									sizeof(szBuffer));
							}
							break;

							case -2: // RW FM
							{
								strlcpy(szBuffer, "Random Walk FM: ",
									sizeof(szBuffer));
							}
							break;

							case -1: // F FM
							{
								strlcpy(szBuffer, "Flicker FM: ",
									sizeof(szBuffer));
							}
							break;

							case -0: // W FM
							{
								strlcpy(szBuffer, "White FM: ",
									sizeof(szBuffer));
							}
							break;

							case 1: // F PM
							{
								strlcpy(szBuffer, "Flicker PM: ",
									sizeof(szBuffer));
							}
							break;

							case 2: // W PM
							{
								strlcpy(szBuffer, "White PM: ",
									sizeof(szBuffer));
							}
							break;

							default: // Noise out of normal range
							{
								_snprintf(szBuffer, sizeof(szBuffer), "",
									sizeof(szBuffer));
							}
						}

						// Show estimated alpha
						_snprintf(szText, sizeof(szText),
							"Estimated alpha=%+1.2f", fAlpha);
						strlcat(szBuffer, szText, sizeof(szBuffer));

						// Use noise type as message if user hasn't entered one
						if((strlen(sAPlot.message_str))==0)
						{
							strlcpy(sAPlot.message_str, szBuffer, MESSAGESIZE);
						}

						// Or if previous message is a noise type
						if( ((strcmp(szMsg, "White PM:"))==0) ||
							((strcmp(szMsg, "Flicker P"))==0) ||
							((strcmp(szMsg, "White FM:"))==0) ||
							((strcmp(szMsg, "Flicker F"))==0) ||
							((strcmp(szMsg, "Random Wa"))==0) ||
							((strcmp(szMsg, "Estimated"))==0) )
						{
							// Store message
							strlcpy(sAPlot.message_str, szBuffer, MESSAGESIZE);

							// Set noise message flag
							bNoiseMsg=TRUE;
						}
						else
						{
							// Reset noise message flag
							bNoiseMsg=FALSE;
						}

						// Put noise type string into message list
						// Don't store again if already in list
						if(ComboBox_FindString(GETHCTL(IDC_APLOT_MESSAGE),
							-1, szBuffer)==CB_ERR)
						{
							if(bNoiseMsg) // Replace noise message
							{
								// Delete current noise message
								nDummy=ComboBox_DeleteString(GETHCTL(
									IDC_APLOT_MESSAGE), 0);

								// Replace it with new one
								nDummy=ComboBox_InsertString(GETHCTL(
									IDC_APLOT_MESSAGE), 0, sAPlot.message_str);
							}
							else // Add noise message
							{
								// Store noise message
								nDummy=ComboBox_InsertString(GETHCTL(
									IDC_APLOT_MESSAGE), 0, sAPlot.message_str);
							}
						}

						// Display the (possibly changed) message
						SetWindowText(GETHCTL(IDC_APLOT_MESSAGE),
							sAPlot.message_str);
					}
					else // Too few data points for noise ID
					{
						// Is previous message a noise type?
						if( ((strcmp(szMsg, "White PM:"))==0) ||
							((strcmp(szMsg, "Flicker P"))==0) ||
							((strcmp(szMsg, "White FM:"))==0) ||
							((strcmp(szMsg, "Flicker F"))==0) ||
							((strcmp(szMsg, "Random Wa"))==0) ||
							((strcmp(szMsg, "Estimated"))==0) )
						{
							// Clear the noise message
							strlcpy(sAPlot.message_str, "", MESSAGESIZE);
							SetWindowText(GETHCTL(IDC_APLOT_MESSAGE),
								sAPlot.message_str);
						}
					}

					// Display normal cursor
					SetCursor(hArrow);

					// Set plot type
					nPlotType=AUTO_PLOT;

					// Create child window for plot
					GPCWINCreate(hChildWnd, hInst, hDlg, SW_SHOWNORMAL,
						&hChildAccel, NULL);

					// This insures that plot is done before continuing here
					YieldControl();

					// Restore original data
					for(i=0; i<nNum+ARRAY_OFFSET; i++)
					{
						fData[i]=fTempData[i];
					}
					
					// Free temporary data mamory
					free(fTempData);

					// Free autocorrelation data memory
					free(fAuto);

					// Put info into log file
					strlcpy(szBuffer, "ACF File=", sizeof(szBuffer));
					strlcat(szBuffer, szAutoFile, sizeof(szBuffer));
					WriteLog(70, szBuffer);
				}
				break;

				// Internal noise ID subroutine
				case IDC_APLOT_NOISEID:
				{
					// Restore original data
					for(i=0; i<nNum+ARRAY_OFFSET; i++)
					{
						fData[i]=fTempData[i];
					}

					// Call ACF noise ID function
					// No sigma type applies, so use dmax=3
					// Has additional 2nd arg
					ACFNoiseID(fData, bDataType, nAF, &fR1, &fAlpha, &nAlpha,
						3, 0);
				}
				break;

				// Respond to scatter button
				case IDC_APLOT_SCATTER:
				{
					// Check for zero range
					FindMinMax(fData, &fMin, &fMax, bDataType);
					if(fMax==fMin)
					{
						ZeroRangeMessage();
						break;
					}

					// Check for too small plot range
					CalcMean(fData, &fAvg, bDataType);

					if( (fAvg) && ((fabs((fMax-fMin)/fAvg))<1e-3) )
					{
						// Must normalize plot data
						MustNormalizeMessage();

						#if(1) // Trail code 07/14/10
						// The usual response to the must normalize message
						// is to open the normalize dialog
						// so why not do it automatically?
						// One can always cancel it (and the plot)
						// Open dialog box
						InvokeDialogBox(hInst, "NormBox", hDlg,
							(DLGPROC)NormDlgProc);

						// Refresh status plots
						SendMessage(hwndMain, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_REFRESH, 0, 0));
						#endif

						break;
					}

					// Allocate memory to save original data
					// Get size
					nNum=(int)fData[0];

					// Allocate memory
					if((fTempData=
						(F_TYPE*)malloc((nNum+ARRAY_OFFSET+EXTRA_MEM)*
						sizeof(F_TYPE)))==NULL)
					{
						// Display error message
						AllocErrorMessage();

						// Close dialog box
						EndDialog (hDlg, 0);
					}
					else
					{
						// Save data
						for(i=0; i<nNum+ARRAY_OFFSET; i++)
						{
							fTempData[i]=fData[i];
						}
					}

					// Fill Gaps
				    FillGaps(fData, bDataType);

					// Average data
					if(bDataType==FREQ_DATA)
					{
						AverageFreqData(fData, nAF);
						sFPlot.y_avg=(float)fAvg;
					}
					else // Phase data
					{
						AveragePhaseData(fData, nAF);
						sPPlot.y_avg=(float)fAvg;
					}

					// Set plot type
					nPlotType=SCATTER_PLOT;

					// Set lag scatter plot scale
					if(bDataType==FREQ_DATA)
					{

						// Use call to InitFreqPlotParams(0)
						// to get a nice scale
						// for freq data in sFPlot structure
						// for lag scatter plot
						// to use to set its freq scale
						InitFreqPlotParams(0);
					}
					else // Phase data
					{
						// Ditto for phase data
						InitPhasePlotParams(0);
					}

					// Create child window for plot
					GPCWINCreate(hChildWnd, hInst, hDlg, SW_SHOWNORMAL,
						&hChildAccel, NULL);

					// This insures that plot is done before continuing here
					YieldControl();

					// Restore original data
					for(i=0; i<nNum+ARRAY_OFFSET; i++)
					{
						fData[i]=fTempData[i];
					}
					
					// Free temporary data mamory
					free(fTempData);
				}
				break;

				// Reset all plot params to defaults
				case IDC_APLOT_RESET:
				{
					// Set initialization flag
					bFirstTime=TRUE;

					// Put message into PSD & scale max & min displays
					SetWindowText(GETHCTL(IDC_APLOT_DATAMAX), "Press Plot");
					SetWindowText(GETHCTL(IDC_APLOT_DATAMIN), "To Calc");
					SetWindowText(GETHCTL(IDC_APLOT_YMAX), "");
					SetWindowText(GETHCTL(IDC_APLOT_YMIN), "");
					SetWindowText(GETHCTL(IDC_APLOT_YTIC), "");

					// Set # y-axis scale tics to zero as code to calc scale
					sAPlot.y_tic=0;

					// Set y-axis scale values to zero as code to calc scale
					sAPlot.y_min=0.0;
					sAPlot.y_max=0.0;

					// Do initialization
					nAvg=1;
					bSave=bUseSpectPlotIni;
					bUseSpectPlotIni=FALSE;
					SendMessage(hDlg, WM_INITDIALOG, (WPARAM)0, (LPARAM)0);
					bUseSpectPlotIni=bSave;

					// Disable y scale boxes so crazy values can't be entered
					EnableWindow(GETHCTL(IDC_APLOT_YMAX), FALSE);
					EnableWindow(GETHCTL(IDC_APLOT_YMIN), FALSE);
					EnableWindow(GETHCTL(IDC_APLOT_YTIC), FALSE);
				}
				break;

				// Respond to esc key or close button
				case IDCANCEL:
				case IDC_APLOT_CANCEL:
				{
					// Save # user-entered title strings
					nUserTitles=ComboBox_GetCount(GETHCTL(IDC_APLOT_TITLE))
						-NUM_APLOT_TITLES;

					// Limit # user titles
					nUserTitles=min(nUserTitles, NUM_TITLES);

					// Save user titles
					if(nUserTitles)
					{
						for(i=0; i<nUserTitles; i++)
						{
							// Get size of title string
							nLength=ComboBox_GetLBTextLen(GETHCTL(
								IDC_APLOT_TITLE), i);

							// Realloc title array
							if((szPlotTitle[i]=
								(LPSTR)realloc(szPlotTitle[i],
								(nLength+1)*sizeof(char)))==NULL)
							{
								// Just dsp err msg & skip saving string
								// We are closing dlg box anyway
								AllocErrorMessage();
							}
							else
							{
								// Save title string
								nDummy=
									ComboBox_GetLBText(GETHCTL(
									IDC_APLOT_TITLE),
									i, szPlotTitle[i]);
							}
						}
					}

					// Save # user-entered subtitle strings
					nUserSubtitles=
						ComboBox_GetCount(GETHCTL(IDC_APLOT_SUBTITLE))-
						NUM_APLOT_SUBTITLES;

					// Limit # user subtitles
					nUserSubtitles=min(nUserSubtitles, NUM_SUBTITLES);

					// Save user subtitles
					if(nUserSubtitles)
					{
						for(i=0; i<nUserSubtitles; i++)
						{
							// Get size of subtitle string
							nLength=ComboBox_GetLBTextLen(GETHCTL(
								IDC_APLOT_SUBTITLE), i);

							// Realloc subtitle array
							if((szPlotSubtitle[i]=
								(LPSTR)realloc(szPlotSubtitle[i],
								(nLength+1)*sizeof(char)))==NULL)
							{
								// Just dsp err msg & skip saving string
								// We are closing dlg box anyway
								AllocErrorMessage();
							}
							else
							{
								// Save subtitle string
								nDummy=ComboBox_GetLBText(GETHCTL(
									IDC_APLOT_SUBTITLE), i, szPlotSubtitle[i]);
							}
						}
					}

					// Save # user-entered message strings
					nUserMessages=
						ComboBox_GetCount(GETHCTL(IDC_APLOT_MESSAGE))-
						NUM_APLOT_MESSAGES;

					// Limit # user messages
					nUserMessages=min(nUserMessages, NUM_MESSAGES);

					// Save user messages
					if(nUserMessages)
					{
						for(i=0; i<nUserMessages; i++)
						{
							// Get size of messsage string
							nLength=ComboBox_GetLBTextLen(GETHCTL(
								IDC_APLOT_MESSAGE), i);

							// Realloc message array
							if((szPlotMessage[i]=
								(LPSTR)realloc(szPlotMessage[i],
								(nLength+1)*sizeof(char)))==NULL)
							{
								// Just dsp err msg & skip saving string
								// We are closing dlg box anyway
								AllocErrorMessage();
							}
							else
							{
								// Save message string
								nDummy=ComboBox_GetLBText(GETHCTL(
									IDC_APLOT_MESSAGE), i, szPlotMessage[i]);
							}
						}
					}

					// Free array
					free(fFreq);

					// Set dead pointer to null so subsequent realloc is OK
					fFreq=0;

					// Close dialog box
					EndDialog (hDlg, 0);
				}
				return TRUE;
			}
		}
		break;
	 }
	 return FALSE;
}

/*****************************************************************************/
#endif

/*****************************************************************************/
/*                                                                           */
/*               Dynamic Stability Plot Dialog Procedure                     */
/*                                                                           */
/*      References:                                                          */
/*				1.  L. Galleani and P. Tavella, "The Characterization of     */
/*					Clock Behavior with the Dynamic Allan Variance",         */
/*					Proc. 2003 Joint FCS/EFTF Meeting, pp. 239-244.          */
/*				2.	L. Galleani and P. Tavella, "Tracking Nonstationarities  */
/*					in Clock Noises Using the Dynamic Allan Variance",       */
/*					2005 Joint FCS/PTTI Meeting.                             */
/*              3.  L. Galleani and P. Tavella, "Dynamic Allan Variance",    */
/*                  http://www.ien.it/tf/clock_behavior.shtml.               */
/*              4.  L. Galleani and P. Tavella, "DAVAR.zip", MatLAB m-code   */
/*                  for dynamic Allan variance.                              */
/*                                                                           */
/*      This function closely follows the DAVAR implementation of the        */
/*      referenced papers and associated MatLAB code.  It also includes the  */
/*      Hadamard variance, and its dynamic stability plot has some           */
/*      differences due to the GraphiC 3D plotting functions (in particular, */
/*		the lack of log scales for the 3D sufface plotting routines).        */
/*                                                                           */
/* 		Revision record:                                                     */
/*			11/12/05	Adapted from AutocorrelationPlotDlgProc()            */
/*          11/16/05	Pretty much done, but not activated in release 1.45  */
/*			11/19/05	Activated in release 1.46 now under development      */
/*			11/29/05	Added colors checkbox                                */
/*			11/30/05	Added color surface plot grid control                */
/*			12/26/06	Added provisions for adjustable viewpoint            */
/*			12/27/06	Changed sigma calcs to treat all zeros as gaps       */
/*						Added code to show gaps in stability data            */
/*			12/28/06	Fixed problem with DAVAR plot with large data sets   */
/*						Added bCalc flag to allow fast replotting            */
/*			12/29/06	Fixed problem with memory allocation for freq data   */
/*			12/30/06	Fixed problem at large AFs with for large data sets  */
/*						Added "many tau" calc speedup                        */
/*						Added reverse checkbox                               */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK DynamicStabilityDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
#include "missings.h"
	
	// Local function prototypes
	int WINAPI CalcDynamicPhaseOverlapSigma(F_TYPE x[],
		F_TYPE *p_sig, F_TYPE tau, int m);
	int WINAPI CalcDynamicPhaseOverlapHadamardDev(F_TYPE x[],
		F_TYPE *p_dev, F_TYPE tau, int m);
	
	// Local macros
	#define	STOP_RATIO 4	// Sets max AF=# Analysis Points/STOP_RATIO
							// Stable32 uses 4 for overlapping AVAR & HVAR
							// Tavella paper uses 3
	// Local variables
	// Handles
	static HWND hChildWnd=NULL;
	static HANDLE hChildAccel=NULL;

	// Chars
	static char szBuffer[BUFFER_SIZE+1]; 		// Text buffer

	// Temporary filename buffers
	static char szTempFile[FILENAMESIZE+1];		// Temp full filename buffer
	static char szTempTitle[FILENAMESIZE+1];	// Temp file title buffer
	static char szTempPath[FILENAMESIZE+1];		// Temp file path buffer
	static char szTempName[FILENAMESIZE+1];		// Temp file name buffer
	static char szTempExt[BUFFER_SIZE+1];		// Temp file extension buffer

	// Unsigned Ints
	static unsigned uTitle;			// HWND of Title combo control
	static unsigned uSubtitle;	  	// HWND of Subtitle combo control
	static unsigned uMessage;	  	// HWND of Message combo control

	// Ints
	static int nAll;				// Total # data points (phase or freq
									// depending on data type)
	static int nStart;				// Analysis start point
	static int nEnd;				// Analysis end point
	static int nAnalysis;			// # analysis points (what DAVAR uses)
	static nWindowSize;				// Analysis window size (# points)
	static nStepSize;				// Step increment that window is moved
	static nNumWindows;				// # analysis windows
	static nStabPoints;				// # stability calc points
	static int nAF;					// Averaging factor
	static int i;					// Outer idex
	static int j;					// Inner index
	static int nLength;				// String length
	static int ret;					// Function return value
	static int nPrevLogAF;			// Previous log AF value

	// Words
	static DWORD dwPos;				// Trackbar slider position

	// zmat variables
	static int k;
	static int xsize;
	static int ysize;
	static int prev_OK;
	static int next_OK;
	static int gap;

	// BOOLs
	static BOOL bErrorTrap=FALSE;   // Flag for entry error
	static BOOL bFirstTime=TRUE;    // Flag for initial opening
	static BOOL bNorm=FALSE;		// Flag to normalize data
	static BOOL bMustNorm=FALSE;	// Flag that normalization is required
	static BOOL bAllocError=FALSE;  // Flag for memory allocation error
	static BOOL bAVAR=TRUE;			// Flag for variance type (0=HVAR, 1=AVAR)
	static BOOL bAlloc=FALSE;		// Flag that working memory was allocated
	static BOOL bAbort=FALSE;		// Flag to abort calc
	static BOOL bCalc=TRUE;			// Flag that new calc is needed
	static BOOL bReverse=FALSE;		// Flag to reverse plot
	static BOOL bSave;				// BOOL to save state of ini flag

	// Floats
	static float fSigMin;			// Minimum sigma
	static float fSigMax;			// Maximum sigma

	// F_TYPEs
	static F_TYPE *fWorkData;       // Working data array
	static F_TYPE fMin;             // Min data value
	static F_TYPE fMax;             // Max data value
	static F_TYPE fAvg;				// Mean value of data
	static F_TYPE fSig;				// Sigma value (AVAR or HAVR)
	static F_TYPE fTau0;			// Measurement tau
	static F_TYPE fPhase0;			// Phase data original # data points 
	static F_TYPE fPhase1;			// Phase data original analysis start 
	static F_TYPE fPhase2;			// Phase data original analysis end 
	static F_TYPE fFreq0;			// Freq data original # data points
	static F_TYPE fFreq1;			// Freq data original analysis start
	static F_TYPE fFreq2;			// Freq data original analysis end

	// Other variables
	static MSG msg;					// Msg struct for yielding control
	static FILE *fXYZ;				// File pointer

	#if(0) // Debugging variables
	float mmin;
	float mmax;
	#endif
	
	// Note: The dynamic stability plot struct, sDPlot is defined globally

	// Put plot dialog box handle into global
	hPlotBox=hDlg;

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Save dialog box handle as global
			hDialog=hDlg;

			// Get size of phase ot frequency data array
			// DAVAR analyzes phase or frequency data between analysis limits
			// Analysis limits are changed during calc, and are restored
			// to these values after calc done
			if(bDataType==FREQ_DATA) // Frequency data
			{
				// Initialize sizes
				nAll=(int)fFreqData[0];		// Total # data points
				nStart=(int)fFreqData[1];	// Analysis start point (all=1)
				nEnd=(int)fFreqData[2];		// Analysis end point (all=nAll)
				nAnalysis=nEnd-nStart+1;	// # analy points (what DAVAR uses)
			}
			else // Phase data
			{
				// Initialize sizes
				nAll=(int)fPhaseData[0];	// Total # data points
				nStart=(int)fPhaseData[1];	// Analysis start point (all=1)
				nEnd=(int)fPhaseData[2];	// Analysis end point (all=nAll)
				nAnalysis=nEnd-nStart+1;	// # analy points (what DAVAR uses)
			}

			// Note that nAll is total # of phase or frequency data points
			// of original data type.  If have freq data that is converted to
			// phase data, then nAll for the phase datais 1 more

			// Check that data size minimum is met
			// Note: This test could be moved to WinMain()
			// where this dialog box is called

			// Then set defaults
			// DAVAR uses a sliding analysis window of size nWindowSize
			// The window is moved in nWindows increments of nStepSize
			// The selected data set and analysis limits determine nAnalysis
			// The user chooses the nWindowSize and nStepSize
			// This determines the nNumWindows according to the expression:
			// nNumWindows = (nAnalysis-(nWindowSize-nStepSize))/nStepSize
			// e.g for nAnalysis=1000 & nWindowSize=100, an nStepSize=10 would
			// result in nNumWindows=91
			// The minimum nNumWindows is 1, and the maximum is 100
			// The min nWindowSize is 4, the default is (int)(nAnalysis/10)
			// for large nAnalysis
			// The minimum nStep is 1 and the maximum nStep is nWindowSize
			// The default nStep is nWindowSize/10 for large nAnalysis
			// The min nAnalysis is 4; for nAnalysis<40 the default nWindowSize
			// is nAnalysis and nStepSize at 1 (nNumWindows=1)
			// The nNumWindows windows may not fit exactly into nAnalysis
			// If so, the data points at the end are ignored (not zero-padded)

			// Another expression for max allowable # windows
			// given # analy points and user selected window size and step size
			// # windows <= ((# analysis points-window size)/(step size))+1
			// So, for 1000 analysis points, window size=100 & step size=10
			// # windows=91
			// If 999 analysis points, could have only 90 of those windows
			// not using 10 points at end
			// Or could use 101 windows of size 99 with step 9 that would
			// fit exactly

			// Set defaults
			if(nAnalysis<4) // Too small data set
			{
				// Too few analysis points
				TooFewMessage();

				// Close dialog box
				EndDialog (hDlg, 0);

				// Quit
				return TRUE;
			}
			else if(nAnalysis<40) // Tiny data set
			// For 4 analysis points, 1 window of size 4 with step 1
			// For 40 analysis points, 1 window of size 40 with step 1
			{
				nWindowSize=(int)(nAnalysis);
				nStepSize=1;
				nNumWindows=1;
			}
			else if(nAnalysis<500) // Small data set
			// For 40 analysis points, 11 windows of size 20 with step 2
			// For 500 analysis points, 11 windows of size 50 with step 5
			{
				nWindowSize=(int)(nAnalysis/2);
				nStepSize=(int)(nWindowSize/10);
				nNumWindows=11;
			}
			else
			// For 500 analy points,
			// 91 windows of 50 points with step 5
			// For 5000 analy points,
			// 91 windows of size 500 points with step 50
			// For 50000 analy points,
			// 91 windows of 5000 points with step 500
			{
				nWindowSize=(int)(nAnalysis/10);
				nStepSize=(int)(nWindowSize/10);
				nNumWindows=91;
			}

			// Load defaults into settings
			_snprintf(szBuffer, sizeof(szBuffer), "%d", nWindowSize);
			SetWindowText(GETHCTL(IDC_DAVAR_WINSIZE), szBuffer);
			_snprintf(szBuffer, sizeof(szBuffer), "%d", nStepSize);
			SetWindowText(GETHCTL(IDC_DAVAR_STEPSIZE), szBuffer);
			_snprintf(szBuffer, sizeof(szBuffer), "%d", nNumWindows);
			SetWindowText(GETHCTL(IDC_DAVAR_NUMWIN), szBuffer);

			// Update # windows to agree with actual numbers
			nNumWindows=(nAnalysis-(nWindowSize-nStepSize))/nStepSize;
			_snprintf(szBuffer, sizeof(szBuffer), "%d", nNumWindows);
			SetWindowText(GETHCTL(IDC_DAVAR_NUMWIN),
				szBuffer);
			if(nNumWindows>100)
			{
				SetWindowText(GETHCTL(IDC_DAVAR_YLABEL), "Window # x10");
			}
			else
			{
				SetWindowText(GETHCTL(IDC_DAVAR_YLABEL), "Window #");
			}

			// Load default axis labels
			SetWindowText(GETHCTL(IDC_DAVAR_XLABEL), "Log AF");
			if(nNumWindows>100)
			{
				SetWindowText(GETHCTL(IDC_DAVAR_YLABEL), "Window # x10");
			}
			else
			{
				SetWindowText(GETHCTL(IDC_DAVAR_YLABEL), "Window #");
			}
			SetWindowText(GETHCTL(IDC_DAVAR_ZLABEL), "Log Sigma");

			// Set AVAR & HVAR radiobuttons
			bAVAR=TRUE;
			sDPlot.vartype=1;
			Button_SetCheck(GETHCTL(IDC_DAVAR_AVAR), bAVAR);
			Button_SetCheck(GETHCTL(IDC_DAVAR_HVAR), !bAVAR);

			// Put dialog box handle into global variable
			// Used at end of GraphiC plotting to assure safe return here
			hDialog=hDlg;

			// Deactivate Abort button
			EnableWindow(GETHCTL(IDC_DAVAR_ABORT), FALSE);

			// Initialize horizontal viewpoint slider
			SendMessage(GETHCTL(IDC_DAVAR_HORIZ), TBM_SETRANGE, (WPARAM) TRUE,
				(LPARAM) MAKELONG(0, 8));  // 9 ticks (0 thru 8)
			SendMessage(GETHCTL(IDC_DAVAR_HORIZ), TBM_SETPOS, (WPARAM) TRUE,
				(LPARAM) 4); // Center tick

			// Initialize vertical viewpoint slider
			SendMessage(GETHCTL(IDC_DAVAR_VERT), TBM_SETRANGE, (WPARAM) TRUE,
				(LPARAM) MAKELONG(0, 6)); // 7 ticks (0 thru 6)
			SendMessage(GETHCTL(IDC_DAVAR_VERT), TBM_SETPOS, (WPARAM) TRUE,
				(LPARAM) 3); // Center tick

			// Initialize viewpoint values
			sDPlot.xvu=50.0;
			sDPlot.yvu=50.0;
			sDPlot.zvu=50.0;

			// Force new calc
			bCalc=TRUE;

			// Clear alloc flag
			bAlloc=FALSE;

			// Full initialization
			if(bFirstTime)
			{
				if(bUseDAVARPlotIni)
				{
					// Read ini file
					ReadIni(INI_DAVAR);
					nWindowSize=sDPlot.winsize;
					nStepSize=sDPlot.stepsize;

					// Load ini file settings
					_snprintf(szBuffer, sizeof(szBuffer), "%d", nWindowSize);
					SetWindowText(GETHCTL(IDC_DAVAR_WINSIZE), szBuffer);
					_snprintf(szBuffer, sizeof(szBuffer), "%d", nStepSize);
					SetWindowText(GETHCTL(IDC_DAVAR_STEPSIZE), szBuffer);
					_snprintf(szBuffer, sizeof(szBuffer), "%d", nNumWindows);
					SetWindowText(GETHCTL(IDC_DAVAR_NUMWIN), szBuffer);

					// Update # windows to agree with actual numbers
					nNumWindows=(nAnalysis-(nWindowSize-nStepSize))/nStepSize;
					_snprintf(szBuffer, sizeof(szBuffer), "%d", nNumWindows);
					SetWindowText(GETHCTL(IDC_DAVAR_NUMWIN),
						szBuffer);
					if(nNumWindows>100)
					{
						SetWindowText(GETHCTL(IDC_DAVAR_YLABEL),
							"Window # x10");
					}
					else
					{
						SetWindowText(GETHCTL(IDC_DAVAR_YLABEL),
							"Window #");
					}

					// Load corresponding axis labels
					SetWindowText(GETHCTL(IDC_DAVAR_XLABEL), "Log AF");
					if(nNumWindows>100)
					{
						SetWindowText(GETHCTL(IDC_DAVAR_YLABEL),
							"Window # x10");
					}
					else
					{
						SetWindowText(GETHCTL(IDC_DAVAR_YLABEL), "Window #");
					}
					SetWindowText(GETHCTL(IDC_DAVAR_ZLABEL), "Log Sigma");
				}
				else
				{
					// Initialize spectrum plot parameters to defaults
					strlcpy(sDPlot.title, "DYNAMIC STABILITY", TITLESIZE);
					strlcpy(sDPlot.subtitle, szFileTitle, SUBTITLESIZE);
					strlcpy(sDPlot.message_str, "", MESSAGESIZE);

					// Set options
					sDPlot.do_date=TRUE;
					sDPlot.do_box=TRUE;
					sDPlot.position=2; // Preferred position is Top Right

					// Set AVAR & HVAR radiobuttons
					bAVAR=TRUE;
					Button_SetCheck(GETHCTL(IDC_DAVAR_AVAR), bAVAR);
					Button_SetCheck(GETHCTL(IDC_DAVAR_HVAR), !bAVAR);

					// Set grid to default
					sDPlot.grid=1;

					// Activate grid list box if colors selcted
					EnableWindow(GETHCTL(IDC_DAVAR_GRID), sDPlot.colors);
					EnableWindow(GETHCTL(IDC_DAVAR_GRIDLABEL), sDPlot.colors);
				}
				bFirstTime=FALSE;
			}
			else // Just initialize strings freed after previous close
			{
				// Initialize spectrum plot parameters to defaults
				strlcpy(sDPlot.title, "DYNAMIC STABILITY", TITLESIZE);
				strlcpy(sDPlot.subtitle, szFileTitle, SUBTITLESIZE);
				strlcpy(sDPlot.message_str, "", MESSAGESIZE);
			}

			// Plot labels are fixed - set in DynamicStabilityPlot()
			// Default message provides info about actual plot scales

			// Fill up message position list box using string table
			// Note usage of DPLOT rather than PSPLOT strings
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_DAVAR_POSITION));
			nDummy=ComboBox_InsertString(GETHCTL(IDC_DAVAR_POSITION),
				0, "None");
			for(i=0; i<NUM_DPLOT_POSITIONS; i++)
			{
				LoadString(hInst, IDS_DPLOT_POSITION_0+i, szBuffer,
					BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_DAVAR_POSITION),
					i, szBuffer);
			}

			// Show position
			nDummy=ComboBox_SetCurSel(GETHCTL(IDC_DAVAR_POSITION),
				sDPlot.position);

			// Clear the title list box
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_DAVAR_TITLE));

			// Load previous user-entered title strings into list box
			if(nUserTitles)
			{
				// Loop through user titles
				for(i=0; i<nUserTitles; i++)
				{
					// Load title string
					nDummy=ComboBox_InsertString(GETHCTL(IDC_DAVAR_TITLE),
						i, szPlotTitle[i]);
				}
			}

			// Load the current title
			nDummy=ComboBox_AddString(GETHCTL(IDC_DAVAR_TITLE), sDPlot.title);
			SetWindowText(GETHCTL(IDC_DAVAR_TITLE),
				sDPlot.title);

			// Clear the subtitle list box
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_DAVAR_SUBTITLE));

			// Load the filenames into the subtitle list box
			nDummy=ComboBox_AddString(GETHCTL(IDC_DAVAR_SUBTITLE),
				szFileTitle);
			nDummy=ComboBox_AddString(GETHCTL(IDC_DAVAR_SUBTITLE), szFile);

			// Load previous user-entered subtitle strings into list box
			if(nUserSubtitles)
			{
				for(i=0; i<nUserSubtitles; i++)
				{
					// Load subtitle string
					nDummy=ComboBox_InsertString(GETHCTL(IDC_DAVAR_SUBTITLE),
						i, szPlotSubtitle[i]);
				}
			}

			// Load the current subtitle
			SetWindowText(GETHCTL(IDC_DAVAR_SUBTITLE),
				sDPlot.subtitle);

			// Clear the message combo box
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_DAVAR_MESSAGE));

			// Load previous user-entered message strings into list box
			if(nUserMessages)
			{
				// Loop through user messages
				for(i=0; i<nUserMessages; i++)
				{
					// Load message string
					nDummy=ComboBox_InsertString(GETHCTL(IDC_DAVAR_MESSAGE),
						i, szPlotMessage[i]);
				}
			}

			// Load the current message
			nDummy=ComboBox_AddString(GETHCTL(IDC_DAVAR_MESSAGE),
				sDPlot.message_str);
			SetWindowText(GETHCTL(IDC_DAVAR_MESSAGE),
				sDPlot.message_str);

			// Clear the grid list box
			nDummy=ListBox_ResetContent(GETHCTL(IDC_DAVAR_GRID));

			// Load grid list box
			for(i=0; i<10; i++)
			{
				_snprintf(szBuffer, sizeof(szBuffer), "%d", i);
				nDummy=ListBox_InsertString(GETHCTL(IDC_DAVAR_GRID),
						i, szBuffer);
			}

			// Select the current grid list box item
			nDummy=ListBox_SetCurSel(GETHCTL(IDC_DAVAR_GRID),
				sDPlot.grid);
			
			// Activate grid list box if colors selcted
			EnableWindow(GETHCTL(IDC_DAVAR_GRID), sDPlot.colors);
			EnableWindow(GETHCTL(IDC_DAVAR_GRIDLABEL), sDPlot.colors);

			// Load the plot filename
			SetWindowText(GETHCTL(IDC_DAVAR_FILENAME),
				sDPlot.plot_filename);

			// Restore the date checkbox state
			Button_SetCheck(GETHCTL(IDC_DAVAR_DATE), sDPlot.do_date);

			// Restore the box checkbox state
			Button_SetCheck(GETHCTL(IDC_DAVAR_BOX), sDPlot.do_box);

			// Restore the colors checkbox state
			Button_SetCheck(GETHCTL(IDC_DAVAR_COLORS), sDPlot.colors);
			
			// Restore the reverse checkbox state
			bReverse=FALSE;
			Button_SetCheck(GETHCTL(IDC_DAVAR_REV), bReverse);
			
			// Restore the variance type
			Button_SetCheck(GETHCTL(IDC_DAVAR_AVAR), sDPlot.vartype);
			Button_SetCheck(GETHCTL(IDC_DAVAR_HVAR), !sDPlot.vartype);

			// Get & save HWNDs returned by GetFocus() for Title, Subtitle &
			// Message combo boxes
			SetFocus(GETHCTL(IDC_DAVAR_TITLE));
			uTitle=(UINT)GetFocus();
			SetFocus(GETHCTL(IDC_DAVAR_SUBTITLE));
			uSubtitle=(UINT)GetFocus();
			SetFocus(GETHCTL(IDC_DAVAR_MESSAGE));
			uMessage=(UINT)GetFocus();

			// Initializations done
			return TRUE;
		}

		// Respond to message from horizontal trackbar
		case WM_HSCROLL:
		{
			switch(LOWORD(wParam))
			{
				// Respond to trackbar message from keyboard or mouse
				case TB_ENDTRACK:
				{
					// Get slider position
					dwPos=SendMessage(GETHCTL(IDC_DAVAR_HORIZ), TBM_GETPOS,
						0, 0);

					// Set horizontal viewpoint values
					if(dwPos<5)
					{
						sDPlot.xvu=(float)50.0;
						sDPlot.yvu=(float)((dwPos+1)*10.0);
					}
					else // dwPos>=5
					{
						sDPlot.xvu=(float)(50.0-(dwPos-4)*10.0);
						sDPlot.yvu=(float)50.0;
					}

					// Reverse viewpoint if requested
					if(bReverse)
					{
						sDPlot.xvu*=-1.0;
						sDPlot.yvu*=-1.0;
					}
				}
				break;
			}
			return TRUE;
		}

		// Respond to message from vertical trackbar
		case WM_VSCROLL:
		{
			switch(LOWORD(wParam))
			{
				// Respond to trackbar message from keyboard or mouse
				case TB_ENDTRACK:
				{
					// Get slider position
					dwPos=SendMessage(GETHCTL(IDC_DAVAR_VERT), TBM_GETPOS,
						0, 0);

					// Set vertical viewpoint value
					sDPlot.zvu=(float)(80.0-dwPos*10.0);
				}
				break;
			}
			return TRUE;
		}

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg,
						"Stable32.chm::DYNAMIC_STABILITY_FUNCTION.HTM",
						HH_DISPLAY_TOPIC,
                        0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::DYNAMIC_STABILITY_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "DYNAMIC_STABILITY_FUNCTION");
					#endif
				}
				break;

				// Detect parameter changes
				// Title change
				case IDC_DAVAR_TITLE:
				{
					// Respond to focus lost
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_KILLFOCUS)
					{
						GetWindowText(GETHCTL(IDC_DAVAR_TITLE),
						sDPlot.title, TITLESIZE-1);

						// Redisplay title - perhaps shortened
						SetWindowText(GETHCTL(IDC_DAVAR_TITLE),
							sDPlot.title);

						// Put new string into list
						// Don't store string if it is same as before
						if(ComboBox_FindString(GETHCTL(IDC_DAVAR_TITLE),
							-1, sDPlot.title)==CB_ERR)
						{
							// Don't store blank title either
							if(strlen(sDPlot.title))
							{
								nDummy=ComboBox_InsertString(GETHCTL(
									IDC_DAVAR_TITLE), 0, sDPlot.title);
							}
						}
					}
				}
				break;

				// Subtitle change
				case IDC_DAVAR_SUBTITLE:
				{
					// Respond to focus lost
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_KILLFOCUS)
					{
						GetWindowText(GETHCTL(IDC_DAVAR_SUBTITLE),
						sDPlot.subtitle, SUBTITLESIZE-1);

						// Redisplay subtitle - perhaps shortened
						SetWindowText(GETHCTL(IDC_DAVAR_SUBTITLE),
							sDPlot.subtitle);

						// Put new string into list
						// Don't store string if it is same as before
						if(ComboBox_FindString(GETHCTL(IDC_DAVAR_SUBTITLE),
							-1, sDPlot.subtitle)==CB_ERR)
						{
							// Don't store blank subtitle either
							if(strlen(sDPlot.subtitle))
							{
								nDummy=ComboBox_InsertString(GETHCTL(
									IDC_DAVAR_SUBTITLE), 0, sDPlot.subtitle);
							}
						}
					}
				}
				break;

				// Message change
				case IDC_DAVAR_MESSAGE:
				{
					// Respond to focus lost
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_KILLFOCUS)
					{
						GetWindowText(GETHCTL(IDC_DAVAR_MESSAGE),
						sDPlot.message_str, 5*MESSAGESIZE-1);

						// Redisplay message - perhaps shortened
						SetWindowText(GETHCTL(IDC_DAVAR_MESSAGE),
							sDPlot.message_str);

						// Put new string into list
						// Don't store string if it is same as before
						if(ComboBox_FindString(GETHCTL(IDC_DAVAR_MESSAGE),
							-1, sDPlot.message_str)==CB_ERR)
						{
							// Don't store blank message either
							if(strlen(sDPlot.message_str))
							{
								nDummy=ComboBox_InsertString(GETHCTL(
									IDC_DAVAR_MESSAGE), 0, sDPlot.message_str);
							}
						}
					}
				}
				break;

				// Plot Filename change
				case IDC_DAVAR_FILENAME:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DAVAR_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// The default *.TKF filename includes full drive/path
						// where program started to avoid writing to floppy
						// or non-writable media.  The edit window AutoHScrolls.
						GetWindowText(GETHCTL(IDC_DAVAR_FILENAME),
							szTempFile, FILENAMESIZE-1);

						// Validate new filename
						if(CheckFilename(szTempFile, szTempTitle, szTempPath,
							szTempName, szTempExt, hDlg,
							"Dynamic Stability Plot Filename"))
						{
							// Filename OK
							strlcpy(sDPlot.plot_filename, szTempFile,
								FILENAMESIZE);

							// Reload the plot filename
							SetWindowText(GETHCTL(IDC_DAVAR_FILENAME),
								sDPlot.plot_filename);
						}
						else // Filename NG
						{
							// Restore original filename
							SetWindowText(GETHCTL(IDC_DAVAR_FILENAME),
								sDPlot.plot_filename);
							SetFocus(GETHCTL(IDC_DAVAR_FILENAME));
							break;
						}
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Window size change
				case IDC_DAVAR_WINSIZE:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DAVAR_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get new window size
						GetWindowText(GETHCTL(IDC_DAVAR_WINSIZE),
							szBuffer, BUFFER_SIZE);

						// Validate it
						// nWindowSize must be >=8 and <= # analysis points
						if((atoi(szBuffer))<8)
						{
							nWindowSize=8;
						}
						else if((atoi(szBuffer))>nAnalysis-2*nStepSize)
						{
							nWindowSize=nAnalysis-2*nStepSize;
						}
						else
						{
							// Assign new window size
							nWindowSize=abs(atoi(szBuffer));
						}

						// Redraw window size
						_snprintf(szBuffer, sizeof(szBuffer),
							"%d", nWindowSize);
						SetWindowText(GETHCTL(IDC_DAVAR_WINSIZE),
								szBuffer);

						// Put window size into plot struct
						sDPlot.winsize=nWindowSize;

						// Update # windows
						nNumWindows=
							(nAnalysis-(nWindowSize-nStepSize))/nStepSize;
						_snprintf(szBuffer, sizeof(szBuffer), "%d",
							nNumWindows);
						SetWindowText(GETHCTL(IDC_DAVAR_NUMWIN),
								szBuffer);
						if(nNumWindows>100)
						{
							SetWindowText(GETHCTL(IDC_DAVAR_YLABEL),
								"Window # x10");
						}
						else
						{
							SetWindowText(GETHCTL(IDC_DAVAR_YLABEL),
								"Window #");
						}

						// Force new calc
						bCalc=TRUE;
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Step size change
				case IDC_DAVAR_STEPSIZE:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_DAVAR_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get new step size
						GetWindowText(GETHCTL(IDC_DAVAR_STEPSIZE),
							szBuffer, BUFFER_SIZE);

						// Validate it
						// Must be >0 and <= # analysis points - window size
						if((atoi(szBuffer))<1)
						{
							nStepSize=1;
						}
						else if((atoi(szBuffer))>((nAnalysis-nWindowSize)/2))
						{
							nStepSize=((nAnalysis-nWindowSize)/2);
						}
						else
						{
							// Assign new step size
							nStepSize=abs(atoi(szBuffer));
						}

						// Redraw step size
						_snprintf(szBuffer, sizeof(szBuffer), "%d", nStepSize);
						SetWindowText(GETHCTL(IDC_DAVAR_STEPSIZE),
								szBuffer);

						// Put step size into plot struct
						sDPlot.stepsize=nStepSize;

						// Update # windows
						nNumWindows=
							(nAnalysis-(nWindowSize-nStepSize))/nStepSize;
						_snprintf(szBuffer, sizeof(szBuffer), "%d",
							nNumWindows);
						SetWindowText(GETHCTL(IDC_DAVAR_NUMWIN),
								szBuffer);
						if(nNumWindows>100)
						{
							SetWindowText(GETHCTL(IDC_DAVAR_YLABEL),
								"Window # x10");
						}
						else
						{
							SetWindowText(GETHCTL(IDC_DAVAR_YLABEL),
								"Window #");
						}

						// Force new calc
						bCalc=TRUE;
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Position change
				case IDC_DAVAR_POSITION:
				{
					sDPlot.position=
						ComboBox_GetCurSel(GETHCTL(IDC_DAVAR_POSITION));
				}
				break;

				// Date flag change
				case IDC_DAVAR_DATE:
				{
					// Get checkbox state
					sDPlot.do_date=Button_GetCheck(GETHCTL(IDC_DAVAR_DATE));
				}
				break;

				// Box flag change
				case IDC_DAVAR_BOX:
				{
					// Get checkbox state
					sDPlot.do_box=Button_GetCheck(GETHCTL(IDC_DAVAR_BOX));
				}
				break;

				// Colors flag change
				case IDC_DAVAR_COLORS:
				{
					// Get checkbox state
					sDPlot.colors=Button_GetCheck(GETHCTL(IDC_DAVAR_COLORS));

					// Activate grid list box if colors selcted
					EnableWindow(GETHCTL(IDC_DAVAR_GRID), sDPlot.colors);
					EnableWindow(GETHCTL(IDC_DAVAR_GRIDLABEL), sDPlot.colors);
				}
				break;

				// Grid list box selection change
				case IDC_DAVAR_GRID:
				{
					// Get checkbox state
					sDPlot.grid=ListBox_GetCurSel(GETHCTL(IDC_DAVAR_GRID));
				}
				break;

				// Reverse flag change
				case IDC_DAVAR_REV:
				{
					// Get checkbox state
					bReverse=Button_GetCheck(GETHCTL(IDC_DAVAR_REV));

					// Get slider position
					dwPos=SendMessage(GETHCTL(IDC_DAVAR_HORIZ), TBM_GETPOS,
						0, 0);

					// Set horizontal viewpoint values
					if(dwPos<5)
					{
						sDPlot.xvu=(float)50.0;
						sDPlot.yvu=(float)((dwPos+1)*10.0);
					}
					else // dwPos>=5
					{
						sDPlot.xvu=(float)(50.0-(dwPos-4)*10.0);
						sDPlot.yvu=(float)50.0;
					}

					// Reverse viewpoint if requested
					if(bReverse)
					{
						sDPlot.xvu*=-1.0;
						sDPlot.yvu*=-1.0;
					}
				}
				break;

				// Read config button
				case IDC_DAVAR_READ:
				{
					bSave=bUseDAVARPlotIni;
					bUseDAVARPlotIni=TRUE;
					ReadIni(INI_DAVAR);
					bUseDAVARPlotIni=bSave;
					
					// Fill up message position list box using string table
					// Note usage of DPLOT rather than PSPLOT strings
					nDummy=ComboBox_ResetContent(GETHCTL(IDC_DAVAR_POSITION));
					nDummy=ComboBox_InsertString(GETHCTL(IDC_DAVAR_POSITION),
						0, "None");
					for(i=0; i<NUM_DPLOT_POSITIONS; i++)
					{
						LoadString(hInst, IDS_DPLOT_POSITION_0+i, szBuffer,
							BUFFER_SIZE);
						nDummy=ComboBox_InsertString(GETHCTL(
							IDC_DAVAR_POSITION),
							i, szBuffer);
					}

					// Show position
					nDummy=ComboBox_SetCurSel(GETHCTL(IDC_DAVAR_POSITION),
						sDPlot.position);

					// Clear the title list box
					nDummy=ComboBox_ResetContent(GETHCTL(IDC_DAVAR_TITLE));

					// Load previous user-entered title strings into list box
					if(nUserTitles)
					{
						for(i=0; i<nUserTitles; i++)
						{
							// Load title string
							nDummy=
								ComboBox_InsertString(GETHCTL(IDC_DAVAR_TITLE),
								i, szPlotTitle[i]);
						}
					}

					// Load the current title
					nDummy=ComboBox_AddString(GETHCTL(IDC_DAVAR_TITLE),
						sDPlot.title);
					SetWindowText(GETHCTL(IDC_DAVAR_TITLE),
						sDPlot.title);

					// Clear the subtitle list box
					nDummy=ComboBox_ResetContent(GETHCTL(IDC_DAVAR_SUBTITLE));

					// Load the filenames into the subtitle list box
					nDummy=ComboBox_AddString(GETHCTL(IDC_DAVAR_SUBTITLE),
						szFileTitle);
					nDummy=ComboBox_AddString(GETHCTL(IDC_DAVAR_SUBTITLE),
						szFile);

					// Load previous user-entered subtitle strings into list box
					if(nUserSubtitles)
					{
						for(i=0; i<nUserSubtitles; i++)
						{
							// Load subtitle string
							nDummy=
								ComboBox_InsertString(GETHCTL(
								IDC_DAVAR_SUBTITLE),
								i, szPlotSubtitle[i]);
						}
					}

					// Load the current subtitle
					SetWindowText(GETHCTL(IDC_DAVAR_SUBTITLE),
						sDPlot.subtitle);

					// Clear the message list box
					nDummy=ComboBox_ResetContent(GETHCTL(IDC_DAVAR_MESSAGE));

					// Load previous user-entered message strings into list box
					if(nUserMessages)
					{
						for(i=0; i<nUserMessages; i++)
						{
							// Load message string
							nDummy=
								ComboBox_InsertString(GETHCTL(
								IDC_DAVAR_MESSAGE),
								i, szPlotMessage[i]);
						}
					}

					// Load the current message
					nDummy=ComboBox_AddString(GETHCTL(IDC_DAVAR_MESSAGE),
						sDPlot.message_str);
					SetWindowText(GETHCTL(IDC_DAVAR_MESSAGE),
						sDPlot.message_str);

					// Load the plot filename
					SetWindowText(GETHCTL(IDC_DAVAR_FILENAME),
						sDPlot.plot_filename);

					// Restore the date checkbox state
					Button_SetCheck(GETHCTL(IDC_DAVAR_DATE), sDPlot.do_date);

					// Restore the box checkbox state
					Button_SetCheck(GETHCTL(IDC_DAVAR_BOX), sDPlot.do_box);

					// Restore the colors checkbox state
					Button_SetCheck(GETHCTL(IDC_DAVAR_COLORS), sDPlot.colors);

					// Activate grid list box if colors selcted
					EnableWindow(GETHCTL(IDC_DAVAR_GRID), sDPlot.colors);
					EnableWindow(GETHCTL(IDC_DAVAR_GRIDLABEL), sDPlot.colors);

					// Select the current grid list box item
					nDummy=ListBox_SetCurSel(GETHCTL(IDC_DAVAR_GRID),
						sDPlot.grid);

					// Restore the variance type
					bAVAR=sDPlot.vartype;
					Button_SetCheck(GETHCTL(IDC_DAVAR_AVAR), sDPlot.vartype);
					Button_SetCheck(GETHCTL(IDC_DAVAR_HVAR), !sDPlot.vartype);

					// Load window and step sizes
					nWindowSize=sDPlot.winsize;
					_snprintf(szBuffer, sizeof(szBuffer), "%d",
						sDPlot.winsize);
					SetWindowText(GETHCTL(IDC_DAVAR_WINSIZE), szBuffer);
					nStepSize=sDPlot.stepsize;
					_snprintf(szBuffer, sizeof(szBuffer), "%d",
						sDPlot.stepsize);
					SetWindowText(GETHCTL(IDC_DAVAR_STEPSIZE), szBuffer);

					// Avoid divide by zero
					if(nStepSize==0)
					{
						nStepSize=1;
					}
					
					// Update # windows to agree with actual numbers
					nNumWindows=(nAnalysis-(nWindowSize-nStepSize))/nStepSize;
					_snprintf(szBuffer, sizeof(szBuffer), "%d", nNumWindows);
					SetWindowText(GETHCTL(IDC_DAVAR_NUMWIN),
						szBuffer);
					if(nNumWindows>100)
					{
						SetWindowText(GETHCTL(IDC_DAVAR_YLABEL),
							"Window # x10");
					}
					else
					{
						SetWindowText(GETHCTL(IDC_DAVAR_YLABEL), "Window #");
					}
				}
				break;

				// Save config button
				case IDC_DAVAR_WRITE:
				{
					// Make sure sizes are updated
					sDPlot.winsize=nWindowSize;
					sDPlot.stepsize=nStepSize;

					// Write ini file
					bSave=bUseDAVARPlotIni;
					bUseDAVARPlotIni=TRUE;
					WriteIni(INI_DAVAR);
					bUseDAVARPlotIni=bSave;
				}
				break;

				// Respond to AVAR radiobuttonn
				case IDC_DAVAR_AVAR:
				{
					// Set AVAR flag
					bAVAR=TRUE;

					// Set variance type in d3plotdata structure
					sDPlot.vartype=1;
					
					// Set title to DAVAR
					strlcpy(sDPlot.title, "DYNAMIC AVAR STABILITY", TITLESIZE);

					// Load the DAVAR title
					// Put new string into list
					// Don't store string if it is same as before
					if(ComboBox_FindString(GETHCTL(IDC_DAVAR_TITLE),
						-1, sDPlot.title)==CB_ERR)
					{
						nDummy=ComboBox_InsertString(GETHCTL(IDC_DAVAR_TITLE),
							0, sDPlot.title);
					}

					// Select the DAVAR title whereever it is
					ComboBox_SelectString(GETHCTL(IDC_DAVAR_TITLE),
						0, sDPlot.title);

					// Force new calc
					bCalc=TRUE;
				}
				break;

				// Respond to HVAR radiobuttonn
				case IDC_DAVAR_HVAR:
				{
					// Clear AVAR flag
					bAVAR=FALSE;
					
					// Set variance type in d3plotdata structure
					sDPlot.vartype=0;

					// Set title to DHVAR
					strlcpy(sDPlot.title, "DYNAMIC HVAR STABILITY", TITLESIZE);

					// Load the DHVAR title
					// Put new string into list
					// Don't store string if it is same as before
					if(ComboBox_FindString(GETHCTL(IDC_DAVAR_TITLE),
						-1, sDPlot.title)==CB_ERR)
					{
						nDummy=ComboBox_InsertString(GETHCTL(IDC_DAVAR_TITLE),
							0, sDPlot.title);
					}

					// Select the DHVAR title whereever it is
					ComboBox_SelectString(GETHCTL(IDC_DAVAR_TITLE),
						0, sDPlot.title);

					// Force new calc
					bCalc=TRUE;
				}
				break;

				// Subroutine to calculate stability data
				// Allocate 3D arrays in memory
				// Calculate sets of sigma-tau values
				// from current phase or freq data over current analysis limits
				// in nNumWindows sets of nWindowSize in steps of nStepSize
				// x=tau expressed as log10 AF
				// y=window #
				// z=sigma expressed as log10 sigma (ADEV or HDEV)
				// 1st window from nStart to (nStart+nWindowSize-1)
				// 2nd " from (nStart+nStepSize) to
				//  (nStart+nStepSize+nWindowSize-1)
				// Nth " from (nStart+N*nStepSize) to
				//  (nStart+N*nStepSize+nWindowSize-1)
				// Last window from (nStart+nNumWindows*nStepSize) to
				// (nStart+nNumWindows*nStepSize+nWindowSize-1)
				// which may be less than nEnd of upper analysis limit
				// Ignore points between end of last window
				// and end of analy data
				// nNumWindows=(nAnalysis-(nWindowSize-nStepSize))/nStepSize
				// Each array's memory allocation size is
				// nNumWindows*nStabPoints
				// where nStabPoints is determined by nWindowSize
				// and the minimum # data points needed
				// to calc a meaningful sigma
				// nStabPoints=Max AF=nWindowSize/STOP_RATIO,
				// where STOP_RATIO=4
				// nStabPoints=Max nAF=nWindowSize/4
				// for overlapping AVAR and HVAR
				// so memory allocation size is nNumWindows*nWindowSize/4
				// Note:  We are doing an "all tau" not "many tau" analysis
				case IDC_DAVAR_CALC:
				{
					// Update # windows
					nNumWindows=(nAnalysis-(nWindowSize-nStepSize))/nStepSize;
					_snprintf(szBuffer, sizeof(szBuffer), "%d", nNumWindows);
					SetWindowText(GETHCTL(IDC_DAVAR_NUMWIN),
							szBuffer);
					if(nNumWindows>100)
					{
						SetWindowText(GETHCTL(IDC_DAVAR_YLABEL),
							"Window # x10");
					}
					else
					{
						SetWindowText(GETHCTL(IDC_DAVAR_YLABEL), "Window #");
					}

					// Set # stability calc points
					nStabPoints=nWindowSize/STOP_RATIO;

					// Allocate memory for 3D surface arrays
					// in d3plotdata struct
					if((sDPlot.x=(float*)malloc((nNumWindows*nStabPoints)*
						sizeof(float)))==NULL)
					{
						bAllocError=TRUE;
					}
					else if((sDPlot.y=(float*)malloc((nNumWindows*nStabPoints)*
						sizeof(float)))==NULL)
					{
						bAllocError=TRUE;
						free(sDPlot.x);
					}
					else if((sDPlot.z=(float*)malloc((nNumWindows*nStabPoints)*
						sizeof(float)))==NULL)
					{
						bAllocError=TRUE;
						free(sDPlot.x);
						free(sDPlot.y);
					}

					// Handle memory allocation error
					if(bAllocError)
					{
						// Display error message
						AllocErrorMessage();

						// Close dialog box
						EndDialog(hDlg, 0);
						return TRUE;
					}

					// The sigma calc is going to be done with phase data
					// in a working data array that holds the complete data set
					// either (1) with phase data being selected, (2) with
					// phase data that is equivalent to the selected freq data,
					// or by converting the freq data to phase data
					// For cases (1) and (2), we simply set the working array
					// pointer to the phase data array.
					// For case (3), we allocate the working array
					// and convert the frequency data into it

					// Save original phase analysis limits
					fPhase0=fPhaseData[0];	// # data points
					fPhase1=fPhaseData[1];	// Analysis start point
					fPhase2=fPhaseData[2];	// Analysis end point

					// Save original freq analysis limits
					fFreq0=fFreqData[0];	// # data points
					fFreq1=fFreqData[1];	// Analysis start point
					fFreq2=fFreqData[2];	// Analysis end point
					
					// If freq data w/o equivalent phase data
					if(bDataType==FREQ_DATA && !bSynch)
					{
						// Increment nAll
						nAll++;

						// Get the tau0 value
						GetWindowText(hwndFreqTau, szBuffer, BUFFER_SIZE);
							fTau0=atof(szBuffer);

						// Allocate space for entire working phase data array
						if((fWorkData=(F_TYPE*)malloc(
							(nAll+ARRAY_OFFSET)*sizeof(F_TYPE)))==NULL)
						{
							// Display error message
							AllocErrorMessage();

							// Close dialog box
							EndDialog(hDlg, 0);
							return TRUE;
						}

						// Set allocation flag
						bAlloc=TRUE;

						// Convert freq data to phase data in working array
						ConvFreqToPhase(fFreqData, fWorkData, fTau0, FALSE);
					}
					else // Phase data (selected or equivalent)
					{
						// Get the tau0 value
						GetWindowText(hwndPhaseTau, szBuffer, BUFFER_SIZE);
						fTau0=atof(szBuffer);

						// Assign fWorkData pointer to phase data
						fWorkData=fPhaseData;

						// Resst allocation flag
						bAlloc=FALSE;
					}

					// Set up the progress bar
					// Ref: See Win32 Help Info "Using Progress Bars"
					// Set its range as the size of the outer loop nNumWindows
					SendMessage(GETHCTL(IDC_DAVAR_PROGRESS), PBM_SETRANGE, 0,
						MAKELPARAM(0, nNumWindows));
					// Set the step size as 1
					SendMessage(GETHCTL(IDC_DAVAR_PROGRESS), PBM_SETSTEP,
						(WPARAM) 1, 0);

					// Activate Abort button
					EnableWindow(GETHCTL(IDC_DAVAR_ABORT), TRUE);

					// Deactivate all other controls
					EnableWindow(GETHCTL(IDC_DAVAR_PLOT), FALSE);
					EnableWindow(GETHCTL(IDC_DAVAR_CANCEL), FALSE);
					EnableWindow(GETHCTL(IDC_DAVAR_HELP), FALSE);
					EnableWindow(GETHCTL(IDC_DAVAR_RESET), FALSE);
					EnableWindow(GETHCTL(IDC_DAVAR_READ), FALSE);
					EnableWindow(GETHCTL(IDC_DAVAR_WRITE), FALSE);
					EnableWindow(GETHCTL(IDC_DAVAR_DATE), FALSE);
					EnableWindow(GETHCTL(IDC_DAVAR_BOX), FALSE);
					EnableWindow(GETHCTL(IDC_DAVAR_COLORS), FALSE);
					EnableWindow(GETHCTL(IDC_DAVAR_GRID), FALSE);
					EnableWindow(GETHCTL(IDC_DAVAR_WINSIZE), FALSE);
					EnableWindow(GETHCTL(IDC_DAVAR_STEPSIZE), FALSE);
					EnableWindow(GETHCTL(IDC_DAVAR_AVAR), FALSE);
					EnableWindow(GETHCTL(IDC_DAVAR_HVAR), FALSE);
					
					// Calculate AVAR or HVAR stability values
					// and put them into 3D surface array
					// Outer loop (i) is through windows (1 to nNumWindows)
					// Inner loop (j) is through AFs
					// (1 to nAnalysis/STOP_RATIO)
					// where STOP_RATIO=4
					// Stab calc is for currently selected phase or freq data
					// for nWindowSize points in increments of nStepSize
					// over currently selected analysis limits
					// Analysis windows do not necessarity fit exactly
					// into # data points:
					// ((nNumWindows-1)*nStepSize)+nWindowSize
					// may be <nAnalysis
					// and then there are unused data point(s) at end 
					for(i=0; i<nNumWindows; i++) // Window loop (t)
					{
						// Set analysis start & end values
						fWorkData[1]=nStart+(i*nStepSize);
						fWorkData[2]=nStart+(i*nStepSize)+nWindowSize-1;

						// Initialize nPrevAF
						nPrevLogAF=-1;
						
						for(j=0; j<nStabPoints; j++) // AF loop (tau)
						{
							// y array values are window #=i+1
							sDPlot.y[(i*nStabPoints)+j]=(float)(i+1);

							// x array values are log10(AF)=log10(j+1)
							sDPlot.x[(i*nStabPoints)+j]=
								(float)log10((double)(j+1));

							// z array values are log10(sigma(t, tau))
							// Sigma (ADEV or HDEV) is calculated
							// for particular data window and AF=j+1
							// Data window start index is nStart+(i*nStepSize)
							// Data window end is
							// nStart+(i*nStepSize)+nWindowSize-1

							// Set parameters
							nAF=j+1;

							// For large data sets,
							// there are many unused sigma points
							// Calc can be speeded up by skipping those AFs
							// (a kind of "many tau" technique)
							// The sigma points that are used lie
							// on integer values of 100*log(AF)
							// Skip calc until
							// (int)(floor(100*log10(nAF))) changes
							if(((int)(floor(100*log10(nAF))))!=nPrevLogAF)
							{
								// Calc sigma
								// Special versions of the sigma calc
								// functions are used that treat all phase data
								// zero values as gaps
								if(bAVAR) // Allan variance
								{
									// Calc overlapping Allan deviation
									// from phase data in working array
									// Special version of
									// CalcPhaseOverlapSigma()
									// that treats all zeros as gaps
									ret=CalcDynamicPhaseOverlapSigma(fWorkData,
										&fSig, fTau0, nAF);

									// Check for no sigma value
									// (all points gaps)
									if(ret==-1)
									{
										fSig=1.0; // Flag for no sigma result
												  // Will get log value = 0
									}
								}
								else // Hadamard variance
								{
									// Calc overlapping Hadamard deviation
									// from phase data in working array
									ret=CalcDynamicPhaseOverlapHadamardDev(
										fWorkData, &fSig, fTau0, nAF);

									// Check for no sigma value
									// (all points gaps)
									if(ret==-1)
									{
										fSig=1.0; // Flag for no sigma result
												  // Will get log value = 0
									}
								}

								// Put sigma value into z array
								sDPlot.z[(i*nStabPoints)+j]=
									(float)(log10(fSig));

								// Keep track of min & max sigma
								if((i==0)&&(j==0))
								{
									fSigMin=(float)fSig;
									fSigMax=(float)fSig;
								}
								else
								{
									if((float)fSig<fSigMin)
									{
										fSigMin=(float)fSig;
									}
									if((float)fSig>fSigMax)
									{
										fSigMax=(float)fSig;
									}
								}

								// Save previous log AF value
								nPrevLogAF=(int)(floor(100*log10(nAF)));
							}

						} // End of inner loop (j)

						// Step progress bar 
						SendMessage(GETHCTL(IDC_DAVAR_PROGRESS), PBM_STEPIT,
							0, 0);

						// Show current analysis limits
						// as another progress indicator
						if(bDataType==FREQ_DATA)
						{
							// Update freq analysis limits
							_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
								(int)fWorkData[1]);
							SetWindowText(hwndFreqStart, szBuffer);
							_snprintf(szBuffer, sizeof(szBuffer), "%5.0d", 
								(int)fWorkData[2]);
							SetWindowText(hwndFreqEnd, szBuffer);
						}
						else // Phase data
						{
							// Update phase analysis limits
							_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
								(int)fWorkData[1]);
							SetWindowText(hwndPhaseStart, szBuffer);
							_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
								(int)fWorkData[2]);
							SetWindowText(hwndPhaseEnd, szBuffer);
						}

						// Process other messages & allow abort
						while(PeekMessage(&msg, NULL, 0, 0, PM_REMOVE))
						{
							if(!IsDialogMessage(hDialog, &msg))
							{
								TranslateMessage(&msg);
								DispatchMessage(&msg);
							}
						}

						// Respond to abort
						if(bAbort)
						{
							// Set # windows calculated before abort
							nNumWindows=i;
							
							bAbort=FALSE;
							break;
						}
					} // End of outer loop (i)

					// Set missing sigma values to log of minimum sigma
					// Missing sigma values were flagged
					// by having a log value = 0
					// Loop thru z array, looking for 0 values
					// and set them to fSigMin
					for(i=0; i<nNumWindows; i++) // Window loop (t)
					{
						for(j=0; j<nStabPoints; j++) // AF loop (tau)
						{
							if(sDPlot.z[(i*nStabPoints)+j]==0.0)
							{
								sDPlot.z[(i*nStabPoints)+j]=
									(float)(log10(fSigMin));
							}
						}
					}
								
					// Restore original freq analysis limits
					fFreqData[0]=fFreq0;	// # data points
					fFreqData[1]=fFreq1;	// Analysis start point
					fFreqData[2]=fFreq2;	// Analysis end point

					// Update freq analysis limits
					_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
						(int)fFreqData[1]);
					SetWindowText(hwndFreqStart, szBuffer);
					_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
						(int)fFreqData[2]);
					SetWindowText(hwndFreqEnd, szBuffer);

					// Restore original phase analysis limits
					fPhaseData[0]=fPhase0;	// # data points
					fPhaseData[1]=fPhase1;	// Analysis start point
					fPhaseData[2]=fPhase2;	// Analysis end point

					// Update phase analysis limits
					_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
						(int)fPhaseData[1]);
					SetWindowText(hwndPhaseStart, szBuffer);
					_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
						(int)fPhaseData[2]);
					SetWindowText(hwndPhaseEnd, szBuffer);

					// Clear progress bar 
					SendMessage(GETHCTL(IDC_DAVAR_PROGRESS), PBM_SETPOS, 0, 0);

					// Deactivate Abort button
					EnableWindow(GETHCTL(IDC_DAVAR_ABORT), FALSE);

					// Reactivate all other controls
					EnableWindow(GETHCTL(IDC_DAVAR_PLOT), TRUE);
					EnableWindow(GETHCTL(IDC_DAVAR_CANCEL), TRUE);
					EnableWindow(GETHCTL(IDC_DAVAR_HELP), TRUE);
					EnableWindow(GETHCTL(IDC_DAVAR_RESET), TRUE);
					EnableWindow(GETHCTL(IDC_DAVAR_READ), TRUE);
					EnableWindow(GETHCTL(IDC_DAVAR_WRITE), TRUE);
					EnableWindow(GETHCTL(IDC_DAVAR_DATE), TRUE);
					EnableWindow(GETHCTL(IDC_DAVAR_BOX), TRUE);
					EnableWindow(GETHCTL(IDC_DAVAR_COLORS), TRUE);
					EnableWindow(GETHCTL(IDC_DAVAR_WINSIZE), TRUE);
					EnableWindow(GETHCTL(IDC_DAVAR_STEPSIZE), TRUE);
					EnableWindow(GETHCTL(IDC_DAVAR_AVAR), TRUE);
					EnableWindow(GETHCTL(IDC_DAVAR_HVAR), TRUE);
					
					// Activate grid list box if colors selcted
					EnableWindow(GETHCTL(IDC_DAVAR_GRID), sDPlot.colors);
					EnableWindow(GETHCTL(IDC_DAVAR_GRIDLABEL), sDPlot.colors);

					// Put # points into d3plotdata struct
					sDPlot.npts=nNumWindows*nStabPoints;

					// Put # windows and # AFs into d3plotdata struct
					sDPlot.ny=nNumWindows;
					sDPlot.nx=nStabPoints;

					// Put window and step size into d3plotdata struct
					sDPlot.winsize=nWindowSize;
					sDPlot.stepsize=nStepSize;

					// Put tau0 into d3plotdata struct
					sDPlot.tau0=(float)fTau0;

					// Put min & max sigma into d3plotdata struct
					sDPlot.smin=fSigMin;
					sDPlot.smax=fSigMax;

					// Note:  The Z data is used only temporarily,
					// and the X and Y is not used at all
					// unless the surmatr() plotting function
					// is used (it has interpolator problems).
					// So the preferred approach is to convert the Z data
					// to the zmat[] format having a uniform grid
					// to be plotted using the surmat() function.

					// Fill z matrix with sigma data
					// Put data into xy array of z values
					// Have discrete window # y values for y index i
					// The log AF x values are multiplied by 100
					// and made into integer index values
					// There are many empty cells which are first
					// filled with NANs and then interpolated log sigma values
					// log AF always starts at 0, and max log AF is
					// sDPlot.xgmax of:
					// minmax(&sDPlot.xgmin,
					// &sDPlot.xgmax, sDPlot.x, sDPlot.npts)
					// so size of x dimension is:
					// is xsize=(int)(ceil(100*sDPlot.xgmax)
					// and size of y dimension is ysize=nNumWindows
					// Allocate z array zmat[] as size
					// nNumWindows*(int)(ceil(100*sDPlot.xgmax))
					// Array is organized as nNumWindows cols of xsize rows
					// Fill array with NANs
					// Then insert log sigma values according to x & y indices
					// Next section of code inserts interpolated log sigma
					// values at every point by interpolating in
					// x (log AF) plane only
					// Access zmat elements as *(zmat+(i*xsize)+j)

					// Assign size of y dimension
					ysize=nNumWindows;
					
					// Get size of x dimension
					minmax(&sDPlot.xgmin, &sDPlot.xgmax, sDPlot.x,
						sDPlot.npts);
					xsize=(int)(ceil(100*sDPlot.xgmax));

					#if(0) // For testing
					TRACE_INT(xsize*ysize);
					#endif
					
					// Allocate or reallocate z matrix
					// Keep this memory allocated after plot in case of replot
					// and reallocate it if another plot
					// Don't free it until DAVAR dialog box is closed
					if((sDPlot.zmat=(float*)
						realloc(sDPlot.zmat, xsize*ysize*sizeof(float)))==
						NULL)
					{
						// Display error message
						AllocErrorMessage();

						// Close dialog box
						EndDialog(hDlg, 0);
						return TRUE;
					}

					// Copy dimensions to d3plotdata struct
					sDPlot.xsize=xsize;
					sDPlot.ysize=ysize;

					// Fill z matrix
					// All i (window #) indices have values
					// Not all j (AF) indices have values
					// Outer loop through y (window #) dimension
					for(i=0; i<ysize; i++)
					{
						// Set AF to 1
						k=1;
						// Inner loop through x (logAF) dimension
						for(j=0; j<xsize; j++)
						{
							// Get known values from sDPlot.z
							// which is arranged in groups by window #
							// so i index is same
							// zmat[] has more j index values than sDPlot.z
							// which has values only at each all tau integer AF
							// 1st one at j=0 is same for AF=0, logAF=0
							// Calc 100*log of next integer AF and compare
							// zmat j index to it
							// Iterate this way up to xsize
							// Note different indices in zmat and sDPlot.z

							// Code to handle excess sigma values
							// at large AFs for large data sets
							if(j==(int)(floor(100*log10(k))))
							// Have sigma value for each zmat row
							{
								sDPlot.zmat[(i*xsize)+j]=
									sDPlot.z[(i*nStabPoints)+k-1];

								k++;
							}
							else if(j>(int)(floor(100*log10(k))))
							// Have excess sigma points - must skip some
							{
								while(j>(int)(floor(100*log10(k))))
								{
									k++;
								}

								sDPlot.zmat[(i*xsize)+j]=
									sDPlot.z[(i*nStabPoints)+k-1];
							}
							else
							// Insufficient sigma points
							// Must insert gap to interpolate
							{
								sDPlot.zmat[(i*xsize)+j]=FLOAT_MISSING;
							}
						}
					}

					// Calc interpolated values for missing sigma points
					// We need an estimated sigma for every 100*logAF
					// Outer loop through y (window #) dimension
					// Note:  1st point is always OK, which primes prev_OK
					for(i=0; i<ysize; i++)
					{
						// Inner loop through x (logAF) dimension
						for(j=0; j<xsize; j++)
						{
							if(IsNotRealFloat(sDPlot.zmat[(i*xsize)+j]))
							{
								#if(0) // For debugging
								MessageBeep(MB_OK);
								#endif

								// Find next OK point
								// Note:  There may not be one at end
								next_OK=(i*xsize)+j+1;
								while(IsNotRealFloat(sDPlot.zmat[next_OK]))
								{
									// Advance to next point
									next_OK++;

									// Check if we have reached end of window
									if(next_OK==(i*xsize)+xsize-1)
									{
										break; // Break out of inner loop
									}
								}

								// Calc how many points between OK ones
								gap=next_OK-prev_OK;

								// Calc interpolated value
								sDPlot.zmat[(i*xsize)+j]=sDPlot.zmat[prev_OK]+
									((sDPlot.zmat[next_OK]-
									sDPlot.zmat[prev_OK])/gap);

								// Call the interpolated value OK
								prev_OK=(i*xsize)+j;
							}
							else // Point OK
							{
								// Save previous OK point
								prev_OK=(i*xsize)+j;
							}
						}

					}

					#if(0) // For debugging
					// Apply minmax() to sDPlot.zmat[]
					minmax(&mmin, &mmax, sDPlot.zmat, sDPlot.npts);
					TRACE_EXP(mmin);
					TRACE_EXP(mmax);
					#endif
					
					// Free allocated working memory
					if(bAlloc)
					{
						free(fWorkData);
						fWorkData=NULL;
					}

					// Write XYZ data file
					fXYZ=fopen("XYZ.dat", "w");

					for(i=0; i<sDPlot.npts; i++)
					{
						_snprintf(szBuffer, sizeof(szBuffer), "%e %e %e\n",
							pow(10, sDPlot.x[i]), sDPlot.y[i],
							pow(10, sDPlot.z[i]));

						// Write data file
						fputs(szBuffer, fXYZ);
					}

					fclose(fXYZ);

					#if(0) // For testing only
					// Write ZMAT interpolated log sigma & sigma data file
					fXYZ=fopen("ZMAT.dat", "w");

					for(i=0; i<xsize*ysize; i++)
					{
						_snprintf(szBuffer, sizeof(szBuffer), " %d %e %e\n",
							(i%xsize), sDPlot.zmat[i], pow(10,
							sDPlot.zmat[i]));
						fputs(szBuffer, fXYZ);
					}

					fclose(fXYZ);
					#endif

					// Reset calc flag
					bCalc=FALSE;
				}
				break;
				
				// Respond to Abort button
				case IDC_DAVAR_ABORT:
				{
					bAbort=TRUE;
				}
				break;

				// Respond to CR in an edit control
				// Note: No button is a DEFPUSHBUTTON
				case IDOK:
				{
					// The HWND returned by GetFocus() is not the same as the
					// one returned by GetDlgItem(), so the uTitle, etc
					// variables are used in these tests
					if((UINT)GetFocus()==uTitle)
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DAVAR_TITLE, NULL, CBN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to SUBTITLE edit control
					if((UINT)GetFocus()==uSubtitle)
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DAVAR_SUBTITLE, NULL, CBN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to MESSAGE edit control
					if((UINT)GetFocus()==uMessage)
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DAVAR_MESSAGE, NULL, CBN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to FILENAME edit control
					if(GetFocus()==GETHCTL(IDC_DAVAR_FILENAME))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DAVAR_FILENAME, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to WINSIZE edit control
					if(GetFocus()==GETHCTL(IDC_DAVAR_WINSIZE))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DAVAR_WINSIZE, NULL, EN_KILLFOCUS));
					}

					// Send EN_KILLFOCUS message to STEPSIZE edit control
					if(GetFocus()==GETHCTL(IDC_DAVAR_STEPSIZE))
					{
						SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(
						IDC_DAVAR_STEPSIZE, NULL, EN_KILLFOCUS));
					}
				}
				break;

				// Respond to plot button
				case IDC_DAVAR_PLOT:
				{
					if(bCalc)
					{
						// Calculate values for surface plot
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DAVAR_CALC, NULL, 0));
					}

					// Refresh message
					// \n's may have been removed by previous plot
					GetWindowText(GETHCTL(IDC_DAVAR_MESSAGE),
						sDPlot.message_str, 5*MESSAGESIZE-1);

					// Set plot type
					nPlotType=DAVAR_PLOT;

					#if(0) // For debugging
					TRACE_INT(sDPlot.npts);
					#endif

					// Create child window for plot
					GPCWINCreate(hChildWnd, hInst, hDlg, SW_SHOWNORMAL,
						&hChildAccel, NULL);
				}
				break;

				// Reset all plot params to defaults
				case IDC_DAVAR_RESET:
				{
					// Display blank field
					strlcpy(sDPlot.message_str, "", MESSAGESIZE);

					// Full filename inc drive & directory where prgm started
					strlcpy(sDPlot.plot_filename, szDrive, FILENAMESIZE);
					strlcat(sDPlot.plot_filename, szDirectory, FILENAMESIZE);
					strlcat(sDPlot.plot_filename, "DAVAR.TKF", FILENAMESIZE);

					// Set initialization flag
					bFirstTime=TRUE;

					// Do initialization
					bSave=bUseDAVARPlotIni;
					bUseDAVARPlotIni=FALSE;
					SendMessage(hDlg, WM_INITDIALOG, (WPARAM)0, (LPARAM)0);
					bUseDAVARPlotIni=bSave;
				}
				break;

				// Respond to esc key or close button
				case IDCANCEL:
				case IDC_DAVAR_CANCEL:
				{
					// Save # user-entered title strings
					nUserTitles=ComboBox_GetCount(GETHCTL(IDC_DAVAR_TITLE))-
						NUM_DAVAR_TITLES;

					// Limit # user titles
					nUserTitles=min(nUserTitles, NUM_TITLES);

					// Save user titles
					if(nUserTitles)
					{
						for(i=0; i<nUserTitles; i++)
						{
							// Get size of title string
							nLength=ComboBox_GetLBTextLen(GETHCTL(
								IDC_DAVAR_TITLE), i);

							// Realloc title array
							if((szPlotTitle[i]=
								(LPSTR)realloc(szPlotTitle[i],
								(nLength+1)*sizeof(char)))==NULL)
							{
								// Just dsp err msg & skip saving string
								// We are closing dlg box anyway
								AllocErrorMessage();
							}
							else
							{
								// Save title string
								nDummy=
									ComboBox_GetLBText(GETHCTL(
									IDC_DAVAR_TITLE),
									i, szPlotTitle[i]);
							}
						}
					}

					// Save # user-entered subtitle strings
					nUserSubtitles=
						ComboBox_GetCount(GETHCTL(IDC_DAVAR_SUBTITLE))-
						NUM_DAVAR_SUBTITLES;

					// Limit # user subtitles
					nUserSubtitles=min(nUserSubtitles, NUM_SUBTITLES);

					// Save user subtitles
					if(nUserSubtitles)
					{
						for(i=0; i<nUserSubtitles; i++)
						{
							// Get size of subtitle string
							nLength=ComboBox_GetLBTextLen(GETHCTL(
								IDC_DAVAR_SUBTITLE), i);

							// Realloc subtitle array
							if((szPlotSubtitle[i]=
								(LPSTR)realloc(szPlotSubtitle[i],
								(nLength+1)*sizeof(char)))==NULL)
							{
								// Just dsp err msg & skip saving string
								// We are closing dlg box anyway
								AllocErrorMessage();
							}
							else
							{
								// Save subtitle string
								nDummy=ComboBox_GetLBText(GETHCTL(
									IDC_DAVAR_SUBTITLE), i, szPlotSubtitle[i]);
							}
						}
					}

					// Save # user-entered message strings
					nUserMessages=
						ComboBox_GetCount(GETHCTL(IDC_DAVAR_MESSAGE))-
						NUM_DAVAR_MESSAGES;

					// Limit # user messages
					nUserMessages=min(nUserMessages, NUM_MESSAGES);

					// Save user messages
					if(nUserMessages)
					{
						for(i=0; i<nUserMessages; i++)
						{
							// Get size of message string
							nLength=ComboBox_GetLBTextLen(GETHCTL(
								IDC_DAVAR_MESSAGE), i);

							// Realloc message array
							if((szPlotMessage[i]=
								(LPSTR)realloc(szPlotMessage[i],
								(nLength+1)*sizeof(char)))==NULL)
							{
								// Just dsp err msg & skip saving string
								// We are closing dlg box anyway
								AllocErrorMessage();
							}
							else
							{
								// Save message string
								nDummy=ComboBox_GetLBText(GETHCTL(
									IDC_DAVAR_MESSAGE), i, szPlotMessage[i]);
							}
						}
					}

					// Free d3plotdata struct arrays
					free(sDPlot.x);
					free(sDPlot.y);
					free(sDPlot.z);
					free(sDPlot.zmat);

					// Don't keep stale pointer values
					sDPlot.x=NULL;
					sDPlot.y=NULL;
					sDPlot.z=NULL;
					sDPlot.zmat=NULL;

					// Close dialog box
					EndDialog (hDlg, 0);
				}
				return TRUE;
			}
		}
		break;
	 }
	 return FALSE;
}

/*****************************************************************************/
/*									 								    	 */
/*  					 CalcDynamicPhaseOverlapSigma()           		     */
/*																		     */
/*		Function to calculate Allan variance using overlapping samples       */
/*		of phase data                                                        */
/*                                                                           */
/*      This function is used for dynamic stability analysis.  It is the     */
/*      same as CalcPhaseOverlapSigma() of the FrequenC library except       */
/*      that it treats all zeros as gaps.                                    */
/*                                                                           */
/*      Parameters:    	F_TYPE x[]    = phase data array                     */
/*                                      x[0] =  # phase data points          */
/*                                      x[1] = analysis start                */
/*                                      x[2] = analysis end                  */
/*  		            F_TYPE *p_sig = pointer to Allan deviation           */
/*			            F_TYPE tau    = averaging time of phase data         */
/*      	            int m         = averaging factor                     */
/*                                                                           */
/*		Return:         int           = # analysis points,  			     */
/*										or -1 if error                       */
/*									 									     */
/*		Notes:          Embedded zeros treated as gaps in phase data.        */
/*						Must have at least 1 analysis point; this            */
/*                      requires at least 3 adjacent non-gap phase data      */
/*                      points.  Averaging time for sigma calculation is     */
/*                      m times the tau parameter of the phase data.         */
/*                      m must be >0 , tau must be >0, and the # non-gap     */
/*                      phase data points N must be > 2m.                    */
/*                                                                           */
/*		Revision record:                                                     */
/*			04/10/97	Cloned from PhaseOverlapSigma() of FrequenC Library  */
/*						Fixed long-standing index error re analysis limits   */
/*			01/01/98	Changes for MS VC++ compatibility & warnings         */
/*			12/27/06	Adapted from CalcPhaseOverlapSigma() of FrequenC lib */
/*																		     */
/* (c) Copyright 1990-2006 Hamilton Technical Services  All Rights Reserved  */
/*                                                                           */
/*****************************************************************************/

int WINAPI CalcDynamicPhaseOverlapSigma(F_TYPE x[],
	F_TYPE *p_sig, F_TYPE tau, int m)
{
	double sum=0;                          /* summing variable to calc sigma */
	float fm=(float)m;                                 /* float version of m */
	int i;                                            /* index for summation */
	int num=0;                                          /* # analysis points */
	int n;                                        /* # frequency data points */

	n=(int)(*(x+2)-*(x+1)+1);                   /* total # phase data points */

	if( (m<1) || (n<2*m) || (tau<=0) )
	{
		return(-1);                                                 /* error */
	}

	for( i=(int)(*(x+1)+2); i<=(int)(*(x+2)-2*m+2); i++)     /* summing loop */
	/* i basically goes from 1 to N-2m where N is # phase data points        */
	/* and m is averaging factor.  Term *(x+1) is the analysis start limit   */
	/* (1 if all data used) & the 2 accounts for the data array offset       */
	{
		if( *(x+i) && *(x+i+m) && *(x+i+(2*m)) )
							         /* skip if any phase data value is zero */
		{
			sum += SQR ( *(x+i+(2*m)) - (2 * (*(x+i+m))) + *(x+i) );
			num++;
		}                                                          /* end if */
	}

	if(num>0)
	{
		*p_sig=sqrt( sum / (2.0*tau*tau*fm*fm*num));
		return(num);                                    /* # analysis points */
	}
	else
	{
		return(-1);                                                 /* error */
	}
}                                      /* end CalcDynamicPhaseOverlapSigma() */

/*****************************************************************************/
/*                                                                           */
/*                 CalcDynamicPhaseOverlapHadamardDev()                      */
/*                                                                           */
/*      Function to calc overlapping Hadamard variance from phase data       */
/*                                                                           */
/*      This function is used for dynamic stability analysis.  It is the     */
/*      same as CalcPhaseOverlapHadamardDev() of the FrequenC library        */
/*      except that it treats all zeros as gaps.                             */
/*                                                                           */
/*      Parameters:     F_TYPE x[]    = phase data                           */
/*                                      x[0] = # data points                 */
/*                                      x[1] = analysis start                */
/*                                      x[2] = analysis end                  */
/*                      F_TYPE *p_dev = pointer to Hadamard deviation        */
/*                      F_TYPE tau    = time between phase measurements      */
/*                      int    m      = averaging factor                     */
/*                                                                           */
/*      Return:         int           = # analysis points,                   */
/*                                      or -1 if error                       */
/*                                                                           */
/*      Note:           Embedded zeros treated as gaps in phase data.        */
/*                      Must have at least 1 analysis point; this            */
/*                      requires at least 4 adjacent non-gap phase data      */
/*                      points.  Tau must be >0.                             */
/*                                                                           */
/*      Reference:      T. Walter, "A Multi-Variance Analysis in the Time    */
/*                      Domain", Proc. 24th PTTI Meeting, Dec. 1992.         */
/*                      Modified by WJR to use fully-overlapping samples.    */
/*                                                                           */
/*      Revision record:                                                     */
/*          03/05/99    Created from CPHD.C of FrequenC32 Library            */
/*			12/27/06	Adapted from CalcPhaseOverlapHadamardDev() of        */
/*						FrequenC library                                     */
/*                                                                           */
/* (c) Copyright 1999-2006 Hamilton Technical Services  All Rights Reserved  */
/*                                                                           */
/*****************************************************************************/

int WINAPI CalcDynamicPhaseOverlapHadamardDev(F_TYPE x[],
	F_TYPE *p_dev, F_TYPE tau, int m)
{
    double sum;                            /* summing variable to calc sigma */
    int i;                                              /* index for summing */
    int num=0;                                          /* # analysis points */
    float fm=(float)m;                                 /* float version of m */

    if(tau<=0)
    {
        return(-1);                                                 /* error */
    }

    for(i=(int)(*(x+1)+2), sum=0; i<=(int)(*(x+2)+2-3*m); i++)
                                                /* index goes from 1 to n-3m */
                       /* for n data points from 1 to n; data starts at x[3] */
    {
        if( *(x+i) && *(x+i+m) && *(x+i+2*m) && *(x+i+3*m) )
                            /* skip if any imbedded phase data value is zero */
        {
            sum+=SQR((*(x+i+(3*m)))-3*(*(x+i+(2*m)))+3*(*(x+i+m))-(*(x+i)));
            num++;
        }                                                          /* end if */
    }                                                             /* end for */

    if(num>0)
    {
        *p_dev=sqrt(sum/(6.0*num*tau*tau*fm*fm));
        return(num);                                    /* # analysis points */
    }                                                              /* end if */
    else                                               /* no analysis points */
    {
        return(-1);                                                 /* error */
    }                                                            /* end else */
}

/*****************************************************************************/

