/*****************************************************************************/
/*                                                                           */
/*                            STABLE_D.C                                     */
/*                                                                           */
/*      Stable Windows 95/NT Dialog Box Functions  (1st Group)               */
/*                                                                           */
/*      AboutDlgProc()                                                       */
/*		WelcomeDlgProc()                                                     */
/*      SigmaDlgProc()                                                       */
/*      SigmaControls()                                                      */
/*      AvgDlgProc()                                                         */
/*		ArcConfigDlgProc()                                                   */
/*      NormDlgProc()                                                        */
/*      FillDlgProc()                                                        */
/*      ConvertDlgProc()                                                     */
/*		ConvertData()                                                        */
/*      StatsDlgProc()                                                       */
/*		CopyStats()                                                          */
/*      ScaleDlgProc()                                                       */
/*      CheckDlgProc()                                                       */
/*      GetOutlierData()                                                     */
/*      OutlierCompare()                                                     */
/*      DriftDlgProc()                                                       */
/*      NoiseDlgProc()                                                       */
/*      CalendarDlgProc()                                                    */
/*      WriteCalendar()                                                      */
/*      DateConv()                                                           */
/*		CopyCalendar()                                                       */
/*      ConfigureDlgProc()                                                   */
/*      FileDlgProc()                                                        */
/*		InputsDlgProc()                                                      */
/*		CopyDialog()                                                         */
/*		PlotInsertDlgProc()                                                  */
/*		RenameTabDlgProc()                                                   */
/*		PhaseFuncDlgProc()                                                   */
/*		FreqFuncDlgProc()                                                    */
/*		FreqJumpDlgProc()                                                    */
/*                                                                           */
/*      Revision record:                                                     */
/*          04/11/97    Changed to NewAverageFreqData() and                  */
/*                      NewAveragePhaseData() usage                          */
/*          06/29/97    Use GET_WM_COMMAND_ID, etc. WIN32 compatibility      */
/*                      macros to process WM_COMMAND messages:               */
/*                      wParam <- GET_WM_COMMAND_ID(wParam, lParam)          */
/*                      HIWORD(lParam) <- GET_WM_COMMAND_CMD(wParam, lParam) */
/*                      Replaced WORD with UINT                              */
/*          06/30/97    Replaced FAR PASCAL _export with WINAPI              */
/*                      Replaced MoveTo() with MoveToEx()                    */
/*			07/08/97	Switched to control message macros                   */
/*						Introduced use of GETHCTL() macro for GetDlgItem()   */
/*			07/10/97	More portability changes to messages                 */
/*			07/24/97	Changes made for Visual C++ compliation w/o warnings */
/*			12/24/97	Made changes for AOK BC 32 bit compliation           */
/*			01/16/98	Added ShortenExp() usage for MSC VC++                */
/*          04/06/98	Added FileDlgProc()                                  */
/*			09/12/00	Added InputsDlgProc()                                */
/*			10/13/02	Added CopyStats()                                    */
/*			10/16/02	Replace CopyCalendar() and CopyStats() with          */
/*						CopyDialog()                                         */
/*			09/30/03	Added PlotInsertDlgProc()                            */
/*			11/20/06	Added RenameTabDlgProc()                             */
/*          07/22/07    Changed to safe string functions                     */
/*          12/21/07	Added PhaseFuncDlgProc() and FreqFuncDlgProc()       */
/*			02/02/08	Added FreqJumpDlgProc()                              */
/*                                                                           */
/*  (c) 1996-2008  W. Riley Hamilton Technical Services All Rights Reserved  */
/*                                                                           */
/*****************************************************************************/

#define STRICT              // For Win32 compatibility
#include "stable_w.h"

// #define LOGGING				// For test logging

// Median value at file scope for comparison function
F_TYPE fMedVal;

/*****************************************************************************/
/*                                                                           */
/*                   About Dialog Procedure                                  */
/*                                                                           */
/*      Revision record:                                                     */
/*          12/07/97    Added stringtable code                               */
/*			02/10/02	Added license information                            */
/*			07/26/03	Added demo version                                   */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK AboutDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	
	// Local variables
	char szBuffer[BIG_BUFFER_SIZE+1];   // Text buffer
	int i;								// General integer

	#if(0) // For testing CompressData()
	F_TYPE fSizeValue;						// Size value
	F_TYPE fTauValue;						// Tau value
	int nSize;						// Compressed size
	#endif

	#if(0) // For testing strptime
	struct tm sTM;						// Time structure
	int nMJD;							// Integer MJD
	double fMJD;						// Complete MJD
	#endif

	#if(0) // For date conversion testing
	char szMJD[BIG_BUFFER_SIZE+1];		// MJD as string
	double fMJD;						// MJD as double
	int nCode;							// Function return code
	#endif

	#if(0) // For performance counter usage
	LARGE_INTEGER nFreq;
	LARGE_INTEGER nCount1;
	LARGE_INTEGER nCount2;
	#endif

	#if(0) // For Greenhall drift testing
	F_TYPE fDrift;
	#endif

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Load and display info for each version
			#ifndef VITSAS_VER
			#ifdef FULL_VER
			// Set dialog box title
			SetWindowText(hDlg, "About Stable32");
			
			// Set version strings
			LoadString(hInst, IDS_VERSION_NUMBER, szBuffer, BUFFER_SIZE);
			SetWindowText(GETHCTL(IDC_ABOUT_VER), szBuffer);
			LoadString(hInst, IDS_VERSION_DATE, szBuffer, BUFFER_SIZE);
			SetWindowText(GETHCTL(IDC_ABOUT_DATE), szBuffer);
			#endif
			#endif

			#ifdef STUDENT_VER
			// Set dialog box title
			SetWindowText(hDlg, "About Stable32 Student Version");

			// Set version strings
			LoadString(hInst, IDS_VERSION_STUNUM, szBuffer, BUFFER_SIZE);
			SetWindowText(GETHCTL(IDC_ABOUT_VER), szBuffer);
			LoadString(hInst, IDS_VERSION_STUDATE, szBuffer, BUFFER_SIZE);
			SetWindowText(GETHCTL(IDC_ABOUT_DATE), szBuffer);
			#endif

			#ifdef LITE_VER
			// Set dialog box title
			SetWindowText(hDlg, "About Stable Lite");
			
			// Set version strings
			LoadString(hInst, IDS_VERSION_LITENUM, szBuffer, BUFFER_SIZE);
			SetWindowText(GETHCTL(IDC_ABOUT_VER), szBuffer);
			LoadString(hInst, IDS_VERSION_LITEDATE, szBuffer, BUFFER_SIZE);
			SetWindowText(GETHCTL(IDC_ABOUT_DATE), szBuffer);
			#endif

			#ifdef DEMO_VER
			// Set dialog box title
			SetWindowText(hDlg, "About Stable32 Demo Version");

			// Set version strings
			LoadString(hInst, IDS_VERSION_DEMONUM, szBuffer, BUFFER_SIZE);
			SetWindowText(GETHCTL(IDC_ABOUT_VER), szBuffer);
			LoadString(hInst, IDS_VERSION_DEMODATE, szBuffer, BUFFER_SIZE);
			SetWindowText(GETHCTL(IDC_ABOUT_DATE), szBuffer);

			// Text that appears only on startup
			SetWindowText(GETHCTL(IDC_ABOUT_TEXT), "This Demo Version "
				"of the Stable32 program has all the features of the "
				"full version except that its use is limited to 30 days "
				"and the plots have a watermark on them.  Please see "
				"www.wriley.com for information about buying "
				"the full version.");
			#endif

			#ifdef VITSAS_VER
			// Set dialog box title
			SetWindowText(hDlg, "About Stable32 V-ITSAS Version");

			// Set version strings
			LoadString(hInst, IDS_VERSION_NUMBER, szBuffer, BUFFER_SIZE);
			SetWindowText(GETHCTL(IDC_ABOUT_VER), szBuffer);
			LoadString(hInst, IDS_VERSION_DATE, szBuffer, BUFFER_SIZE);
			SetWindowText(GETHCTL(IDC_ABOUT_DATE), szBuffer);
			#endif

			LoadString(hInst, IDS_FREQUENC_VER, szBuffer, BUFFER_SIZE);
			SetWindowText(GETHCTL(IDC_ABOUT_DLL), szBuffer);

			return TRUE;
		}

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
            {
				case IDC_ABOUT_LICENSE:
				{
					// Get license code #
					i=CheckLicense();

					#if(0) // 11/03/17 Remove all these options for IEEE UFFC Version 1.61
					#ifdef DEMO_VER
					MessageBox(hDlg,
						"A license is hereby granted to use this program "
						"for demonstration purposes only.  The Stable32 Demo "
						"Version may be installed on a single computer "
						"within the immediate user group that obtained it, "
						"and no other copies may be made or installed, nor "
						"may this or additional copies "
						"be distributed to others.  "
						"This program has been extensively tested, "
						"but it is never possible to declare a program "
						"completely bug-free.  No warranty is made, "
						"nor is any liability assumed, "
						"in connection with the use of the program.",
						"Stable32 Demo Version License", MB_ICONINFORMATION);
					#endif

					#ifdef VITSAS_VER
					MessageBox(hDlg,
						"A license is hereby granted to use this program "
						"for evaluation purposes only.  The Stable32 V-ITSAS "
						"Version may be installed on a single computer "
						"within the immediate user group that obtained it, "
						"and no other copies may be made or installed, nor "
						"may this or additional copies "
						"be distributed to others.  "
						"This program has been extensively tested, "
						"but it is never possible to declare a program "
						"completely bug-free.  No warranty is made, "
						"nor is any liability assumed, "
						"in connection with the use of the program.",
						"Stable32 V-ITSAS Version License", MB_ICONINFORMATION);
					#endif

					#ifndef DEMO_VER
					#ifndef VITSAS_VER
					// Version # applies to full version # >= 1.50
					if(i>=150)
					{
						_snprintf(szBuffer, sizeof(szBuffer),
							"A license is hereby granted to the purchaser "
							"for the use of this program.  Stable32 may be "
							"installed on any number of computers within "
							"the immediate user group that purchased it, "
							"and backup copies may be made, but only one "
							"copy of the program may be used at any time.  "
							"Separate licenses are required for each "
							"concurrent use.  Additional copies of the "
							"program may not be distributed to others.  "
							"Stable32 has been extensively tested, but it "
							"is never possible to declare a program "
							"completely bug-free.  No warranty is made, "
							"nor is any liability assumed, "
							"in connection with the use of the program.\n\n"
							"Original Stable32 Licensed Version # = %3.2f",
							(double)i/100.0);
						MessageBox(hDlg,szBuffer, "Stable32 License",
							MB_ICONINFORMATION);
					}
					else // Version < 1.50
						MessageBox(hDlg,
							"A license is hereby granted to the purchaser "
							"for the use of this program.  "
							"Stable32 may be installed on any number of "
							"computers within the immediate user group that "
							"purchased it, and backup copies may be made, "
							"but only one copy of the program may be used at "
							"any time.  Separate licenses are required for "
							"each concurrent use.  Additional copies of the "
							"program may not be distributed to others.  "
							"Stable32 has been extensively tested, "
							"but it is never possible to declare a program "
							"completely bug-free.  No warranty is made, "
							"nor is any liability assumed, "
							"in connection with the use of the program.",
							"Stable32 License", MB_ICONINFORMATION);
					#endif
					#endif
					#endif

					// License for IEEE UFFC Version 1.61
					#if(1)
						MessageBox(hDlg,
							"A license is hereby granted "
							"for the use of this free IEEE UFFC version of Stable32.  "
							"See the program documentation for the complete license provisions.  "
							"Stable32 has been extensively tested, "
							"but it is never possible to declare a program "
							"completely bug-free.  No warranty is made, "
							"nor is any liability assumed, "
							"in connection with the use of the program.",
							"Stable32 License", MB_ICONINFORMATION);
					#endif
				}
				break;    
				
				case IDOK:
                case IDCANCEL:
                {
					#if(0) // For testing
					TRACE_EXP(fabs(invstudenttdistribution(18, 0.025)));
					#endif

					#if(0) // For testing
					TRACE_EXP(fabs(studenttdistribution(198, 7.07)));
					#endif

					#if(0) // For testing
					Prewhiten(fFreqData, 1.0);
					#endif

					#if(0) // For testing
					// LOWPASS = 0
					// Zero FFT data from index high to n2-1
					// and its conjugate
					// FFTFilter(fData, bDataType, 0, 0, 100);

					// HIGHPASS = 1
					// Zero FFT data from index 1 to low
					// and its conjugate
					// FFTFilter(fData, bDataType, 1, 100, 0);

					// BANDPASS = 2
					// Zero FFT data from index 1 to low
					// and from index high to n2-1
					// and their conjugates
					// FFTFilter(fData, bDataType, 2, 100, 125);

					// BANDSTOP = 3
					// Zero FFT data from low to high
					// and its conjugate
					// FFTFilter(fData, bDataType, 3, 100, 1000);
					#endif

					#if(0) // For testing
					strcpy(szBuffer, " 123 456  789 ");
					TRACE_STR(szBuffer);
					TRACE_INT(strlen(szBuffer));
					i=RemoveWhitespace(szBuffer);
					TRACE_INT(i);
					TRACE_STR(szBuffer);
					TRACE_INT(strlen(szBuffer));
					#endif

					#if(0) // For testing
					// Note:  This test code investigates the possibility
					// of parsing date and time fields in a data file
					// and converting them to a MJD timetag
					// using the UNIX strptime() function
					// This particular example is only one of several
					// possible time formats that could be supported
					// In particular, one would want to handle both
					// U.S. and ISO dates
					// e.g., mm/dd/yyyy or yyyy/mm/dd
					// where the year can be either yyyy or yy
					strptime("08/10/08 12:15:36", "%D %T", &sTM);

					// Show day, month and year
					TRACE_INT(sTM.tm_mday); // tm.mday is 1-31
					TRACE_INT(sTM.tm_mon);  // tm_mon is 0-11
					TRACE_INT(sTM.tm_year); // tm_year is 1900=0

					// Show hour, minute and second (12.26 hours = 0.5108333 day)
					TRACE_INT(sTM.tm_hour); // tm.hour is 0-23
					TRACE_INT(sTM.tm_min);  // tm_min is 0-59
					TRACE_INT(sTM.tm_sec); // tm_sec is 0-59

					// Convert calendar date and time to integer plus fractional MJD
					// Date to integer MJD (54688)
					nMJD=DateToMJD(sTM.tm_mday, sTM.tm_mon+1, sTM.tm_year+1900);
					TRACE_INT(nMJD);

					// Calc the fractional MJD
					fMJD=(sTM.tm_hour/24.)+(sTM.tm_min/1440.)+(sTM.tm_sec/86400.);

					// Combine them
					fMJD+=(double)nMJD;

					// Show complete MJD (54688.5108333)
					sprintf(szBuffer, "%12.7f", fMJD);
					TRACE_STR(szBuffer);
					#endif

					#if(0) // For testing 07/27/09
					// A problem with dates and data reading has been reported
					// for the Database function
					// Among other things, it gives a non-existent June 31 date
					// For example:
					// MJD = 55013.522546
					// UTC = 2009-06-31 12:32:28
					// MJD 55013 is really July 1, 2009
					// Suspect problem with MJD - PostgreSQL timestamp conversions
					// MJDtoTimestamp() and TimestampToMJD():
					//     int TimestampToMJD(char *timestamp, char *mjd, double *mjdval)
					//     void MJDtoTimestamp(double mjd, char *timestamp)
					// Exercise them for debugging purposes here

					// Title
					TRACE_STR("MJD/Timestamp Testing");

					// Try MJD to timestamp conversion
					fMJD=55013.522546;
					MJDtoTimestamp(fMJD, szBuffer);
					TRACE_STR(szBuffer);
					// Works OK - get 2009-07-01 12:32:28

					// Try timestamp to MJD conversion with invalid date
					fMJD=0.0; // Initialize to zero so error can be seen
					strcpy(szBuffer, "2009-06-31 12:32:28");
					nCode=TimestampToMJD(szBuffer, szMJD, &fMJD);
					TRACE_INT(nCode);
					// Get error code=5 (invalid day)
					// Error is correctly reported
					// Day value 31 is wrong
					TRACE_STR(szMJD);
					// MJD string is NG - function failed before setting it
					sprintf(szBuffer, "%12.6f", fMJD);
					TRACE_STR(szBuffer);
					// fMJD correct - get 55013.522546

					// Try timestamp to MJD conversion with valid date
					fMJD=0.0; // Initialize to zero so error can be seen
					strcpy(szBuffer, "2009-07-01 12:32:28");
					nCode=TimestampToMJD(szBuffer, szMJD, &fMJD);
					TRACE_INT(nCode);
					// Get success code=0
					TRACE_STR(szMJD);
					// MJD string is OK
					sprintf(szBuffer, "%12.6f", fMJD);
					TRACE_STR(szBuffer);
					// fMJD correct - get 55013.522546
					#endif

					#if(0) // For testing 06/02/10
					// Try QueryPerformanceFrequency() and QueryPerformanceCounter()
					QueryPerformanceFrequency(&nFreq);
					TRACE_INT(nFreq.HighPart);
					TRACE_UINT(nFreq.LowPart);
					QueryPerformanceCounter(&nCount1);
					TRACE_INT(nCount1.HighPart);
					TRACE_UINT(nCount1.LowPart);
					QueryPerformanceCounter(&nCount2);
					TRACE_INT(nCount2.HighPart);
					TRACE_UINT(nCount2.LowPart);
					// The high part of nFreq is zero
					// The low part of nFreq is 2,727,578 so the resolution is about 0.37 us
					// Calc time difference in us
					// Ignore high part
					TRACE_UINT((((nCount2.LowPart-nCount1.LowPart)*1000000)/nFreq.LowPart));
					// Result is unreasonably small ???
					#endif

					#if(0) // For testing 11/21/11
					// Try Greemhall drift calc
					GreenhallDrift(fData, 1.0, &fDrift);
					TRACE_EXP(fDrift);
					#endif

					#if(0) // Added for testing 11/27/11
					// Is special command flag set?
					if(bSpecialCmd)
					{
						// Launching Stable32 with -* on the command line
						// sets the bSpecialCmd flag
						// If that flag is set, whatever code is inserted here
						// will be executed when the About box is closed
						strlcpy(szBuffer, "No Diagnostic Message", sizeof(szBuffer));
						MessageBox(hwndMain, szBuffer,"Stable32 Information", MB_OK);
					}
					#endif

					#if(0) // Try CompressData()
					// Call data compression function
					nSize=CompressData(fData, bDataType, PLOT_PIXELS);

					// For testing
					// TRACE_INT(nSize);

                    // Get original data size
					if(bDataType)
                    {
                        GetWindowText(hwndFreqNum, szBuffer, BUFFER_SIZE);
                        fSizeValue=(F_TYPE)atof(szBuffer);
                    }
                    else // Phase data
                    {
                        GetWindowText(hwndPhaseNum, szBuffer, BUFFER_SIZE);
                        fSizeValue=(F_TYPE)atof(szBuffer);
                    }

                    // Make adjustments for the compressed data
					// if compression is used to alter data
					// and not just for plotting
					// # data points changes and so does tau
					// Must update status display and plot
					// and put an entry in the log file
					// 
					// Update status display
                    _snprintf(szBuffer, sizeof(szBuffer), "%d",
						(int)fData[0]);
					if(bDataType==FREQ_DATA)
                    {
                        SetWindowText(hwndFreqNum, szBuffer);
                        SetWindowText(hwndFreqEnd, szBuffer);
                        SetWindowText(hwndFreqStart, "1");
					}
                    else // Phase data
                    {
                        SetWindowText(hwndPhaseNum, szBuffer);
                        SetWindowText(hwndPhaseEnd, szBuffer);
                        SetWindowText(hwndPhaseStart, "1");
                    }

                    // Set data changes flag
                    if(bDataType==FREQ_DATA)
                    {
						// Put info into log file (not done)
								
                        // Update flags
						bFreqDataChanged=TRUE;
						bFreqDataUnsaved=TRUE;
						sFPlot.new_file=TRUE;
                        bFreqScaleChanged=TRUE;
						bFreqRedraw=TRUE;

                        // Increment filename
                        if(bIncExtension)
                        {
                            IncExtension(szFile, FREQ_DATA);
                            IncExtension(szFileTitle, FREQ_DATA);
                            IncExtension(szFreqFile, FREQ_DATA);
                            IncExtension(szFreqFileTitle, FREQ_DATA);
                            SetWindowText(hwndFreqFilename, szFileTitle);
                        }
					}
                    else
                    {
						// Put info into log file (not done)
								
                        // Update flags
						bPhaseDataChanged=TRUE;
						bPhaseDataUnsaved=TRUE;
                        bPhaseScaleChanged=TRUE;
						bPhaseRedraw=TRUE;

                        // Increment filename
                        if(bIncExtension)
                        {
                            IncExtension(szFile, PHASE_DATA);
                            IncExtension(szFileTitle, PHASE_DATA);
                            IncExtension(szPhaseFile, PHASE_DATA);
                            IncExtension(szPhaseFileTitle, PHASE_DATA);
                            SetWindowText(hwndPhaseFilename, szFileTitle);
                        }
                    }

					// Force new PSD plot scale
					sPSPlot.y_tic=0;

					// Redraw status plots from new data
					UpdateStatusBar(hwndMain, NEW_DATA);

					// Reset redraw flags
					bPhaseRedraw=FALSE;
					bFreqRedraw=FALSE;

					// Clear synch flag
					bSynch=FALSE;

					// Clear plot lines
					ClearLines();

					// Adjust tau value
					// Tau is multiplied by n/2m
					// n is original # points
					// 2m is new # points = CompressData() return value (i here)
                    if(bDataType)
                    {
                        GetWindowText(hwndFreqTau, szBuffer, BUFFER_SIZE);
                        fTauValue=(F_TYPE)atof(szBuffer);
						_snprintf(szBuffer, sizeof(szBuffer), "%11.5e",
							fTauValue*fSizeValue/((double)nSize));
						ShortenExp(szBuffer);
                        SetWindowText(hwndFreqTau, szBuffer);
                    }
                    else // Phase data
                    {
                        GetWindowText(hwndPhaseTau, szBuffer, BUFFER_SIZE);
                        fTauValue=(F_TYPE)atof(szBuffer);
						_snprintf(szBuffer, sizeof(szBuffer), "%11.5e",
							fTauValue*fSizeValue/((double)nSize));
						ShortenExp(szBuffer);
                        SetWindowText(hwndPhaseTau, szBuffer);
                    }
					#endif

 					EndDialog (hDlg, 0);
                }
			    break;

                return TRUE;
			}
        }
     }
     return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*                   Welcome Dialog Procedure                                */
/*                                                                           */
/*      Revision record:                                                     */
/*          02/28/98    Created                                              */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK WelcomeDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Set state of show checkbox
			Button_SetCheck(GETHCTL(IDC_WELCOME_SHOW), bShowWelcome);

			return TRUE;
		}

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
            {
				// Respond to show welcome checkbox
				case IDC_WELCOME_SHOW:
				{
					// Get the state of the show welcome checkbox
					bShowWelcome=
						(BOOL)Button_GetCheck(GETHCTL(IDC_WELCOME_SHOW));
				}
				break;

				// Respond to OK or cancel
				case IDOK:
                case IDCANCEL:
                {
                    DestroyWindow(hDlg);

					// QUESTION: Should hDlgModeless2 be set to 0 here?
					// I think so - added this 08/11/98
					// Don't notice any difference

					// Was hDlgModeless2
					hDlgModeless=0;
                }
                return TRUE;
			}
        }
        break;
     }
     return FALSE;
}
/*****************************************************************************/
/*                                                                           */
/*                   Sigma Dialog Procedure                                  */
/*                                                                           */
/*      Sigma dialog box controls:                                           */
/*         IDC_SIGMA_AVGFACTOR      Averaging factor                         */
/*         IDC_SIGMA_VALUE          Non-normal Sigma or Std Dev value (ro)   */
/*         IDC_SIGMA_LABEL          Label for non-normal Sigma or Std Dev    */
/*         IDC_SIGMA_SIGMA          Normal Sigma value (read only)           */
/*         IDC_SIGMA_SHOW           Show details check box                   */
/*         IDC_SIGMA_PARAMS         Groupbox                                 */
/*         IDC_SIGMA_NOISETYPE      Groupbox                                 */
/*         IDC_SIGMA_MU             Mu noise parameter (read only)           */
/*         IDC_SIGMA_KN             Kn noise coefficient (read only)         */
/*         IDC_SIGMA_CONFIDENCE     Groupbox                                 */
/*         IDC_SIGMA_SINGLE         Single-sided CI radio button             */
/*         IDC_SIGMA_DOUBLE         Double-sided CI radio button             */
/*         IDC_SIGMA_MIN            Min sigma value (read only)              */
/*         IDC_SIGMA_MAX            Max sigma value (read only)              */
/*         IDC_SIGMA_CI             Confidence interval (not used)           */
/*         IDC_SIGMA_CF             Confidence factor                        */
/*         IDC_SIGMA_DF             Degrees of freedom (read only)           */
/*         IDC_SIGMA_NUM            # analysis points (read only)            */
/*         IDC_SIGMA_ALPHA          Alpha noise parameter (read only)        */
/*         IDC_SIGMA_NOISE          Estimated noise type (read only)         */
/*         IDC_SIGMA_B1             B1 ratio (read only)                     */
/*         IDC_SIGMA_STDDEV         Standard deviation value (read only)     */
/*         IDC_SIGMA_TAU            Averaging time (read only)               */
/*         IDC_SIGMA_BWFACTOR       Bandwidth factor                         */
/*         IDC_SIGMA_RESULTS        Groupbox                                 */
/*         IDC_SIGMA_HIDE           Hide details check box                   */
/*         IDC_SIGMA_TYPE           Sigma type combo box                     */
/*         IDC_SIGMA_MODSIG         Same as B1 ratio (read only)             */
/*         IDC_SIGMA_TIMESIG        Same as B1 ratio (read only)             */
/*                                                                           */
/*      Noise Types               Alpha                                      */
/*           W_PM                   2                                        */
/*           F_PM                   1                                        */
/*           W_FM                   0                                        */
/*           F_FM                  -1                                        */
/*          RW_FM                  -2                                        */
/*          FW_FM                  -3                                        */
/*			RR_FM				   -4                                        */
/*                                                                           */
/*      Revision record:                                                     */
/*          10/12/96    Added abort code                                     */
/*          12/18/96    Added noise ID & CI calc to TOTALDEV                 */
/*          01/21/97    Fixed error in phase mod sigma for AF!=1             */
/*          02/01/97    Added avg factor check when sigma type changes       */
/*          02/04/97    Changed inverse chi square function                  */
/*          02/05/97    Added bounds checks on CF entry                      */
/*          02/19/97    Added error traps for zero sigma                     */
/*          03/18/97    Added logic for autocalc                             */
/*                      Added data endpoint matching for phase TOTALDEV      */
/*          03/31/97    Changed to new reflected TOTALVAR for phase data     */
/*          04/05/97    Adjusted max avg factor for analysis limits          */
/*                      Incremented df+1 for TOTALVAR                        */
/*                      Changed freq TOTALDEV calc to conv to phase data     */
/*                      and then calc reflected TOTALVAR as phase data       */
/*                      Applied bias correction to TOTALDEV                  */
/*                      Added provisions for setting noise type              */
/*          04/06/97    Added display of B(TOTALVAR) bias function           */
/*          04/30/97    Added 'm' command for maximum AF                     */
/*			11/27/97	Fixed error for phase mod sigma with gaps            */
/*			12/06/97	Changed from ReflectedTotalvarCalc() to latest       */
/*						doubly-reflected TotvarCalc()                        */
/*						Fixed error for phase time sigma with gaps           */
/*			12/18/98	Added copy button to copy results to clipboard       */
/*			01/14/99	Added global sigma type usage                        */
/*			01/29/99	Changed to NewCalcFreqOverlapSigma()                 */
/*			03/14/99	Added overlapping Hadamard deviation                 */
/*			04/24/99	Added handling of RR FM noise                        */
/*			11/26/99	Fixed Totvar mem alloc error code & recovery         */
/*			12/24/99	Added provisions for Mod Total Sigma                 */
/*			05/06/00	Added TTOT                                           */
/*			05/07/00	Added abort                                          */
/*			06/13/00	Changed to faster MTOT calculation                   */
/*			11/02/00	Added HTOT                                           */
/*			11/24/00	Reorganized a lot of the sigma calc & noise id code  */
/*			12/18/00	Changed HTOT to use overlapping HDEV at AF=1         */
/*			12/24/00	Revised per final draft of PTTI'00 HTOT paper        */
/*			06/16/02	Replace CalcPhaseModSigma() with new version         */
/*			08/28/02	Changed to NewConvFreqToPhase()                      */
/*			09/22/02	Added provisions for deadtime correction.            */
/*			02/08/03	Added Tho1                                          */
/*			03/15/03	Use ConvFreqToPhase() w/o New with FrequenC DLL V2.0 */
/*			03/31/03	Fixed gap problem with Totvar calc                   */
/*			04/30/03	Revised Theo1 per D. Howe's final version            */
/*			05/09/03	Added edf & CI calc to Tho1                         */
/*			06/20/03	Remove gaps before MDEV calc                         */
/*			07/15/03	Added use of Combined EDF()                          */
/*			09/08/03	Added Greenhall ACF lag 1 noise ID calc              */
/*						ACF noise ID calc done if >= ACFNUM analysis points  */
/*						ACF noise ID applied if bACFNoiseID flag is set      */
/*						bACFNoiseID flag forced false if not enough points   */
/*						or if set noise flag is set                          */
/*						Previous bACGNoiseID flag setting preserved if AF    */
/*						makes # analysis points too small                    */
/*						B1/Rn noise ID calc not done if bACFNoiseID is set   */
/*			12/20/03	Changed to New Tho1 bias function                   */
/*						Added THEO1_MIN macro to set min Tho1 AF            */
/*			08/24/07	Added nClip usage                                    */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK SigmaDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local macros
	#define ROOT3 1.732050808				// Square root of 3
	#define ACFNUM 30						// # pts to do ACF noise calc
	#define	THEO1_MIN 10					// Min AF for Tho1

	// Local variables
	// Chars
	char szBuffer[BUFFER_SIZE+1];   // Text buffer
	char szTemp[BUFFER_SIZE+1];		// Temporary buffer

	// Noise type array: index=alpha+4
	static char *szNoiseType[]=
		{"RR FM", "FW FM","RW FM","F FM","W FM","F PM","W PM"};
	// Noise mu array: index=alpha+4
	static char *szNoiseMu[]={"+3","+2","+1","0","-1","-2","-2"};
	// Noise coefficient array: index=alpha+4
	static char *szNoiseCoeff[]=
		{"0.75","0.75","0.75","0.77","0.87","0.99","0.99"};

	// Ints
	int i;                          // Index
	int nTheo1Noise;				// Estimated Tho1 noise alpha
	static int nNum;                // # analysis points
	static int nAlpha;              // Noise type S(f) exponent
	static int nACFAlpha;			// Noise exponent determined by lag 1 ACF
	static int nMu;					// Sigma-tau log-log slope
	static int nGaps;               // # gaps in data
	static int nDat;                // Data type correct factor (1-bDataType)
	static int nNumb;               // Total # analysis points
	static int nPoints;             // Total # data points
	static int nNoiseOffset;		// Offset to noise type code
	static int nDmax;				// Lag 1 ACF maximum differencing parameter
	
	int nEntry;                     // User avg factor entry to be validated
	int nPrev;                      // Previous value
	int nMinAF;						// Min allowable AF
	static int nMaxAF[15];          // Max allowable AF for each sigma type
	// Index was 6 until 06/03/98
	// Index was 8 until 09/14/98 - was too small - caused undetected O/F!
	// Changed from 10 to 11 when overlapping Hadamard added 03/14/99
	// Changed from 11 to 13 when mod total and time total added 05/05/00
	// Changed from 13 to 14 when HTOT added 11/02/00
	// Changed to 15 when Tho1 was added 02/08/03 
	static int nAvgFactor=1;        // Averaging factor
	static int nSigmaType=0;        // Sigma type
	static int nNoiseType=4;        // # of manually set noise type (alpha+4)
									// Default=2 (alpha+2) until 04/25/99
	static int nClip;				// Size of szClipboard (chars)
	// BOOLs
	static BOOL bCIType=FALSE;      // CI type: 0=single, 1=double
	static BOOL bErrorTrap=FALSE;   // Flag for entry error
	static BOOL bSetNoise=FALSE;    // Flag to manually set noise type
	static BOOL bSaveSetNoise;		// Saved set noise flag
	static BOOL bSaveACFNoiseID;	// Saved ACF noise ID flag
	// Floats
	float fNum;						// General temporary float number
	float fTheo1BiasFactor;			// Tho1 bias factor
	static float fB1Ratio;          // B1 bias function
	static float fB2Ratio;          // B2 ratio
	static float fB3Ratio;          // B3 ratio
	static float fRnRatio;          // R(n) ratio
	static float fDeadtime=1.0;		// T/tau deadtime ratio
	static float fKn;               // Kn noise coefficient
	static float fDF;               // # X^2 degrees of freedom
	static float fLow;              // Low confidence factor limit
	static float fHigh;             // High confidence factor limit
	static float fChiLow;           // X^2 value for low limit
	static float fChiHigh;          // X^2 value for high limit
	static float fBias;             // TOTALVAR bias factor
	static float fCF=(float)0.95;   // Confidence factor
	static float fBW=(float)10.0;   // Bandwidth factor
	static float fPrev;				// Previous value during entry
	static float fEntry;			// New value during entry
	static float fTheo1Bias=1.0;	// Tho1 bias factor
	// F_TYPEs
	static F_TYPE fSigma;           // General sigma value
	static F_TYPE fMaxSigma;        // Maximum sigma (upper confidence limit)
	static F_TYPE fMinSigma;        // Minimum sigma (lower confidence limit)
	static F_TYPE fNormalSigma;     // Normal sigma value
	static F_TYPE fOverlappingSigma;// Overlapping sigma value
	static F_TYPE fModSigma;        // Mod sigma value
	static F_TYPE fTimeSigma;       // Time sigma value
	static F_TYPE fHadamardSigma;   // Hadamard deviation value
	static F_TYPE fOverlapHadSigma; // Overlapping Hadamard deviation value
	static F_TYPE fDriftStdDev;		// Std dev of freq drift value
	static F_TYPE fTotalSigma;      // Total sigma value
	static F_TYPE fModTotalSigma;	// Mod total sigma value
	static F_TYPE fTimeTotalSigma;	// Time total sigma value
	static F_TYPE fHadTotalSigma;	// Hadamard total sigma value
	static F_TYPE fTheo1Sigma;		// Tho1 sigma value
	static F_TYPE fTIErms;			// TIErms value;
	static F_TYPE fMTIE;			// MTIE value;
	static F_TYPE fStdDev;          // Standard deviation value
	static F_TYPE fValue;           // Value of non-normal sigma or std dev
	static F_TYPE *fSigmaData;      // Pointer to working data array
	static F_TYPE fTau;             // Tau value
	F_TYPE fTemp;					// Temporary value
	
	// Clipboard variables
	char szFormat[BUFFER_SIZE+1];   // Format string
	HGLOBAL hClipboard;				// Handle to clipboard text buffer
	LPSTR	szClipboard;			// Ptr to clipboard text string

	// ACF noise ID variables
	//float fOne[2];				// Lag 1 only autocorrelation array
	//static float fDelta;			// Greenhall delta
	//int n2Delta;					// Greenhall 2*delta
	//static int nN;				// # points in noise ID function
	//static int nP;				// Greenhall p = alpha estimate
	//static int nD;				// Greenhall d = difference order
	float fR1;						// Lag 1 ACF for original data
	float fAlpha;					// Estimated alpha as decimal value

	// Set global dialog box handle
	hDialog=hDlg;

	LoadIcon(hInst, "FlatSigmaIcon");

	switch(message)
	{
		case WM_INITDIALOG:
		{
            // Write prompt message
            WritePromptMessage(TB_SIGMA);

			// Get dialog box title
			GetWindowText(hDlg, szBoxTitle, TITLESIZE);

			// Clear abort and yield flags
			bAbort=FALSE;
			bYield=FALSE;

			// Disable the copy button until there are results
			EnableWindow(GETHCTL(IDC_SIGMA_COPY), FALSE);

			// Allocate working memory
			// Note the +1 to allow use of this array for freq to phase conv
			if((fSigmaData=(F_TYPE*)malloc(
				((int)fData[0]+ARRAY_OFFSET+EXTRA_MEM+1)*sizeof(F_TYPE)))==
				NULL)
			{
				// Announce error and bail out
				AllocErrorMessage();
				EndDialog(hDlg, 0);
				return TRUE;
			}

			// Copy complete data array to working memory
			for(i=0; i<fData[0]+ARRAY_OFFSET; i++)
			{
				fSigmaData[i]=fData[i];
			}

			// Write prompt message
			WritePromptMessage(TB_SIGMA);

			// Set local sigma type to global value
			nSigmaType=nGlobalSigmaType;

			// Fill up the noise type combo box list
			// Show RR FM and FW FM for Hadamard devs only 
			if( (nSigmaType==HADAMARD_SIGMA) ||
				(nSigmaType==OVERLAPHAD_SIGMA) ||
				(nSigmaType==HADTOTAL_SIGMA) )
			{
				for(i=0; i<7; i++)
				{
					LoadString(hInst, IDS_SIGMA_NOISE_0+i, szBuffer,
						BUFFER_SIZE);
					nDummy=ComboBox_InsertString(GETHCTL(IDC_SIGMA_NOISES), i,
						szBuffer);
				}
				nNoiseOffset=0;
			}
			else // All other sigma types
			{
				for(i=0; i<5; i++)
				{
					LoadString(hInst, IDS_SIGMA_NOISE_2+i, szBuffer,
						BUFFER_SIZE);
					nDummy=ComboBox_InsertString(GETHCTL(IDC_SIGMA_NOISES), i,
						szBuffer);
				}
				nNoiseOffset=2;
			}

			// Show current noise type
			nDummy=ComboBox_SetCurSel(GETHCTL(IDC_SIGMA_NOISES),
				nNoiseType-nNoiseOffset);

			// Save original set noise state
			bSaveSetNoise=bSetNoise;
			
			{
				Button_SetCheck(GETHCTL(IDC_SIGMA_SETNOISE), bSetNoise);
				EnableWindow(GETHCTL(IDC_SIGMA_SETNOISE), TRUE);
			}
			
			// Hide/Show noise type list box depending on bSetNoise state
			if(bSetNoise)
			{
				ShowWindow(GETHCTL(IDC_SIGMA_NOISES), SW_SHOWNORMAL);

				// Set the alpha value
				nAlpha=nNoiseType-4;

				// Show the alpha value
				_snprintf(szBuffer, sizeof(szBuffer), "%d", nAlpha);
				SetWindowText(GETHCTL(IDC_SIGMA_ALPHA), szBuffer);

				// Show the mu value
				SetWindowText(GETHCTL(IDC_SIGMA_MU), szNoiseMu[nAlpha+4]);
			}
			else // Set noise not checked
			{
				ShowWindow(GETHCTL(IDC_SIGMA_NOISES), SW_HIDE);
			}

			// Fill up the sigma type list box
			for(i=0; i<NUM_SIGMA_TYPES-3*bDataType; i++)
			// Was 6 until 06/03/98 when TIE rms & MTIE added for phase data
			// And those new IDS_SIGMA_TYPE strings created
			// Was 9 until 12/24/99 when made 10 to add Mod Total
			// HTOT added 11/02/00, raising # sigma types to 0-11
			// THEO1 added 02/08/03 raising types to 12
			{
				LoadString(hInst, IDS_SIGMA_TYPE_0+i, szBuffer, BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_SIGMA_TYPE), i,
					szBuffer);
			}

			// Show sigma type
			// Don't allow TIE rms or MTIE for frequency data
			if(bDataType==FREQ_DATA)
			{
				if(nSigmaType>HADTOTAL_SIGMA)
				{
					nSigmaType=NORMAL_SIGMA;
				}
			}
			else // Phase data
			{
				if(nSigmaType>THEO1_SIGMA)
				{
					nSigmaType=NORMAL_SIGMA;
				}
			}

			nDummy=nSigmaType;

			nDummy=ComboBox_SetCurSel(GETHCTL(IDC_SIGMA_TYPE), nDummy);

			// Make sure AF is at least THEO1_MIN for Tho1
			if(nSigmaType==THEO1_SIGMA)
			{
				nAvgFactor=max(nAvgFactor, THEO1_MIN);
			}
			
			// Show the averaging factor
			_snprintf(szBuffer, sizeof(szBuffer), "%d", nAvgFactor);
			SetWindowText(GETHCTL(IDC_SIGMA_AVGFACTOR),	szBuffer);

			// Show the bw factor
			_snprintf(szBuffer, sizeof(szBuffer), "%0.3f", fBW);
			SetWindowText(GETHCTL(IDC_SIGMA_BWFACTOR), szBuffer);

			// Load the conf factor
			_snprintf(szBuffer, sizeof(szBuffer), "%0.3f", fCF);
			SetWindowText(GETHCTL(IDC_SIGMA_CF), szBuffer);

			// Restore the show details checkbox state
			Button_SetCheck(GETHCTL(IDC_SIGMA_SHOW), bSigmaDetails);

			// Restore the set noise checkbox state
			Button_SetCheck(GETHCTL(IDC_SIGMA_SETNOISE), bSetNoise);

			// Restore the apply ACF noise ID checkbox state
			Button_SetCheck(GETHCTL(IDC_SIGMA_ACFID), bACFNoiseID);

			// Show the CI type radio buttons
			Button_SetCheck(GETHCTL(IDC_SIGMA_SINGLE), !bCIType);
			Button_SetCheck(GETHCTL(IDC_SIGMA_DOUBLE), bCIType);

			// Initialize & show deadtime ratio
			fDeadtime=1.0;
			_snprintf(szBuffer, sizeof(szBuffer), "%3.2f", fDeadtime);
			SetWindowText(GETHCTL(IDC_SIGMA_DEADTIME), szBuffer);

            // Set controls
            SigmaControls(hDlg, nSigmaType, bSigmaDetails, TRUE, bSetNoise,
				bACFNoiseID);

			// Check for enough analysis points to use
			// lag 1 ACF noise ID
			
			// Get total # data points and # gaps in data
            if(bDataType==FREQ_DATA)
            {
                nPoints=(int)fFreqData[0];
                nNumb=(int)(fFreqData[2]-fFreqData[1]+1);
                nGaps=CountGaps(fFreqData, FREQ_DATA);
				nDat=0;
            }
			else // Phase data
            {
                nPoints=(int)fPhaseData[0];
                nNumb=(int)(fPhaseData[2]-fPhaseData[1]+1);
                nGaps=CountGaps(fPhaseData, PHASE_DATA);
				nDat=1;
            }

			if(nNumb/nAvgFactor<ACFNUM)
			{
				// Clear ACF noise flag 
				bACFNoiseID=FALSE;
				Button_SetCheck(GETHCTL(IDC_SIGMA_ACFID), bACFNoiseID);

				// Disable ACF noise ID checkbox
				EnableWindow(GETHCTL(IDC_SIGMA_ACFID), FALSE);
				ShowWindow(GETHCTL(IDC_SIGMA_ACFID), SW_HIDE);
				ShowWindow(GETHCTL(IDC_SIGMA_TOOFEW), SW_SHOWNORMAL);
			}
			else // Enough points
			{
				//if(!bSetNoise) // Disabled 12/25/03
				{
					// Enable ACF noise checkbox
					EnableWindow(GETHCTL(IDC_SIGMA_ACFID), TRUE);
					ShowWindow(GETHCTL(IDC_SIGMA_ACFID), SW_SHOWNORMAL);
					
					if(bSetNoise)
					{
						// Disable Apply checkbox if Set Noise is on
						EnableWindow(GETHCTL(IDC_SIGMA_ACFID), FALSE);
					}
					else
					{
						// Enable Apply checkbox if Set Noise is off
						EnableWindow(GETHCTL(IDC_SIGMA_ACFID), TRUE);
					}
					
					ShowWindow(GETHCTL(IDC_SIGMA_TOOFEW), SW_HIDE);
				}
			}

			// Calculate the max allowable avg factor for each variance type
			// Need 2 freq points for sigma and 3 freq points for mod sigma
			// so, for 1001 phase points = 1000 freq points (no gaps)
			// can have max AF = 1000/2 = 500
			// for sigma (inc overlapping & total)
			// and max AF = 1000/3 = 333 for mod sigma (inc time, mod total &
			// time total.  Hadamard var also requires 3 freq points so it is
			// like mod sigma.
			nMaxAF[NORMAL_SIGMA]=(nNumb-nGaps-nDat)/2;
			nMaxAF[OVERLAPPING_SIGMA]=(nNumb-nGaps-nDat)/2;
			nMaxAF[MODIFIED_SIGMA]=(nNumb-nGaps-nDat)/3;
			nMaxAF[TIME_SIGMA]=(nNumb-nGaps-nDat)/3;
			nMaxAF[TOTAL_SIGMA]=(nNumb-nGaps-nDat)/2;
			nMaxAF[MODTOTAL_SIGMA]=(nNumb-nGaps-nDat)/3;
			nMaxAF[TIMETOTAL_SIGMA]=(nNumb-nGaps-nDat)/3;
			nMaxAF[HADAMARD_SIGMA]=(nNumb-nGaps-nDat)/3;
			nMaxAF[OVERLAPHAD_SIGMA]=(nNumb-nGaps-nDat)/3;
			nMaxAF[HADTOTAL_SIGMA]=(nNumb-nGaps-nDat)/3;

			// TIErms and MTIE apply to phase data only
			nMaxAF[TIERMS_SIGMA]=(nNumb-nGaps-nDat)/2;

			// Changed 01/27/01
			// Old code was: nMaxAF[MTIE_SIGMA]=(nNumb-nGaps-nDat)/2;
			// For MTIE, N phase data points provide N-1 time intervals
			// and the # of time intervals that can be processed for a certain
			// AF is N-AF, and the maximum allowable AF is N-1.
			nMaxAF[MTIE_SIGMA]=nNumb-nGaps-1;

			// Added 02/08/03
			// Tho1 can use even avg factor up to = # phase data points -1
			nMaxAF[THEO1_SIGMA]=nNumb-nGaps-1;
			if(nMaxAF[THEO1_SIGMA]%2)
			{
				nMaxAF[THEO1_SIGMA]--;
			}
		}

		// Autocalc sigma
		// Doing this gives immediate result for current sigma type & AF
		if(bAutoCalc)
		{
			PostMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDC_SIGMA_CALC,
				NULL, 0));
		}

		return TRUE;

        case WM_COMMAND:
        {
            switch(GET_WM_COMMAND_ID(wParam, lParam))
            {
                case IDHELP:
                {
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::SIGMA_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::SIGMA_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif
 
					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "SIGMA_FUNCTION");
					#endif
               }
                break;

                case IDM_SIGMA_PRINT:
                case IDM_SIGMA_BITMAP:
                case IDM_SIGMA_METAFILE:
                {
                    DrawMenuBar(hDlg);
                    LoadString(hInst, IDS_MESSAGE_NOTIMP, szBuffer,
                        BUFFER_SIZE);
                    MessageBox(hDlg, szBuffer, "Notice", MB_ICONEXCLAMATION);
                }
                DrawMenuBar(hDlg);
				break;

                // Detect avg factor change
                case IDC_SIGMA_AVGFACTOR:
                {
                    if(GET_WM_COMMAND_CMD(wParam, lParam)==EN_CHANGE)
                    {
						// Disable the copy button until there are results
						EnableWindow(GETHCTL(IDC_SIGMA_COPY), FALSE);

                        // Clear all the results boxes
                        SetWindowText(GETHCTL(IDC_SIGMA_VALUE), "");
                        SetWindowText(GETHCTL(IDC_SIGMA_SIGMA), "");
                        SetWindowText(GETHCTL(IDC_SIGMA_NUM), "");
                        SetWindowText(GETHCTL(IDC_SIGMA_DF), "");
                        SetWindowText(GETHCTL(IDC_SIGMA_MAX), "");
                        SetWindowText(GETHCTL(IDC_SIGMA_MIN),   "");
						SetWindowText(GETHCTL(IDC_SIGMA_NUM), "");
						SetWindowText(GETHCTL(IDC_SIGMA_B1RN), "");
						SetWindowText(GETHCTL(IDC_SIGMA_CI), "");
						SetWindowText(GETHCTL(IDC_SIGMA_R1), "");
						SetWindowText(GETHCTL(IDC_SIGMA_A), "");
						if(!bSetNoise)
						{
							SetWindowText(GETHCTL(IDC_SIGMA_NOISE),
								"");
							SetWindowText(GETHCTL(IDC_SIGMA_ALPHA),
								"");
							SetWindowText(GETHCTL(IDC_SIGMA_MU), "");
							SetWindowText(GETHCTL(IDC_SIGMA_KN), "");
						}

						// Write prompt message
						WritePromptMessage(TB_SIGMA);
					}

                    // Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (!bErrorTrap) && (GetFocus()!=GETHCTL(IDCANCEL)))
					{
						// Set error flag to avoid multiple error messages
                        bErrorTrap=TRUE;

                        // Save previous value
                        nPrev=nAvgFactor;

                        // Get new averaging factor
						GetWindowText(GETHCTL(IDC_SIGMA_AVGFACTOR), szBuffer,
							BUFFER_SIZE);
						nEntry=abs(atoi(szBuffer));

                        // Get # data points
                        if(bDataType==FREQ_DATA)
                        {
                            nPoints=(int)fFreqData[0];
                        }
                        else // Phase data
                        {
                            nPoints=(int)fPhaseData[0];
						}

						// Is max AF asked for?
						if( (szBuffer[0]=='m') || (szBuffer[0]=='M') )
						{
							nEntry=nMaxAF[nSigmaType];
						}

						// Force avg factor to even # for Tho1
						if(nSigmaType==THEO1_SIGMA)
						{
							nPrev=THEO1_MIN;
							if(nEntry%2)
							{
								nEntry--;
							}
							nEntry=max(nEntry, THEO1_MIN);
                            _snprintf(szBuffer, sizeof(szBuffer), "%d",
								nEntry);
						}

                        // Check entry - must be between nMinAF and nMaxAF
                        // for particular variance type
						nMinAF=1;
						if(nSigmaType==THEO1_SIGMA)
						{
							nMinAF=THEO1_MIN;
						}

                        if(ValidateInteger(hDlg, nEntry, nMinAF,
                            nMaxAF[nSigmaType])==TRUE)
                        {
                            // New value OK
                            nAvgFactor=nEntry;
                            _snprintf(szBuffer, sizeof(szBuffer), "%d",
								nAvgFactor);
							SetWindowText(GETHCTL(IDC_SIGMA_AVGFACTOR),
								szBuffer);

							// Check for enough analysis points to use
							// lag 1 ACF noise ID
							if(nNumb/nAvgFactor<ACFNUM)
							{
								// Clear ACF noise flag 
								bACFNoiseID=FALSE;
								Button_SetCheck(GETHCTL(IDC_SIGMA_ACFID),
									bACFNoiseID);

								// Disable ACF noise ID checkbox
								EnableWindow(GETHCTL(IDC_SIGMA_ACFID), FALSE);
								ShowWindow(GETHCTL(IDC_SIGMA_ACFID),
									SW_HIDE);
								ShowWindow(GETHCTL(IDC_SIGMA_TOOFEW),
									SW_SHOWNORMAL);
							}
							else // Enough points
							{
								//if(!bSetNoise) // Disabled 12/25/03
								{
									// Enable ACF noise checkbox
									EnableWindow(GETHCTL(IDC_SIGMA_ACFID),
										TRUE);
									ShowWindow(GETHCTL(IDC_SIGMA_ACFID),
										SW_SHOWNORMAL);
									ShowWindow(GETHCTL(IDC_SIGMA_TOOFEW),
										SW_HIDE);
								}
							}
						}
						else
						{
							// Invalid entry - restore previous value
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nPrev);
							SetWindowText(GETHCTL(IDC_SIGMA_AVGFACTOR),
								szBuffer);
							nAvgFactor=nPrev;
							SetFocus(GETHCTL(IDC_SIGMA_AVGFACTOR));
						}
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

                // Detect conf factor change
                case IDC_SIGMA_CF:
                {
                    if(GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS)
                    {
						// Disable the copy button until there are results
						EnableWindow(GETHCTL(IDC_SIGMA_COPY), FALSE);

                        // Clear conf interval results boxes
						SetWindowText(GETHCTL(IDC_SIGMA_MAX), "");
						SetWindowText(GETHCTL(IDC_SIGMA_MIN),   "");
						SetWindowText(GETHCTL(IDC_SIGMA_CI), "");

                        // Get new CF value
						GetWindowText(GETHCTL(IDC_SIGMA_CF), szBuffer,
							BUFFER_SIZE);
						fCF=(float)atof(szBuffer);

                        // Don't allow CF to be 0 or 1
                        if(fCF<=0.0)
                        {
                            fCF=(float)0.001;
                        }

                        if(fCF>=1.0)
                        {
                            fCF=(float)0.999;
                        }

                        // Redisplay confidence factor
						_snprintf(szBuffer, sizeof(szBuffer), "%5.3f", fCF);
                        SetWindowText(GETHCTL(IDC_SIGMA_CF), szBuffer);

						// Write prompt message
						WritePromptMessage(TB_SIGMA);
                    }
				}
                break;

                // Detect single/double conf interval change
                case IDC_SIGMA_SINGLE:
                case IDC_SIGMA_DOUBLE:
				{
					if(GET_WM_COMMAND_CMD(wParam, lParam)==BN_CLICKED)
					{
						// Disable the copy button until there are results
						EnableWindow(GETHCTL(IDC_SIGMA_COPY), FALSE);

						// Clear conf interval results boxes
						SetWindowText(GETHCTL(IDC_SIGMA_MAX), "");
						SetWindowText(GETHCTL(IDC_SIGMA_MIN),   "");
						SetWindowText(GETHCTL(IDC_SIGMA_CI), "");

						// Read the CI type
						bCIType=
							(BOOL)Button_GetCheck(GETHCTL(IDC_SIGMA_DOUBLE));

						// Write prompt message
						WritePromptMessage(TB_SIGMA);
					}
				}
                break;

                // Detect bw factor change
                case IDC_SIGMA_BWFACTOR:
                {
                    if(GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS)
                    {
						// Disable the copy button until there are results
						EnableWindow(GETHCTL(IDC_SIGMA_COPY), FALSE);

                        // Clear all the results boxes
						SetWindowText(GETHCTL(IDC_SIGMA_DF), "");
						SetWindowText(GETHCTL(IDC_SIGMA_MAX), "");
						SetWindowText(GETHCTL(IDC_SIGMA_MIN),   "");
						SetWindowText(GETHCTL(IDC_SIGMA_NUM), "");
						SetWindowText(GETHCTL(IDC_SIGMA_CI), "");
						if(!bSetNoise)
						{
							SetWindowText(GETHCTL(IDC_SIGMA_NOISE),	"");
							SetWindowText(GETHCTL(IDC_SIGMA_ALPHA), "");
							SetWindowText(GETHCTL(IDC_SIGMA_MU), "");
							SetWindowText(GETHCTL(IDC_SIGMA_KN), "");
						}

						// Get new BW value
						GetWindowText(GETHCTL(IDC_SIGMA_BWFACTOR), szBuffer,
							BUFFER_SIZE);

						// Ignore if "Not Applicable", otherwise update value
						if(strcmp(szBuffer, "Not Applicable")!=0)
						{
							// Find numeric BW factor
							fBW=(float)atof(szBuffer);

							// Redisplay the new BW factor
							_snprintf(szBuffer, sizeof(szBuffer), "%0.3f",
								fBW);
							SetWindowText(GETHCTL(IDC_SIGMA_BWFACTOR),
								szBuffer);
						}
						else
						{
							// Redisplay N/A message
							SetWindowText(GETHCTL(IDC_SIGMA_BWFACTOR),
								"Not Applicable");
						}

						// Write prompt message
						WritePromptMessage(TB_SIGMA);
					}
				}
				break;

				case IDC_SIGMA_NOISES:
				{
					// Detect change in noise type selection
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_SELCHANGE)
					{
						// Get the new noise type
						nNoiseType=
							ComboBox_GetCurSel(GETHCTL(IDC_SIGMA_NOISES));

						nNoiseType+=nNoiseOffset;

						// Set the alpha value
						nAlpha=nNoiseType-4;

						// Disable the copy button until there are results
						EnableWindow(GETHCTL(IDC_SIGMA_COPY), FALSE);

						// Clear all the results boxes
						SetWindowText(GETHCTL(IDC_SIGMA_VALUE), "");
						SetWindowText(GETHCTL(IDC_SIGMA_SIGMA), "");
						SetWindowText(GETHCTL(IDC_SIGMA_NUM), "");
						SetWindowText(GETHCTL(IDC_SIGMA_DF), "");
						SetWindowText(GETHCTL(IDC_SIGMA_MAX), "");
						SetWindowText(GETHCTL(IDC_SIGMA_MIN),   "");
						SetWindowText(GETHCTL(IDC_SIGMA_NUM), "");
						SetWindowText(GETHCTL(IDC_SIGMA_B1RN), "");
						SetWindowText(GETHCTL(IDC_SIGMA_CI), "");
						SetWindowText(GETHCTL(IDC_SIGMA_R1), "");
						SetWindowText(GETHCTL(IDC_SIGMA_A), "");

						// Show the alpha value
						_snprintf(szBuffer, sizeof(szBuffer), "%d", nAlpha);
						SetWindowText(GETHCTL(IDC_SIGMA_ALPHA), szBuffer);

						// Show the mu value
						SetWindowText(GETHCTL(IDC_SIGMA_MU),
							szNoiseMu[nAlpha+4]);

						// Show Th01 bias factor
						if(nSigmaType==THEO1_SIGMA)
						{
							// Read noise type & set bias accordingly
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_SIGMA_THEO1BIAS, NULL,
								0));
						}

						// Write prompt message
						WritePromptMessage(TB_SIGMA);
					}
				}
				break;

				case IDC_SIGMA_TYPE:
				{
					// Detect change in sigma type selection
					// Note: Need to recheck nAF when sigma type changes
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_SELCHANGE)
                    {
						// Get the new sigma type
						nSigmaType=ComboBox_GetCurSel(GETHCTL(IDC_SIGMA_TYPE));

						// Tho1 setup
						if(nSigmaType==THEO1_SIGMA)
						{
							// Tho1 nAF must be even and at least THEO1_MIN
							nAvgFactor=max(nAvgFactor, THEO1_MIN);
							if(nAvgFactor%2)
							{
								nAvgFactor--;
							}
							_snprintf(szBuffer, sizeof(szBuffer), "%d",
								nAvgFactor);
							SetWindowText(GETHCTL(IDC_SIGMA_AVGFACTOR),
								szBuffer);
						}

						// Restore bSetNoise
						bSetNoise=bSaveSetNoise;
						Button_SetCheck(GETHCTL(IDC_SIGMA_SETNOISE),
							bSetNoise);
						EnableWindow(GETHCTL(IDC_SIGMA_SETNOISE), FALSE);

						// Check nAvgFactor
						// If AF is too large, then reduce it to max allowable
						if(nAvgFactor>nMaxAF[nSigmaType])
						{
							nAvgFactor=nMaxAF[nSigmaType];
							_snprintf(szBuffer, sizeof(szBuffer), "%d",
								nAvgFactor);
							SetWindowText(GETHCTL(IDC_SIGMA_AVGFACTOR),
								szBuffer);
						}
						
						// Clear noise type combobox
						nDummy=
							ComboBox_ResetContent(GETHCTL(IDC_SIGMA_NOISES));

						// Show RR FM and FW FM for Hadamard dev only 
						if( (nSigmaType==OVERLAPHAD_SIGMA) ||
							(nSigmaType==HADAMARD_SIGMA) ||
							(nSigmaType==HADTOTAL_SIGMA) )
						{
							for(i=0; i<7; i++)
							{
								LoadString(hInst, IDS_SIGMA_NOISE_0+i,
									szBuffer, BUFFER_SIZE);
								nDummy=ComboBox_InsertString(GETHCTL(
									IDC_SIGMA_NOISES), i, szBuffer);
							}
							nNoiseOffset=0;
						}
						else // All other sigma types
						{
							for(i=0; i<5; i++)
							{
								LoadString(hInst, IDS_SIGMA_NOISE_2+i,
									szBuffer, BUFFER_SIZE);
								nDummy=ComboBox_InsertString(GETHCTL(
									IDC_SIGMA_NOISES), i, szBuffer);
							}
							nNoiseOffset=2;
							
							// Avoid previous RR FM & FW FM types
							if(nAlpha<-2)
							{
								// Force W FM noise type
								nNoiseType=4;

								// Set the alpha value
								nAlpha=nNoiseType-4;

								// Show the alpha value
								_snprintf(szBuffer, sizeof(szBuffer), "%d",
									nAlpha);
								SetWindowText(GETHCTL(IDC_SIGMA_ALPHA),
									szBuffer);

								// Show the mu value
								SetWindowText(GETHCTL(IDC_SIGMA_MU),
									szNoiseMu[nAlpha+4]);
							}
						}

						// Show current noise type
						nDummy=ComboBox_SetCurSel(GETHCTL(IDC_SIGMA_NOISES),
							nNoiseType-nNoiseOffset);

						// Make sure the noise selection box doesn't appear
						// for these sigma types
						if(nSigmaType==TIERMS_SIGMA || nSigmaType==MTIE_SIGMA)
						{
							ShowWindow(GETHCTL(IDC_SIGMA_NOISES), SW_HIDE);
						}
						else // And can show when it should
						{
							if(bSetNoise)
							{
								ShowWindow(GETHCTL(IDC_SIGMA_NOISES),
									SW_SHOWNORMAL);
							}
						}

						switch(nSigmaType)
                        {
                            case NORMAL_SIGMA:
                            case TOTAL_SIGMA:
							case MODTOTAL_SIGMA:
                            {
                                // Set controls
                                SigmaControls(hDlg, nSigmaType, bSigmaDetails,
                                    TRUE, bSetNoise, bACFNoiseID);
                            }
                            break;

                            case OVERLAPPING_SIGMA:
                            {
                                // Set controls
                                SigmaControls(hDlg, nSigmaType, bSigmaDetails,
									TRUE, bSetNoise, bACFNoiseID);

								// Show the CI type radio buttons
								Button_SetCheck(GETHCTL(IDC_SIGMA_SINGLE),
									!bCIType);
								Button_SetCheck(GETHCTL(IDC_SIGMA_DOUBLE),
									bCIType);

								// Show the CF
								_snprintf(szBuffer, sizeof(szBuffer), "%0.3f",
									fCF);
								SetWindowText(GETHCTL(IDC_SIGMA_CF), szBuffer);
							}
							break;

							case HADAMARD_SIGMA:
							{
								// Set controls
								SigmaControls(hDlg, nSigmaType, bSigmaDetails,
									TRUE, bSetNoise, bACFNoiseID);
							}
							break;

							case OVERLAPHAD_SIGMA:
							case HADTOTAL_SIGMA: // Added 11/02/00
                            {
                                // Set controls
                                SigmaControls(hDlg, nSigmaType, bSigmaDetails,
									TRUE, bSetNoise, bACFNoiseID);

								// Show the CI type radio buttons
								Button_SetCheck(GETHCTL(IDC_SIGMA_SINGLE),
									!bCIType);
								Button_SetCheck(GETHCTL(IDC_SIGMA_DOUBLE),
									bCIType);

								// Show the CF
								_snprintf(szBuffer, sizeof(szBuffer), "%0.3f",
									fCF);
								SetWindowText(GETHCTL(IDC_SIGMA_CF), szBuffer);
							}
							break;

							case MODIFIED_SIGMA:
							{
								// Set controls
								SigmaControls(hDlg, nSigmaType, bSigmaDetails,
									TRUE, bSetNoise, bACFNoiseID);

								// Show the bw factor
								_snprintf(szBuffer, sizeof(szBuffer), "%0.3f",
									fBW);
								SetWindowText(GETHCTL(IDC_SIGMA_BWFACTOR),
									szBuffer);

								// Show the CI type radio buttons
								Button_SetCheck(GETHCTL(IDC_SIGMA_SINGLE),
									!bCIType);
								Button_SetCheck(GETHCTL(IDC_SIGMA_DOUBLE),
									bCIType);

                                // Show the CF
                                _snprintf(szBuffer, sizeof(szBuffer), "%0.3f",
									fCF);
								SetWindowText(GETHCTL(IDC_SIGMA_CF), szBuffer);
                            }
                            break;

                            case TIME_SIGMA:
							case TIMETOTAL_SIGMA:
                            {
                                // Set controls
                                SigmaControls(hDlg, nSigmaType, bSigmaDetails,
                                    TRUE, bSetNoise, bACFNoiseID);

                                // Show the bw factor
                                _snprintf(szBuffer, sizeof(szBuffer), "%0.3f",
									fBW);
								SetWindowText(GETHCTL(IDC_SIGMA_BWFACTOR),
									szBuffer);

								// Show the CI type radio buttons
								Button_SetCheck(GETHCTL(IDC_SIGMA_SINGLE),
									!bCIType);
								Button_SetCheck(GETHCTL(IDC_SIGMA_DOUBLE),
									bCIType);

								// Show the CF
								_snprintf(szBuffer, sizeof(szBuffer), "%0.3f",
									fCF);
								SetWindowText(GETHCTL(IDC_SIGMA_CF), szBuffer);
							}
							break;

							case TIERMS_SIGMA:
							{
								// Set controls
								SigmaControls(hDlg, nSigmaType, bSigmaDetails,
									TRUE, bSetNoise, bACFNoiseID);
							}
							break;

							case MTIE_SIGMA:
							{
								// Set controls
								SigmaControls(hDlg, nSigmaType, bSigmaDetails,
									TRUE, bSetNoise, bACFNoiseID);
							}
							break;

							case THEO1_SIGMA:
							{
								// Set controls
								SigmaControls(hDlg, nSigmaType, bSigmaDetails,
									TRUE, bSetNoise, bACFNoiseID);

								// Show the alpha value
								_snprintf(szBuffer, sizeof(szBuffer), "%d",
									nAlpha);
								SetWindowText(GETHCTL(IDC_SIGMA_ALPHA),
									szBuffer);

								// Show the mu value
								SetWindowText(GETHCTL(IDC_SIGMA_MU),
								szNoiseMu[nAlpha+4]);
							}
							break;
						}

						// Disable the copy button until there are results
						EnableWindow(GETHCTL(IDC_SIGMA_COPY), FALSE);

						// Clear all the results boxes
						SetWindowText(GETHCTL(IDC_SIGMA_VALUE), "");
						SetWindowText(GETHCTL(IDC_SIGMA_SIGMA), "");
						SetWindowText(GETHCTL(IDC_SIGMA_NUM), "");
						SetWindowText(GETHCTL(IDC_SIGMA_DF), "");
						SetWindowText(GETHCTL(IDC_SIGMA_MAX), "");
						SetWindowText(GETHCTL(IDC_SIGMA_MIN),   "");
						SetWindowText(GETHCTL(IDC_SIGMA_NUM), "");
						SetWindowText(GETHCTL(IDC_SIGMA_B1RN), "");
						SetWindowText(GETHCTL(IDC_SIGMA_CI), "");
						SetWindowText(GETHCTL(IDC_SIGMA_R1), "");
						SetWindowText(GETHCTL(IDC_SIGMA_A), "");
						if(!bSetNoise)
						{
							SetWindowText(GETHCTL(IDC_SIGMA_NOISE),	"");
							SetWindowText(GETHCTL(IDC_SIGMA_ALPHA),	"");
							SetWindowText(GETHCTL(IDC_SIGMA_MU), "");
							SetWindowText(GETHCTL(IDC_SIGMA_KN), "");
						}

						// Show Tho1 bias factor if applicable
						if(nSigmaType==THEO1_SIGMA)
						{
							_snprintf(szBuffer, sizeof(szBuffer), "%0.3f",
								fTheo1Bias);
							SetWindowText(GETHCTL(IDC_SIGMA_B1RN), szBuffer);
						}
					}

					// Write prompt message
					WritePromptMessage(TB_SIGMA);
				}
				break;

				case IDC_SIGMA_SHOW:
				{
					// Get the state of the Show Details checkbox
					bSigmaDetails=
						(BOOL)Button_GetCheck(GETHCTL(IDC_SIGMA_SHOW));

					// Free working memory
					// nDummy is to avoid compiler warning
					free(fSigmaData);

					// Change to other Sigma dialog box template
					// Note: hwmd & cmd args not needed
					PostMessage(hwndMain, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDM_SIGMA, NULL, 0));

					EndDialog(hDlg, 0);
					return TRUE;
				}

				case IDC_SIGMA_SETNOISE:
				{
					// Get the state of the Set Noise checkbox
					bSetNoise=
						(BOOL)Button_GetCheck(GETHCTL(IDC_SIGMA_SETNOISE));

					// Hide/Show noise type list box depending on bSetNoise
					if(bSetNoise)
					{
						ShowWindow(GETHCTL(IDC_SIGMA_NOISES), SW_SHOWNORMAL);

						// Set the alpha value
						nAlpha=nNoiseType-4;

						// Show the alpha value
						_snprintf(szBuffer, sizeof(szBuffer), "%d", nAlpha);
						SetWindowText(GETHCTL(IDC_SIGMA_ALPHA),	szBuffer);

						// Show the mu value
						SetWindowText(GETHCTL(IDC_SIGMA_MU),
							szNoiseMu[nAlpha+4]);

						// Save current ACF noise ID flag setting
						bSaveACFNoiseID=bACFNoiseID;
						
						// Clear ACF noise ID flag
						bACFNoiseID=FALSE;
						Button_SetCheck(GETHCTL(IDC_SIGMA_ACFID),
							bACFNoiseID);

						// Disable ACF noise ID checkbox
						EnableWindow(GETHCTL(IDC_SIGMA_ACFID), FALSE);
					}
					else // Set noise flag cleared
					{
						ShowWindow(GETHCTL(IDC_SIGMA_NOISES), SW_HIDE);

						// Clear noise result boxes
						SetWindowText(GETHCTL(IDC_SIGMA_B1RN), "");
						SetWindowText(GETHCTL(IDC_SIGMA_NOISE), "");
						SetWindowText(GETHCTL(IDC_SIGMA_ALPHA), "");
						SetWindowText(GETHCTL(IDC_SIGMA_MU), "");
						SetWindowText(GETHCTL(IDC_SIGMA_KN), "");

						if(!bSetNoise)
						{
							// Restore ACF noise ID flag
							bACFNoiseID=bSaveACFNoiseID;

							// Enable ACF noise checkbox
							EnableWindow(GETHCTL(IDC_SIGMA_ACFID), TRUE);
						}
					}

					// Disable the copy button until there are results
					EnableWindow(GETHCTL(IDC_SIGMA_COPY), FALSE);

					// Clear other results boxes
					SetWindowText(GETHCTL(IDC_SIGMA_VALUE), "");
					SetWindowText(GETHCTL(IDC_SIGMA_SIGMA), "");
					SetWindowText(GETHCTL(IDC_SIGMA_NUM), "");
					SetWindowText(GETHCTL(IDC_SIGMA_DF), "");
					SetWindowText(GETHCTL(IDC_SIGMA_MAX), "");
					SetWindowText(GETHCTL(IDC_SIGMA_MIN),   "");
					SetWindowText(GETHCTL(IDC_SIGMA_NUM), "");
					SetWindowText(GETHCTL(IDC_SIGMA_B1RN), "");
					SetWindowText(GETHCTL(IDC_SIGMA_CI), "");
					SetWindowText(GETHCTL(IDC_SIGMA_R1), "");
					SetWindowText(GETHCTL(IDC_SIGMA_A), "");

					// Save new set noise state
					bSaveSetNoise=bSetNoise;
					
					// Update noise parameter labels
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_SIGMA_TYPE, 0, CBN_SELCHANGE));

					if(!bSetNoise)
					{
						// Clear bias again
						SetWindowText(GETHCTL(IDC_SIGMA_B1RN), "");
					}

					// Write prompt message
					WritePromptMessage(TB_SIGMA);
				}
				break;

				// Respond to ACF noise ID apply checkbox
				case IDC_SIGMA_ACFID:
				{
					// Disable the copy button until there are results
					EnableWindow(GETHCTL(IDC_SIGMA_COPY), FALSE);

					// Clear all the results boxes
					SetWindowText(GETHCTL(IDC_SIGMA_VALUE), "");
					SetWindowText(GETHCTL(IDC_SIGMA_SIGMA), "");
					SetWindowText(GETHCTL(IDC_SIGMA_NUM), "");
					SetWindowText(GETHCTL(IDC_SIGMA_DF), "");
					SetWindowText(GETHCTL(IDC_SIGMA_MAX), "");
					SetWindowText(GETHCTL(IDC_SIGMA_MIN),   "");
					SetWindowText(GETHCTL(IDC_SIGMA_NUM), "");
					SetWindowText(GETHCTL(IDC_SIGMA_B1RN), "");
					SetWindowText(GETHCTL(IDC_SIGMA_CI), "");
					SetWindowText(GETHCTL(IDC_SIGMA_R1), "");
					SetWindowText(GETHCTL(IDC_SIGMA_A), "");
					if(!bSetNoise)
					{
						SetWindowText(GETHCTL(IDC_SIGMA_NOISE), "");
						SetWindowText(GETHCTL(IDC_SIGMA_ALPHA), "");
						SetWindowText(GETHCTL(IDC_SIGMA_MU), "");
						SetWindowText(GETHCTL(IDC_SIGMA_KN), "");
					}

					// Get checkbox state
					bACFNoiseID=
						(BOOL)Button_GetCheck(GETHCTL(IDC_SIGMA_ACFID));

					// Check for enough analysis pts to use lag 1 ACF noise ID
					if(nNumb/nAvgFactor<ACFNUM)
					{
						bACFNoiseID=FALSE;
						Button_SetCheck(GETHCTL(IDC_SIGMA_ACFID), bACFNoiseID);
					}
				}
				break;

				// Respond to fDeadtime edit control message
				case IDC_SIGMA_DEADTIME:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDCANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Save previous value
						fPrev=fDeadtime;

						// Get (new) deadtime ratio
						GetWindowText(GETHCTL(IDC_SIGMA_DEADTIME), szBuffer,
							BUFFER_SIZE);
						fEntry=(float)(fabs(atof(szBuffer)));

						// Validate deadtime ratio entry
						// fDeadtime must be >=1 and <= 8192
						// Numeric params are value, min & max
						// Validate entry
						if(ValidateFloat(hDlg, fEntry, 1.0, 8192.0)==TRUE)
						{
							// New value OK
							fDeadtime=fEntry;
							_snprintf(szBuffer, sizeof(szBuffer), "%3.2f",
								fDeadtime);
							SetWindowText(GETHCTL(IDC_SIGMA_DEADTIME),
								szBuffer);
						}
						else
						{
							// Invalid entry - restore previous value
							_snprintf(szBuffer, sizeof(szBuffer), "%3.2f",
								fPrev);
							SetWindowText(GETHCTL(IDC_SIGMA_DEADTIME),
								szBuffer);
							SetFocus(GETHCTL(IDC_SIGMA_DEADTIME));
						}

						// Disable the copy button until there are results
						EnableWindow(GETHCTL(IDC_SIGMA_COPY), FALSE);

						// Clear other results boxes
						SetWindowText(GETHCTL(IDC_SIGMA_VALUE), "");
						SetWindowText(GETHCTL(IDC_SIGMA_SIGMA), "");
						SetWindowText(GETHCTL(IDC_SIGMA_NUM), "");
						SetWindowText(GETHCTL(IDC_SIGMA_DF), "");
						SetWindowText(GETHCTL(IDC_SIGMA_MAX), "");
						SetWindowText(GETHCTL(IDC_SIGMA_MIN),   "");
						SetWindowText(GETHCTL(IDC_SIGMA_NUM), "");
						SetWindowText(GETHCTL(IDC_SIGMA_B1RN), "");
						SetWindowText(GETHCTL(IDC_SIGMA_CI), "");
						SetWindowText(GETHCTL(IDC_SIGMA_R1), "");
						SetWindowText(GETHCTL(IDC_SIGMA_A), "");

						// Write prompt message
						WritePromptMessage(TB_SIGMA);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Respond to CR in an edit control
				// Note: No button is a DEFPUSHBUTTON
				case IDOK:
				{
					// Does avg factor edit control have focus?
					if(GetFocus()==GETHCTL(IDC_SIGMA_AVGFACTOR))
					{
						// Send EN_KILLFOCUS message to avg factor edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_SIGMA_AVGFACTOR, 0,
							EN_KILLFOCUS));
					}

					// Does BW factor edit control have focus?
					if(GetFocus()==GETHCTL(IDC_SIGMA_BWFACTOR))
					{
						// Send EN_KILLFOCUS message to BW factor edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_SIGMA_BWFACTOR, 0,
							EN_KILLFOCUS));
					}

					// Does conf factor edit control have focus?
					if(GetFocus()==GETHCTL(IDC_SIGMA_CF))
					{
						// Send EN_KILLFOCUS msg to conf factor edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_SIGMA_CF, 0, EN_KILLFOCUS));
					}

					// Does deadtime ratio edit control have focus?
					if(GetFocus()==GETHCTL(IDC_SIGMA_DEADTIME))
					{
						// Send EN_KILLFOCUS msg to deadtime edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_SIGMA_DEADTIME, 0,
							EN_KILLFOCUS));
					}
				}
				break;

				// Internal subroutine to set Tho1 bias
				case IDC_SIGMA_THEO1BIAS:
				{
					// Get noise type
					nDummy=
						ComboBox_GetCurSel(GETHCTL(IDC_SIGMA_NOISES));

					// Set Tho1 bias factor
					fTheo1Bias=Theo1Bias(nDummy-2, (float)0.75*nAvgFactor);

					// Display Tho1 bias factor
					// Note:  This is bias factor for the variance (not dev)
					_snprintf(szBuffer, sizeof(szBuffer), "%0.3f", fTheo1Bias);
					SetWindowText(GETHCTL(IDC_SIGMA_B1RN), szBuffer);
				}
				break;
				
				case IDC_SIGMA_CALC:
				{
					// Reset abort flag
					bAbort=FALSE;

					// Set yield flag - will stay set until calc is done
					bYield=TRUE;

					// Copy complete data array to working memory
					for(i=0; i<fData[0]+ARRAY_OFFSET; i++)
					{
						fSigmaData[i]=fData[i];
					}

					// Get averaging factor
					GetWindowText(GETHCTL(IDC_SIGMA_AVGFACTOR),	szBuffer,
						BUFFER_SIZE);
					nAvgFactor=atoi(szBuffer);

					#ifdef LOGGING
					_snprintf(szBuffer, sizeof(szBuffer),
						"Sigma Calc for AF=%d", nAvgFactor);
					WriteLog(60, szBuffer);
					#endif

					// Get tau value
					if(bDataType)
					{
						GetWindowText(hwndFreqTau, szBuffer, BUFFER_SIZE);
						fTau=(F_TYPE)atof(szBuffer);
					}
					else
					{
						GetWindowText(hwndPhaseTau, szBuffer, BUFFER_SIZE);
						fTau=(F_TYPE)atof(szBuffer);
					}

					// Show the Tau value
					_snprintf(szBuffer, sizeof(szBuffer), "%10.6e",
						fTau*nAvgFactor);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_SIGMA_TAU), szBuffer);

					// Display wait cursor & "Calculating" message
					SetCursor(hWait);
					LoadString(hInst, IDS_MESSAGE_CALC, szBuffer, BUFFER_SIZE);
					SetWindowText(GETHCTL(IDC_SIGMA_VALUE), szBuffer);
					UpdateWindow(GETHCTL(IDC_SIGMA_VALUE));

					// Disable controls
					EnableWindow(GETHCTL(IDC_SIGMA_CALC), FALSE);
					EnableWindow(GETHCTL(IDHELP), FALSE);
					EnableWindow(GETHCTL(IDC_SIGMA_TYPE), FALSE);
					EnableWindow(GETHCTL(IDC_SIGMA_AVGFACTOR), FALSE);
					EnableWindow(GETHCTL(IDC_SIGMA_SHOW), FALSE);
					EnableWindow(GETHCTL(IDC_SIGMA_CF), FALSE);
					EnableWindow(GETHCTL(IDC_SIGMA_BWFACTOR), FALSE);
					EnableWindow(GETHCTL(IDC_SIGMA_SINGLE), FALSE);
					EnableWindow(GETHCTL(IDC_SIGMA_DOUBLE), FALSE);
					EnableWindow(GETHCTL(IDC_SIGMA_DEADTIME), FALSE);
					EnableWindow(GETHCTL(IDC_SIGMA_COPY), FALSE);

					// Disable/rename Close button
					// No abort except for MTIE or MTOT or TTOT calcs
					// for which Close button is relabeled Stop
					if((nSigmaType!=MTIE_SIGMA) &&
						(nSigmaType!=MODTOTAL_SIGMA) &&
						(nSigmaType!=TIMETOTAL_SIGMA) &&
						(nSigmaType!=THEO1_SIGMA))
					{
						EnableWindow(GETHCTL(IDCANCEL), FALSE);
					}
					else
					{
						SetWindowText(GETHCTL(IDCANCEL), "St&op");
					}

					// Get sigma type
					nSigmaType=ComboBox_GetCurSel(GETHCTL(IDC_SIGMA_TYPE));

					switch(nSigmaType)
					{
						case NORMAL_SIGMA:
						{
							// Set controls
							SigmaControls(hDlg, nSigmaType, bSigmaDetails,
								FALSE, bSetNoise, bACFNoiseID);

							if(bDataType==FREQ_DATA)
							{
								// Average freq data
								AverageFreqData(fSigmaData, nAvgFactor);

								// Calc normal sigma
								nNum=CalcFreqSigma(fSigmaData, &fNormalSigma);

								// Error trap for bad calc
								if(nNum<1)
								{
									SetWindowText(GETHCTL(IDC_SIGMA_VALUE),
										"Error");
									bAbort=TRUE;
									break;
								}

								// Calc standard deviation
								CalcFreqStdDev(fSigmaData, &fStdDev);
							}
							else // Phase data
							{
								// Average phase data
								AveragePhaseData(fSigmaData, nAvgFactor);

								// Calc normal sigma
								nNum=CalcPhaseSigma(fSigmaData, &fNormalSigma,
									fTau*nAvgFactor);

								// Error trap for bad calc
								if(nNum<1)
								{
									SetWindowText(GETHCTL(IDC_SIGMA_VALUE),
										"Error");
									bAbort=TRUE;
									break;
								}

								// Avoid problem with CalcPhaseStdDev()
								if(nNum>1)
								{
									// Calc standard deviation
									CalcPhaseStdDev(fSigmaData, &fStdDev,
										fTau*nAvgFactor);
								}
								// Set std dev = sigma for #=1
								else
								{
									fStdDev=fNormalSigma;
								}
							}

							// Copy fStdDev to fValue
							fValue=fStdDev;

							// Apply dead time correction if manually-set noise
							if(bSetNoise)
							{
								// Calc mu
								nMu=max(-nAlpha-1, -2);

								// Calc B2 bias function
								fB2Ratio=CalcBias2(fDeadtime, (float)nMu);

								// Show B2 bias ratio
								_snprintf(szBuffer, sizeof(szBuffer), "%f",
									fB2Ratio);
								SetWindowText(GETHCTL(IDC_SIGMA_B2), szBuffer);

								// Calc B3 bias function
								fB3Ratio=CalcBias3(nAvgFactor, fDeadtime,
									(float)nMu);

								// Show B3 bias ratio
								_snprintf(szBuffer, sizeof(szBuffer), "%f",
									fB3Ratio);
								SetWindowText(GETHCTL(IDC_SIGMA_B3), szBuffer);

								// Apply bias functions
								fNormalSigma/=
									((float)sqrt(fB2Ratio)*
									(float)sqrt(fB3Ratio));
							}

							// Copy fNormalSigma to fSigma
							fSigma=fNormalSigma;

							// Find noise type
							if(!bSetNoise)
							{
								// ID noise
								SendMessage(hDlg, WM_COMMAND,
									GET_WM_COMMAND_MPS(IDC_SIGMA_NOISEID, NULL,
									0));
								
								// Test to calc ACF noise ID
								if(nNumb/nAvgFactor>=ACFNUM)
								{
									// ID noise using Greenhall ACF method
									SendMessage(hDlg, WM_COMMAND,
										GET_WM_COMMAND_MPS(IDC_SIGMA_ACFNOISEID,
										NULL, 0));

									// Test to apply ACF noise ID
									if(bACFNoiseID)
									{
										// Set alpha to ACF noise ID result
										nAlpha=nACFAlpha;
									}
								}
							}
							else // Use selected noise type
							{
								nAlpha=nNoiseType-4;
							}

							// Show the alpha value
							_snprintf(szBuffer, sizeof(szBuffer), "%d",
								nAlpha);
							SetWindowText(GETHCTL(IDC_SIGMA_ALPHA),	szBuffer);

							// Show the noise type
							if(!bSetNoise)
							{
								SetWindowText(GETHCTL(IDC_SIGMA_NOISE),
									szNoiseType[nAlpha+4]);
							}

							// Show the mu value
							SetWindowText(GETHCTL(IDC_SIGMA_MU),
								szNoiseMu[nAlpha+4]);

							// Show the # analysis points
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nNum);
							SetWindowText(GETHCTL(IDC_SIGMA_NUM), szBuffer);

							#ifdef NEWEDF // New code 07/15/03
							fDF=CombinedEDF(nPoints-nGaps+bDataType,
								nAvgFactor, nAlpha, 2, nAvgFactor,	1, 1);

							// Show the df
							_snprintf(szBuffer, sizeof(szBuffer), "%1.3f",
								fDF);
							SetWindowText(GETHCTL(IDC_SIGMA_DF), szBuffer);

							// Calc CI limits
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_SIGMA_CICALC, NULL, 0));

							if(bCIType) // Double-sided CI
							{
								// Show Min sigma
								// Make sure low limit is OK
								// (may not be for small CF)
								if(sqrt(fDF/fChiLow>=1.0))
								{
									_snprintf(szBuffer, sizeof(szBuffer),
										"%10.6e",
										fSigma / sqrt(fDF/fChiHigh));
									ShortenExp(szBuffer);
									SetWindowText(GETHCTL(IDC_SIGMA_MIN),
										szBuffer);
								}
								else // OK
								{
									_snprintf(szBuffer, sizeof(szBuffer),
										"%10.6e",
										fSigma * sqrt(fDF/fChiLow));
									ShortenExp(szBuffer);
									SetWindowText(GETHCTL(IDC_SIGMA_MIN),
										szBuffer);
								}
							}
							else // Single-sided
							{
								LoadString(hInst, IDS_MESSAGE_NA, szBuffer,
									BUFFER_SIZE);
								SetWindowText(GETHCTL(IDC_SIGMA_MIN),
									szBuffer);
							}

							// Show Max sigma
							_snprintf(szBuffer, sizeof(szBuffer), "%10.6e",
								fSigma * sqrt(fDF/fChiHigh));
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_SIGMA_MAX), szBuffer);

							#else
							// Calc the confidence limits
							fKn=(float)atof(szNoiseCoeff[nAlpha+4]);
							fMaxSigma=fSigma+fSigma*fKn/sqrt(nNum);
							fMinSigma=fSigma-fSigma*fKn/sqrt(nNum);

							// Display max sigma
							_snprintf(szBuffer, sizeof(szBuffer), "%10.6e",
								fMaxSigma);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_SIGMA_MAX), szBuffer);

							// Display min sigma
							_snprintf(szBuffer, sizeof(szBuffer), "%10.6e",
								fMinSigma);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_SIGMA_MIN), szBuffer);
							#endif

							if(bAbort)
							{
								// Free working memory
								free(fSigmaData);
							}
						}
						break;

						case OVERLAPPING_SIGMA:
						{
							// Set controls
							SigmaControls(hDlg, nSigmaType, bSigmaDetails,
								FALSE, bSetNoise, bACFNoiseID);

							if(bDataType==FREQ_DATA)
							{
								// This fixes a problem when there are equal
								// adjacent freq data points
								// Calc overlapping sigma
								nNum=CalcFreqOverlapSigma(fSigmaData,
									&fOverlappingSigma, nAvgFactor);

								// Error trap for bad calc
								if(nNum<1)
								{
									SetWindowText(GETHCTL(IDC_SIGMA_VALUE),
										"Error");
									bAbort=TRUE;
									break;
								}
							}
							else // Phase data
							{
								// Calc overlapping sigma
								nNum=CalcPhaseOverlapSigma(fSigmaData,
									&fOverlappingSigma, fTau, nAvgFactor);

								// Error trap for bad calc
								if(nNum<1)
								{
									SetWindowText(GETHCTL(IDC_SIGMA_VALUE),
										"Error");
									bAbort=TRUE;
									break;
								}
							}

							// Apply dead time correction if manually-set noise
							if(bSetNoise)
							{
								// Calc mu
								nMu=max(-nAlpha-1, -2);

								// Calc B2 bias function
								fB2Ratio=CalcBias2(fDeadtime, (float)nMu);

								// Show B2 bias ratio
								_snprintf(szBuffer, sizeof(szBuffer), "%f",
									fB2Ratio);
								SetWindowText(GETHCTL(IDC_SIGMA_B2), szBuffer);

								// Calc B3 bias function
								fB3Ratio=CalcBias3(nAvgFactor, fDeadtime,
									(float)nMu);

								// Show B3 bias ratio
								_snprintf(szBuffer, sizeof(szBuffer), "%f",
									fB3Ratio);
								SetWindowText(GETHCTL(IDC_SIGMA_B3), szBuffer);

								// Apply bias functions
								fOverlappingSigma/=
									((float)sqrt(fB2Ratio)*
									(float)sqrt(fB3Ratio));
							}

							// Copy fOverlappingSigma to fSigma
							fSigma=fOverlappingSigma;

							// Find noise type
							if(!bSetNoise)
							{
								// ID noise
								SendMessage(hDlg, WM_COMMAND,
									GET_WM_COMMAND_MPS(IDC_SIGMA_NOISEID, NULL,
									0));

								// Test to calc ACF noise ID
								if(nNumb/nAvgFactor>=ACFNUM)
								{
									// ID noise using Greenhall ACF method
									SendMessage(hDlg, WM_COMMAND,
										GET_WM_COMMAND_MPS(IDC_SIGMA_ACFNOISEID,
										NULL, 0));

									// Test to apply ACF noise ID
									if(bACFNoiseID)
									{
										nAlpha=nACFAlpha;
									}
								}
							}
							else // Use selected noise type
							{
								nAlpha=nNoiseType-4;
							}

							// Copy fStdDev to fValue - calc'd in noise id
							fValue=fStdDev;

							// Show the alpha value
							_snprintf(szBuffer, sizeof(szBuffer), "%d",
								nAlpha);
							SetWindowText(GETHCTL(IDC_SIGMA_ALPHA),	szBuffer);

							// Show the noise type
							if(!bSetNoise)
							{
								SetWindowText(GETHCTL(IDC_SIGMA_NOISE),
									szNoiseType[nAlpha+4]);
							}

							// Show the mu value
							SetWindowText(GETHCTL(IDC_SIGMA_MU),
								szNoiseMu[nAlpha+4]);

							// Show the # analysis points
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nNum);
							SetWindowText(GETHCTL(IDC_SIGMA_NUM), szBuffer);

							// Calc df
							// 2nd arg = # non-gap phase points
							#ifdef NEWEDF // New code 07/15/03
							fDF=CombinedEDF(nPoints-nGaps+bDataType,
								nAvgFactor,	nAlpha, 2, nAvgFactor,
								nAvgFactor, 1);

							#else
							fDF=CalcDegFree(nAlpha,
								(nPoints-nGaps+bDataType), nAvgFactor);
							#endif

							// Show the df
							_snprintf(szBuffer, sizeof(szBuffer), "%1.3f",
								fDF);
							SetWindowText(GETHCTL(IDC_SIGMA_DF), szBuffer);

							// Calc CI limits
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_SIGMA_CICALC, NULL, 0));

							if(bCIType) // Double-sided CI
							{
								// Show Min sigma
								// Make sure low limit is OK
								// (may not be for small CF)
								if(sqrt(fDF/fChiLow>=1.0))
								{
									_snprintf(szBuffer, sizeof(szBuffer),
										"%10.6e",
										fSigma / sqrt(fDF/fChiHigh));
									ShortenExp(szBuffer);
									SetWindowText(GETHCTL(IDC_SIGMA_MIN),
										szBuffer);
								}
								else // OK
								{
									_snprintf(szBuffer, sizeof(szBuffer),
										"%10.6e",
										fSigma * sqrt(fDF/fChiLow));
									ShortenExp(szBuffer);
									SetWindowText(GETHCTL(IDC_SIGMA_MIN),
										szBuffer);
								}
							}
							else // Single-sided
							{
								LoadString(hInst, IDS_MESSAGE_NA, szBuffer,
									BUFFER_SIZE);
								SetWindowText(GETHCTL(IDC_SIGMA_MIN),
									szBuffer);
							}

							// Show Max sigma
							_snprintf(szBuffer, sizeof(szBuffer), "%10.6e",
								fSigma * sqrt(fDF/fChiHigh));
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_SIGMA_MAX), szBuffer);
						}
						break;

						case MODIFIED_SIGMA:
						{
							// Set controls
							SigmaControls(hDlg, nSigmaType, bSigmaDetails,
								FALSE, bSetNoise, bACFNoiseID);

							// Show the bw factor
							_snprintf(szBuffer, sizeof(szBuffer), "%0.3f",
								fBW);
							SetWindowText(GETHCTL(IDC_SIGMA_BWFACTOR),
								szBuffer);

							if(bDataType==FREQ_DATA)
							{
								// Do MVAR processing by converting freq data
								// to phase data in working array

								// Conv freq to phase data in working array
								ConvFreqToPhase(fFreqData, fSigmaData, fTau,
									FALSE);

								// Fill gaps in converted data
								FillGaps(fSigmaData, PHASE_DATA);

								if(CountGaps(fSigmaData, PHASE_DATA))
								{
									// Calc mod sigma
									nNum=CalcPhaseModSigma(fSigmaData,
										&fModSigma,	fTau*nAvgFactor,
										nAvgFactor, &bAbort, TRUE,
										(void*)WriteProgressMessage);
								}
								else // No gaps - use faster method
								{
									nNum=CalcFastModSigma(fSigmaData,
										&fModSigma,	fTau*nAvgFactor,
										nAvgFactor);
								}

								// Restore freq data to working array
								for(i=0; i<fData[0]+ARRAY_OFFSET; i++)
								{
									fSigmaData[i]=fData[i];
								}

								// Error trap for bad calc
								if(nNum<1)
								{
									SetWindowText(GETHCTL(IDC_SIGMA_VALUE),
										"Error");
									bAbort=TRUE;
									break;
								}
							}
							else // Phase data
							{
								// Fill gaps in converted data
								FillGaps(fSigmaData, PHASE_DATA);

								// Calc mod sigma
								// No gaps - use faster method
								nNum=CalcFastModSigma(fSigmaData, &fModSigma,
									fTau*nAvgFactor, nAvgFactor);

								// Error trap for bad calc
								if(nNum<1)
								{
									SetWindowText(GETHCTL(IDC_SIGMA_VALUE),
										"Error");
									bAbort=TRUE;
									break;
								}
							}

							// Copy fModSigma to fValue
							fValue=fModSigma;

							// Find noise type
							if(!bSetNoise)
							{
								// ID noise
								SendMessage(hDlg, WM_COMMAND,
									GET_WM_COMMAND_MPS(IDC_SIGMA_NOISEID, NULL,
									0));

								// Test to calc ACF noise ID
								if(nNumb/nAvgFactor>=ACFNUM)
								{
									// ID noise using Greenhall ACF method
									SendMessage(hDlg, WM_COMMAND,
										GET_WM_COMMAND_MPS(IDC_SIGMA_ACFNOISEID,
										NULL, 0));

									// Test to apply ACF noise ID
									if(bACFNoiseID)
									{
										nAlpha=nACFAlpha;
									}
								}
							}
							else // Use selected noise type
							{
								nAlpha=nNoiseType-4;
							}

							// Copy fNormalSigma to fSigma - calc'd in noise id
							fSigma=fNormalSigma;

							// Show the alpha value
							_snprintf(szBuffer, sizeof(szBuffer), "%d",
								nAlpha);
							SetWindowText(GETHCTL(IDC_SIGMA_ALPHA),	szBuffer);

							// Show the noise type
							if(!bSetNoise)
							{
								SetWindowText(GETHCTL(IDC_SIGMA_NOISE),
									szNoiseType[nAlpha+4]);
							}

							// Show the mu value
							SetWindowText(GETHCTL(IDC_SIGMA_MU),
								szNoiseMu[nAlpha+4]);

							// Show the # analysis points
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nNum);
							SetWindowText(GETHCTL(IDC_SIGMA_NUM), szBuffer);

							// Calc df
							// Use HVAR edf function with adjusted args
							// as better way to calc MVAR edf
							// per C. Greenhall suggestion
							#ifdef NEWEDF // New code 07/15/03
							fDF=CombinedEDF(nPoints-nGaps+bDataType, nAvgFactor,
								nAlpha, 2, 1, nAvgFactor, 1);

							#else
							fDF=HadamardEDF(nPoints-nGaps+bDataType+1,
								nAvgFactor, nAlpha-4);
							#endif

							// Show the df
							_snprintf(szBuffer, sizeof(szBuffer), "%1.3f", fDF);
							SetWindowText(GETHCTL(IDC_SIGMA_DF), szBuffer);

							// Calc CI limits
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_SIGMA_CICALC, NULL, 0));

							if(bCIType) // Double-sided
							{
								// Show min mod sigma
								// Make sure low limit is OK
								// (may not be for small CF)
								if(sqrt(fDF/fChiLow>=1.0))
								{
									_snprintf(szBuffer, sizeof(szBuffer),
										"%10.6e",
										fModSigma / sqrt(fDF/fChiHigh));
									ShortenExp(szBuffer);
									SetWindowText(GETHCTL(IDC_SIGMA_MIN),
										szBuffer);
								}
								else // OK
								{
									_snprintf(szBuffer, sizeof(szBuffer),
										"%10.6e",
										fModSigma * sqrt(fDF/fChiLow));
									ShortenExp(szBuffer);
									SetWindowText(GETHCTL(IDC_SIGMA_MIN),
										szBuffer);
								}
							}
							else // Single-sided
							{
								LoadString(hInst, IDS_MESSAGE_NA, szBuffer,
									BUFFER_SIZE);
								SetWindowText(GETHCTL(IDC_SIGMA_MIN),
									szBuffer);
							}

							// Show max mod sigma
							_snprintf(szBuffer, sizeof(szBuffer), "%10.6e",
								fModSigma * sqrt(fDF/fChiHigh));
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_SIGMA_MAX), szBuffer);
						}
						break;

						case TIME_SIGMA:
						{
							// Set controls
							SigmaControls(hDlg, nSigmaType, bSigmaDetails,
								FALSE, bSetNoise, bACFNoiseID);

							// Show the bw factor
							_snprintf(szBuffer, sizeof(szBuffer), "%0.3f", fBW);
							SetWindowText(GETHCTL(IDC_SIGMA_BWFACTOR),
								szBuffer);

							if(bDataType==FREQ_DATA)
							{
								// Do TVAR processing by converting freq data
								// to phase data in working array

								// Conv freq to phase data in working array
								ConvFreqToPhase(fFreqData, fSigmaData, fTau,
									FALSE);

								// Calc mod sigma
								if(CountGaps(fSigmaData, PHASE_DATA))
								{
									// Calc mod sigma
									nNum=CalcPhaseModSigma(fSigmaData,
										&fModSigma,	fTau*nAvgFactor,
										nAvgFactor, &bAbort, TRUE,
										(void*)WriteProgressMessage);
								}
								else // No gaps - use faster method
								{
									nNum=CalcFastModSigma(fSigmaData,
										&fModSigma,	fTau*nAvgFactor,
										nAvgFactor);
								}

								// Restore freq data to working array
								for(i=0; i<fData[0]+ARRAY_OFFSET; i++)
								{
									fSigmaData[i]=fData[i];
								}

								// Error trap for bad calc
								if(nNum<1)
								{
									SetWindowText(GETHCTL(IDC_SIGMA_VALUE),
										"Error");
									bAbort=TRUE;
									break;
								}
							}
							else // Phase data
							{
								// Calc mod sigma
								if(CountGaps(fSigmaData, PHASE_DATA))
								{
									// Calc mod sigma
									nNum=CalcPhaseModSigma(fSigmaData,
										&fModSigma,	fTau*nAvgFactor,
										nAvgFactor, &bAbort, TRUE,
										(void*)WriteProgressMessage);
								}
								else // No gaps - use faster method
								{
									nNum=CalcFastModSigma(fSigmaData,
										&fModSigma,	fTau*nAvgFactor,
										nAvgFactor);
								}

								// Error trap for bad calc
								if(nNum<1)
								{
									SetWindowText(GETHCTL(IDC_SIGMA_VALUE),
										"Error");
									bAbort=TRUE;
									break;
								}
							}

							// Apply scaling factor
							fTimeSigma=fModSigma*fTau*nAvgFactor/ROOT3;

							// Copy fTimeSigma to fValue
							fValue=fTimeSigma;

							// Find noise type
							if(!bSetNoise)
							{
								// ID noise
								SendMessage(hDlg, WM_COMMAND,
									GET_WM_COMMAND_MPS(IDC_SIGMA_NOISEID, NULL,
									0));

								// Test to calc ACF noise ID
								if(nNumb/nAvgFactor>=ACFNUM)
								{
									// ID noise using Greenhall ACF method
									SendMessage(hDlg, WM_COMMAND,
										GET_WM_COMMAND_MPS(IDC_SIGMA_ACFNOISEID,
										NULL, 0));

									// Test to apply ACF noise ID
									if(bACFNoiseID)
									{
										nAlpha=nACFAlpha;
									}
								}
							}
							else // Use selected noise type
							{
								nAlpha=nNoiseType-4;
							}

							// Copy fNormalSigma to fSigma - calc'd in noise id
							fSigma=fNormalSigma;

							// Show the alpha value
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nAlpha);
							SetWindowText(GETHCTL(IDC_SIGMA_ALPHA),	szBuffer);

							// Show the noise type
							if(!bSetNoise)
							{
								SetWindowText(GETHCTL(IDC_SIGMA_NOISE),
									szNoiseType[nAlpha+4]);
							}

							// Show the mu value
							SetWindowText(GETHCTL(IDC_SIGMA_MU),
								szNoiseMu[nAlpha+4]);

							// Show the # analysis points
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nNum);
							SetWindowText(GETHCTL(IDC_SIGMA_NUM), szBuffer);

							// Calc df
							// Use HVAR edf function with adjusted args
							// as better way to calc MVAR edf
							// per C. Greenhall suggestion
							#ifdef NEWEDF // New code 07/15/03
							fDF=CombinedEDF(nPoints-nGaps+bDataType, nAvgFactor,
								nAlpha, 2, 1, nAvgFactor, 1);

							#else
							fDF=HadamardEDF(nPoints-nGaps+bDataType+1,
								nAvgFactor, nAlpha-4);
							#endif

							// Show the df
							_snprintf(szBuffer, sizeof(szBuffer), "%1.3f", fDF);
							SetWindowText(GETHCTL(IDC_SIGMA_DF), szBuffer);

							// Calc CI limits
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_SIGMA_CICALC, NULL, 0));

							if(bCIType) // Double-sided
							{
								// Show min time sigma
								// Make sure low limit is OK
								// May not be for small CF
								if(sqrt(fDF/fChiLow>=1.0))
								{
									_snprintf(szBuffer, sizeof(szBuffer),
										"%10.6e",
									fTimeSigma/sqrt(fDF/fChiHigh));
									ShortenExp(szBuffer);
									SetWindowText(GETHCTL(IDC_SIGMA_MIN),
										szBuffer);
								}
								else
								{
									_snprintf(szBuffer, sizeof(szBuffer),
										"%10.6e",
									fTimeSigma*sqrt(fDF/fChiLow));
									ShortenExp(szBuffer);
									SetWindowText(GETHCTL(IDC_SIGMA_MIN),
										szBuffer);
								}
							}
							else // Single-sided
							{
								LoadString(hInst, IDS_MESSAGE_NA, szBuffer,
									BUFFER_SIZE);
								SetWindowText(GETHCTL(IDC_SIGMA_MIN),
									szBuffer);
							}

							// Show max time sigma
							_snprintf(szBuffer, sizeof(szBuffer), "%10.6e",
								fTimeSigma*sqrt(fDF/fChiHigh));
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_SIGMA_MAX), szBuffer);
						}
						break;

						case TOTAL_SIGMA:
						{
							// Set controls
							SigmaControls(hDlg, nSigmaType, bSigmaDetails,
								FALSE, bSetNoise, bACFNoiseID);

							if(bDataType== FREQ_DATA)
							{
								// Do TOTALVAR processing using
								// TotvarCalc() by first converting freq data
								// to phase data in working array
								// Note: The +1 size of the phase data array is
								// allowed for in the fSigmaData allocation
								// Conv freq to phase data in working array
								ConvFreqToPhase(fFreqData, fSigmaData, fTau,
									FALSE);

								FillGaps(fSigmaData, PHASE_DATA);
								
								// Calc TOTDEV w/o progress bar
								nNum=TotvarCalc(fSigmaData,
									&fTotalSigma, fTau, nAvgFactor,
									(void*)NULL);

								// Trap memory allocation error
								if(nNum==-1)
								{
									// Display error message
									AllocErrorMessage();

									// Set abort flag
									bAbort=TRUE;

									// Display normal cursor
									SetCursor(hArrow);

									// Free working memory
									free(fSigmaData);
	
									// Close Sigma dialog box
									EndDialog(hDlg, 0);

									// Return control to Windows
									return TRUE;
								}

								// Restore freq data to working array
								for(i=0; i<fData[0]+ARRAY_OFFSET; i++)
								{
									fSigmaData[i]=fData[i];
								}

								// Error trap for bad calc
								if(nNum<1)
								{
									SetWindowText(GETHCTL(IDC_SIGMA_VALUE),
										"Error");
									bAbort=TRUE;
									break;
								}
							}
							else // Phase data
							{
								FillGaps(fSigmaData, PHASE_DATA);
								
								nNum=TotvarCalc(fSigmaData,
									&fTotalSigma, fTau, nAvgFactor,
									(void*)NULL);

								// Trap memory allocation error
								if(nNum==-1)
								{
									// Display error message
									AllocErrorMessage();

									// Set abort flag
									bAbort=TRUE;

									// Display normal cursor
									SetCursor(hArrow);

									// Free working memory
									free(fSigmaData);
	
									// Close Sigma dialog box
									EndDialog(hDlg, 0);

									// Return control to Windows
									return TRUE;
								}

								// Error trap for bad calc
								if(nNum<1)
								{
									SetWindowText(GETHCTL(IDC_SIGMA_VALUE),
										"Error");
									bAbort=TRUE;
									break;
								}
							}

							// Find noise type
							if(!bSetNoise)
							{
								// ID noise
								SendMessage(hDlg, WM_COMMAND,
									GET_WM_COMMAND_MPS(IDC_SIGMA_NOISEID, NULL,
									0));

								// Test to calc ACF noise ID
								if(nNumb/nAvgFactor>=ACFNUM)
								{
									// ID noise using Greenhall ACF method
									SendMessage(hDlg, WM_COMMAND,
										GET_WM_COMMAND_MPS(IDC_SIGMA_ACFNOISEID,
										NULL, 0));

									// Test to apply ACF noise ID
									if(bACFNoiseID)
									{
										nAlpha=nACFAlpha;
									}
								}
							}
							else // Use selected noise type
							{
								nAlpha=nNoiseType-4;
							}

							// Show the alpha value
							_snprintf(szBuffer, sizeof(szBuffer), "%d",
								nAlpha);
							SetWindowText(GETHCTL(IDC_SIGMA_ALPHA), szBuffer);

							// Show the noise type
							if(!bSetNoise)
							{
								SetWindowText(GETHCTL(IDC_SIGMA_NOISE),
									szNoiseType[nAlpha+4]);
							}

							// Show the mu value
							SetWindowText(GETHCTL(IDC_SIGMA_MU),
								szNoiseMu[nAlpha+4]);

							// Apply TOTALVAR bias function
							// Calc bias factor
							// OK for all alpha (-2 to +2)
							fBias=TotvarBias(nAlpha,
								(float)nNumb/(float)nAvgFactor);

							if(bSetNoise)
							{
								// Show the B(TOTALVAR) ratio
								_snprintf(szBuffer, sizeof(szBuffer), "%5.3f",
									fBias);
								SetWindowText(GETHCTL(IDC_SIGMA_B1RN),
									szBuffer);
							}

							// Correct TOTALDEV
							fTotalSigma/=sqrt(fBias);

							// Show # analysis points
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nNum);
							SetWindowText(GETHCTL(IDC_SIGMA_NUM), szBuffer);

							// Calc edf for Totvar for alpha -2 to 0
							// Returns -1 for other alphas
							fDF=TotvarEDF(nAlpha,
								(float)(nNumb+bDataType)/(float)nAvgFactor);

							// Calc df for cases where alpha is >0
							// Where TotvarEDF has returned -1 error code
							if(fDF<0)
							{
								fDF=CalcDegFree(nAlpha, nNumb+bDataType,
									nAvgFactor);

								// Add 2 to df for this TOTVAR case
								// Note: Was 1 in previous TOTALVAR definition
								fDF+=2.0;
							}

							// Show the df
							_snprintf(szBuffer, sizeof(szBuffer), "%1.3f",
								fDF);
							SetWindowText(GETHCTL(IDC_SIGMA_DF), szBuffer);

							// Calc CI limits
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_SIGMA_CICALC, NULL, 0));

							if(bCIType) // Double-sided
							{
								// Show min total sigma
								// Make sure low limit is OK
								// (may not be for small CF)
								if(sqrt(fDF/fChiLow>=1.0))
								{
									_snprintf(szBuffer, sizeof(szBuffer),
										"%10.6e",
										fTotalSigma / sqrt(fDF/fChiHigh));
									ShortenExp(szBuffer);
									SetWindowText(GETHCTL(IDC_SIGMA_MIN),
										szBuffer);
								}
								else // OK
								{
									_snprintf(szBuffer, sizeof(szBuffer),
										"%10.6e",
										fTotalSigma * sqrt(fDF/fChiLow));
									ShortenExp(szBuffer);
									SetWindowText(GETHCTL(IDC_SIGMA_MIN),
										szBuffer);
								}
							}
							else // Single-sided
							{
								LoadString(hInst, IDS_MESSAGE_NA, szBuffer,
									BUFFER_SIZE);
								SetWindowText(GETHCTL(IDC_SIGMA_MIN),
									szBuffer);

							}

							// Show max total sigma
							_snprintf(szBuffer, sizeof(szBuffer), "%10.6e",
								fTotalSigma * sqrt(fDF/fChiHigh));
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_SIGMA_MAX), szBuffer);

							fSigma=fNormalSigma; // Found in noise id
							fValue=fTotalSigma;
						}
						break;

						case MODTOTAL_SIGMA:
						case TIMETOTAL_SIGMA:
						{
							// Set controls
							SigmaControls(hDlg, nSigmaType, bSigmaDetails,
								FALSE, bSetNoise, bACFNoiseID);

							if(bDataType== FREQ_DATA)
							{
								// Do MODTOTALVAR processing using
								// NewModTotvarCalc() by first converting freq
								// data to phase data in working array
								// Note: The +1 size of the phase data array is
								// allowed for in the fSigmaData allocation
								// Conv freq to phase data in working array
								ConvFreqToPhase(fFreqData, fSigmaData, fTau,
									FALSE);

								// Calc Mod Totvar
								nNum=ModTotvarCalc(fSigmaData, &fModTotalSigma,
									fTau, nAvgFactor, &bAbort, TRUE,
									(void*)WriteProgressMessage);

								// Bail out if abort
								if(bAbort)
								{
									break;
								}

								// Trap memory allocation error
								if(nNum==-1)
								{
									// Display error message
									AllocErrorMessage();

									// Set abort flag
									bAbort=TRUE;

									// Display normal cursor
									SetCursor(hArrow);

									// Free working memory
									free(fSigmaData);
	
									// Close Sigma dialog box
									EndDialog(hDlg, 0);

									// Return control to Windows
									return TRUE;
								}

								// Restore freq data to working array
								for(i=0; i<fData[0]+ARRAY_OFFSET; i++)
								{
									fSigmaData[i]=fData[i];
								}

								// Error trap for bad calc
								if(nNum<1)
								{
									SetWindowText(GETHCTL(IDC_SIGMA_VALUE),
										"Error");
									bAbort=TRUE;
									break;
								}
							}
							else // Phase data
							{
								// Calc Mod Totvar
								nNum=ModTotvarCalc(fSigmaData, &fModTotalSigma,
									fTau, nAvgFactor, &bAbort, TRUE,
									(void*)WriteProgressMessage);
								
								// Bail out if abort
								if(bAbort)
								{
									break;
								}

								// Trap memory allocation error
								if(nNum==-1)
								{
									// Display error message
									AllocErrorMessage();

									// Set abort flag
									bAbort=TRUE;

									// Display normal cursor
									SetCursor(hArrow);

									// Free working memory
									free(fSigmaData);
	
									// Close Sigma dialog box
									EndDialog(hDlg, 0);

									// Return control to Windows
									return TRUE;
								}

								// Error trap for bad calc
								if(nNum<1)
								{
									SetWindowText(GETHCTL(IDC_SIGMA_VALUE),
										"Error");
									bAbort=TRUE;
									break;
								}
							}

							// Find noise type
							if(!bSetNoise)
							{
								// ID noise
								SendMessage(hDlg, WM_COMMAND,
									GET_WM_COMMAND_MPS(IDC_SIGMA_NOISEID, NULL,
									0));

								// Test to calc ACF noise ID
								if(nNumb/nAvgFactor>=ACFNUM)
								{
									// ID noise using Greenhall ACF method
									SendMessage(hDlg, WM_COMMAND,
										GET_WM_COMMAND_MPS(IDC_SIGMA_ACFNOISEID,
										NULL, 0));

									// Test to apply ACF noise ID
									if(bACFNoiseID)
									{
										nAlpha=nACFAlpha;
									}
								}
							}
							else // Use selected noise type
							{
								nAlpha=nNoiseType-4;
							}

							// Show the alpha value
							_snprintf(szBuffer, sizeof(szBuffer), "%d",
								nAlpha);
							SetWindowText(GETHCTL(IDC_SIGMA_ALPHA), szBuffer);

							// Show the noise type
							if(!bSetNoise)
							{
								SetWindowText(GETHCTL(IDC_SIGMA_NOISE),
									szNoiseType[nAlpha+4]);
							}

							// Show the mu value
							SetWindowText(GETHCTL(IDC_SIGMA_MU),
								szNoiseMu[nAlpha+4]);

							// Calc bias factor
							// OK for all alpha (-2 to +2)
							fBias=ModTotvarBias(nAlpha);

							if(bSetNoise)
							{
								// Show the B(Mod Totvar) ratio
								_snprintf(szBuffer, sizeof(szBuffer), "%5.3f",
									fBias);
								SetWindowText(GETHCTL(IDC_SIGMA_B1RN),
									szBuffer);
							}

							// Correct Mod Totdev
							fModTotalSigma/=sqrt(fBias);

							// Set values
							fSigma=fNormalSigma; // Found in noise id
							fValue=fModTotalSigma;

							if(nSigmaType==TIMETOTAL_SIGMA)
							{
								// Apply scaling factor
								fTimeTotalSigma=
									fModTotalSigma*fTau*nAvgFactor/ROOT3;

								// Copy fTimeTotalSigma to fValue
								fValue=fTimeTotalSigma;
							}
							
							// Show # analysis points
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nNum);
							SetWindowText(GETHCTL(IDC_SIGMA_NUM), szBuffer);

							// Calc ModTotvar edf
							// nNumb is # non-gap tau=tau0 data points
							// Adding bDataType makes it = N = # phase data pts
							// nAvgFactor is averaging factor m
							// 2nd arg is nRatio = N/m = T/tau
							// where T is recond length
							// Applies for alpha -2 to -2 and m>8
							// Returns -1 (error) for nRatio < 3
							fDF=ModTotvarEDF(nAlpha,
								(float)(nNumb+bDataType)/(float)nAvgFactor);

							// Use MVAR edf for cases where m <= 8
							if(nAvgFactor<=8)
							{
								// Use HVAR edf function with adjusted args
								// as consistent way to calc MVAR edf
								// per C. Greenhall suggestion
								fDF=HadamardEDF(nNumb+bDataType+1, nAvgFactor,
									nAlpha-4);
							}

							// Show the edf
							_snprintf(szBuffer, sizeof(szBuffer), "%1.3f",
								fDF);
							SetWindowText(GETHCTL(IDC_SIGMA_DF), szBuffer);

							// Calc CI limits
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_SIGMA_CICALC, NULL, 0));

							if(bCIType) // Double-sided
							{
								// Show min mod total or time total sigma
								// Make sure low limit is OK
								// (may not be for small CF)
								// Note: The nominal sigma val in the following
								// expressions is fValue, which is either
								// fModTotalSigma or fTimeTotalSigma depending
								// on whether nSigmaType is MODTOTAL_SIGMA or
								// TIMETOTAL_SIGMA
								if(sqrt(fDF/fChiLow>=1.0))
								{
									_snprintf(szBuffer, sizeof(szBuffer),
										"%10.6e",
										fValue/sqrt(fDF/fChiHigh));
									ShortenExp(szBuffer);
									SetWindowText(GETHCTL(IDC_SIGMA_MIN),
										szBuffer);
								}
								else // OK
								{
									_snprintf(szBuffer, sizeof(szBuffer),
										"%10.6e",
										fValue*sqrt(fDF/fChiLow));
									ShortenExp(szBuffer);
									SetWindowText(GETHCTL(IDC_SIGMA_MIN),
										szBuffer);
								}
							}
							else // Single-sided
							{
								LoadString(hInst, IDS_MESSAGE_NA, szBuffer,
									BUFFER_SIZE);
								SetWindowText(GETHCTL(IDC_SIGMA_MIN),
									szBuffer);
							}

							// Show max mod total or time total sigma
							_snprintf(szBuffer, sizeof(szBuffer), "%10.6e",
								fValue*sqrt(fDF/fChiHigh));
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_SIGMA_MAX), szBuffer);
						}
						break;

						case HADAMARD_SIGMA:
						{
							// Set controls
							SigmaControls(hDlg, nSigmaType, bSigmaDetails,
								FALSE, bSetNoise, bACFNoiseID);

							if(bDataType==FREQ_DATA)
							{
								// Average freq data
								AverageFreqData(fSigmaData, nAvgFactor);

								// Calc Hadamard dev
								nNum=CalcFreqHadamardDev(fSigmaData,
									&fHadamardSigma);

								// Calc normal sigma
								CalcFreqSigma(fSigmaData, &fNormalSigma);
							}
							else // Phase data
							{
								// Average phase data
								AveragePhaseData(fSigmaData, nAvgFactor);

								// Calc Hadamard dev
								nNum=CalcPhaseHadamardDev(fSigmaData,
									&fHadamardSigma, fTau*nAvgFactor);

								// Calc normal sigma
								CalcPhaseSigma(fSigmaData, &fNormalSigma,
									fTau*nAvgFactor);
							}

							fSigma=fNormalSigma;
							fValue=fHadamardSigma;

							// Check for zero normal sigma
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_SIGMA_CHECK, NULL, 0));

							// Show the # analysis points
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nNum);
							SetWindowText(GETHCTL(IDC_SIGMA_NUM), szBuffer);
							
							// Find noise type
							if(!bSetNoise)
							{
								// ID noise
								SendMessage(hDlg, WM_COMMAND,
									GET_WM_COMMAND_MPS(IDC_SIGMA_NOISEID, NULL,
									0));

								// Test to calc ACF noise ID
								if(nNumb/nAvgFactor>=ACFNUM)
								{
									// ID noise using Greenhall ACF method
									SendMessage(hDlg, WM_COMMAND,
										GET_WM_COMMAND_MPS(IDC_SIGMA_ACFNOISEID,
										NULL, 0));

									// Test to apply ACF noise ID
									if(bACFNoiseID)
									{
										nAlpha=nACFAlpha;
									}
								}
							}
							else // Use selected noise type
							{
								nAlpha=nNoiseType-4;
							}

							// Show the alpha value
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nAlpha);
							SetWindowText(GETHCTL(IDC_SIGMA_ALPHA),	szBuffer);

							// Show the noise type
							if(!bSetNoise)
							{
								SetWindowText(GETHCTL(IDC_SIGMA_NOISE),
									szNoiseType[nAlpha+4]);
							}

							// Show the mu value
							SetWindowText(GETHCTL(IDC_SIGMA_MU),
								szNoiseMu[nAlpha+4]);

							#ifdef NEWEDF // New code 07/15/03
							// Calc EDF
							fDF=CombinedEDF(nPoints-nGaps+bDataType, nAvgFactor,
								nAlpha, 3, nAvgFactor, 1, 1);

							// Show the df
							_snprintf(szBuffer, sizeof(szBuffer), "%1.3f", fDF);
							SetWindowText(GETHCTL(IDC_SIGMA_DF), szBuffer);

							// Calc CI limits
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_SIGMA_CICALC, NULL, 0));

							if(bCIType) // Double-sided CI
							{
								// Show Min sigma
								// Make sure low limit is OK
								// (may not be for small CF)
								if(sqrt(fDF/fChiLow>=1.0))
								{
									_snprintf(szBuffer, sizeof(szBuffer),
										"%10.6e",
										fValue / sqrt(fDF/fChiHigh));
									ShortenExp(szBuffer);
									SetWindowText(GETHCTL(IDC_SIGMA_MIN),
										szBuffer);
								}
								else // OK
								{
									_snprintf(szBuffer, sizeof(szBuffer),
										"%10.6e",
										fValue * sqrt(fDF/fChiLow));
									ShortenExp(szBuffer);
									SetWindowText(GETHCTL(IDC_SIGMA_MIN),
										szBuffer);
								}
							}
							else // Single-sided
							{
								LoadString(hInst, IDS_MESSAGE_NA, szBuffer,
									BUFFER_SIZE);
								SetWindowText(GETHCTL(IDC_SIGMA_MIN),
									szBuffer);
							}

							// Show Max sigma
							_snprintf(szBuffer, sizeof(szBuffer), "%10.6e",
								fValue * sqrt(fDF/fChiHigh));
									ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_SIGMA_MAX), szBuffer);
							#endif
						}
						break;

						case OVERLAPHAD_SIGMA:
						{
							// Set controls
							SigmaControls(hDlg, nSigmaType, bSigmaDetails,
								FALSE, bSetNoise, bACFNoiseID);

							if(bDataType==FREQ_DATA)
							{
								// Calc overlapping Hadamard deviation
								nNum=CalcFreqOverlapHadamardDev(fSigmaData,
									&fOverlapHadSigma, nAvgFactor);

								// Error trap for bad calc
								if(nNum<1)
								{
									SetWindowText(GETHCTL(IDC_SIGMA_VALUE),
										"Error");
									bAbort=TRUE;
									break;
								}
							}
							else // Phase data
							{
								// Calc overlapping Hadamard deviation
								nNum=CalcPhaseOverlapHadamardDev(fSigmaData,
									&fOverlapHadSigma, fTau, nAvgFactor);

								// Error trap for bad calc
								if(nNum<1)
								{
									SetWindowText(GETHCTL(IDC_SIGMA_VALUE),
										"Error");
									bAbort=TRUE;
									break;
								}
							}

							// Copy fOverlapHadSigma to fValue
							fValue=fOverlapHadSigma;

							// Find noise type
							if(!bSetNoise)
							{
								// ID noise
								SendMessage(hDlg, WM_COMMAND,
									GET_WM_COMMAND_MPS(IDC_SIGMA_NOISEID, NULL,
									0));

								// Test to calc ACF noise ID
								if(nNumb/nAvgFactor>=ACFNUM)
								{
									// ID noise using Greenhall ACF method
									SendMessage(hDlg, WM_COMMAND,
										GET_WM_COMMAND_MPS(IDC_SIGMA_ACFNOISEID,
										NULL, 0));

									// Test to apply ACF noise ID
									if(bACFNoiseID)
									{
										nAlpha=nACFAlpha;
									}
								}
							}
							else // Use selected noise type
							{
								nAlpha=nNoiseType-4;
							}

							// Copy fNormalSigma to fSigma - calc'd in noise id
							fSigma=fNormalSigma;

							// Show the alpha value
							_snprintf(szBuffer, sizeof(szBuffer), "%d",
								nAlpha);
							SetWindowText(GETHCTL(IDC_SIGMA_ALPHA),	szBuffer);

							// Show the noise type
							if(!bSetNoise)
							{
								SetWindowText(GETHCTL(IDC_SIGMA_NOISE),
									szNoiseType[nAlpha+4]);
							}

							// Show the mu value
							SetWindowText(GETHCTL(IDC_SIGMA_MU),
								szNoiseMu[nAlpha+4]);

							// Show the # analysis points
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nNum);
							SetWindowText(GETHCTL(IDC_SIGMA_NUM), szBuffer);

							#ifdef NEWEDF // New code 07/15/03
							fDF=CombinedEDF(nPoints-nGaps+bDataType,
								nAvgFactor,
								nAlpha, 3, nAvgFactor, nAvgFactor, 1);

							#else
							if(nAlpha<1)
							{
								// Calc Hadamard edf
								// Use for alpha=0 to -4, beta=-2 to -6 
								// Args = # phase data pts, avg factor & beta
								fDF=HadamardEDF(nPoints-nGaps+bDataType,
									nAvgFactor,	nAlpha-2);
							}
							else // F PM or W PM (alpha 1 or 2)
							{
								// Calc df
								// 2nd arg = # non-gap phase points
								fDF=CalcDegFree(nAlpha,
									(nPoints-nGaps+bDataType), nAvgFactor);
							}
							#endif
							
							// Show the df
							_snprintf(szBuffer, sizeof(szBuffer), "%1.3f", fDF);
							SetWindowText(GETHCTL(IDC_SIGMA_DF), szBuffer);

							// Calc CI limits
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_SIGMA_CICALC, NULL, 0));

							if(bCIType) // Double-sided CI
							{
								// Show Min sigma
								// Make sure low limit is OK
								// (may not be for small CF)
								if(sqrt(fDF/fChiLow>=1.0))
								{
									_snprintf(szBuffer, sizeof(szBuffer), "%10.6e",
										fValue / sqrt(fDF/fChiHigh));
									ShortenExp(szBuffer);
									SetWindowText(GETHCTL(IDC_SIGMA_MIN),
										szBuffer);
								}
								else // OK
								{
									_snprintf(szBuffer, sizeof(szBuffer),
										"%10.6e",
										fValue * sqrt(fDF/fChiLow));
									ShortenExp(szBuffer);
									SetWindowText(GETHCTL(IDC_SIGMA_MIN),
										szBuffer);
								}
							}
							else // Single-sided
							{
								LoadString(hInst, IDS_MESSAGE_NA, szBuffer,
									BUFFER_SIZE);
								SetWindowText(GETHCTL(IDC_SIGMA_MIN),
									szBuffer);
							}

							// Show Max sigma
							_snprintf(szBuffer, sizeof(szBuffer),
								"%10.6e",
								fValue * sqrt(fDF/fChiHigh));
									ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_SIGMA_MAX), szBuffer);
						}
						break;

						case HADTOTAL_SIGMA:
						{
							// Set controls
							SigmaControls(hDlg, nSigmaType, bSigmaDetails,
								FALSE, bSetNoise, bACFNoiseID);

							if(bDataType==FREQ_DATA)
							{
								if(nAvgFactor==1)
								{
									// Calc overlapping Hadamard deviation
									nNum=CalcFreqOverlapHadamardDev(fSigmaData,
										&fHadTotalSigma, nAvgFactor);
								}
								else // AF>1
								{
									// Calc Hadamard Totvar
									nNum=HadTotvarCalc(fSigmaData, 
										&fHadTotalSigma, nAvgFactor, &bAbort,
										TRUE, (void*)WriteProgressMessage);
								}
							}
							else // Phase data
							{
								if(nAvgFactor==1)
								{
									// Calc overlapping Hadamard deviation
									nNum=CalcPhaseOverlapHadamardDev(fSigmaData,
										&fHadTotalSigma, fTau, nAvgFactor);
								}
								else // AF>1
								{
									// Convert phase data to frequency data
									ConvPhaseToFreq(fPhaseData, fSigmaData,
										fTau, FALSE);

									// Calc Hadamard Totvar
									nNum=HadTotvarCalc(fSigmaData, 
										&fHadTotalSigma, nAvgFactor, &bAbort,
										TRUE, (void*)WriteProgressMessage);
								}
							}

							// Error trap for bad calc
							if(nNum<1)
							{
								SetWindowText(GETHCTL(IDC_SIGMA_VALUE),
									"Error");
								bAbort=TRUE;
								break;
							}

							// Copy fHadTotalSigma to fValue
							fValue=fHadTotalSigma;

							// Find noise type
							if(!bSetNoise)
							{
								// ID noise
								SendMessage(hDlg, WM_COMMAND,
									GET_WM_COMMAND_MPS(IDC_SIGMA_NOISEID, NULL,
									0));

								// Test to calc ACF noise ID
								if(nNumb/nAvgFactor>=ACFNUM)
								{
									// ID noise using Greenhall ACF method
									SendMessage(hDlg, WM_COMMAND,
										GET_WM_COMMAND_MPS(IDC_SIGMA_ACFNOISEID,
										NULL, 0));

									// Test to apply ACF noise ID
									if(bACFNoiseID)
									{
										nAlpha=nACFAlpha;
									}
								}
							}
							else // Use selected noise type
							{
								nAlpha=nNoiseType-4;
							}

							// Copy fNormalSigma to fSigma - calc'd in noise id
							fSigma=fNormalSigma;

							// Show the alpha value
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nAlpha);
							SetWindowText(GETHCTL(IDC_SIGMA_ALPHA),	szBuffer);

							// Show the noise type
							if(!bSetNoise)
							{
								SetWindowText(GETHCTL(IDC_SIGMA_NOISE),
									szNoiseType[nAlpha+4]);
							}

							// Show the mu value
							SetWindowText(GETHCTL(IDC_SIGMA_MU),
								szNoiseMu[nAlpha+4]);

							// Show the # analysis points
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nNum);
							SetWindowText(GETHCTL(IDC_SIGMA_NUM), szBuffer);

							// Calc edf
							if( (nAlpha<1) && (nAvgFactor>15) )
							// Note: Was 24 until 12/24/00
							{
								// Calc HTOT edf
								// Use for alpha=0 to -4 m=nAvgFactor>15
								// Args are nAlpha and T/tau = N/m
								// where N = # non-gap freq data points
								// N=nPoints-nGaps
								fDF=HadTotvarEDF(nAlpha,
									((float)(nPoints-nGaps)/
									(float)(nAvgFactor)));
							}
							else // F PM or W PM (alpha 1 or 2) or AF<16
								 // Note: Was 25 until 12/24/00
							{
								// Calc df
								// 2nd arg = # non-gap freq points
								fDF=CalcDegFree(nAlpha,
									(nPoints-nGaps), nAvgFactor);

								// For the case where alpha is -3 or -4
								// and AF<16 which cannot be handled by either
								// HadTotvarEDF() or CalcDegFree(),
								// CalcDegFree() returns -1 (error) and we use
								// HadamardEDF()
								if(fDF==-1)
								{
									// Args are # phase data points, avg factor,
									// and beta = alpha-2
									fDF=HadamardEDF(nPoints-nGaps+1, nAvgFactor,
										nAlpha-2);
								}
								else // Use CalcDegFree() result
								{
									// Add 2 because this is a total statistic
									fDF+=2;
								}
							}

							// Show the df
							_snprintf(szBuffer, sizeof(szBuffer), "%1.3f", fDF);
							SetWindowText(GETHCTL(IDC_SIGMA_DF), szBuffer);

							// Apply Hadamard Totvar bias function
							// Calc Hadamard Totvar bias factor
							// Applies for all alpha -4 to 0
							// Otherwise it returns -1
							fBias=HadTotvarBias(nAlpha);

							// Test for error or AF=1
							if(fBias==-1.0 || nAvgFactor==1)
							{
                                // Set fBias to unity
                                // This is approximately correct for
                                // alpha >0 (W and F PM)
                                // and allows calculation to proceed
                                fBias=1.0;
 							}

							if(bSetNoise)
							{
								// Show the B(Mod Totvar) ratio
								_snprintf(szBuffer, sizeof(szBuffer), "%5.3f",
									fBias);
								SetWindowText(GETHCTL(IDC_SIGMA_B1RN),
									szBuffer);
							}

							// Correct HTOTDEV
							// Note: This does not correct fHadTotalSigma
							fValue/=(float)sqrt(fBias);

							// Calc CI limits
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_SIGMA_CICALC, NULL, 0));

							if(bCIType) // Double-sided CI
							{
								// Show Min sigma
								// Make sure low limit is OK
								// (may not be for small CF)
								if(sqrt(fDF/fChiLow>=1.0))
								{
									_snprintf(szBuffer, sizeof(szBuffer),
										"%10.6e",
										fValue / sqrt(fDF/fChiHigh));
									ShortenExp(szBuffer);
									SetWindowText(GETHCTL(IDC_SIGMA_MIN),
										szBuffer);
								}
								else // OK
								{
									_snprintf(szBuffer, sizeof(szBuffer),
										"%10.6e",
										fValue * sqrt(fDF/fChiLow));
									ShortenExp(szBuffer);
									SetWindowText(GETHCTL(IDC_SIGMA_MIN),
										szBuffer);
								}
							}
							else // Single-sided
							{
								LoadString(hInst, IDS_MESSAGE_NA, szBuffer,
									BUFFER_SIZE);
								SetWindowText(GETHCTL(IDC_SIGMA_MIN),
									szBuffer);
							}

							// Show Max sigma
							_snprintf(szBuffer, sizeof(szBuffer), "%10.6e",
								fValue * sqrt(fDF/fChiHigh));
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_SIGMA_MAX), szBuffer);
						}
						break;

						case TIERMS_SIGMA:
						// Note: Applies only to phase data
						{
							// Calc rms time interval error
							TIErms(fSigmaData, &fValue, nAvgFactor);

							fTIErms=fValue;

							// Calc normal sigma
							CalcPhaseSigma(fSigmaData, &fSigma,
								fTau*nAvgFactor);
						}
						break;

						case MTIE_SIGMA:
						// Note: Applies only to phase data
						{
							// As precaution, fill gaps in working copy of
							// phase data.  CalcMTIE does not include any
							// gap checking.  Don't want a zero to affect
							// the max or min values processed.
							FillGaps(fSigmaData, PHASE_DATA);
							
							// Calc maximum time interval error
							CalcMTIE(fSigmaData, &fValue, nAvgFactor, &bAbort,
								TRUE, (void*)WriteProgressMessage);
							fMTIE=fValue;

							// Bail out if abort
							if(bAbort)
							{
								break;
							}

							// Calc normal sigma
							CalcPhaseSigma(fSigmaData, &fSigma,
								fTau*nAvgFactor);
						}
						break;						

						case THEO1_SIGMA:
						{
							// Set controls
							SigmaControls(hDlg, nSigmaType, bSigmaDetails,
								FALSE, bSetNoise, bACFNoiseID);

							if(bDataType== FREQ_DATA)
							{
								; // Not implemented for freq data
							}
							else // Phase data
							{
								if(bSetNoise) // Forced noise type
								{
									fNum=Theo1(fSigmaData, &fTheo1Sigma, fTau,
										nAvgFactor, &bAbort, TRUE,
										(void*)WriteProgressMessage);
								}
								else // Automatic bias correction
								{
									// Note:  Use Tasset & Howe NewTho1 funct
									// with built-in bias correction, so no
									// subsequent bias factor should be applied
									fNum=NewTheo1(fSigmaData, &fTheo1Sigma,
										fTau, nAvgFactor, &fTheo1BiasFactor,
										&nTheo1Noise, &bAbort, TRUE, TRUE,
										(void*)WriteProgressMessage);

									// Set bAbort to false
									// Stop in this THEO1_SIGMA case using
									// NewTheo1() halts the Thoq bias calc
									// and either trancates or continues it
									// By the time the program gets here
									// there is no reason to abort because
									// all results are done
									bAbort=FALSE;
									
									// Set alpha based on NewTho1 noise ID
									nAlpha=nTheo1Noise;

									// Show the alpha value
									_snprintf(szBuffer, sizeof(szBuffer), "%d",
										nAlpha);
									SetWindowText(GETHCTL(IDC_SIGMA_ALPHA),
										szBuffer);

									// Show the noise type
									if(!bSetNoise)
									{
										SetWindowText(GETHCTL(IDC_SIGMA_NOISE),
											szNoiseType[nAlpha+4]);
									}

									// Show the mu value
									SetWindowText(GETHCTL(IDC_SIGMA_MU),
										szNoiseMu[nAlpha+4]);

									// Show bias value
									_snprintf(szBuffer, sizeof(szBuffer),
										"%0.3f", fTheo1BiasFactor);
									SetWindowText(GETHCTL(IDC_SIGMA_B1RN),
										szBuffer);
								}

								// Bail out if abort
								if(bAbort)
								{
									break;
								}

								// Error trap for bad calc
								if(fNum==-1.0)
								{
									SetWindowText(GETHCTL(IDC_SIGMA_VALUE),
										"Error");
									bAbort=TRUE;
									break;
								}
							}

							// Noise ID not yet implemented for Tho1
							// What's going on here is this:
							// As presently implemented, one must set noise type
							// for Tho1 variance (bSetNoise is always TRUE).
							// No noise ID is done, and the
							// bias correction comes from Theo1Bias() in
							// IDC_SIGMA_THEO1BIAS subroutine.
							// But below are two ways for automatic Tho1 noise
							// ID and bias correction, (1) using ACF lag 1 noise
							// ID method, and (2) using AutoTheo1Bias() and
							// Theo1BiasToAlpha().  Both work, but neither is
							// implemented.
							// The ACF method requires about 30 data points.
							// the bias method requires about 10 data points.

							// Changes of 12/26/03 activate NewTho1 method
							// SetNoise can be turned on & off
							// With it off, noise ID is done by NewTho1

							// Apply Tho1 bias factor if noise type was set
							if(bSetNoise)
							{
								fTheo1Sigma*=sqrt(fTheo1Bias);
							}

							// Show the Tho1 scaled tau
							_snprintf(szBuffer, sizeof(szBuffer), "%e",
								fTau*0.75*nAvgFactor);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_SIGMA_TAU), szBuffer);

							// Show # analysis points
							_snprintf(szBuffer, sizeof(szBuffer), "%e", fNum);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_SIGMA_NUM), szBuffer);

							// Calc edf
							// 2nd arg = # non-gap phase points
							fDF=Theo1EDF(nAlpha,
								(nPoints-nGaps+bDataType), (float)nAvgFactor);

							// Error trap for bad edf calc
							if(fDF==-1.0)
							{
								SetWindowText(GETHCTL(IDC_SIGMA_DF),
									"Error");
								bAbort=TRUE;
								break;
							}

							// Show the df
							_snprintf(szBuffer, sizeof(szBuffer), "%1.3f",
								fDF);
							SetWindowText(GETHCTL(IDC_SIGMA_DF), szBuffer);

							// Calc CI limits
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_SIGMA_CICALC, NULL, 0));

							if(bCIType) // Double-sided CI
							{
								// Show Min sigma
								// Make sure low limit is OK
								// (may not be for small CF)
								if(sqrt(fDF/fChiLow>=1.0))
								{
									_snprintf(szBuffer, sizeof(szBuffer),
										"%10.6e",
										fTheo1Sigma / sqrt(fDF/fChiHigh));
									ShortenExp(szBuffer);
									SetWindowText(GETHCTL(IDC_SIGMA_MIN),
										szBuffer);
								}
								else // OK
								{
									_snprintf(szBuffer, sizeof(szBuffer),
										"%10.6e",
										fTheo1Sigma * sqrt(fDF/fChiLow));
									ShortenExp(szBuffer);
									SetWindowText(GETHCTL(IDC_SIGMA_MIN),
										szBuffer);
								}
							}
							else // Single-sided
							{
								LoadString(hInst, IDS_MESSAGE_NA, szBuffer,
									BUFFER_SIZE);
								SetWindowText(GETHCTL(IDC_SIGMA_MIN),
									szBuffer);
							}

							// Show Max sigma
							_snprintf(szBuffer, sizeof(szBuffer), "%10.6e",
								fTheo1Sigma * sqrt(fDF/fChiHigh));
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_SIGMA_MAX), szBuffer);

							// Can't calc normal sigma along with Tho1 because
							// the tau is different and the AF may be too large
							// so make its window blank
							SetWindowText(GETHCTL(IDC_SIGMA_SIGMA),
								"Not Applicable");
							
							// Save Tho1 result
							fValue=fTheo1Sigma;
						}
						break;
					}

					if(!bAbort)
					{
						// Enable the copy button - now there are results
						EnableWindow(GETHCTL(IDC_SIGMA_COPY), TRUE);

						// Put info into log file
						strlcpy(szBuffer, "Type=", sizeof(szBuffer));
						GetWindowText(GETHCTL(IDC_SIGMA_TYPE),
							szFormat, BUFFER_SIZE);
						strlcat(szBuffer, szFormat, sizeof(szBuffer));
						_snprintf(szFormat, sizeof(szFormat), ", AF=%d",
							nAvgFactor);
						strlcat(szBuffer, szFormat, sizeof(szBuffer));
						if( (nSigmaType==NORMAL_SIGMA) ||
							(nSigmaType==OVERLAPPING_SIGMA) )
						{
							_snprintf(szFormat, sizeof(szFormat),
								", Sigma=%e", fSigma);
						}
						else
						{
							_snprintf(szFormat, sizeof(szFormat),
								", Sigma=%e", fValue);
						}
						strlcat(szBuffer, szFormat, sizeof(szBuffer));
						ShortenExp(szBuffer);
						if(bDataType==FREQ_DATA)
						{
							WriteLog(35, szBuffer);
						}
						else // Phase data
						{
							WriteLog(34, szBuffer);
						}
									
						if(bSigmaDetails)
						{
							if(nSigmaType!=THEO1_SIGMA)
							{
								// Display sigma
								_snprintf(szBuffer, sizeof(szBuffer),
									"%10.6e", fSigma);
								ShortenExp(szBuffer);
								SetWindowText(GETHCTL(IDC_SIGMA_SIGMA),
									szBuffer);
							}

							// Display non-normal sigma or std dev
							_snprintf(szBuffer, sizeof(szBuffer), "%10.6e",
								fValue);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_SIGMA_VALUE), szBuffer);
						}
						else
						{
							if(nSigmaType==NORMAL_SIGMA ||
								nSigmaType==OVERLAPPING_SIGMA)
							{
								// Display sigma
								_snprintf(szBuffer, sizeof(szBuffer), "%10.6e",
									fSigma);
								ShortenExp(szBuffer);
								SetWindowText(GETHCTL(IDC_SIGMA_VALUE),
									szBuffer);
							}
							else
							{
								// Display sigma
								_snprintf(szBuffer, sizeof(szBuffer), "%10.6e",
									fValue);
								ShortenExp(szBuffer);
								SetWindowText(GETHCTL(IDC_SIGMA_VALUE),
									szBuffer);
							}
						}
					}

					// Reenable controls
					EnableWindow(GETHCTL(IDC_SIGMA_CALC), TRUE);
					EnableWindow(GETHCTL(IDHELP), TRUE);
					EnableWindow(GETHCTL(IDC_SIGMA_TYPE), TRUE);
					EnableWindow(GETHCTL(IDC_SIGMA_AVGFACTOR), TRUE);
					EnableWindow(GETHCTL(IDC_SIGMA_SHOW), TRUE);
					EnableWindow(GETHCTL(IDC_SIGMA_CF), TRUE);
					EnableWindow(GETHCTL(IDC_SIGMA_BWFACTOR), TRUE);
					EnableWindow(GETHCTL(IDC_SIGMA_SINGLE), TRUE);
					EnableWindow(GETHCTL(IDC_SIGMA_DOUBLE), TRUE);
					
					if((bSetNoise) &&
						(nSigmaType==NORMAL_SIGMA ||
						nSigmaType==OVERLAPPING_SIGMA))
					{
						EnableWindow(GETHCTL(IDC_SIGMA_DEADTIME), TRUE);
					}

					SetWindowText(GETHCTL(IDCANCEL), "&Close");
					EnableWindow(GETHCTL(IDCANCEL), TRUE);
					EnableWindow(GETHCTL(IDC_SIGMA_COPY), TRUE);

					// Display normal cursor
					SetCursor(hArrow);

					// Write prompt message
					LoadString(hInst, IDS_MESSAGE_SIGDONE, szBuffer,
						BUFFER_SIZE);
					WriteMessage(szBuffer);

					// Reset yield flag
					bYield=FALSE;
				}
				break;

				// Internal subroutine for CI calc & display
				case IDC_SIGMA_CICALC:
				{
					// Calc CI 
					if(bCIType) // Double-sided
					{
						fLow=(1-fCF)/2;
						fHigh=1-fLow;
						fChiHigh=CalcInvChiSqr(fHigh, fDF);
						fChiLow=CalcInvChiSqr(fLow, fDF);
						_snprintf(szBuffer, sizeof(szBuffer),
							"X=%4.3f, %4.3f", fChiLow, fChiHigh);
					}
					else // Single-sided
					{
						fHigh=fCF;
						fChiHigh=CalcInvChiSqr(fHigh, fDF);
						_snprintf(szBuffer, sizeof(szBuffer),
							"X=%4.3f",	fChiHigh);
					}

					// Show CI results
					SetWindowText(GETHCTL(IDC_SIGMA_CI), szBuffer);
					ShowWindow((GETHCTL(IDC_SIGMA_CI)), SW_SHOWNORMAL);
				}
				break;

				// Internal subroutine for noise id
				case IDC_SIGMA_NOISEID:
				{
					if(nSigmaType!=NORMAL_SIGMA)
					// Already have normal sigma & std dev if NORMAL_SIGMA
					// and must not average data or calc them again
					{
						if(bDataType==FREQ_DATA)
						{
							// Average freq data
							AverageFreqData(fSigmaData, nAvgFactor);

							// Calc normal sigma
							CalcFreqSigma(fSigmaData, &fNormalSigma);

							// Calc standard deviation
							CalcFreqStdDev(fSigmaData, &fStdDev);
						}
						else // Phase data
						{
							// Average phase data
							AveragePhaseData(fSigmaData, nAvgFactor);

							// Calc normal sigma
							CalcPhaseSigma(fSigmaData, &fNormalSigma,
								fTau*nAvgFactor);

							// Avoid problem with CalcPhaseStdDev()
							if(nNum>1)
							{
								// Calc standard deviation
								CalcPhaseStdDev(fSigmaData, &fStdDev,
									fTau*nAvgFactor);
							}
							// Set std dev = sigma for #=1
							else
							{
								fStdDev=fNormalSigma;
							}
						}
					}

					// Check for zero normal sigma
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_SIGMA_CHECK, NULL, 0));

					// Restore data after averaging
					// Copy complete data array to working memory
					for(i=0; i<fData[0]+ARRAY_OFFSET; i++)
					{
						fSigmaData[i]=fData[i];
					}

					// Calc B1 ratio
					fB1Ratio=(float)SQR(fStdDev/fNormalSigma);

					// Show the B1 ratio
					if(fB1Ratio<99999.)
					{
						_snprintf(szBuffer, sizeof(szBuffer), "%5.3f",
							fB1Ratio);
					}
					else
					{
						_snprintf(szBuffer, sizeof(szBuffer), "%5.1f",
							fB1Ratio);
					}
					SetWindowText(GETHCTL(IDC_SIGMA_B1RN), szBuffer);

					
					if(!bACFNoiseID) // Not used with ACF noise ID
					{
						// Find noise type
						// Call NoiseID() with B1 and nSigmaType=NORMAL_SIGMA
						// which will use B1 to find alpha from -2 to +1.
						// If alpha is +1 and AF>1,
						// then call NoiseID() with R(n)
						// nSigmaType=MODIFIED_SIGMA to resolve alpha +1 or +2.
						// Or if alpha is -2, then calc *B1 with CalcStarB1()
						// and call NoiseID() with *B1
						// and nSigmaType=NORMAL_SIGMA
						// and add 2 to mu (subtract 2 from alpha).

						// Call NoiseID with nSigmaType=NORMAL_SIGMA
						// to find alpha -2 to +1 using CalcB1()
						// Note: BW factor not applicable
						nAlpha=NoiseID(nNum, NORMAL_SIGMA, nAvgFactor, 10.0,
							fB1Ratio);

						#ifdef LOGGING
						_snprintf(szBuffer, sizeof(szBuffer),
							"Called NoiseID() for NORMAL_SIGMA "
							"with nNum=%d, nAvgFactor=%d, fBW=10.0,
							fB1Ratio=%f", nNum, nAvgFactor, fB1Ratio);
						WriteLog(60, szBuffer);
						_snprintf(szBuffer, sizeof(szBuffer),
							"NoiseID() returned nAlpha=%d", nAlpha);
						WriteLog(60, szBuffer);
						#endif

						// Check for alpha<-2 with non-Hadamard sigma type
						// An Allan variance shouldn't be used for alpha<-2
						// Hadamard variance is OK thru alpha=-4
						// Note: This possibility could be avoided by changing
						// NoiseID() so it doesn't return alpha<-2
						// Could show alpha as -3 but use -2 for OK CI calc
						// Or we could just silently change alpha to -2
						// But better to display a warning message
						// No space to show warning on Sigma screens
						if( !(nSigmaType==HADAMARD_SIGMA ||
							 nSigmaType==OVERLAPHAD_SIGMA ||
							 nSigmaType==HADTOTAL_SIGMA) && (nAlpha<-2) )
						{
							// Show warning message if detailed dislog box
							if(bSigmaDetails)
							{
								MessageBox(hDlg,
									"Warning: Alpha<-2 detected.\n"
								"Use of a Hadamard variance recommended.\n"
								"Alpha set to -2.", "Sigma",
								MB_ICONEXCLAMATION);
							}
							
							// Force alpha to -2
							nAlpha=-2;
						}

						// Check if alpha=+1 and AF>1 to use R(n)
						// to resolve alpha +1 or +2 ambiguity
						if( (nAlpha==1) && (nAvgFactor>1) )
						{
							// Calc mod sigma
							if(bDataType==FREQ_DATA)
							{
								// Do MVAR processing by converting freq
								// data to phase data in working array
								// Conv freq to phase data in work array
								ConvFreqToPhase(fFreqData, fSigmaData, fTau,
									FALSE);

								// Calc mod sigma
								nDummy=CalcPhaseModSigma(fSigmaData, &fModSigma,
									fTau*nAvgFactor, nAvgFactor, &bAbort, TRUE,
									(void*)WriteProgressMessage);

								// Error trap for bad calc
								if(nDummy<1)
								{
									SetWindowText(GETHCTL(IDC_SIGMA_VALUE),
										"Error");
									bAbort=TRUE;
									break;
								}
							}
							else // Phase data
							{
								// Calc mod sigma
								nDummy=CalcPhaseModSigma(fSigmaData,
									&fModSigma,	fTau*nAvgFactor, nAvgFactor,
									&bAbort, TRUE,
									(void*)WriteProgressMessage);

								// Error trap for bad calc
								if(nDummy<1)
								{
									SetWindowText(GETHCTL(IDC_SIGMA_VALUE),
										"Error");
									bAbort=TRUE;
									break;
								}
							}
										
							#ifdef LOGGING
							WriteLog(60,
								"Resolve alpha 1,2 ambiguity with R(n)");
							#endif

							// Calc R(n)
							fRnRatio=(float)SQR(fModSigma/fNormalSigma);

							#ifdef LOGGING
							_snprintf(szBuffer, sizeof(szBuffer),
								"Calc fModSigma=%e", fModSigma);
							WriteLog(60, szBuffer);
							#endif

							// Call NoiseID with nSigmaType=MODIFIED_SIGMA
							// to find alpha -2 to +1 using R(n)
							nAlpha=NoiseID(nNum, MODIFIED_SIGMA, nAvgFactor,
								10.0, fRnRatio);

							#ifdef LOGGING
							_snprintf(szBuffer, sizeof(szBuffer),
								"Called NoiseID() for MODIFIED_SIGMA "
								"with nNum=%d, nAvgFactor=%d, fBW=10.0, "
								fRnRatio=%f",
								nNum, nAvgFactor, fRnRatio);
							WriteLog(60, szBuffer);
							_snprintf(szBuffer, sizeof(szBuffer),
								"NoiseID() returned nAlpha=%d", nAlpha);
							WriteLog(60, szBuffer);
							#endif

							// The R(n) test isn't always effective
							// and can return non-pm noise types
							// We don't want to allow alpha <1 here
							nAlpha=max(nAlpha, 1);

							#ifdef LOGGING
							_snprintf(szBuffer, sizeof(szBuffer),
								"Limit alpha to PM; nAlpha=%d", nAlpha);
							WriteLog(60, szBuffer);
							#endif
						}

						// For Hadamard sigmas, check if alpha<=-2
						// If so, use *B1 to resolve alpha -2 thru -4
						// No alpha less than -2 will be reported for a
						// non-Hadamard sigma because the Allan family of
						// variances do not apply to those noises
						// Note:  This routine is not called for HADAMARD_SIGMA
						// but that sigma type is included here anyway
						if( (nSigmaType==HADAMARD_SIGMA ||
							 nSigmaType==OVERLAPHAD_SIGMA ||
							 nSigmaType==HADTOTAL_SIGMA) && (nAlpha<=-2) )
						{
							// Must use main phase or freq data arrays
							// because the fSigmaData array has been averaged
							if(bDataType==FREQ_DATA)
							{
								// Calc *B1 from freq data
								fB1Ratio=CalcStarB1(fFreqData, bDataType, fTau,
									nAvgFactor);
							}
							else // Phase data
							{
								// Calc *B1 from phase data
								fB1Ratio=CalcStarB1(fPhaseData,	bDataType,
									fTau,
									nAvgFactor);
							}

							// Call NoiseID with nSigmaType=NORMAL_SIGMA
							// to find alpha+2 using CalcB1()
							// Note: BW factor not applicable
							nAlpha=-2 +NoiseID(nNum, NORMAL_SIGMA, nAvgFactor,
								10.0, fB1Ratio);
						}
					}
				}
				break;

				// Internal subroutine for autocorrelation noise id
				// Note:  This subroutine is called after NOISEID
				// and therefore superceeds the NOISEID alpha value
				case IDC_SIGMA_ACFNOISEID:
				{
					// Set dmax for lag 1 ACF noise ID (Allan=2, Hadamard=3)
					nDmax=2;
					if( (nSigmaType==HADAMARD_SIGMA ||
						 nSigmaType==OVERLAPHAD_SIGMA ||
						 nSigmaType==HADTOTAL_SIGMA) )
					{
						nDmax=3;
					}

					// Call ACF noise ID function
					// Has additional 2nd arg
					ACFNoiseID(fData, bDataType, nAvgFactor, &fR1, &fAlpha,
						&nACFAlpha,	nDmax, 0);

					// Display r1
					_snprintf(szBuffer, sizeof(szBuffer), "%+1.3f", fR1);
					SetWindowText(GETHCTL(IDC_SIGMA_R1), szBuffer);

					// Show estimated alpha as decimal value
					_snprintf(szBuffer, sizeof(szBuffer), "%+1.2f", fAlpha);
					SetWindowText(GETHCTL(IDC_SIGMA_A), szBuffer);

					// Simple log message
					#ifdef LOGGING
					_snprintf(szBuffer, sizeof(szBuffer),
						"Called ACFNoiseID()");
					WriteLog(60, szBuffer);
					_snprintf(szBuffer, sizeof(szBuffer), "Alpha=%+1.2f",
						fAlpha);
					WriteLog(60, szBuffer);
					#endif

					// Trap alpha < -2 if not a Hadamard variance
					if( !(nSigmaType==HADAMARD_SIGMA ||
						 nSigmaType==OVERLAPHAD_SIGMA ||
						 nSigmaType==HADTOTAL_SIGMA) && (nACFAlpha<-2) )
					{
						// Show warning message if detailed dislog box
						if(bSigmaDetails && bACFNoiseID)
						{
							MessageBox(hDlg, "Warning: Alpha<-2 detected.\n"
							"Use of a Hadamard variance recommended.\n"
							"Alpha set to -2.", "Sigma", MB_ICONEXCLAMATION);
						}
						
						// Force alpha to -2
						nACFAlpha=-2;
					}

					// Trap alpha > 2
					if(nACFAlpha>2)
					{
						nACFAlpha=2;
					}
				}
				break;

				// Internal subroutine to check for zero normal sigma
				case IDC_SIGMA_CHECK:
				{
					// Is normal sigma zero?
					if(fNormalSigma==0.0)
					{
						// Display error message
						LoadString(hInst, IDS_MESSAGE_ZEROSIGMA,
							szBuffer, BUFFER_SIZE);
						MessageBox(hDlg, szBuffer, szBoxTitle,
							MB_ICONEXCLAMATION);

						// Close function
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDCANCEL, NULL, 0));
						break;
					}
				}
				break;

				// Respond to copy button
				case IDC_SIGMA_COPY:
				{
					// Allocate clipboard memory
					nClip=(10+sNormSigData.points)*80;
					hClipboard=GlobalAlloc(GMEM_DDESHARE,
						(DWORD)nClip);
					szClipboard=GlobalLock(hClipboard);

					// Items that apply to all variance types:
					// Heading
					LoadString(hInst, IDS_FORMAT_26, szFormat, BUFFER_SIZE);
					_snprintf(szBuffer, sizeof(szBuffer), szFormat,
						szFileTitle);
					strlcpy(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);

					// Variance type
					strlcat(szClipboard, " Variance Type: ",
						nClip);
					GetWindowText(GETHCTL(IDC_SIGMA_TYPE), szBuffer,
						BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);

					// Avg factor
					_snprintf(szBuffer, sizeof(szBuffer), " Avg Factor=%d",
						nAvgFactor);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);

					// Tau
					if(nSigmaType!=THEO1_SIGMA)
					{
						_snprintf(szBuffer, sizeof(szBuffer), " Tau=%e",
							fTau*nAvgFactor);
					}
					else // Tho1
					{
						_snprintf(szBuffer, sizeof(szBuffer), " Tau=%e",
							fTau*nAvgFactor*0.75);
					}
					ShortenExp(szBuffer);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);

					// Items that vary with variance type:

					if(nSigmaType!=THEO1_SIGMA)
					{
						// Sigma
						_snprintf(szBuffer, sizeof(szBuffer), " Sigma=%e",
							fSigma);
						ShortenExp(szBuffer);
						strlcat(szClipboard, szBuffer, nClip);
						strlcat(szClipboard, "\r\n", nClip);
					}

					// # points
					if(nSigmaType!=THEO1_SIGMA)
					{
						GetWindowText(GETHCTL(IDC_SIGMA_NUM), szBuffer,
							BUFFER_SIZE);
						if(i=atoi(szBuffer))
						{
							_snprintf(szBuffer, sizeof(szBuffer),
								" # Analysis Points=%d", i);
							strlcat(szClipboard, szBuffer, nClip);
							strlcat(szClipboard, "\r\n", nClip);
						}
					}
					else // Tho1
					{
						GetWindowText(GETHCTL(IDC_SIGMA_NUM), szBuffer,
							BUFFER_SIZE);
						if(fTemp=atof(szBuffer))
						{
							_snprintf(szBuffer, sizeof(szBuffer),
								" # Analysis Points=%e", fTemp);
							ShortenExp(szBuffer);
							strlcat(szClipboard, szBuffer,
								nClip);
							strlcat(szClipboard, "\r\n", nClip);
						}
					}

					// Specific sigmas
					switch(nSigmaType)
					{
						case NORMAL_SIGMA:
						case OVERLAPPING_SIGMA:
						{
							// Std dev
							_snprintf(szBuffer, sizeof(szBuffer),
								" Std Dev=%e", fStdDev);
							ShortenExp(szBuffer);
							strlcat(szClipboard, szBuffer,
								nClip);
							strlcat(szClipboard, "\r\n", nClip);

							// Variance label
							strlcpy(szTemp, "ADEV", sizeof(szTemp));
						}
						break;

						case MODIFIED_SIGMA:
						{
							// Mod sigma
							_snprintf(szBuffer, sizeof(szBuffer),
								" Mod Sigma=%e", fModSigma);
							ShortenExp(szBuffer);
							strlcat(szClipboard, szBuffer,
								nClip);
							strlcat(szClipboard, "\r\n", nClip);

							// Variance label
							strlcpy(szTemp, "MDEV", sizeof(szTemp));
						}
						break;

						case HADAMARD_SIGMA:
						{
							// Hadamard dev
							_snprintf(szBuffer, sizeof(szBuffer),
								" Hadamard Dev=%e",
								fHadamardSigma);
							ShortenExp(szBuffer);
							strlcat(szClipboard, szBuffer, nClip);
							strlcat(szClipboard, "\r\n", nClip);
						}
						break;

						case OVERLAPHAD_SIGMA:
						{
							// Overlapping Hadamard dev
							_snprintf(szBuffer, sizeof(szBuffer),
								" Hadamard Dev=%e",
								fHadamardSigma);
							ShortenExp(szBuffer);
							strlcat(szClipboard, szBuffer, nClip);
							strlcat(szClipboard, "\r\n", nClip);
						}
						break;

						case TOTAL_SIGMA:
						{
							// Total dev
							_snprintf(szBuffer, sizeof(szBuffer),
								" Total Dev=%e", fTotalSigma);
							ShortenExp(szBuffer);
							strlcat(szClipboard, szBuffer, nClip);
							strlcat(szClipboard, "\r\n", nClip);

							// Variance label
							strlcpy(szTemp, "TOTDEV", sizeof(szTemp));
						}
						break;

						case MODTOTAL_SIGMA: 
						{
							// Total dev
							_snprintf(szBuffer, sizeof(szBuffer),
								" ModTotdev=%e", fModTotalSigma);
							ShortenExp(szBuffer);
							strlcat(szClipboard, szBuffer, nClip);
							strlcat(szClipboard, "\r\n", nClip);

							// Variance label
							strlcpy(szTemp, "Mod Totdev", sizeof(szTemp));
						}
						break;

						case TIME_SIGMA:
						{
							// Time sigma
							_snprintf(szBuffer, sizeof(szBuffer),
								" Time Sigma=%e", fTimeSigma);
							ShortenExp(szBuffer);
							strlcat(szClipboard, szBuffer, nClip);
							strlcat(szClipboard, "\r\n", nClip);

							// Variance label
							strlcpy(szTemp, "TDEV", sizeof(szTemp));
						}
						break;

						case TIERMS_SIGMA:
						{
							// TIErms
							_snprintf(szBuffer, sizeof(szBuffer),
								" TIErms=%e", fTIErms);
							ShortenExp(szBuffer);
							strlcat(szClipboard, szBuffer, nClip);
							strlcat(szClipboard, "\r\n", nClip);
						}
						break;

						case MTIE_SIGMA:
						{
							// MTIE
							_snprintf(szBuffer, sizeof(szBuffer),
								" MTIE=%e", fMTIE);
							ShortenExp(szBuffer);
							strlcat(szClipboard, szBuffer, nClip);
							strlcat(szClipboard, "\r\n", nClip);
						}
						break;

						case THEO1_SIGMA:
						{
							// Tho1 dev
							_snprintf(szBuffer, sizeof(szBuffer),
								" Tho1 Dev=%e",
								fTheo1Sigma);
							ShortenExp(szBuffer);
							strlcat(szClipboard, szBuffer, nClip);
							strlcat(szClipboard, "\r\n", nClip);

							// Variance label
							strlcpy(szTemp, "Tho1", sizeof(szTemp));
						}
						break;
					}

					// BW factor
					GetWindowText(GETHCTL(IDC_SIGMA_BWFACTOR), szBuffer,
						BUFFER_SIZE);
					if(atof(szBuffer))
					{
						_snprintf(szBuffer, sizeof(szBuffer),
							" BW Factor=%f", fBW);
						strlcat(szClipboard, szBuffer, nClip);
						strlcat(szClipboard, "\r\n", nClip);
					}

					// DF
					GetWindowText(GETHCTL(IDC_SIGMA_DF), szBuffer,
						BUFFER_SIZE);
					if(atof(szBuffer))
					{
						_snprintf(szBuffer, sizeof(szBuffer),
							" Chi Square DF=%f", fDF);
						strlcat(szClipboard, szBuffer, nClip);
						strlcat(szClipboard, "\r\n", nClip);
					}

					// CF
					if(nSigmaType==OVERLAPPING_SIGMA ||
					   nSigmaType==MODIFIED_SIGMA    ||
					   nSigmaType==TIME_SIGMA        ||
					   nSigmaType==TOTAL_SIGMA         )
					{
						// CF type
						if(bCIType)
						{
							strlcpy(szBuffer, " CI Type=Double",
								sizeof(szBuffer));
						}
						else
						{
							strlcpy(szBuffer, " CI Type=Single",
								sizeof(szBuffer));
						}
						strlcat(szClipboard, szBuffer, nClip);
						strlcat(szClipboard, "\r\n", nClip);
						
						// CF value
						_snprintf(szBuffer, sizeof(szBuffer),
							" Confidence Factor=%f", fCF);
						strlcat(szClipboard, szBuffer, nClip);
						strlcat(szClipboard, "\r\n", nClip);
					}

					// Max Sig
					GetWindowText(GETHCTL(IDC_SIGMA_MAX), szBuffer,
						BUFFER_SIZE);
					if(fTemp=atof(szBuffer))
					{
						strlcpy(szBuffer, " Max ", sizeof(szBuffer));
						strlcat(szBuffer, szTemp, sizeof(szBuffer));
						strlcat(szClipboard, szBuffer, nClip);
						_snprintf(szBuffer, sizeof(szBuffer), "=%e", fTemp);
						ShortenExp(szBuffer);
						strlcat(szClipboard, szBuffer, nClip);
						strlcat(szClipboard, "\r\n", nClip);
					}

					// Min Sig
					GetWindowText(GETHCTL(IDC_SIGMA_MIN), szBuffer,
						BUFFER_SIZE);
					if(fTemp=atof(szBuffer))
					{
						strlcpy(szBuffer, " Min ", sizeof(szBuffer));
						strlcat(szBuffer, szTemp, sizeof(szBuffer));
						strlcat(szClipboard, szBuffer, nClip);
						_snprintf(szBuffer, sizeof(szBuffer), "=%e", fTemp);
						ShortenExp(szBuffer);
						strlcat(szClipboard, szBuffer, nClip);
						strlcat(szClipboard, "\r\n", nClip);
					}

					// B1 or Rn
					GetWindowText(GETHCTL(IDC_SIGMA_B1RN), szBuffer,
						BUFFER_SIZE);
					if(atof(szBuffer))
					{
						if(nSigmaType==MODIFIED_SIGMA ||
						   nSigmaType==TIME_SIGMA)
						{
							_snprintf(szBuffer, sizeof(szBuffer),
								" Rn Ratio=%f", fRnRatio);
						}
						else if(nSigmaType==THEO1_SIGMA)
						{
							GetWindowText(GETHCTL(IDC_SIGMA_B1RN), szBuffer,
								BUFFER_SIZE);
							fTemp=atof(szBuffer);
							_snprintf(szBuffer, sizeof(szBuffer),
								" Bias Factor=%f", fTemp);
						}
						else
						{
							_snprintf(szBuffer, sizeof(szBuffer),
								" B1 Ratio=%f", fB1Ratio);
						}

						strlcat(szClipboard, szBuffer, nClip);
						strlcat(szClipboard, "\r\n", nClip);
					}

					// Noise type
					if(bSetNoise)
					{
						GetWindowText(GETHCTL(IDC_SIGMA_NOISES), szBuffer,
							BUFFER_SIZE);
					}
					else // Automatic noise ID
					{
						GetWindowText(GETHCTL(IDC_SIGMA_NOISE), szBuffer,
							BUFFER_SIZE);
					}

					if(strlen(szBuffer))
					{
						strlcat(szClipboard, " Noise Type: ",
							nClip);
						strlcat(szClipboard, szBuffer, nClip);
						strlcat(szClipboard, "\r\n", nClip);
					}

					// Alpha
					GetWindowText(GETHCTL(IDC_SIGMA_ALPHA), szBuffer,
						BUFFER_SIZE);
					if(strlen(szBuffer))
					{
						i=atoi(szBuffer);
						_snprintf(szBuffer, sizeof(szBuffer), " Alpha=%d", i);
						strlcat(szClipboard, szBuffer, nClip);
						strlcat(szClipboard, "\r\n", nClip);
					}

					// Mu
					GetWindowText(GETHCTL(IDC_SIGMA_MU), szBuffer,
						BUFFER_SIZE);
					if(i=atoi(szBuffer))
					{
						_snprintf(szBuffer, sizeof(szBuffer), " Mu=%d", i);
						strlcat(szClipboard, szBuffer, nClip);
						strlcat(szClipboard, "\r\n", nClip);
					}

					// Deadtime ratio r=T/tau
					GetWindowText(GETHCTL(IDC_SIGMA_DEADTIME), szBuffer,
						BUFFER_SIZE);
					if(atof(szBuffer)>1.0)
					{
						_snprintf(szBuffer, sizeof(szBuffer),
							" T/Tau=%f\r\n", fDeadtime);
						strlcat(szClipboard, szBuffer, nClip);
						_snprintf(szBuffer, sizeof(szBuffer),
							" B2=%f\r\n", fB2Ratio);
						strlcat(szClipboard, szBuffer, nClip);
						_snprintf(szBuffer, sizeof(szBuffer),
							" B3=%f\r\n", fB3Ratio);
						strlcat(szClipboard, szBuffer, nClip);
					}

					// Write info to clipboard
					GlobalUnlock(hClipboard);
						OpenClipboard(NULL);
						EmptyClipboard();
						SetClipboardData(CF_TEXT, hClipboard);
						CloseClipboard();
				}
				break;

				// Respond to esc key or close button
				case IDCANCEL:
				{
					// Set abort flag if we are yielding
					bAbort=bYield;

					if(!bAbort)
					{
						// Free working memory
						free(fSigmaData);

						// Set global sigma type to local value
						nGlobalSigmaType=nSigmaType;

						// Close dialog box
						EndDialog(hDlg, 0);
					}
					else
					{
						// Display abort message instead of result
						SetWindowText(GETHCTL(IDC_SIGMA_VALUE),
							"Calc Aborted");
						UpdateWindow(GETHCTL(IDC_SIGMA_VALUE));
					}
				}
				return TRUE;
			}
		}
		break;
	 }
	 return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*                   SigmaControls() Function                                */
/*                                                                           */
/*  Function to label, show or hide controls in detailed sigma dialog box    */
/*                                                                           */
/*  Revision record:                                                         */
/*      12/18/96        Changed CI display logic; added CI to TOTALDEV       */
/*      04/06/97        Added BOOL bSetNoise parameter                       */
/*		03/14/99		Added overlapping Hadamard deviation                 */
/*		12/24/99		Added Mod Totdev                                     */
/*		05/06/00		Added Time Totdev                                    */
/*		11/02/00		Added Hadamard Totdev                                */
/*		02/08/03		Added Tho1                                          */
/*		09/24/03		Added BOOL bApply parameter                          */		
/*                                                                           */
/*****************************************************************************/

void CALLBACK SigmaControls(HWND hDlg, int nSigmaType,
    BOOL bSigmaDetails, BOOL bSetEnable, BOOL bSetNoise, BOOL bApply)
{
    // Local variables
    RECT rect;
	char szBuffer[BUFFER_SIZE+1];   // Text buffer

	switch(nSigmaType)
	{
		case NORMAL_SIGMA:
		{
			// Label Value box
			SetWindowText(GETHCTL(IDC_SIGMA_LABEL), "Sigma:");

			// Mark BW Factor as N/A
			LoadString(hInst, IDS_MESSAGE_NA, szBuffer, BUFFER_SIZE);
			SetWindowText(GETHCTL(IDC_SIGMA_BWFACTOR), szBuffer);

            // Label Ratio box
			SetWindowText(GETHCTL(IDC_SIGMA_RATIO), "B1 Ratio:");

			// Enable set noise checkbox
			Button_SetCheck(GETHCTL(IDC_SIGMA_SETNOISE), bSetNoise);
			EnableWindow(GETHCTL(IDC_SIGMA_SETNOISE), TRUE);

			if(!bSetNoise)
			{
				// Enable apply checkbox
				Button_SetCheck(GETHCTL(IDC_SIGMA_ACFID), bApply);
				EnableWindow(GETHCTL(IDC_SIGMA_ACFID), TRUE);
			}

			#ifdef NEWEDF // New code 07/16/03
			// Show the Single, Double and Conf Factor controls
			ShowWindow(GETHCTL(IDC_SIGMA_SINGLE), SW_SHOWNORMAL);
			ShowWindow(GETHCTL(IDC_SIGMA_DOUBLE), SW_SHOWNORMAL);
			ShowWindow(GETHCTL(IDC_SIGMA_CF), SW_SHOWNORMAL);

			// Hide the CI control
			ShowWindow(GETHCTL(IDC_SIGMA_CI), SW_HIDE);

			// Enable the Single, Double and Conf Factor controls
			if(bSetEnable)
			{
				EnableWindow(GETHCTL(IDC_SIGMA_SINGLE), TRUE);
				EnableWindow(GETHCTL(IDC_SIGMA_DOUBLE), TRUE);
                EnableWindow(GETHCTL(IDC_SIGMA_CF), TRUE);
            }

			#else
			// Hide the Single, Double, Conf Factor $ CI controls
			ShowWindow(GETHCTL(IDC_SIGMA_SINGLE), SW_HIDE);
			ShowWindow(GETHCTL(IDC_SIGMA_DOUBLE), SW_HIDE);
			ShowWindow(GETHCTL(IDC_SIGMA_CF), SW_HIDE);
			ShowWindow(GETHCTL(IDC_SIGMA_CI), SW_HIDE);

			// Disable the Single, Double and Conf Factor controls
			if(bSetEnable)
			{
				EnableWindow(GETHCTL(IDC_SIGMA_SINGLE), FALSE);
				EnableWindow(GETHCTL(IDC_SIGMA_DOUBLE), FALSE);
				EnableWindow(GETHCTL(IDC_SIGMA_CF), FALSE);
			}
			#endif

			if(bSigmaDetails)
			{
				// Label Max box
				SetWindowText(GETHCTL(IDC_SIGMA_MAXLABEL), "Max ADEV:");

				// Label Min box
				SetWindowText(GETHCTL(IDC_SIGMA_MINLABEL), "Min ADEV:");

				// Relabel Value box
				SetWindowText(GETHCTL(IDC_SIGMA_LABEL), "Std Dev:");

				#ifdef NEWEDF // New code 07/16/03
                // Show the CI window - move mask off screen
				MoveWindow(GETHCTL(IDC_SIGMA_NOCONF), 0, 0, 0, 0, 1);

                // Show most of the Noise window - move mask mostly off screen
                // Just block the Kn label and box
                SetRect(&rect, 260, 146, 260+55, 146+18);
                MapDialogRect(hDlg, &rect);
				MoveWindow(GETHCTL(IDC_SIGMA_NONOISE), (rect.left), (rect.top),
					(rect.right-rect.left), (rect.bottom-rect.top), 1);
				
				
				// Trial code 09/19/06 - Allows apply checkbox to work
				MoveWindow(GETHCTL(IDC_SIGMA_NONOISE), 0, 0, 0, 0, 1);


				#else
				// Hide some of the CI window - move mask on screen
				// Max and Min Sigma still show
				SetRect(&rect, 139, 31, 139+118, 31+66);
				MapDialogRect(hDlg, &rect);
				MoveWindow(GETHCTL(IDC_SIGMA_NOCONF), (rect.left), (rect.top),
					(rect.right-rect.left), (rect.bottom-rect.top), 1);

				// Show the Noise window - move mask off screen
				MoveWindow(GETHCTL(IDC_SIGMA_NONOISE), 0, 0, 0, 0, 1);
				#endif

				// Enable deadtime ratio, B2 & B3 if noise manually set
				if(bSetNoise)
				{
					EnableWindow(GETHCTL(IDC_SIGMA_DEADTIME), TRUE);
					EnableWindow(GETHCTL(IDC_SIGMA_B2), TRUE);
					EnableWindow(GETHCTL(IDC_SIGMA_B3), TRUE);
				}
				else
				{
					EnableWindow(GETHCTL(IDC_SIGMA_DEADTIME), FALSE);
					EnableWindow(GETHCTL(IDC_SIGMA_B2), FALSE);
					EnableWindow(GETHCTL(IDC_SIGMA_B3), FALSE);
				}
			}
		}
		break;

		case OVERLAPPING_SIGMA:
		{
			// Label Value box
			SetWindowText(GETHCTL(IDC_SIGMA_LABEL), "Sigma:");

			// Mark BW Factor as N/A
			LoadString(hInst, IDS_MESSAGE_NA, szBuffer, BUFFER_SIZE);
			SetWindowText(GETHCTL(IDC_SIGMA_BWFACTOR), szBuffer);

			// Label Ratio box
			SetWindowText(GETHCTL(IDC_SIGMA_RATIO), "B1 Ratio:");

			// Enable set noise checkbox
			Button_SetCheck(GETHCTL(IDC_SIGMA_SETNOISE), bSetNoise);
			EnableWindow(GETHCTL(IDC_SIGMA_SETNOISE), TRUE);

			if(!bSetNoise)
			{
				// Enable apply checkbox
				Button_SetCheck(GETHCTL(IDC_SIGMA_ACFID), bApply);
				EnableWindow(GETHCTL(IDC_SIGMA_ACFID), TRUE);
			}

			// Show the Single, Double and Conf Factor controls
			ShowWindow(GETHCTL(IDC_SIGMA_SINGLE), SW_SHOWNORMAL);
			ShowWindow(GETHCTL(IDC_SIGMA_DOUBLE), SW_SHOWNORMAL);
			ShowWindow(GETHCTL(IDC_SIGMA_CF), SW_SHOWNORMAL);

			// Hide the CI control
			ShowWindow(GETHCTL(IDC_SIGMA_CI), SW_HIDE);

			// Enable the Single, Double and Conf Factor controls
			if(bSetEnable)
			{
				EnableWindow(GETHCTL(IDC_SIGMA_SINGLE), TRUE);
				EnableWindow(GETHCTL(IDC_SIGMA_DOUBLE), TRUE);
                EnableWindow(GETHCTL(IDC_SIGMA_CF), TRUE);
            }

            if(bSigmaDetails)
            {
                // Label Max box
				SetWindowText(GETHCTL(IDC_SIGMA_MAXLABEL), "Max ADEV:");

                // Label Min box
				SetWindowText(GETHCTL(IDC_SIGMA_MINLABEL), "Min ADEV:");

                // Relabel Value box
				SetWindowText(GETHCTL(IDC_SIGMA_LABEL), "Std Dev:");

                // Show the CI window - move mask off screen
				MoveWindow(GETHCTL(IDC_SIGMA_NOCONF), 0, 0, 0, 0, 1);

                // Show most of the Noise window - move mask mostly off screen
                // Just block the Kn label and box
                SetRect(&rect, 260, 146, 260+55, 146+18);
                MapDialogRect(hDlg, &rect);
				MoveWindow(GETHCTL(IDC_SIGMA_NONOISE), (rect.left), (rect.top),
					(rect.right-rect.left), (rect.bottom-rect.top), 1);

				// Trial code 09/19/06 - Allows apply checkbox to work
				MoveWindow(GETHCTL(IDC_SIGMA_NONOISE), 0, 0, 0, 0, 1);

				// Enable deadtime ratio, B2 & B3 if noise manually set
				if(bSetNoise)
				{
					EnableWindow(GETHCTL(IDC_SIGMA_DEADTIME), TRUE);
					EnableWindow(GETHCTL(IDC_SIGMA_B2), TRUE);
					EnableWindow(GETHCTL(IDC_SIGMA_B3), TRUE);
				}
				else
				{
					EnableWindow(GETHCTL(IDC_SIGMA_DEADTIME), FALSE);
					EnableWindow(GETHCTL(IDC_SIGMA_B2), FALSE);
					EnableWindow(GETHCTL(IDC_SIGMA_B3), FALSE);
				}
           }
        }
        break;

        case MODIFIED_SIGMA:
        {
            // Label Value box
			SetWindowText(GETHCTL(IDC_SIGMA_LABEL), "Mod Sigma:");

           // Label Ratio box
			SetWindowText(GETHCTL(IDC_SIGMA_RATIO), "B1 Ratio:");

			// Enable set noise checkbox
			Button_SetCheck(GETHCTL(IDC_SIGMA_SETNOISE), bSetNoise);
			EnableWindow(GETHCTL(IDC_SIGMA_SETNOISE), TRUE);

			if(!bSetNoise)
			{
				// Enable apply checkbox
				Button_SetCheck(GETHCTL(IDC_SIGMA_ACFID), bApply);
				EnableWindow(GETHCTL(IDC_SIGMA_ACFID), TRUE);
			}

            // Show the Single, Double and Conf Factor controls
			ShowWindow(GETHCTL(IDC_SIGMA_SINGLE), SW_SHOWNORMAL);
			ShowWindow(GETHCTL(IDC_SIGMA_DOUBLE), SW_SHOWNORMAL);
			ShowWindow(GETHCTL(IDC_SIGMA_CF), SW_SHOWNORMAL);

			// Hide the CI control
			ShowWindow(GETHCTL(IDC_SIGMA_CI), SW_HIDE);

            // Enable the Single, Double and Conf Factor controls
            if(bSetEnable)
            {
				EnableWindow(GETHCTL(IDC_SIGMA_SINGLE), TRUE);
				EnableWindow(GETHCTL(IDC_SIGMA_DOUBLE), TRUE);
				EnableWindow(GETHCTL(IDC_SIGMA_CF), TRUE);
			}

            if(bSigmaDetails)
            {
                // Label Max box
				SetWindowText(GETHCTL(IDC_SIGMA_MAXLABEL), "Max MDEV:");

                // Label Min box
				SetWindowText(GETHCTL(IDC_SIGMA_MINLABEL), "Min MDEV:");

                // Show the CI window - move mask off screen
				MoveWindow(GETHCTL(IDC_SIGMA_NOCONF), 0, 0, 0, 0, 1);

                SetRect(&rect, 260, 146, 260+55, 146+18);
                MapDialogRect(hDlg, &rect);
				MoveWindow(GETHCTL(IDC_SIGMA_NONOISE), (rect.left), (rect.top),
					(rect.right-rect.left), (rect.bottom-rect.top), 1);

				// Trial code 09/19/06 - Allows apply checkbox to work
				MoveWindow(GETHCTL(IDC_SIGMA_NONOISE), 0, 0, 0, 0, 1);

				// Disable deadtime, B2 & B3
				EnableWindow(GETHCTL(IDC_SIGMA_DEADTIME), FALSE);
				EnableWindow(GETHCTL(IDC_SIGMA_B2), FALSE);
				EnableWindow(GETHCTL(IDC_SIGMA_B3), FALSE);
            }
        }
        break;

        case TIME_SIGMA:
        {
            // Label Value box
            SetWindowText(GETHCTL(IDC_SIGMA_LABEL), "Time Sigma:");

            // Label Ratio box
			SetWindowText(GETHCTL(IDC_SIGMA_RATIO), "B1 Ratio:");

			// Enable set noise checkbox
			Button_SetCheck(GETHCTL(IDC_SIGMA_SETNOISE), bSetNoise);
			EnableWindow(GETHCTL(IDC_SIGMA_SETNOISE), TRUE);

			if(!bSetNoise)
			{
				// Enable apply checkbox
				Button_SetCheck(GETHCTL(IDC_SIGMA_ACFID), bApply);
				EnableWindow(GETHCTL(IDC_SIGMA_ACFID), TRUE);
			}

			// Show the Single, Double and Conf Factor controls
			ShowWindow(GETHCTL(IDC_SIGMA_SINGLE), SW_SHOWNORMAL);
			ShowWindow(GETHCTL(IDC_SIGMA_DOUBLE), SW_SHOWNORMAL);
			ShowWindow(GETHCTL(IDC_SIGMA_CF), SW_SHOWNORMAL);

			// Hide the CI control
			ShowWindow(GETHCTL(IDC_SIGMA_CI), SW_HIDE);

            // Enable the Single, Double and Conf Factor controls
            if(bSetEnable)
            {
				EnableWindow(GETHCTL(IDC_SIGMA_SINGLE), TRUE);
				EnableWindow(GETHCTL(IDC_SIGMA_DOUBLE), TRUE);
				EnableWindow(GETHCTL(IDC_SIGMA_CF), TRUE);
			}

			if(bSigmaDetails)
			{
				// Label Max box
				SetWindowText(GETHCTL(IDC_SIGMA_MAXLABEL), "Max TDEV:");

				// Label Min box
				SetWindowText(GETHCTL(IDC_SIGMA_MINLABEL), "Min  TDEV:");

				// Show the CI window - move mask off screen
				MoveWindow(GETHCTL(IDC_SIGMA_NOCONF), 0, 0, 0, 0, 1);

				// Show most of the Noise window - move mask mostly off screen
				// Just block the Kn label and box
				SetRect(&rect, 260, 146, 260+55, 146+18);
				MapDialogRect(hDlg, &rect);
				MoveWindow(GETHCTL(IDC_SIGMA_NONOISE), (rect.left), (rect.top),
					(rect.right-rect.left), (rect.bottom-rect.top), 1);

				// Trial code 09/19/06 - Allows apply checkbox to work
				MoveWindow(GETHCTL(IDC_SIGMA_NONOISE), 0, 0, 0, 0, 1);

				// Disable deadtime, B2 & B3
				EnableWindow(GETHCTL(IDC_SIGMA_DEADTIME), FALSE);
				EnableWindow(GETHCTL(IDC_SIGMA_B2), FALSE);
				EnableWindow(GETHCTL(IDC_SIGMA_B3), FALSE);
			}
		}
		break;

		case TOTAL_SIGMA:
		{
			// Label Value box
			SetWindowText(GETHCTL(IDC_SIGMA_LABEL), "Total Sigma:");

			// Enable set noise checkbox
			Button_SetCheck(GETHCTL(IDC_SIGMA_SETNOISE), bSetNoise);
			EnableWindow(GETHCTL(IDC_SIGMA_SETNOISE), TRUE);

			if(!bSetNoise)
			{
				// Enable apply checkbox
				Button_SetCheck(GETHCTL(IDC_SIGMA_ACFID), bApply);
				EnableWindow(GETHCTL(IDC_SIGMA_ACFID), TRUE);
			}

			// Mark BW Factor as N/A
			LoadString(hInst, IDS_MESSAGE_NA, szBuffer, BUFFER_SIZE);
			SetWindowText(GETHCTL(IDC_SIGMA_BWFACTOR), szBuffer);

			// Label Ratio box
			if(bSetNoise)
			{
				SetWindowText(GETHCTL(IDC_SIGMA_RATIO), "B(Total):");
			}
			else
			{
				SetWindowText(GETHCTL(IDC_SIGMA_RATIO), "B1 Ratio:");
			}

			// Show the Single, Double and Conf Factor controls
			ShowWindow(GETHCTL(IDC_SIGMA_SINGLE), SW_SHOWNORMAL);
			ShowWindow(GETHCTL(IDC_SIGMA_DOUBLE), SW_SHOWNORMAL);
			ShowWindow(GETHCTL(IDC_SIGMA_CF), SW_SHOWNORMAL);

			// Hide the CI control
			// No longer used to display "(Data Endpoints Matched)"
			ShowWindow(GETHCTL(IDC_SIGMA_CI), SW_HIDE);
 
			// Enable the Single, Double and Conf Factor controls
			if(bSetEnable)
			{
				EnableWindow(GETHCTL(IDC_SIGMA_SINGLE), TRUE);
				EnableWindow(GETHCTL(IDC_SIGMA_DOUBLE), TRUE);
				EnableWindow(GETHCTL(IDC_SIGMA_CF), TRUE);
			}

			if(bSigmaDetails)
			{
				// Label Max box
				SetWindowText(GETHCTL(IDC_SIGMA_MAXLABEL), "Max TOT:");

				// Label Min box
				SetWindowText(GETHCTL(IDC_SIGMA_MINLABEL), "Min TOT:");

				// Relabel Value box
				SetWindowText(GETHCTL(IDC_SIGMA_LABEL), "Total Sigma:");

				// Show the CI window - move mask off screen
				MoveWindow(GETHCTL(IDC_SIGMA_NOCONF), 0, 0, 0, 0, 1);

				// Show most of the Noise window - move mask mostly off screen
				// Just block the Kn label and box
				SetRect(&rect, 260, 146, 260+55, 146+18);
				MapDialogRect(hDlg, &rect);
				MoveWindow(GETHCTL(IDC_SIGMA_NONOISE), (rect.left), (rect.top),
					(rect.right-rect.left), (rect.bottom-rect.top), 1);

				// Trial code 09/19/06 - Allows apply checkbox to work
				MoveWindow(GETHCTL(IDC_SIGMA_NONOISE), 0, 0, 0, 0, 1);

				// Disable deadtime, B2 & B3
				EnableWindow(GETHCTL(IDC_SIGMA_DEADTIME), FALSE);
				EnableWindow(GETHCTL(IDC_SIGMA_B2), FALSE);
				EnableWindow(GETHCTL(IDC_SIGMA_B3), FALSE);
			}
		}
		break;

		case MODTOTAL_SIGMA:
		{
			// Label Value box
			SetWindowText(GETHCTL(IDC_SIGMA_LABEL), "Mod Totdev:");

			// Enable set noise checkbox
			Button_SetCheck(GETHCTL(IDC_SIGMA_SETNOISE), bSetNoise);
			EnableWindow(GETHCTL(IDC_SIGMA_SETNOISE), TRUE);

			if(!bSetNoise)
			{
				// Enable apply checkbox
				Button_SetCheck(GETHCTL(IDC_SIGMA_ACFID), bApply);
				EnableWindow(GETHCTL(IDC_SIGMA_ACFID), TRUE);
			}

			// Mark BW Factor as N/A
			LoadString(hInst, IDS_MESSAGE_NA, szBuffer, BUFFER_SIZE);
			SetWindowText(GETHCTL(IDC_SIGMA_BWFACTOR), szBuffer);

			// Label Ratio box
			if(bSetNoise)
			{
				SetWindowText(GETHCTL(IDC_SIGMA_RATIO), "B(MTOT):");
			}
			else
			{
				SetWindowText(GETHCTL(IDC_SIGMA_RATIO), "B1 Ratio:");
			}

			// Show the Single, Double and Conf Factor controls
			ShowWindow(GETHCTL(IDC_SIGMA_SINGLE), SW_SHOWNORMAL);
			ShowWindow(GETHCTL(IDC_SIGMA_DOUBLE), SW_SHOWNORMAL);
			ShowWindow(GETHCTL(IDC_SIGMA_CF), SW_SHOWNORMAL);

			// Hide the CI control
			// No longer used to display "(Data Endpoints Matched)"
			ShowWindow(GETHCTL(IDC_SIGMA_CI), SW_HIDE);
 
			// Enable the Single, Double and Conf Factor controls
			if(bSetEnable)
			{
				EnableWindow(GETHCTL(IDC_SIGMA_SINGLE), TRUE);
				EnableWindow(GETHCTL(IDC_SIGMA_DOUBLE), TRUE);
				EnableWindow(GETHCTL(IDC_SIGMA_CF), TRUE);
			}

			if(bSigmaDetails)
			{
				// Label Max box
				SetWindowText(GETHCTL(IDC_SIGMA_MAXLABEL), "Max MTOT:");

				// Label Min box
				SetWindowText(GETHCTL(IDC_SIGMA_MINLABEL), "Min MTOT:");

				// Relabel Value box
				SetWindowText(GETHCTL(IDC_SIGMA_LABEL), "Mod Totdev:");

				// Show the CI window - move mask off screen
				MoveWindow(GETHCTL(IDC_SIGMA_NOCONF), 0, 0, 0, 0, 1);

				// Show most of the Noise window - move mask mostly off screen
				// Just block the Kn label and box
				SetRect(&rect, 260, 146, 260+55, 146+18);
				MapDialogRect(hDlg, &rect);
				MoveWindow(GETHCTL(IDC_SIGMA_NONOISE), (rect.left), (rect.top),
					(rect.right-rect.left), (rect.bottom-rect.top), 1);

				// Trial code 09/19/06 - Allows apply checkbox to work
				MoveWindow(GETHCTL(IDC_SIGMA_NONOISE), 0, 0, 0, 0, 1);

				// Disable deadtime, B2 & B3
				EnableWindow(GETHCTL(IDC_SIGMA_DEADTIME), FALSE);
				EnableWindow(GETHCTL(IDC_SIGMA_B2), FALSE);
				EnableWindow(GETHCTL(IDC_SIGMA_B3), FALSE);
			}
		}
		break;

		case HADTOTAL_SIGMA:
		{
			// Label Value box
			SetWindowText(GETHCTL(IDC_SIGMA_LABEL), "Had Totdev:");

			// Enable set noise checkbox
			Button_SetCheck(GETHCTL(IDC_SIGMA_SETNOISE), bSetNoise);
			EnableWindow(GETHCTL(IDC_SIGMA_SETNOISE), TRUE);

			if(!bSetNoise)
			{
				// Enable apply checkbox
				Button_SetCheck(GETHCTL(IDC_SIGMA_ACFID), bApply);
				EnableWindow(GETHCTL(IDC_SIGMA_ACFID), TRUE);
			}

			// Mark BW Factor as N/A
			LoadString(hInst, IDS_MESSAGE_NA, szBuffer, BUFFER_SIZE);
			SetWindowText(GETHCTL(IDC_SIGMA_BWFACTOR), szBuffer);

			// Label Ratio box
			// Note: May want to add *B1 ratio for RR FM noise
			if(bSetNoise)
			{
				SetWindowText(GETHCTL(IDC_SIGMA_RATIO), "B(HTOT):");
			}
			else
			{
				SetWindowText(GETHCTL(IDC_SIGMA_RATIO), "B1 Ratio:");
			}

			// Show the Single, Double and Conf Factor controls
			ShowWindow(GETHCTL(IDC_SIGMA_SINGLE), SW_SHOWNORMAL);
			ShowWindow(GETHCTL(IDC_SIGMA_DOUBLE), SW_SHOWNORMAL);
			ShowWindow(GETHCTL(IDC_SIGMA_CF), SW_SHOWNORMAL);

			// Hide the CI control
			ShowWindow(GETHCTL(IDC_SIGMA_CI), SW_HIDE);
 
			// Enable the Single, Double and Conf Factor controls
			if(bSetEnable)
			{
				EnableWindow(GETHCTL(IDC_SIGMA_SINGLE), TRUE);
				EnableWindow(GETHCTL(IDC_SIGMA_DOUBLE), TRUE);
				EnableWindow(GETHCTL(IDC_SIGMA_CF), TRUE);
			}

			if(bSigmaDetails)
			{
				// Label Max box
				SetWindowText(GETHCTL(IDC_SIGMA_MAXLABEL), "Max HTOT:");

				// Label Min box
				SetWindowText(GETHCTL(IDC_SIGMA_MINLABEL), "Min HTOT:");

				// Relabel Value box
				SetWindowText(GETHCTL(IDC_SIGMA_LABEL), "Had Totdev:");

				// Show the CI window - move mask off screen
				MoveWindow(GETHCTL(IDC_SIGMA_NOCONF), 0, 0, 0, 0, 1);

				// Show most of the Noise window - move mask mostly off screen
				// Just block the Kn label and box
				SetRect(&rect, 260, 146, 260+55, 146+18);
				MapDialogRect(hDlg, &rect);
				MoveWindow(GETHCTL(IDC_SIGMA_NONOISE), (rect.left), (rect.top),
					(rect.right-rect.left), (rect.bottom-rect.top), 1);

				// Trial code 09/19/06 - Allows apply checkbox to work
				MoveWindow(GETHCTL(IDC_SIGMA_NONOISE), 0, 0, 0, 0, 1);

				// Disable deadtime, B2 & B3
				EnableWindow(GETHCTL(IDC_SIGMA_DEADTIME), FALSE);
				EnableWindow(GETHCTL(IDC_SIGMA_B2), FALSE);
				EnableWindow(GETHCTL(IDC_SIGMA_B3), FALSE);
			}
		}
		break;

		case TIMETOTAL_SIGMA:
		{
			// Label Value box
			SetWindowText(GETHCTL(IDC_SIGMA_LABEL), "Time Totdev:");

			// Enable set noise checkbox
			Button_SetCheck(GETHCTL(IDC_SIGMA_SETNOISE), bSetNoise);
			EnableWindow(GETHCTL(IDC_SIGMA_SETNOISE), TRUE);

			if(!bSetNoise)
			{
				// Enable apply checkbox
				Button_SetCheck(GETHCTL(IDC_SIGMA_ACFID), bApply);
				EnableWindow(GETHCTL(IDC_SIGMA_ACFID), TRUE);
			}

			// Mark BW Factor as N/A
			LoadString(hInst, IDS_MESSAGE_NA, szBuffer, BUFFER_SIZE);
			SetWindowText(GETHCTL(IDC_SIGMA_BWFACTOR), szBuffer);

			// Label Ratio box
			if(bSetNoise)
			{
				SetWindowText(GETHCTL(IDC_SIGMA_RATIO), "B(Total):");
			}
			else
			{
				SetWindowText(GETHCTL(IDC_SIGMA_RATIO), "B1 Ratio:");
			}

			// Show the Single, Double and Conf Factor controls
			ShowWindow(GETHCTL(IDC_SIGMA_SINGLE), SW_SHOWNORMAL);
			ShowWindow(GETHCTL(IDC_SIGMA_DOUBLE), SW_SHOWNORMAL);
			ShowWindow(GETHCTL(IDC_SIGMA_CF), SW_SHOWNORMAL);

			// Hide the CI control
			// No longer used to display "(Data Endpoints Matched)"
			ShowWindow(GETHCTL(IDC_SIGMA_CI), SW_HIDE);
 
			// Enable the Single, Double and Conf Factor controls
			if(bSetEnable)
			{
				EnableWindow(GETHCTL(IDC_SIGMA_SINGLE), TRUE);
				EnableWindow(GETHCTL(IDC_SIGMA_DOUBLE), TRUE);
				EnableWindow(GETHCTL(IDC_SIGMA_CF), TRUE);
			}

			if(bSigmaDetails)
			{
				// Label Max box
				SetWindowText(GETHCTL(IDC_SIGMA_MAXLABEL), "Max TTOT:");

				// Label Min box
				SetWindowText(GETHCTL(IDC_SIGMA_MINLABEL), "Min TTOT:");

				// Relabel Value box
				SetWindowText(GETHCTL(IDC_SIGMA_LABEL), "Time Totdev:");

				// Show the CI window - move mask off screen
				MoveWindow(GETHCTL(IDC_SIGMA_NOCONF), 0, 0, 0, 0, 1);

				// Show most of the Noise window - move mask mostly off screen
				// Just block the Kn label and box
				SetRect(&rect, 260, 146, 260+55, 146+18);
				MapDialogRect(hDlg, &rect);
				MoveWindow(GETHCTL(IDC_SIGMA_NONOISE), (rect.left), (rect.top),
					(rect.right-rect.left), (rect.bottom-rect.top), 1);

				// Trial code 09/19/06 - Allows apply checkbox to work
				MoveWindow(GETHCTL(IDC_SIGMA_NONOISE), 0, 0, 0, 0, 1);

				// Disable deadtime, B2 & B3
				EnableWindow(GETHCTL(IDC_SIGMA_DEADTIME), FALSE);
				EnableWindow(GETHCTL(IDC_SIGMA_B2), FALSE);
				EnableWindow(GETHCTL(IDC_SIGMA_B3), FALSE);
			}
		}
		break;

		case HADAMARD_SIGMA:
		{
			// Label Value box
			SetWindowText(GETHCTL(IDC_SIGMA_LABEL), "Hadamard Dev:");

			// Mark BW Factor as N/A
			LoadString(hInst, IDS_MESSAGE_NA, szBuffer, BUFFER_SIZE);
			SetWindowText(GETHCTL(IDC_SIGMA_BWFACTOR), szBuffer);

			// Hide the CI control
			ShowWindow(GETHCTL(IDC_SIGMA_CI), SW_HIDE);

			#ifdef NEWEDF // New code 07/16/03
			// Label Ratio box
			SetWindowText(GETHCTL(IDC_SIGMA_RATIO), "B1 Ratio:");

			// Enable set noise checkbox
			Button_SetCheck(GETHCTL(IDC_SIGMA_SETNOISE), bSetNoise);
			EnableWindow(GETHCTL(IDC_SIGMA_SETNOISE), TRUE);

			if(!bSetNoise)
			{
				// Enable apply checkbox
				Button_SetCheck(GETHCTL(IDC_SIGMA_ACFID), bApply);
				EnableWindow(GETHCTL(IDC_SIGMA_ACFID), TRUE);
			}

			// Show the Single, Double and Conf Factor controls
			ShowWindow(GETHCTL(IDC_SIGMA_SINGLE), SW_SHOWNORMAL);
			ShowWindow(GETHCTL(IDC_SIGMA_DOUBLE), SW_SHOWNORMAL);
			ShowWindow(GETHCTL(IDC_SIGMA_CF), SW_SHOWNORMAL);

			// Enable the Single, Double and Conf Factor controls
			if(bSetEnable)
			{
				EnableWindow(GETHCTL(IDC_SIGMA_SINGLE), TRUE);
				EnableWindow(GETHCTL(IDC_SIGMA_DOUBLE), TRUE);
                EnableWindow(GETHCTL(IDC_SIGMA_CF), TRUE);
            }

			#else
			// Disable set noise checkbox
			EnableWindow(GETHCTL(IDC_SIGMA_SETNOISE), FALSE);

			// Remove Ratio box label
			SetWindowText(GETHCTL(IDC_SIGMA_RATIO), "");

			// Hide the Single, Double and Conf Factor controls
			ShowWindow(GETHCTL(IDC_SIGMA_SINGLE), SW_HIDE);
			ShowWindow(GETHCTL(IDC_SIGMA_DOUBLE), SW_HIDE);
			ShowWindow(GETHCTL(IDC_SIGMA_CF), SW_HIDE);

			// Disable the Single, Double and Conf Factor controls
			if(bSetEnable)
			{
				EnableWindow(GETHCTL(IDC_SIGMA_SINGLE), FALSE);
				EnableWindow(GETHCTL(IDC_SIGMA_DOUBLE), FALSE);
				EnableWindow(GETHCTL(IDC_SIGMA_CF), FALSE);
			}
			#endif

			if(bSigmaDetails)
			{
				#ifdef NEWEDF // New code 07/16/03
                // Label Max box
				SetWindowText(GETHCTL(IDC_SIGMA_MAXLABEL), "Max HDEV:");

                // Label Min box
				SetWindowText(GETHCTL(IDC_SIGMA_MINLABEL), "Min HDEV:");

                // Relabel Value box
				SetWindowText(GETHCTL(IDC_SIGMA_LABEL), "Hadamard Dev:");

                // Show the CI window - move mask off screen
				MoveWindow(GETHCTL(IDC_SIGMA_NOCONF), 0, 0, 0, 0, 1);

                // Show most of the Noise window - move mask mostly off screen
                // Just block the Kn label and box
                SetRect(&rect, 260, 146, 260+55, 146+18);
                MapDialogRect(hDlg, &rect);
				MoveWindow(GETHCTL(IDC_SIGMA_NONOISE), (rect.left), (rect.top),
					(rect.right-rect.left), (rect.bottom-rect.top), 1);

				// Trial code 09/19/06 - Allows apply checkbox to work
				MoveWindow(GETHCTL(IDC_SIGMA_NONOISE), 0, 0, 0, 0, 1);

				#else
				// Hide the CI window - move mask on screen
				SetRect(&rect, 140, 16, 140+116, 16+114);
				MapDialogRect(hDlg, &rect);
				MoveWindow(GETHCTL(IDC_SIGMA_NOCONF), (rect.left),	(rect.top),
					(rect.right-rect.left), (rect.bottom-rect.top), 1);

				// Hide the Noise window - move mask on screen
				SetRect(&rect, 8, 146, 8+308, 146+18);
				MapDialogRect(hDlg, &rect);
				MoveWindow(GETHCTL(IDC_SIGMA_NONOISE), (rect.left), (rect.top),
					(rect.right-rect.left), (rect.bottom-rect.top), 1);
				#endif

				// Disable deadtime, B2 & B3
				EnableWindow(GETHCTL(IDC_SIGMA_DEADTIME), FALSE);
				EnableWindow(GETHCTL(IDC_SIGMA_B2), FALSE);
				EnableWindow(GETHCTL(IDC_SIGMA_B3), FALSE);
			}
		}
		break;

		case OVERLAPHAD_SIGMA:
		{
			// Label Value box
			SetWindowText(GETHCTL(IDC_SIGMA_LABEL), "Hadamard Dev:");

			// Mark BW Factor as N/A
			LoadString(hInst, IDS_MESSAGE_NA, szBuffer, BUFFER_SIZE);
			SetWindowText(GETHCTL(IDC_SIGMA_BWFACTOR), szBuffer);

			// Label Ratio box
			SetWindowText(GETHCTL(IDC_SIGMA_RATIO), "B1 Ratio:");

			// Enable set noise checkbox
			Button_SetCheck(GETHCTL(IDC_SIGMA_SETNOISE), bSetNoise);
			EnableWindow(GETHCTL(IDC_SIGMA_SETNOISE), TRUE);

			if(!bSetNoise)
			{
				// Enable apply checkbox
				Button_SetCheck(GETHCTL(IDC_SIGMA_ACFID), bApply);
				EnableWindow(GETHCTL(IDC_SIGMA_ACFID), TRUE);
			}

			// Show the Single, Double and Conf Factor controls
			ShowWindow(GETHCTL(IDC_SIGMA_SINGLE), SW_SHOWNORMAL);
			ShowWindow(GETHCTL(IDC_SIGMA_DOUBLE), SW_SHOWNORMAL);
			ShowWindow(GETHCTL(IDC_SIGMA_CF), SW_SHOWNORMAL);

			// Hide the CI control
			ShowWindow(GETHCTL(IDC_SIGMA_CI), SW_HIDE);

			// Enable the Single, Double and Conf Factor controls
			if(bSetEnable)
			{
				EnableWindow(GETHCTL(IDC_SIGMA_SINGLE), TRUE);
				EnableWindow(GETHCTL(IDC_SIGMA_DOUBLE), TRUE);
                EnableWindow(GETHCTL(IDC_SIGMA_CF), TRUE);
            }

            if(bSigmaDetails)
            {
                // Label Max box
				SetWindowText(GETHCTL(IDC_SIGMA_MAXLABEL), "Max HDEV:");

                // Label Min box
				SetWindowText(GETHCTL(IDC_SIGMA_MINLABEL), "Min HDEV:");

                // Relabel Value box
				SetWindowText(GETHCTL(IDC_SIGMA_LABEL), "Hadamard Dev:");

                // Show the CI window - move mask off screen
				MoveWindow(GETHCTL(IDC_SIGMA_NOCONF), 0, 0, 0, 0, 1);

                // Show most of the Noise window - move mask mostly off screen
                // Just block the Kn label and box
                SetRect(&rect, 260, 146, 260+55, 146+18);
                MapDialogRect(hDlg, &rect);
				MoveWindow(GETHCTL(IDC_SIGMA_NONOISE), (rect.left), (rect.top),
					(rect.right-rect.left), (rect.bottom-rect.top), 1);

				// Trial code 09/19/06 - Allows apply checkbox to work
				MoveWindow(GETHCTL(IDC_SIGMA_NONOISE), 0, 0, 0, 0, 1);

				// Disable deadtime, B2 & B3
				EnableWindow(GETHCTL(IDC_SIGMA_DEADTIME), FALSE);
				EnableWindow(GETHCTL(IDC_SIGMA_B2), FALSE);
				EnableWindow(GETHCTL(IDC_SIGMA_B3), FALSE);
            }
        }
        break;

		case TIERMS_SIGMA:
		{
			// Label Value box
			SetWindowText(GETHCTL(IDC_SIGMA_LABEL), "TIE rms:");

			// Mark BW Factor as N/A
			LoadString(hInst, IDS_MESSAGE_NA, szBuffer, BUFFER_SIZE);
			SetWindowText(GETHCTL(IDC_SIGMA_BWFACTOR), szBuffer);

			// Remove Ratio box label
			SetWindowText(GETHCTL(IDC_SIGMA_RATIO), "");

			// Hide the Single, Double and Conf Factor controls
			ShowWindow(GETHCTL(IDC_SIGMA_SINGLE), SW_HIDE);
			ShowWindow(GETHCTL(IDC_SIGMA_DOUBLE), SW_HIDE);
			ShowWindow(GETHCTL(IDC_SIGMA_CF), SW_HIDE);

			// Hide the CI control
			ShowWindow(GETHCTL(IDC_SIGMA_CI), SW_HIDE);

			// Disable set noise checkbox
			Button_SetCheck(GETHCTL(IDC_SIGMA_SETNOISE), bSetNoise);
			EnableWindow(GETHCTL(IDC_SIGMA_SETNOISE), FALSE);

			// Disable apply checkbox
			Button_SetCheck(GETHCTL(IDC_SIGMA_ACFID), FALSE);
			EnableWindow(GETHCTL(IDC_SIGMA_ACFID), FALSE);

			// Disable the Single, Double and Conf Factor controls
			if(bSetEnable)
			{
				EnableWindow(GETHCTL(IDC_SIGMA_SINGLE), FALSE);
				EnableWindow(GETHCTL(IDC_SIGMA_DOUBLE), FALSE);
				EnableWindow(GETHCTL(IDC_SIGMA_CF), FALSE);
			}

			if(bSigmaDetails)
			{
				// Hide the CI window - move mask on screen
				SetRect(&rect, 140, 16, 140+116, 16+114);
				MapDialogRect(hDlg, &rect);
				MoveWindow(GETHCTL(IDC_SIGMA_NOCONF), (rect.left),	(rect.top),
					(rect.right-rect.left), (rect.bottom-rect.top), 1);

				// Hide the Noise window - move mask on screen
				// SetRect(&rect, 8, 146, 8+308, 146+18); // Too long
				SetRect(&rect, 8, 146, 8+247, 146+18);
				MapDialogRect(hDlg, &rect);
				MoveWindow(GETHCTL(IDC_SIGMA_NONOISE), (rect.left), (rect.top),
					(rect.right-rect.left), (rect.bottom-rect.top), 1);

				// Disable deadtime, B2 & B3
				EnableWindow(GETHCTL(IDC_SIGMA_DEADTIME), FALSE);
				EnableWindow(GETHCTL(IDC_SIGMA_B2), FALSE);
				EnableWindow(GETHCTL(IDC_SIGMA_B3), FALSE);
			}
		}
		break;

		case MTIE_SIGMA:
		{
			// Label Value box
			SetWindowText(GETHCTL(IDC_SIGMA_LABEL), "MTIE:");

			// Mark BW Factor as N/A
			LoadString(hInst, IDS_MESSAGE_NA, szBuffer, BUFFER_SIZE);
			SetWindowText(GETHCTL(IDC_SIGMA_BWFACTOR), szBuffer);

			// Remove Ratio box label
			SetWindowText(GETHCTL(IDC_SIGMA_RATIO), "");

			// Disable set noise checkbox
			Button_SetCheck(GETHCTL(IDC_SIGMA_SETNOISE), bSetNoise);
			EnableWindow(GETHCTL(IDC_SIGMA_SETNOISE), FALSE);

			// Disable apply checkbox
			Button_SetCheck(GETHCTL(IDC_SIGMA_ACFID), FALSE);
			EnableWindow(GETHCTL(IDC_SIGMA_ACFID), FALSE);

			// Hide the Single, Double and Conf Factor controls
			ShowWindow(GETHCTL(IDC_SIGMA_SINGLE), SW_HIDE);
			ShowWindow(GETHCTL(IDC_SIGMA_DOUBLE), SW_HIDE);
			ShowWindow(GETHCTL(IDC_SIGMA_CF), SW_HIDE);

			// Hide the CI control
			ShowWindow(GETHCTL(IDC_SIGMA_CI), SW_HIDE);

			// Disable the Single, Double and Conf Factor controls
			if(bSetEnable)
			{
				EnableWindow(GETHCTL(IDC_SIGMA_SINGLE), FALSE);
				EnableWindow(GETHCTL(IDC_SIGMA_DOUBLE), FALSE);
				EnableWindow(GETHCTL(IDC_SIGMA_CF), FALSE);
			}

			if(bSigmaDetails)
			{
				// Hide the CI window - move mask on screen
				SetRect(&rect, 140, 16, 140+116, 16+114);
				MapDialogRect(hDlg, &rect);
				MoveWindow(GETHCTL(IDC_SIGMA_NOCONF), (rect.left),	(rect.top),
					(rect.right-rect.left), (rect.bottom-rect.top), 1);

				// Hide the Noise window - move mask on screen
				// SetRect(&rect, 8, 146, 8+308, 146+18); // Too long
				SetRect(&rect, 8, 146, 8+247, 146+18);
				MapDialogRect(hDlg, &rect);
				MoveWindow(GETHCTL(IDC_SIGMA_NONOISE), (rect.left), (rect.top),
					(rect.right-rect.left), (rect.bottom-rect.top), 1);

				// Disable deadtime, B2 & B3
				EnableWindow(GETHCTL(IDC_SIGMA_DEADTIME), FALSE);
				EnableWindow(GETHCTL(IDC_SIGMA_B2), FALSE);
				EnableWindow(GETHCTL(IDC_SIGMA_B3), FALSE);
			}

		}
		break;

		case THEO1_SIGMA:
		{
			// Label Value box
			SetWindowText(GETHCTL(IDC_SIGMA_LABEL), "Tho1 Dev:");

			// Enable set noise checkbox
			Button_SetCheck(GETHCTL(IDC_SIGMA_SETNOISE), bSetNoise);
			EnableWindow(GETHCTL(IDC_SIGMA_SETNOISE), TRUE);

            // Label Ratio box
			SetWindowText(GETHCTL(IDC_SIGMA_RATIO), "Bias:");

			// Mark BW Factor as N/A
			LoadString(hInst, IDS_MESSAGE_NA, szBuffer, BUFFER_SIZE);
			SetWindowText(GETHCTL(IDC_SIGMA_BWFACTOR), szBuffer);

			// Show the Single, Double and Conf Factor controls
			ShowWindow(GETHCTL(IDC_SIGMA_SINGLE), SW_SHOWNORMAL);
			ShowWindow(GETHCTL(IDC_SIGMA_DOUBLE), SW_SHOWNORMAL);
			ShowWindow(GETHCTL(IDC_SIGMA_CF), SW_SHOWNORMAL);

			// Hide the CI control
			ShowWindow(GETHCTL(IDC_SIGMA_CI), SW_HIDE);

			// Disable apply checkbox
			Button_SetCheck(GETHCTL(IDC_SIGMA_ACFID), FALSE);
			EnableWindow(GETHCTL(IDC_SIGMA_ACFID), FALSE);

			// Enable the Single, Double and Conf Factor controls
			if(bSetEnable)
			{
				EnableWindow(GETHCTL(IDC_SIGMA_SINGLE), TRUE);
				EnableWindow(GETHCTL(IDC_SIGMA_DOUBLE), TRUE);
                EnableWindow(GETHCTL(IDC_SIGMA_CF), TRUE);
            }

            if(bSigmaDetails)
            {
                // Label Max box
				SetWindowText(GETHCTL(IDC_SIGMA_MAXLABEL), "Max Tho1:");

                // Label Min box
				SetWindowText(GETHCTL(IDC_SIGMA_MINLABEL), "Min Tho1:");

                // Show the CI window - move mask off screen
				MoveWindow(GETHCTL(IDC_SIGMA_NOCONF), 0, 0, 0, 0, 1);

                // Show most of the Noise window - move mask mostly off screen
                // Just block the Kn label and box
                SetRect(&rect, 260, 146, 260+55, 146+18);
                MapDialogRect(hDlg, &rect);
				MoveWindow(GETHCTL(IDC_SIGMA_NONOISE), (rect.left), (rect.top),
					(rect.right-rect.left), (rect.bottom-rect.top), 1);

				// Trial code 09/19/06 - Allows apply checkbox to work
				MoveWindow(GETHCTL(IDC_SIGMA_NONOISE), 0, 0, 0, 0, 1);

				// Disable deadtime, B2 & B3
				EnableWindow(GETHCTL(IDC_SIGMA_DEADTIME), FALSE);
				EnableWindow(GETHCTL(IDC_SIGMA_B2), FALSE);
				EnableWindow(GETHCTL(IDC_SIGMA_B3), FALSE);
			}

			// Read noise type & set bias accordingly
			SendMessage(hDlg, WM_COMMAND,
				GET_WM_COMMAND_MPS(IDC_SIGMA_THEO1BIAS, NULL, 0));
		}
		break;
	 
	}
}

/*****************************************************************************/
/*                                                                           */
/*                   Avg Dialog Procedure                                    */
/*                                                                           */
/*  Revision record:                                                         */
/*      10/30/96    Added edit control CR logic                              */
/*      11/03/96    Added increment file extension logic                     */
/*		08/15/98	Added code to also average timetags                      */
/*		11/18/06	Added CreateTab() call                                   */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK AvgDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	// Chars
	char szBuffer[BUFFER_SIZE+1];   // Text buffer
	// Ints
	int nPoints;                    // # data points
	int nEntry;                     // User avg factor entry to be validated
	int nPrev;                      // Previous value
	static int nAvgFactor=1;        // Averaging factor
	// BOOLs
	static BOOL bErrorTrap=FALSE;   // Flag for entry error
	// F_TYPEs
	F_TYPE fTau;                    // Tau value

	LoadIcon(hInst, "FlatAvgIcon");

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Write prompt message
			WritePromptMessage(TB_AVG);

			// Initialize the averaging factor to 1
			// Want to do this every time as a default safety measure
			SetWindowText(GETHCTL(IDC_AVG_FACTOR), "1");
		}
		return TRUE;

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				// Respond to help button message
				case IDHELP:
				{
					#if(0)
					HtmlHelp(hDlg, "Stable32.chm::AVERAGE_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::AVERAGE_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "AVERAGE_FUNCTION");
					#endif
				}
				break;

				// Respond to avg factor edit control message
				case IDC_AVG_FACTOR:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) && (GetFocus()!=GETHCTL(IDC_AVG_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Save previous value
						nPrev=nAvgFactor;

						// Get (new) avg factor
						GetWindowText(GETHCTL(IDC_AVG_FACTOR), szBuffer,
							BUFFER_SIZE);
						nEntry=abs(atoi(szBuffer));

						// Get # data points
						if(bDataType==FREQ_DATA)
						{
							nPoints=(int)fFreqData[0];
						}
						else
						{
							nPoints=(int)fPhaseData[0];
						}

						// Check entry - must be between 1 and nPoints
						if(ValidateInteger(hDlg, nEntry, 1, nPoints)==TRUE)
						{
							// New value OK
							nAvgFactor=nEntry;
							_snprintf(szBuffer, sizeof(szBuffer), "%d",
								nAvgFactor);
							SetWindowText(GETHCTL(IDC_AVG_FACTOR), szBuffer);
						}
						else
						{
							// Invalid entry - restore default value
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nPrev);
							SetWindowText(GETHCTL(IDC_AVG_FACTOR), szBuffer);
							SetFocus(GETHCTL(IDC_AVG_FACTOR));
						}
                    }
                    else
                    {
                        // Reset error flag
                        bErrorTrap=FALSE;
                    }
                }
                break;

                // Respond to CR in an edit control
                // Note: No button is a DEFPUSHBUTTON
                case IDOK:
                {
                    // Does avg factor edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_AVG_FACTOR))
                    {
						// Send EN_KILLFOCUS message to factor edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_AVG_FACTOR, 0,
							EN_KILLFOCUS));
					}
				}
                break;

				// Respond to OK buttom message
                case IDC_AVG_ACCEPT:
                {
                    // Get averaging factor
                    GetWindowText(GETHCTL(IDC_AVG_FACTOR), szBuffer,
                        BUFFER_SIZE);
                    nAvgFactor=atoi(szBuffer);

                    // Display wait cursor
                    SetCursor(hWait);

					// Set busy flag
					bBusy=TRUE;

                    if(nAvgFactor>1)
                    {
						// Create tab to save previous data if requested
						if(bTabs && bTabChange)
						{
							CreateTab();
						}
						
                        if(bDataType) // Freq data
                        {
                            // Average freq data
							nPoints=AverageFreqData(fData, nAvgFactor);

                            // Shrink freq data array
                            if((fNew=(F_TYPE*)realloc((char*)fFreqData,
                                (nPoints+ARRAY_OFFSET+EXTRA_MEM)*
								sizeof(F_TYPE)))==NULL)
                            {
								// Shouldn't happen and not fatal anyway
								// so just announce error w/o bailing out
                                AllocErrorMessage();
                            }
                            else
                            {
                                fFreqData=fNew;
                                fData=fFreqData;
							}

							// Average freq timetags
							// Done as phase data
							// to simply skip intermediate pts
							if(bFreqTimetags)
							{
								// Average freq timetags
								AveragePhaseData(fFreqTimetags, nAvgFactor);

							   // Shrink freq timetag array
							   if((fNew=(F_TYPE*)realloc((char *)fFreqTimetags,
									(nPoints+ARRAY_OFFSET+EXTRA_MEM)*
									sizeof(F_TYPE)))==NULL)
								{
									 // Shouldn't happen and not fatal anyway
									 // so just announce error w/o bailing out
									 AllocErrorMessage();
								}
								else
								{
									fFreqTimetags=fNew;
									fTags=fFreqTimetags;
								}
							}
                        }
                        else // Phase data
                        {
                            // Average phase data
							nPoints=AveragePhaseData(fData, nAvgFactor);

                            // Shrink phase data array
                            if((fNew=(F_TYPE*)realloc((char *)
                                fPhaseData, (nPoints+ARRAY_OFFSET+EXTRA_MEM)*
								sizeof(F_TYPE)))==NULL)
                            {
								// Shouldn't happen and not fatal anyway
								// so just announce error w/o bailing out
                                AllocErrorMessage();
                            }
                            else
                            {
                                fPhaseData=fNew;
                                fData=fPhaseData;
                            }

							// Average phase timetags
							if(bPhaseTimetags)
							{
								// Avg phase timetags
								AveragePhaseData(fPhaseTimetags, nAvgFactor);

								// Shrink phase timetag array
							   if((fNew=(F_TYPE*)realloc((char *)fPhaseTimetags,
									(nPoints+ARRAY_OFFSET+EXTRA_MEM)*
									sizeof(F_TYPE)))==NULL)
								{
									 // Shouldn't happen and not fatal anyway
									 // so just announce error w/o bailing out
									 AllocErrorMessage();
								}
								else
								{
									fPhaseTimetags=fNew;
									fTags=fPhaseTimetags;
								}
							}
                         }

                        // Update data #, start and end
                        fData[0]=(F_TYPE)nPoints;
                        fData[1]=(F_TYPE)1.0;
                        fData[2]=fData[0];

                        // Update status display
                        _snprintf(szBuffer, sizeof(szBuffer), "%d",
							(int)fData[0]);
						if(bDataType==FREQ_DATA)
                        {
                            SetWindowText(hwndFreqNum, szBuffer);
                            SetWindowText(hwndFreqEnd, szBuffer);
                            SetWindowText(hwndFreqStart, "1");
						}
                        else // Phase data
                        {
                            SetWindowText(hwndPhaseNum, szBuffer);
                            SetWindowText(hwndPhaseEnd, szBuffer);
                            SetWindowText(hwndPhaseStart, "1");
                        }

                        // Set data changes flag
                        if(bDataType==FREQ_DATA)
                        {
							// Put info into log file
							_snprintf(szBuffer, sizeof(szBuffer), "AF=%d",
								nAvgFactor);
							WriteLog(11, szBuffer);
								
                            bFreqDataChanged=TRUE;
							bFreqDataUnsaved=TRUE;
							sFPlot.new_file=TRUE;
                            bFreqScaleChanged=TRUE;
							bFreqRedraw=TRUE;

                            // Increment filename
                            if(bIncExtension)
                            {
                                IncExtension(szFile, FREQ_DATA);
                                IncExtension(szFileTitle, FREQ_DATA);
                                IncExtension(szFreqFile, FREQ_DATA);
                                IncExtension(szFreqFileTitle, FREQ_DATA);
                                SetWindowText(hwndFreqFilename, szFileTitle);
                            }
						}
                        else
                        {
							// Put info into log file
							_snprintf(szBuffer, sizeof(szBuffer), "AF=%d",
								nAvgFactor);
							WriteLog(10, szBuffer);
								
                            bPhaseDataChanged=TRUE;
							bPhaseDataUnsaved=TRUE;
                            bPhaseScaleChanged=TRUE;
							bPhaseRedraw=TRUE;

                            // Increment filename
                            if(bIncExtension)
                            {
                                IncExtension(szFile, PHASE_DATA);
                                IncExtension(szFileTitle, PHASE_DATA);
                                IncExtension(szPhaseFile, PHASE_DATA);
                                IncExtension(szPhaseFileTitle, PHASE_DATA);
                                SetWindowText(hwndPhaseFilename, szFileTitle);
                            }
                        }

						// Force new PSD plot scale
						sPSPlot.y_tic=0;

						// Redraw status plots from new data
						UpdateStatusBar(hwndMain, NEW_DATA);

						// Reset redraw flags
						bPhaseRedraw=FALSE;
						bFreqRedraw=FALSE;

						// Clear synch flag
						bSynch=FALSE;

						// Clear plot lines
						ClearLines();

                        // Adjust tau value
                        if(bDataType)
                        {
                            GetWindowText(hwndFreqTau, szBuffer, BUFFER_SIZE);
                            fTau=(F_TYPE)atof(szBuffer);
							_snprintf(szBuffer, sizeof(szBuffer), "%11.5e",
								fTau*nAvgFactor);
							ShortenExp(szBuffer);
                            SetWindowText(hwndFreqTau, szBuffer);
                        }
                        else
                        {
                            GetWindowText(hwndPhaseTau, szBuffer, BUFFER_SIZE);
							fTau=(F_TYPE)atof(szBuffer);
                            _snprintf(szBuffer, sizeof(szBuffer), "%11.5e",
								fTau*nAvgFactor);
							ShortenExp(szBuffer);
                            SetWindowText(hwndPhaseTau, szBuffer);
                        }
                    }

                    // Display normal cursor
                    SetCursor(hArrow);

					// Reset busy flag
					bBusy=FALSE;
                }

                // Go right into EndDialog()
                // Respond to esc key or cancel button
                case IDCANCEL:
                case IDC_AVG_CANCEL:
                {
                    EndDialog (hDlg, 0);
                }
                return TRUE;
            }
        }
        break;
	 }
     return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*                     Step Dialog Procedure                                 */
/*                                                                           */
/*  Revision record:                                                         */
/*      05/25/11    Created; working OK; still need help file                */
/*		08/06/11	Working on details                                       */
/*					Note that one cannot average the phase data before       */
/*					doing the step correction because averaging will spoil   */
/*                  the data around the jump                                 */
/*					Added option to insert gaps at jump points if bGap flag  */
/*                  is set                                                   */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK StepDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	// Chars
	char szBuffer[BUFFER_SIZE+1];   // Text buffer
	// Ints
	int i;							// Point index
	int j;							// Array index
	static int nNumSteps=0;			// # steps
	static nStart=0;				// Start data point
	static nEnd=0;					// End Data point
	// BOOLs
	static BOOL bErrorTrap=FALSE;   // Flag for entry error
	static BOOL bStep=FALSE;		// Flag for jump detected
	static BOOL bGap=FALSE;			// Flag for inserting gap at jump
	// F_TYPEs
	static F_TYPE fPrevSpan;		// Previous span value
    static F_TYPE fMin;             // Minimum data value
    static F_TYPE fMax;             // Maximum data value
	static F_TYPE fPrev;			// Previous data value
	static F_TYPE fSpan;            // Data span
	static F_TYPE fCorrection=0;	// Cumulative data correction

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Write prompt message
			WritePromptMessage(TB_STEP);

			// Initialize the step count to 0
			nNumSteps=0;
			SetWindowText(GETHCTL(IDC_STEP_NUM), "0");

			// Initialize the gap checkbox
			bGap=FALSE;
			Button_SetCheck(GETHCTL(IDC_STEP_GAP), bGap);

			// Get span of data
            FindMinMax(fData, &fMin, &fMax, bDataType);
		    fSpan=fMax-fMin;

			// Initialize the span edit control
			// If necessary, user can use edit control
			// to adjust span to exact value
		    // e.g., 100 ns for 10 MHz carrier
			sprintf(szBuffer, "%e", fSpan);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_STEP_SPAN), szBuffer);

			// Assign start and end limits
			nStart=(int)fData[1];
			nEnd=(int)fData[2];

			// Scan the data and count the # of steps
			// Between start and end limits
			for(i=nStart+1; i<nEnd; i++)  
			{
				// Adjust index for array offset
				j=i+ARRAY_OFFSET-1;

				// Don't process gaps
				if(fData[j-1] && fData[j])
				{
					// Check if positive jump
					if((fData[j]-fData[j-1])>(fSpan*0.5))
					{
						nNumSteps++;
					}
					// Check if negative jump
					else if((fData[j-1]-fData[j])>(fSpan*0.5))
					{
						nNumSteps++;
					}
				}
			}

			// Show # steps
			sprintf(szBuffer, "%d", nNumSteps);
			SetWindowText(GETHCTL(IDC_STEP_NUM), szBuffer);
		}
		return TRUE;

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				// Respond to help button message
				case IDHELP:
				{
					#if(0)
					HtmlHelp(hDlg, "Stable32.chm::UNSTEP_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::UNSTEP_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "UNSTEP_FUNCTION");
					#endif
				}
				break;

				// Respond to threshold edit control message
				case IDC_STEP_SPAN:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) && (GetFocus()!=GETHCTL(IDC_STEP_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Save previous threshold value
						fPrevSpan=fSpan;

						// Get (new) span value
						GetWindowText(GETHCTL(IDC_STEP_SPAN), szBuffer,
							BUFFER_SIZE);
						ShortenExp(szBuffer);
						fSpan=fabs(atof(szBuffer));

						// Validate entry?

						// Redisplay span value
 						sprintf(szBuffer, "%e", fSpan);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_STEP_SPAN), szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
                }
                break;

				// Respond to gap checkbox
				case IDC_STEP_GAP:
				{
					bGap=Button_GetCheck(GETHCTL(IDC_STEP_GAP));
				}
				break;

                // Respond to CR in an edit control
                // Note: No button is a DEFPUSHBUTTON
                case IDOK:
                {
                    // Does span edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_STEP_SPAN))
                    {
						// Send EN_KILLFOCUS message to factor edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_STEP_SPAN, 0,
							EN_KILLFOCUS));
					}
				}
                break;

				// Respond to OK buttom message
                case IDC_STEP_ACCEPT:
                {
                    // Skip if no steps
					if(nNumSteps>0)
					{
						// Get span value
						GetWindowText(GETHCTL(IDC_STEP_SPAN), szBuffer,
							BUFFER_SIZE);
						fSpan=atof(szBuffer);

						// Display wait cursor
						SetCursor(hWait);

						// Set busy flag
						bBusy=TRUE;

						// Put info into log file
						_snprintf(szBuffer, sizeof(szBuffer), "# Steps=%d, Span=%e",
							nNumSteps, fSpan);
						ShortenExp(szBuffer);
						WriteLog(81, szBuffer);
									
						// Initializations
						// Set correction to zero
						fCorrection=0.0;

						// Assign start and end limits
						nStart=(int)fData[1];
						nEnd=(int)fData[2];

						// Assign 1st previous value
						fPrev=fData[nStart+ARRAY_OFFSET-1];
						
						// Reset jump flag
						bStep=FALSE;

						// Main loop
						// Read data and apply unstepping algorithm
						// to data between start and end limits
						for(i=nStart+1; i<=nEnd; i++)  
						{
							// Adjust index for array offset
							j=i+ARRAY_OFFSET-1;

							// Don't apply jump test to a gap
							if(fData[j])
							{
								// Check if positive jump
								if((fData[j]-fPrev)>(fSpan*0.5))
								{
									// Value is a lot bigger so decrement correction by span
									fCorrection-=fSpan;

									// Set jump flag
									bStep=TRUE;
								}
								// Check if negative jump
								else if((fPrev-fData[j])>(fSpan*0.5))
								{
									// Value is a lot smaller so increment correction by span 
									fCorrection+=fSpan;

									// Set jump flag
									bStep=TRUE;
								}

								// Set current value as previous value
								fPrev=fData[j];

								// Apply correction
								fData[j]+=fCorrection;

								#if(1) // New code 08/06/11
								// Check for jump
								if(bStep && bGap)
								{
									// Set current point to gap if bGap flag is set
									// We don't know exactly when the jump occurred
									// so we can't accurately determine the post-step value
									fData[j]=0.0;

									// Reset jump flag
									bStep=FALSE;
								}
								#endif
							}
						}

						// We could automatically remove outliers here, but that's pretty intrusive
						// Have to convert to freq data, remove them, and convert back to phase data
						// perhaps then replacing the gaps with interpolated values
						// Better to leave it up to analyst judgment
						
						if(bDataType==PHASE_DATA)
						{
							bPhaseDataChanged=TRUE;
							bPhaseDataUnsaved=TRUE;
							bPhaseScaleChanged=TRUE;
							bPhaseRedraw=TRUE;

							// Increment filename
							if(bIncExtension)
							{
								IncExtension(szFile, PHASE_DATA);
								IncExtension(szFileTitle, PHASE_DATA);
								IncExtension(szPhaseFile, PHASE_DATA);
								IncExtension(szPhaseFileTitle, PHASE_DATA);
								SetWindowText(hwndPhaseFilename, szFileTitle);
							 }

 							// Force new PSD plot scale
							sPSPlot.y_tic=0;

							// Redraw status plots from new data
							UpdateStatusBar(hwndMain, NEW_DATA);

							// Reset redraw flags
							bPhaseRedraw=FALSE;
							bFreqRedraw=FALSE;

							// Clear synch flag
							bSynch=FALSE;

							// Clear plot lines
							ClearLines();
						}
						else // We don't allow freq data
						{
							bFreqDataChanged=TRUE;
							bFreqDataUnsaved=TRUE;
							bFreqScaleChanged=TRUE;
							bFreqRedraw=TRUE;

							// Increment filename
							if(bIncExtension)
							{
								IncExtension(szFile, FREQ_DATA);
								IncExtension(szFileTitle, FREQ_DATA);
								IncExtension(szPhaseFile, FREQ_DATA);
								IncExtension(szPhaseFileTitle, FREQ_DATA);
								SetWindowText(hwndFreqFilename, szFileTitle);
							 }

 							// Force new PSD plot scale
							sPSPlot.y_tic=0;

							// Redraw status plots from new data
							UpdateStatusBar(hwndMain, NEW_DATA);

							// Reset redraw flags
							bPhaseRedraw=FALSE;
							bFreqRedraw=FALSE;

							// Clear synch flag
							bSynch=FALSE;

							// Clear plot lines
							ClearLines();
						}

						// Display normal cursor
						SetCursor(hArrow);

						// Reset busy flag
						bBusy=FALSE;
					}
                }

                // Go right into EndDialog()
                // Respond to esc key or cancel button
                case IDCANCEL:
                case IDC_STEP_CANCEL:
                {
                    EndDialog (hDlg, 0);
                }
                return TRUE;
            }
        }
        break;
	 }
     return FALSE;
}

#ifndef LITE_VER
/*****************************************************************************/
/*                                                                           */
/*               Read Archive Configuration Dialog Procedure                 */
/*                                                                           */
/*	This function reads, edits & stores default Num, Meas & Ref values       */
/*	for Read Archive function in STABLE32.INI.  The only coupling to that    */
/*	function is that it reads the values from the INI file as its defaults.  */
/*                                                                           */
/*  Revision record:                                                         */
/*      05/02/98    Created                                                  */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK ArcConfigDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local macro
	#define MAX_NUM_CHANS	999		// Max # channels (arbitrary)

	// Local variables
	// Chars
	char szBuffer[BUFFER_SIZE+1];   // Text buffer
	char szSection[BUFFER_SIZE+1];  // INI file section name
	// Ints
	int nEntry;                     // User avg factor entry to be validated
	int nPrev;                      // Previous value
	static int nNum;				// # channels
	static int nMeas;				// Measurement channel #
	static int nRef;				// Reference channel #
	static int nPrevNum;			// Original # channels
	static int nPrevMeas;			// Original measurement channel #
	static int nPrevRef;			// Original reference channel #
	// BOOLs
	static BOOL bErrorTrap=FALSE;   // Flag for entry error

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Write prompt message
			strlcpy(szBuffer, "Set Read Archive function defaults.",
				sizeof(szBuffer));
			WriteMessage(szBuffer);

			// Read arcconfig values from INI file
			SendMessage(hDlg, WM_COMMAND,
				GET_WM_COMMAND_MPS(IDC_ARCCONFIG_READINI, 0, 0));

			// Save original values
			nPrevNum=nNum;
			nPrevMeas=nMeas;
			nPrevRef=nRef;
				
			// Show # channels
			_snprintf(szBuffer, sizeof(szBuffer), "%d", nNum);
			SetWindowText(GETHCTL(IDC_ARCCONFIG_NUM), szBuffer);

			// Show the meas ch #
			if(nMeas>0)
			{
				_snprintf(szBuffer, sizeof(szBuffer), "%d", nMeas);
			}
			else // Sense reversed
			{
				_snprintf(szBuffer, sizeof(szBuffer), "%d (Rev)", nMeas);
			}

			SetWindowText(GETHCTL(IDC_ARCCONFIG_MEAS), szBuffer);

			// Show the ref ch #
			if(nRef)
			{
				_snprintf(szBuffer, sizeof(szBuffer), "%d", nRef);
			}
			else // 0=NOREF case
			{
				_snprintf(szBuffer, sizeof(szBuffer), "%d (No Ref)", nRef);
			}

			SetWindowText(GETHCTL(IDC_ARCCONFIG_REF), szBuffer);

			// Initialize the # channels spin control base to 10
			SendMessage(GETHCTL(IDC_ARCCONFIG_CSPIN), UDM_SETBASE,
				(DWORD)10, 0);

			// Initialize the # channels spin control range from 1 to 999
			// Note: The "max" & "min" usages are reversed
			SendMessage(GETHCTL(IDC_ARCCONFIG_CSPIN), UDM_SETRANGE, 0,
				MAKELONG((WORD)999, (WORD)1));

			// Initialize the # channels spin control value to nNum
			SendMessage(GETHCTL(IDC_ARCCONFIG_CSPIN), UDM_SETPOS, 0,
				MAKELONG((WORD)nNum, 0));

			// Initialize the meas chan # spin control base to 10
			SendMessage(GETHCTL(IDC_ARCCONFIG_MSPIN), UDM_SETBASE,
				(DWORD)10, 0);

			// Init the meas chan # spin control range from -nNum to nNum
			// Note: The "max" & "min" usages are reversed
			SendMessage(GETHCTL(IDC_ARCCONFIG_MSPIN), UDM_SETRANGE, 1,
				MAKELONG((WORD)nNum, (WORD)-nNum));

			// Initialize the meas chan # spin control value to nMeas
			SendMessage(GETHCTL(IDC_ARCCONFIG_MSPIN), UDM_SETPOS, 0,
				MAKELONG((WORD)nMeas, 0));

			// Initialize the ref chan # spin control base to 10
			SendMessage(GETHCTL(IDC_ARCCONFIG_RSPIN), UDM_SETBASE,
				(DWORD)10, 0);

			// Init the ref chan # spin control range from 0 to nNum
			// Note: The "max" & "min" usages are reversed
			SendMessage(GETHCTL(IDC_ARCCONFIG_RSPIN), UDM_SETRANGE, 0,
				MAKELONG((WORD)nNum, (WORD)0));

			// Initialize the ref chan # spin control value to nRef
			SendMessage(GETHCTL(IDC_ARCCONFIG_RSPIN), UDM_SETPOS, 0,
				MAKELONG((WORD)nRef, 0));
		}
		return TRUE;

		// Receove messages from spin controls
		// Note: These are not set up as "buddy" controls of their edit boxes
		// because we need more complex text than just simple ints

		case WM_VSCROLL:
		{
			// Is message from # channels spin control?
			if((HWND)lParam==GETHCTL(IDC_ARCCONFIG_CSPIN))
			{
				// Get & display new position (value)
				nNum=HIWORD(wParam);
				_snprintf(szBuffer, sizeof(szBuffer), "%d", nNum);
				SetWindowText(GETHCTL(IDC_ARCCONFIG_NUM), szBuffer);

				// Reinitialize the meas chan # spin control range from
				// -nNum to nNum
				SendMessage(GETHCTL(IDC_ARCCONFIG_MSPIN), UDM_SETRANGE, 1,
					MAKELONG((WORD)nNum, (WORD)-nNum));

				// Reinitialize the ref chan # spin control range from
				// 0 to nNum
				SendMessage(GETHCTL(IDC_ARCCONFIG_RSPIN), UDM_SETRANGE, 0,
					MAKELONG((WORD)nNum, (WORD)0));
			}

			// Is message from measurement channel spin control?
			if((HWND)lParam==GETHCTL(IDC_ARCCONFIG_MSPIN))
			{
				// Get new position (value)
				nEntry=HIWORD(wParam);

				// Convert negative value to signed value
				if(nEntry>32767)
				{
					nEntry=nEntry-65536;
				}

				// Value=0 or nRef not allowed
				if(nEntry==0 || abs(nEntry)==nRef)
				{
					break;
				}

				// Entry OK
				nMeas=nEntry;

				if(nMeas>0)
				{
					_snprintf(szBuffer, sizeof(szBuffer), "%d", nMeas);
				}
				else // Sense reversed
				{
					_snprintf(szBuffer, sizeof(szBuffer), "%d (Rev)", nMeas);
				}

				SetWindowText(GETHCTL(IDC_ARCCONFIG_MEAS), szBuffer);
			}

			// Is message from reference channel spin control?			
			if((HWND)lParam==GETHCTL(IDC_ARCCONFIG_RSPIN))
			{
				// Get new position (value)
				nEntry=HIWORD(wParam);

				// Value=nMeas not allowed
				if(nEntry==nMeas)
				{
					break;
				}

				// Entry OK
				nRef=nEntry;

				if(nRef)
				{
					_snprintf(szBuffer, sizeof(szBuffer), "%d", nRef);
				}
				else // 0=NOREF case
				{
					_snprintf(szBuffer, sizeof(szBuffer), "%d (No Ref)", nRef);
				}

				SetWindowText(GETHCTL(IDC_ARCCONFIG_REF), szBuffer);
			}
		}
		break;

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				// Respond to help button message
				case IDC_ARCCONFIG_HELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::READ_ARCHIVE_CONFIGURE.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::READ_ARCHIVE_CONFIGURE.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "READ_ARCHIVE_CONFIGURE");
					#endif
				}
				break;

				// Respond to # channels edit control message
				case IDC_ARCCONFIG_NUM:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_ARCCONFIG_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Save previous value
						nPrev=nNum;

						// Get (new) # channels
						GetWindowText(GETHCTL(IDC_ARCCONFIG_NUM), szBuffer,
							BUFFER_SIZE);
						nEntry=abs(atoi(szBuffer));

						// Check entry - must be between 1 and MAX_NUM_CHANS
						if(ValidateInteger(hDlg, nEntry, 1, MAX_NUM_CHANS)==
							TRUE)
						{
							// New value OK
							nNum=nEntry;
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nNum);
							SetWindowText(GETHCTL(IDC_ARCCONFIG_NUM),
								szBuffer);

							// Reinit the meas chan # spin control range from
							// -nNum to nNum
							SendMessage(GETHCTL(IDC_ARCCONFIG_MSPIN),
								UDM_SETRANGE, 1,
								MAKELONG((WORD)nNum, (WORD)-nNum));

							// Reinit the ref chan # spin control range from
							// 0 to nNum
							SendMessage(GETHCTL(IDC_ARCCONFIG_RSPIN),
								UDM_SETRANGE, 0,
								MAKELONG((WORD)nNum, (WORD)0));
						}
						else
						{
							// Invalid entry - restore previous value
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nPrev);
							SetWindowText(GETHCTL(IDC_ARCCONFIG_NUM),
								szBuffer);
							SetFocus(GETHCTL(IDC_ARCCONFIG_NUM));
						}
                    }
                    else
                    {
                        // Reset error flag
                        bErrorTrap=FALSE;
                    }
                }
                break;

				// Respond to meas ch # edit control message
				case IDC_ARCCONFIG_MEAS:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_ARCCONFIG_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Save previous value
						nPrev=nMeas;

						// Get (new) meas ch # factor
						GetWindowText(GETHCTL(IDC_ARCCONFIG_MEAS), szBuffer,
							BUFFER_SIZE);

						// Note: negative value OK (sense reversed)
						nEntry=(atoi(szBuffer));

						// Check entry - must be between +/- nNum
						if(ValidateInteger(hDlg, nEntry, -nNum,	nNum)==TRUE)
						{
							// Check that entry not equal ref channel #
							if(abs(nEntry)==nRef)
							{
								// Error message
								LoadString(hInst, IDS_MESSAGE_CHANSEQUAL,
								   szBuffer, BUFFER_SIZE);
								MessageBox(hwndMain, szBuffer, "Invalid Entry",
									MB_ICONEXCLAMATION);

								// Invalid entry - restore previous value
								_snprintf(szBuffer, sizeof(szBuffer), "%d",
									nPrev);
								SetWindowText(GETHCTL(IDC_ARCCONFIG_MEAS),
									szBuffer);
								SetFocus(GETHCTL(IDC_ARCCONFIG_MEAS));
								break;
							}

							// New value OK range - also check for 0
							if(nEntry==0)
							{
								// Show error message
								LoadString(hInst, IDS_MESSAGE_NOZERO,
									szBuffer, BUFFER_SIZE);
								MessageBox(hDlg, szBuffer, "Invalid Entry",
									MB_ICONEXCLAMATION);

								// Invalid entry - restore previous value
								if(nPrev>0)
								{	
									_snprintf(szBuffer, sizeof(szBuffer),
										"%d", nPrev);
								}
								else // Sense reversed
								{
									_snprintf(szBuffer, sizeof(szBuffer),
										"%d (Rev)", nPrev);
								}

								SetWindowText(GETHCTL(IDC_ARCCONFIG_MEAS),
									szBuffer);
								SetFocus(GETHCTL(IDC_ARCCONFIG_MEAS));
								break;
							}

							nMeas=nEntry;
							if(nMeas>0)
							{
								_snprintf(szBuffer, sizeof(szBuffer), "%d",
									nMeas);
							}
							else // Sense reversed
							{
								_snprintf(szBuffer, sizeof(szBuffer),
									"%d (Rev)", nMeas);
							}

							SetWindowText(GETHCTL(IDC_ARCCONFIG_MEAS),
								szBuffer);
						}
						else
						{
							// Invalid entry - restore previous value
							if(nPrev>0)
							{
								_snprintf(szBuffer, sizeof(szBuffer), "%d",
									nPrev);
							}
							else // Sense reversed
							{
								_snprintf(szBuffer, sizeof(szBuffer),
									"%d (Rev)", nPrev);
							}

							SetWindowText(GETHCTL(IDC_ARCCONFIG_MEAS),
								szBuffer);
							SetFocus(GETHCTL(IDC_ARCCONFIG_MEAS));
						}
                    }
                    else
                    {
                        // Reset error flag
                        bErrorTrap=FALSE;
                    }
                }
                break;

				// Respond to ref ch # edit control message
				case IDC_ARCCONFIG_REF:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_ARCCONFIG_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Save previous value
						nPrev=nRef;

						// Get (new) ref ch # factor
						GetWindowText(GETHCTL(IDC_ARCCONFIG_REF), szBuffer,
							BUFFER_SIZE);
						nEntry=abs(atoi(szBuffer));

						// Check entry - must be between 0 and nNum
						// Note: 0=NOREF
						if(ValidateInteger(hDlg, nEntry, 0, nNum)==TRUE)
						{
							// Check that entry not equal meas channel #
							if(nEntry==nMeas)
							{
								// Error message
								LoadString(hInst, IDS_MESSAGE_CHANSEQUAL,
								   szBuffer, BUFFER_SIZE);
								MessageBox(hwndMain, szBuffer, "Invalid Entry",
									MB_ICONEXCLAMATION);

								// Invalid entry - restore previous value
								_snprintf(szBuffer, sizeof(szBuffer), "%d",
									nPrev);
								SetWindowText(GETHCTL(IDC_ARCCONFIG_REF),
									szBuffer);
								SetFocus(GETHCTL(IDC_ARCCONFIG_REF));
								break;
							}

							// New value OK
							nRef=nEntry;
							if(nRef)
							{
								_snprintf(szBuffer, sizeof(szBuffer), "%d",
									nRef);
							}
							else // 0=NOREF case
							{
								_snprintf(szBuffer, sizeof(szBuffer),
									"%d (No Ref)", nRef);
							}

							SetWindowText(GETHCTL(IDC_ARCCONFIG_REF),
								szBuffer);
						}
						else
						{
							// Invalid entry - restore previous value
							if(nPrev)
							{
								_snprintf(szBuffer, sizeof(szBuffer), "%d",
									nPrev);
							}
							else // 0=NOREF case
							{
								_snprintf(szBuffer, sizeof(szBuffer),
									"%d (No Ref)", nPrev);
							}

							SetWindowText(GETHCTL(IDC_ARCCONFIG_REF),
								szBuffer);
							SetFocus(GETHCTL(IDC_ARCCONFIG_REF));
						}
                    }
                    else
                    {
                        // Reset error flag
                        bErrorTrap=FALSE;
                    }
                }
                break;

                // Respond to CR in an edit control
                // Note: No button is a DEFPUSHBUTTON
                case IDOK:
                {
                    // Does # channels edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_ARCCONFIG_NUM))
                    {
						// Send EN_KILLFOCUS message to factor edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_ARCCONFIG_NUM, 0,
							EN_KILLFOCUS));
					}

                    // Does meas ch # edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_ARCCONFIG_MEAS))
                    {
						// Send EN_KILLFOCUS message to factor edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_ARCCONFIG_MEAS, 0,
							EN_KILLFOCUS));
					}

                    // Does ref ch # edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_ARCCONFIG_REF))
                    {
						// Send EN_KILLFOCUS message to factor edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_ARCCONFIG_REF, 0,
							EN_KILLFOCUS));
					}
				}
                break;

				// Subfunction to read arcconfig data from INI file
				case IDC_ARCCONFIG_READINI:
				{
					strlcpy(szSection, "Archive", sizeof(szSection));
					nNum=GetPrivateProfileInt(szSection, "Num", 4,
						szIniFile);
					nMeas=GetPrivateProfileInt(szSection, "Meas", 2,
						szIniFile);
					nRef=GetPrivateProfileInt(szSection, "Ref", 1,
						szIniFile);
				}
				break;

				// Subfunction to write arcconfig data to INI file
				case IDC_ARCCONFIG_WRITEINI:
				{
					strlcpy(szSection, "Archive", sizeof(szSection));
					_snprintf(szBuffer, sizeof(szBuffer), "%d", nNum);
					WritePrivateProfileString(szSection, "Num", szBuffer,
						szIniFile);
					_snprintf(szBuffer, sizeof(szBuffer), "%d", nMeas);
					WritePrivateProfileString(szSection, "Meas", szBuffer,
						szIniFile);
					_snprintf(szBuffer, sizeof(szBuffer), "%d", nRef);
					WritePrivateProfileString(szSection, "Ref", szBuffer,
						szIniFile);
				}
				break;

				// Respond to OK buttom message
                case IDC_ARCCONFIG_ACCEPT:
                {
					// Write arcconfig values to INI file
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_ARCCONFIG_WRITEINI, 0, 0));
                    EndDialog (hDlg, 0);
				}
				break;

                 // Respond to esc key or cancel button
                case IDCANCEL:
                case IDC_ARCCONFIG_CANCEL:
                {
					// Restore original values
					nNum=nPrevNum;
					nMeas=nPrevMeas;
					nRef=nPrevRef;
					
					EndDialog (hDlg, 0);
                }
                return TRUE;
            }
        }
        break;
	 }
     return FALSE;
}
#endif

/*****************************************************************************/
/*                                                                           */
/*                   Norm Dialog Procedure                                   */
/*                                                                           */
/*  Revision record:                                                         */
/*      11/03/96    Added increment file extension logic                     */
/*      01/01/97    Added saving of offset removed                           */
/*		10/03/01	Added bBusy usage                                        */
/*		11/18/06	Added CreateTab() call                                   */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK NormDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam)
{
    // Local variables
	static F_TYPE fAvg;             // Average value
    char szBuffer[BUFFER_SIZE+1];   // Text buffer

    LoadIcon(hInst, "FlatNormIcon");

    switch(message)
    {
		case WM_INITDIALOG:
        {
            // Write prompt message
            WritePromptMessage(TB_NORM);

            // Set global dialog box handle
            hDialog=hDlg;

            // Find the average value
            CalcMean(fData, &fAvg, bDataType);

            // Display the average
            _snprintf(szBuffer, sizeof(szBuffer), "%10.6e", fAvg);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_NORM_AVERAGE), szBuffer);
		}
		return TRUE;

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::NORMALIZE_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::NORMALIZE_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "NORMALIZE_FUNCTION");
					#endif
				}
				break;

				case IDOK:
				{
					// Display wait cursor
					SetCursor(hWait);

                    // Create tab to save previous data if requested
					if(bTabs && bTabChange)
					{
						CreateTab();
					}
						
					// Set busy flag
					bBusy=TRUE;

					// Normalize data
					NormalizeData(fData, fAvg, bDataType);

					// Set data changes flag
					if(bDataType==FREQ_DATA)
					{
						// Save freq offset removed
						fFreqOffsetRemoved=fAvg;

						// Put info into log file
						_snprintf(szBuffer, sizeof(szBuffer), "Mean=%e", fAvg);
						ShortenExp(szBuffer);
						WriteLog(13, szBuffer);
								
						// Set flags
						bFreqDataChanged=TRUE;
						bFreqDataUnsaved=TRUE;
						bFreqScaleChanged=TRUE;
						bFreqNorm=TRUE;
						bFreqRedraw=TRUE;

						// Increment filename
						if(bIncExtension)
						{
							IncExtension(szFile, FREQ_DATA);
							IncExtension(szFileTitle, FREQ_DATA);
							IncExtension(szFreqFile, FREQ_DATA);
							IncExtension(szFreqFileTitle, FREQ_DATA);
							SetWindowText(hwndFreqFilename, szFileTitle);
						}
					}
					else // Phase data
					{
						// Save phase offset removed
						fPhaseOffsetRemoved=fAvg;

						// Put info into log file
						_snprintf(szBuffer, sizeof(szBuffer), "Mean=%e", fAvg);
						ShortenExp(szBuffer);
						WriteLog(12, szBuffer);
								
						// Set flags
						bPhaseDataChanged=TRUE;
						bPhaseDataUnsaved=TRUE;
						bPhaseScaleChanged=TRUE;
						bPhaseNorm=TRUE;
						bPhaseRedraw=TRUE;


						// Increment filename
						if(bIncExtension)
						{
							IncExtension(szFile, PHASE_DATA);
							IncExtension(szFileTitle, PHASE_DATA);
							IncExtension(szPhaseFile, PHASE_DATA);
							IncExtension(szPhaseFileTitle, PHASE_DATA);
							SetWindowText(hwndPhaseFilename, szFileTitle);
						}
					}

					// Force new PSD plot scale
					sPSPlot.y_tic=0;

					// Redraw status plots from new data
					UpdateStatusBar(hwndMain, NEW_DATA);

					// Reset redraw flags
					bPhaseRedraw=FALSE;
					bFreqRedraw=FALSE;

					// Clear synch flag
					bSynch=FALSE;

					// Clear plot lines
					ClearLines();

					// Display normal cursor
					SetCursor(hArrow);

					// Set busy flag
					bBusy=FALSE;

					// Close normalize dialog
					EndDialog (hDlg, 0);

					// Did we normalize in response to phase plot?
					if(bNormPhasePlot)
					{
						// Clear flag
						bNormPhasePlot=FALSE;

						// Set plot type
						nPlotType=PHASE_PLOT;

						// Open dialog box
						InvokeDialogBox(hInst, "PlotBox", hwndMain,
							(DLGPROC)PlotDlgProc);

						// Save configuration info in INI file
						WriteIni(INI_PHASE);

						// Refresh status plots
						SendMessage(hwndMain, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_REFRESH, 0, 0));
					}

					// Did we normalize in response to freq plot?
					if(bNormFreqPlot)
					{
						// Clear flag
						bNormFreqPlot=FALSE;

						// Set plot type
						nPlotType=FREQ_PLOT;

						// Open dialog box
						InvokeDialogBox(hInst, "PlotBox", hwndMain,
							(DLGPROC)PlotDlgProc);

						// Save configuration info in INI file
						WriteIni(INI_FREQ);

						// Refresh status plots
						SendMessage(hwndMain, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_REFRESH, 0, 0));
					}
				}
				return TRUE;

				case IDCANCEL:
				{
					// Close normalize dialog
					EndDialog (hDlg, 0);
				}
				return TRUE;
			}
		}
		break;
	 }
	 return FALSE;
}

#ifndef LITE_VER
/*****************************************************************************/
/*                                                                           */
/*                   Fill Dialog Procedure                                   */
/*                                                                           */
/*  Revision record:                                                         */
/*      11/03/96    Added increment file extension logic                     */
/*      11/19/96    Added updating of # data points                          */
/*		05/19/02	Added adjustment of timetags                             */
/*		11/18/06	Added CreateTab() call                                   */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK FillDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	static int nGaps;               // # gaps
	int nTop;						// # gaps removed from beginning of data
	int i;							// Index
	char szBuffer[BUFFER_SIZE+1];   // Text buffer

	LoadIcon(hInst, "FlatFillIcon");

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Write prompt message
			WritePromptMessage(TB_FILL);

			// Set global dialog box handle
			hDialog=hDlg;

			// Find the # of gaps value
			nGaps=CountGaps(fData, bDataType);

			// Display the # of gaps
			_snprintf(szBuffer, sizeof(szBuffer), "%d", nGaps);
			SetWindowText(GETHCTL(IDC_FILL_GAPS), szBuffer);
		}
		return TRUE;

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::FILL_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::FILL_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "FILL_FUNCTION");
					#endif
				}
				break;

				case IDOK:
				{
					if(nGaps)
					{
						// Display wait cursor
						SetCursor(hWait);

						// Create tab to save previous data if requested
						if(bTabs && bTabChange)
						{
							CreateTab();
						}
						
						// Fill gaps in data
						nTop=FillGaps(fData, bDataType);

						// Gaps at beginning and end of file are removed, not
						// filled, so # data points may have changed
						
						// New comments 05/18/02
						// What about timetags?  If gaps were removed at
						// beginning of data file, then the same # of
						// beginning timetags should be removed.  Otherwise,
						// the timetags can remain the same.  The FillGaps()
						// function is also used for temporary gap removal, and
						// that will not alter the timetags, which is done here.
						// In order to adjust the beginning of file timetags,
						// the FillGap() function returns
						// the # of such gaps removed.

						// Adjust timetags if leading gaps were removed
						if(nTop)
						{
							// Adjust freq timetags if any
							if( (bDataType==FREQ_DATA) && (bFreqTimetags) )
							{
								// Shift timetags up as required
								for(i=ARRAY_OFFSET;
									i<((int)fData[0])+ARRAY_OFFSET; i++)
								{
									fFreqTimetags[i]=fFreqTimetags[i+nTop];
								}

								// Adjust timetag array limits
								fFreqTimetags[0]=fData[0];
								fFreqTimetags[1]=fData[1];
								fFreqTimetags[2]=fData[2];
							}

							// Adjust phase timetags if any
							if( (bDataType==PHASE_DATA) && (bPhaseTimetags) )
							{
								// With phase data, where a leading zero is
								// considered a data point, there is no way to
								// say whether a block of leading zeros
								// is all gaps.
								// We are going to leave one zero
								// at the beginning.
								// Shift timetags up as required
								for(i=ARRAY_OFFSET;
									i<((int)fData[0])+ARRAY_OFFSET; i++)
								{
									fPhaseTimetags[i]=fPhaseTimetags[i+nTop];
								}

								// Adjust timetag array limits
								fPhaseTimetags[0]=fData[0];
								fPhaseTimetags[1]=fData[1];
								fPhaseTimetags[2]=fData[2];
							}
						}

						// Update status display
						if(bDataType==FREQ_DATA)
						{
							// Put info into log file
							_snprintf(szBuffer, sizeof(szBuffer), "#=%d",
								nGaps);
							WriteLog(15, szBuffer);

							// Update display
							_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
								(int)fData[0]);
							SetWindowText(hwndFreqNum, szBuffer);
							SetWindowText(hwndFreqEnd, szBuffer);
							_snprintf(szBuffer, sizeof(szBuffer), "%5.0d", 1);
							SetWindowText(hwndFreqStart, szBuffer);
							bFreqDataChanged=TRUE;
							bFreqDataUnsaved=TRUE;
							sFPlot.new_file=TRUE;
							bFreqScaleChanged=TRUE;
							bFreqGapFill=TRUE;
							nFreqGapsFilled=nGaps;
							bFreqRedraw=TRUE;

							// Increment filename
							if(bIncExtension)
							{
								IncExtension(szFile, FREQ_DATA);
								IncExtension(szFileTitle, FREQ_DATA);
								IncExtension(szFreqFile, FREQ_DATA);
								IncExtension(szFreqFileTitle, FREQ_DATA);
								SetWindowText(hwndFreqFilename, szFileTitle);
							}
						}
						else // Phase data
						{
							// Put info into log file
							_snprintf(szBuffer, sizeof(szBuffer), "#=%d",
								nGaps);
							WriteLog(14, szBuffer);
								
							// Update dsiplay
							_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
								(int)fData[0]);
							SetWindowText(hwndPhaseNum, szBuffer);
							SetWindowText(hwndPhaseEnd, szBuffer);
							_snprintf(szBuffer, sizeof(szBuffer), "%5.0d", 1);
							SetWindowText(hwndPhaseStart, szBuffer);
							bPhaseDataChanged=TRUE;
							bPhaseDataUnsaved=TRUE;
							bPhaseScaleChanged=TRUE;
							bPhaseGapFill=TRUE;
							nPhaseGapsFilled=nGaps;
							bPhaseRedraw=TRUE;

							// Increment filename
							if(bIncExtension)
							{
								IncExtension(szFile, PHASE_DATA);
								IncExtension(szFileTitle, PHASE_DATA);
								IncExtension(szPhaseFile, PHASE_DATA);
								IncExtension(szPhaseFileTitle, PHASE_DATA);
								SetWindowText(hwndPhaseFilename, szFileTitle);
							}
						}

						// Force new PSD plot scale
						sPSPlot.y_tic=0;

						// Redraw status plots from new data
						UpdateStatusBar(hwndMain, NEW_DATA);

						// Clear synch flag
						bSynch=FALSE;

						// Clear plot lines
						ClearLines();

						// Display normal cursor
						SetCursor(hArrow);
					}
				}
				// Go right into EndDialog()
				case IDCANCEL:
				{
					EndDialog (hDlg, 0);
				}
				return TRUE;
			}
		}
		break;
	 }
	 return FALSE;
}
#endif

/*****************************************************************************/
/*                                                                           */
/*                   Convert Dialog Procedure                                */
/*                                                                           */
/*      Revision record:                                                     */
/*          10/06/96        Changed graying of norm & timetag checkboxes     */
/*                          Grayed conversion for which there is no data     */
/*          11/03/96        Added new filename transfer & increment logic    */
/*          12/19/96        Added update of previous file list after conv    */
/*          12/20/96        Added update of plot menu after conversion       */
/*          04/10/96        Changed to use analysis limits                   */
/*          06/03/97        Clear plot lines in converted data               */
/*			05/01/98		Changed to use ConvertData()                     */
/*			11/10/99		Added bFreqTimetags and bPhaseTimetags to        */
/*							bTransfer logic to fix potential runtime error   */
/*			05/22/01		Added control of adjusting zero freq.  If freq   */
/*							data, top checkbox is normalize, and is always   */
/*							activated.  If phase data top checkbox is adj,   */
/*							and is activated only if there is at least one   */
/*							pair of equal adjacent phase points.  In that    */
/*							case, if box is checked, freq is set to 1e-99.   */
/*			03/17/02		Clear previous timetags of converted data        */
/*			09/27/02		Added use timetags flag and method               */
/*			03/19/08		Added nFTag arg to ConvertData() call            */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK ConvertDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	static BOOL bNormalize=FALSE;   // Normalization flag
	static BOOL bTransfer=FALSE;    // Transfer flag
	static BOOL bZeroFreq=FALSE;	// Zero frequency flag
	UINT wConvType;                 // Conversion type
	F_TYPE fD;						// First difference
	// char szBuffer[BUFFER_SIZE+1];   // Text buffer

	LoadIcon(hInst, "FlatConvIcon");

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Write prompt message
			WritePromptMessage(TB_CONV);

			// Read the global normalize flag
			bNormalize=bGlobalNormFreq;

			// Initialize
			if(bDataType==FREQ_DATA)
			{
				// Set local transfer flag
				bTransfer=(bGlobalXferTags && bFreqTimetags);

				// Initialize the normalize checkbox
				Button_SetCheck(GETHCTL(IDC_CONV_NORM), bNormalize);

				// Reset the bUseTags flag if there are no timetags
				if(!bFreqTimetags)
				{
					bUseTags=FALSE;
				}
			}
			else // Phase data
			{
				// Set local transfer flag
				bTransfer=(bGlobalXferTags && bPhaseTimetags);

				// Initialize the adjust checkbox
				Button_SetCheck(GETHCTL(IDC_CONV_NORM), bNoZeroFreq);

				// Reset the bUseTags flag if there are no timetags
				if(!bPhaseTimetags)
				{
					bUseTags=FALSE;
				}

				// Check for zero frequency
				// (two adjacent phase data points the same)
				// and enable adj checkbox if have any
				bZeroFreq=FALSE;
				CalcFirstDiff(fPhaseData, &fD);
				if(fD==0.0)
				{
					// Set the zero freq flag
					bZeroFreq=TRUE;
				}

				// Enable adjust frequency check box if have zero freq points
				EnableWindow(GETHCTL(IDC_CONV_NORM), bZeroFreq);
			}	

			// Initialize the use timetags checkbox
			Button_SetCheck(GETHCTL(IDC_CONV_USETAGS), bUseTags);

			// Enable the use timetags check box if phase data with timetags
			EnableWindow(GETHCTL(IDC_CONV_USETAGS), 
				((bDataType==PHASE_DATA)&&(bPhaseTimetags)));

			// If the global flag to force timetag transfer is set
			// then set the local flag, and reset the global one
			// This supports regularization in automatic scripting
			if(bForceTagTransfer)
			{
				bTransfer=TRUE;
				bForceTagTransfer=FALSE;
			}

			// Initialize the transfer timetags checkbox
			Button_SetCheck(GETHCTL(IDC_CONV_TAGS), bTransfer);

			// Set the conversion type for from the current data type
			if(bDataType==FREQ_DATA)
			{
				Button_SetCheck(GETHCTL(IDC_CONV_FTOP), TRUE);

				// Initialize the transfer timetags checkbox
				if(!bFreqTimetags)
				{
					// Disable transfer timetags check box
					EnableWindow(GETHCTL(IDC_CONV_TAGS), FALSE);
					bTransfer=FALSE;
				}

				// Disable phase to freq conv if no phase data
				if(!bPhaseData)
				{
					// Disable phase to freq conv
					EnableWindow(GETHCTL(IDC_CONV_PTOF), FALSE);
				}

				// Set top checkbox text to normalize
				SetWindowText(GETHCTL(IDC_CONV_NORM), "&Normalize Frequency");
			}
			else // Phase data
			{
				Button_SetCheck(GETHCTL(IDC_CONV_PTOF), TRUE);

				// Initialize the transfer timetags checkbox
				if(!bPhaseTimetags)
				{
					// Disable transfer timetags check box
					EnableWindow(GETHCTL(IDC_CONV_TAGS), FALSE);
					bTransfer=FALSE;
				}

				// Disable freq to phase conv if no freq data
				if(!bFreqData)
				{
					// Disable freq to phase conv
					EnableWindow(GETHCTL(IDC_CONV_FTOP), FALSE);
				}

				// Set top checkbox text to adjust
				SetWindowText(GETHCTL(IDC_CONV_NORM),
					"&Adjust Zero Frequency");
			}
		}
		return TRUE;

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				// Respond to help button
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::CONVERT_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::CONVERT_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "CONVERT_FUNCTION");
					#endif
				}
				break;

				// Respond to frequency to phase checkbox
				case IDC_CONV_FTOP:
				{
					// Set top checkbox text to normalize
					SetWindowText(GETHCTL(IDC_CONV_NORM),
						"&Normalize Frequency");

					// Initialize the normalize checkbox
					Button_SetCheck(GETHCTL(IDC_CONV_NORM), bNormalize);

					// Enable normalize frequency check box
					EnableWindow(GETHCTL(IDC_CONV_NORM), TRUE);

					// Disable use timetags check box
					EnableWindow(GETHCTL(IDC_CONV_USETAGS), FALSE);

					if(bFreqTimetags)
					{
						// Enable transfer timetags check box
						EnableWindow(GETHCTL(IDC_CONV_TAGS), TRUE);
					}
					else
					{
						// Disable transfer timetags check box
						EnableWindow(GETHCTL(IDC_CONV_TAGS), FALSE);
					}
				}
				break;

				// Respond to phase to frequency checkbox
				case IDC_CONV_PTOF:
				{
					// Set top checkbox text to adjust
					SetWindowText(GETHCTL(IDC_CONV_NORM),
						"&Adjust Zero Frequency");

					// Initialize the adjust checkbox
					Button_SetCheck(GETHCTL(IDC_CONV_NORM), bNoZeroFreq);

					// Enable adj frequency check box have zero freq points
					EnableWindow(GETHCTL(IDC_CONV_NORM), bZeroFreq);

					if(bPhaseTimetags)
					{
						// Enable transfer timetags check box
						EnableWindow(GETHCTL(IDC_CONV_TAGS), TRUE);

						// Enable use timetags check box
						EnableWindow(GETHCTL(IDC_CONV_USETAGS), TRUE);
					}
					else
					{
						// Disable transfer timetags check box
						EnableWindow(GETHCTL(IDC_CONV_TAGS), FALSE);
					}
				}
				break;

				case IDOK:
				{
					// Display wait cursor
					SetCursor(hWait);

					// Set busy flag
					bBusy=TRUE;

					// Get conversion type and test that source data exists
					wConvType=NO_CONVERSION;

					// Get use tags flag state
					bUseTags=Button_GetCheck(GETHCTL(IDC_CONV_USETAGS));

					if(Button_GetCheck(GETHCTL(IDC_CONV_PTOF)) && bPhaseData)
					{
						wConvType=PHASE_TO_FREQ;

						// Clear freq timetag arrays
						// Don't want to have old timetag data that may have
						// different # of data points
						ClearTimetagArray(FREQ_DATA);

						// Get adjust flag
						bNoZeroFreq=Button_GetCheck(GETHCTL(IDC_CONV_NORM));

						// Put info into log file
						WriteLog(18, "");
					}
					else if(Button_GetCheck(GETHCTL(IDC_CONV_FTOP)) &&
						bFreqData)
					{
						wConvType=FREQ_TO_PHASE;

						// Clear phase timetag arrays
						// Don't want to have old timetag data that may have
						// different # of data points
						ClearTimetagArray(PHASE_DATA);

						// Get normalization flag
						bNormalize=Button_GetCheck(GETHCTL(IDC_CONV_NORM));

						if(bNormalize)
						{
							// Put info into log file
							WriteLog(19, "");
						}
						else
						{
							// Put info into log file
							WriteLog(20, "");
						}
					}

					// Get transfer timetags flag
					bTransfer=Button_GetCheck(GETHCTL(IDC_CONV_TAGS));

					// Perform conversion
					if(ConvertData(wConvType, bNormalize, bTransfer,
						TRUE, bUseTags, nFTag)==0)
					{
						// Reset busy flag
						bBusy=FALSE;

						// Display normal cursor
						SetCursor(hArrow);

						// Activate data-dependent functions
						ActivateFunctions(MF_ENABLED);

						// Bail out
						EndDialog(hDlg, 0); // Error during conversion
						return TRUE;
					}

					// Save the global flags
					bGlobalNormFreq=bNormalize;
					bGlobalXferTags=bTransfer;
				
					// Display normal cursor
					SetCursor(hArrow);

					// Reset busy flag
					bBusy=FALSE;

					// Activate data-dependent functions
					ActivateFunctions(MF_ENABLED);

					// Update tab control
					if(bTabs)
					{
						UpdateTabControl();
					}
				}
				 // Go right into EndDialog()
				case IDCANCEL:
				{
					EndDialog(hDlg, 0);
				}
				return TRUE;
			}
		}
		break;
	 }
	 return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*                         ConvertData()                                     */
/*                                                                           */
/*		Function to convert between phase and frequency data.                */
/*                                                                           */
/*      Parameters:                                                          */
/*			UINT wConvType		Conversion type                              */
/*			BOOL bNormalize     Normalization flag                           */
/*			BOOL bTransfer      Normalization flag                           */
/*			BOOL bUpdate		Update status bar plots flag                 */
/*			BOOL bUseTags		Flag to use timetags as tau for p->f conv    */
/*			int  nFTag			Code for type of freq timetag:               */
/*								FTAG_FIRST, FTAG_MID or FTAG_LAST            */
/*                                                                           */
/*      Return: int code		1=OK, 0=NG                                   */
/*                                                                           */
/*                                                                           */
/*      Revision record:                                                     */
/*          05/01/98    Adapted from ConvertDlgProc()                        */
/*			09/10/98	Added bUpdate argument                               */
/*			06/13/99	Added return code                                    */
/*			05/22/01	Changed to NewConvPhaseToFreq()                      */
/*			08/28/02	Changed to NewConvFreqToPhase()                      */
/*			09/27/02	Added bUseTags parameter                             */
/*			03/15/03	Use ConvFreqToPhase() w/o New with FrequenC DLL V2.0 */
/*			07/10/03	Added removal of duplicate timetags from phase data  */
/*						and/or filling of gaps caused by missing data        */
/*			10/15/03	Fixed problem with filling gaps                      */
/*			03/01/08	Quietly use absolute value of timetage as tau        */
/*						in case they are reversed                            */
/*			03/19/08	Added nFTag argument                                 */
/*                                                                           */
/*****************************************************************************/

int WINAPI ConvertData(UINT wConvType, BOOL bNormalize, BOOL bTransfer,
		BOOL bUpdate, BOOL bUseTags, int nFTag)
{
	// Local variables
	int i;                          // Index
	int j;                          // Secondary index
	int nPoints;                    // # data points to convert
	int nGaps;						// # gaps in data
	int nMissingPoints;				// # missing points in data
	int nResponse;					// Response code from message box
	char szBuffer[BUFFER_SIZE+1];   // Text buffer
	F_TYPE fTau;                    // Tau value
	F_TYPE fAvgTau;					// Average tau value from timetags
	F_TYPE fDelta;					// Timetag increment

	#if(0)  // For testing
	TRACE_INT(nFTag);
	#endif
	
	// Make sure data type is right
	if(wConvType==PHASE_TO_FREQ) // Phase to freq conv
	{
		// Set data type to phase data
		bDataType=PHASE_DATA;
	}
	else if(wConvType==FREQ_TO_PHASE)
	{
		// Set data type to freq data
		bDataType=FREQ_DATA;
	}

	// Clear data array being converted to
	// This resets all process flags
	// & will elim obsolete plot messages
	ClearDataArray(1-bDataType);

	// Reallocate memory
	if(wConvType==PHASE_TO_FREQ) // Phase to freq conv
	{
		// Get tau of phase data
		GetWindowText(hwndPhaseTau, szBuffer,
			BUFFER_SIZE);
		fTau=(F_TYPE)atof(szBuffer);

		// reallocate freq data array
		// size of freq data array is # phase points+2
		nPoints=(int)(fPhaseData[2]-fPhaseData[1]+1);

		// Note: +4 required to avoid crash
		if((fNew=(F_TYPE*)realloc((char *)fFreqData,
			(nPoints+4)*sizeof(F_TYPE)))==NULL)
		{
			// Activate data-dependent functions
			ActivateFunctions(MF_ENABLED);

			// Display error message and abort
			AllocErrorMessage();
			return 0; // Note: The original freq data was cleared
		}
		else
		{
			fFreqData=fNew;
		}
		fData=fFreqData;

		// Perform conversion
		if(bUseTags)
		{
			// Perform conversion unless there are duplicate timetags
			// in which case this function will return -1
			i=ConvPhaseToFreqUsingTimetags(fPhaseData, fFreqData,
				fPhaseTimetags, fPhaseTagScale, &fAvgTau, bNoZeroFreq);

			// Check for missing points
			RegularizeCount(fPhaseData, fPhaseTimetags, &nGaps,
					&nMissingPoints);

			// Check for error indicating 1 or more duplicate timetags
			// or if there are any missing points
			if( (i==-1) || (nMissingPoints>0) )
			{
				if(i==-1)
				{
					// Count duplicated timetags
					i=CountEqualTimetags(fPhaseData, fPhaseTimetags);

					if(!bAuto)
					{
						// Compose message
						_snprintf(szBuffer, sizeof(szBuffer), "%d", i);
						strlcat(szBuffer, " Equal Adjacent Timetag(s) Found\n"
							"Duplicate Phase Data Will Be Removed\n"
							"Before Performing Conversion", sizeof(szBuffer));

						// Display message
						nResponse=MessageBox(hwndMain, szBuffer,
							"Duplicate Timetags", MB_OKCANCEL);

						// Quit is user want to
						if(nResponse==IDCANCEL)
						{
							// Abort
							return 0;
						}
					}

					// Remove duplicated timetags
					i=ElimEqualTimetags(fPhaseData, fPhaseTimetags);

					// Set new # phase points
					nPoints=(int)(fPhaseData[2]-fPhaseData[1]+1);

					// Reallocate phase data array
					if((fNew=(F_TYPE*)realloc((char *)fPhaseData,
						(nPoints+ARRAY_OFFSET)*sizeof(F_TYPE)))==NULL)
					{
						// Activate data-dependent functions
						ActivateFunctions(MF_ENABLED);

						// Display error message and abort
						AllocErrorMessage();
						return 0; // Note: The original freq data was cleared
					}
					else
					{
						fPhaseData=fNew;
					}
				}

				// Remove and fill gaps
				// Get # of missing points
				RegularizeCount(fPhaseData, fPhaseTimetags, &nGaps,
					&nMissingPoints);

				// Are there missing points?
				if(nMissingPoints)
				{
					if(!bAuto)
					{
						// Compose message
						_snprintf(szBuffer, sizeof(szBuffer),
							"%d", nMissingPoints);
						strlcat(szBuffer, " Missing Point(s) Found\n"
							"Gap(s) Will Be Filled\n"
							"Before Performing Conversion", sizeof(szBuffer));

						// Display message
						nResponse=MessageBox(hwndMain, szBuffer,
							"Missing Points", MB_OKCANCEL);

						// Quit if user wants to
						if(nResponse==IDCANCEL)
						{
							// Abort
							return 0;
						}
					}
					
					// Increment # phase data points
					nPoints+=nMissingPoints;

					// Fill gaps in phase data
					// Reallocate phase data array
					// NOTE 10/30/03: Sometimes have to increase size of
					// this and next array to aviod crash when converting
					// Squid data
					// +100 required in some cases
					// Don't understand
					if((fNew=(F_TYPE*)realloc((char *)fPhaseData,
						(nPoints+0+ARRAY_OFFSET)*sizeof(F_TYPE)))==NULL)
					{
						// Activate data-dependent functions
						ActivateFunctions(MF_ENABLED);

						// Display error message and abort
						AllocErrorMessage();
						return 0;
					}
					else
					{
						fPhaseData=fNew;
					}

					// Reallocate phase timetag array
					if((fNew=(F_TYPE*)realloc((char *)fPhaseTimetags,
						(nPoints+0+ARRAY_OFFSET)*sizeof(F_TYPE)))==NULL)
					{
						// Activate data-dependent functions
						ActivateFunctions(MF_ENABLED);

						// Display error message and abort
						AllocErrorMessage();
						return 0;
					}
					else
					{
						fPhaseTimetags=fNew;
					}
					
					// Reallocate freq data array
					if((fNew=(F_TYPE*)realloc((char *)fFreqData,
						(nPoints+4+ARRAY_OFFSET)*sizeof(F_TYPE)))==NULL)
					{
						// Activate data-dependent functions
						ActivateFunctions(MF_ENABLED);

						// Display error message and abort
						AllocErrorMessage();
						return 0;
					}
					else
					{
						fFreqData=fNew;
					}

					// Reallocate freq timetag array
					if((fNew=(F_TYPE*)realloc((char *)fFreqTimetags,
						(nPoints+4+ARRAY_OFFSET)*sizeof(F_TYPE)))==NULL)
					{
						// Activate data-dependent functions
						ActivateFunctions(MF_ENABLED);

						// Display error message and abort
						AllocErrorMessage();
						return 0;
					}
					else
					{
						fFreqTimetags=fNew;
					}

					if(bDataType==FREQ_DATA)
					{
						fData=fFreqData;
						fTags=fFreqTimetags;
					}
					else // Phase data
					{
						fData=fPhaseData;
						fTags=fPhaseTimetags;
					}
					
					// Insert gaps where there are missing points
					RegularizeInsert(fPhaseData, fPhaseTimetags);

					// Fill gaps with interpolated values
					FillGaps(fPhaseData, PHASE_DATA);

					//  Write #, start and end values
					fPhaseData[0]=(F_TYPE)nPoints;
					fPhaseData[1]=(F_TYPE)1.0;
					fPhaseData[2]=fPhaseData[0];
					fPhaseTimetags[0]=(F_TYPE)nPoints;
					fPhaseTimetags[1]=(F_TYPE)1.0;
					fPhaseTimetags[2]=fPhaseData[0];

					// Update phase status display
					_snprintf(szBuffer, sizeof(szBuffer), "%5.0d", nPoints);
					SetWindowText(hwndPhaseNum, szBuffer);
					SetWindowText(hwndPhaseEnd, szBuffer);
					SetWindowText(hwndPhaseStart, "1");
				}
				
				// Convert data with duplicate timetags removed
				ConvPhaseToFreqUsingTimetags(fPhaseData, fFreqData,
					fPhaseTimetags, fPhaseTagScale, &fAvgTau, bNoZeroFreq);
			}

			// Assign tau to average of timetag increments
			// Quietly use absolute value in case timetags are reversed 
			fTau=fabs(fAvgTau);

			// Make freq timetag scale same as one used for conversion
			fFreqTagScale=fPhaseTagScale;
		}
		else // Not using timetags as tau
		{
			ConvPhaseToFreq(fPhaseData, fFreqData, fTau, bNoZeroFreq);
		}

		//  Write #, start and end values
		fFreqData[0]=(F_TYPE)nPoints-1;
		fFreqData[1]=(F_TYPE)1.0;
		fFreqData[2]=fFreqData[0];

		// Update freq status display
		_snprintf(szBuffer, sizeof(szBuffer), "%5.0d", nPoints-1);
		SetWindowText(hwndFreqNum, szBuffer);
		SetWindowText(hwndFreqEnd, szBuffer);
		_snprintf(szBuffer, sizeof(szBuffer), "%5.0d", 1);
		SetWindowText(hwndFreqStart, szBuffer);
		_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fTau);
		ShortenExp(szBuffer);
		SetWindowText(hwndFreqTau, szBuffer);
		bFreqData=TRUE;

		// Copy filenames
		strlcpy(szFreqFile, szPhaseFile, FILE_NAME_SIZE);
		strlcpy(szFreqFileTitle, szPhaseFileTitle, FILE_TITLE_SIZE);
		strlcpy(szFile, szPhaseFile, FILE_NAME_SIZE);
		strlcpy(szFileTitle, szPhaseFileTitle, FILE_TITLE_SIZE);

		// Increment new filename extensions
		IncExtension(szFreqFile, -3);
		IncExtension(szFreqFileTitle, -3);
		IncExtension(szFile, -3);
		IncExtension(szFileTitle, -3);

		// Eliminate all freq plot lines
		for(i=0; i<FLINE_NUMLINES; i++)
		{
			sFLine[i].nLineType=FLINE_NONE;
		}

		// Eliminate all sigma plot lines
		for(i=0; i<SLINE_NUMLINES; i++)
		{
			sSLine[i].nLineType=SLINE_NONE;
		}

		// Display new filename
		SetWindowText(hwndFreqFilename, szFileTitle);

		// Switch status indicators to freq data
		bDataType=FREQ_DATA;
		Button_SetCheck(hwndFreqSelectButton, bDataType);
		Button_SetCheck(hwndPhaseSelectButton, (1-bDataType));

		// Set data pointer to freq data
		fData=fFreqData;

		// Put previous freq file list into file menu
		UpdateFileInfo(szPreviousFreqFilename);

		// Activate data-dependent functions
		ActivateFunctions(MF_ENABLED);

		// Set data change flag
		bFreqDataChanged=TRUE;
		bFreqDataUnsaved=TRUE;
		sFPlot.new_file=TRUE;
		bFreqScaleChanged=TRUE;
		bSynch=TRUE;

		// Force new PSD plot scale
		sPSPlot.y_tic=0;

		// Transfer phase timetags to freq array
		if(bTransfer)
		{
			// Reallocate freq timetag array
			// Size of freq data array is # phase points+2
			if((fNew=(F_TYPE*)realloc((char *)
				fFreqTimetags, (nPoints+2)*
				sizeof(F_TYPE)))==NULL)
			{
				AllocErrorMessage();
				// The best thing to do now is to clear the freq timetags
				ClearTimetagArray(FREQ_DATA);
				bFreqTimetags=FALSE;
				return 0;
			}
			else
			{
				fFreqTimetags=fNew;
			}
			fTags=fFreqTimetags;

			// Transfer timetags
			j=3;
			for(i=(int)fPhaseData[1]+2; i<(int)fPhaseData[2]+2; i++)
			{
				// New code 03/19/08
				// Original code was FTAG_FIRST type only
				// New freq timetag type code and macros
				// Choose freq timetag type
				switch(nFTag)
				{
					case FTAG_FIRST:
					{
						// Freq timetag is 1st phase timetag
						fFreqTimetags[j]=fPhaseTimetags[i];
					}
					break;

					case FTAG_MID:
					{
						// Freq timetag is avg of phase timetags
						fFreqTimetags[j]=(fPhaseTimetags[i]+fPhaseTimetags[i+1])/2;
					}
					break;

					case FTAG_LAST:
					{
						// Freq timetag is 2nd phase timetag
						fFreqTimetags[j]=fPhaseTimetags[i+1];
					}
					break;
				}
				j++;
			}

			//  Write #, start and end values
			fFreqTimetags[0]=fFreqData[0];
			fFreqTimetags[1]=fFreqData[1];
			fFreqTimetags[2]=fFreqData[2];

			// Set freq timetag flag
			bFreqTimetags=TRUE;
		}

		if(bUpdate)
		{
			// Set redraw flags
			bFreqRedraw=TRUE;
			bPhaseRedraw=TRUE;

			// Redraw status plots
			UpdateStatusBar(hwndMain, NEW_DATA);
		}
	}
	else if(wConvType==FREQ_TO_PHASE)
	{
		// Get tau of freq data
		GetWindowText(hwndFreqTau, szBuffer,
			BUFFER_SIZE);
		fTau=(F_TYPE)atof(szBuffer);

		// Reallocate phase data array
		// Size of phase data array is # freq points+4
		nPoints=(int)(fFreqData[2]-fFreqData[1]+1);

		if((fNew=(F_TYPE*)realloc((char *)fPhaseData,
			(nPoints+4)*sizeof(F_TYPE)))==NULL)
		{
			// Activate data-dependent functions
			ActivateFunctions(MF_ENABLED);

			// Display error message and abort
			AllocErrorMessage();
			return 0; // Note: The original phase data was cleared
		}
		else
		{
			fPhaseData=fNew;
		}
		fData=fPhaseData;

		// Perform conversion
		ConvFreqToPhase(fFreqData, fPhaseData, fTau,
			bNormalize);

		//  Write #, start and end values
		fPhaseData[0]=(F_TYPE)nPoints+1;
		fPhaseData[1]=(F_TYPE)1.0;
		fPhaseData[2]=fPhaseData[0];

		// Update phase status display
		_snprintf(szBuffer, sizeof(szBuffer), "%5.0d", nPoints+1);
		SetWindowText(hwndPhaseNum, szBuffer);
		SetWindowText(hwndPhaseEnd, szBuffer);
		_snprintf(szBuffer, sizeof(szBuffer), "%5.0d", 1);
		SetWindowText(hwndPhaseStart, szBuffer);
		_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fTau);
		ShortenExp(szBuffer);
		SetWindowText(hwndPhaseTau, szBuffer);
		bPhaseData=TRUE;

		// Copy filenames
		strlcpy(szPhaseFile, szFreqFile, FILE_NAME_SIZE);
		strlcpy(szPhaseFileTitle, szFreqFileTitle, FILE_TITLE_SIZE);
		strlcpy(szFile, szFreqFile, FILE_NAME_SIZE);
		strlcpy(szFileTitle, szFreqFileTitle, FILE_TITLE_SIZE);

		// Increment new filename extensions
		IncExtension(szPhaseFile, -3);
		IncExtension(szPhaseFileTitle, -3);
		IncExtension(szFile, -3);
		IncExtension(szFileTitle, -3);

		// Eliminate all phase plot lines
		for(i=0; i<PLINE_NUMLINES; i++)
		{
			sPLine[i].nLineType=PLINE_NONE;
		}

		// Eliminate all sigma plot lines
		for(i=0; i<SLINE_NUMLINES; i++)
		{
			sSLine[i].nLineType=SLINE_NONE;
		}

		// Display new filename
		SetWindowText(hwndPhaseFilename, szFileTitle);

		// Switch status indicators to phase data
		bDataType=PHASE_DATA;

		Button_SetCheck(hwndFreqSelectButton, bDataType);
		Button_SetCheck(hwndPhaseSelectButton, (1-bDataType));

		// Put previous freq file list into file menu
		UpdateFileInfo(szPreviousPhaseFilename);

		// Activate data-dependent functions
		ActivateFunctions(MF_ENABLED);

		// Set data change flag
		bPhaseDataChanged=TRUE;
		bPhaseDataUnsaved=TRUE;
		bPhaseScaleChanged=TRUE;
		bSynch=TRUE;

		// Force new PSD plot scale
		sPSPlot.y_tic=0;

		// Transfer freq timetags to phase array
		if(bTransfer)
		{
			// Reallocate phase timetag array
			// Size of phase data array is # freq points+4
			if((fNew=(F_TYPE*)realloc((char *)
				fPhaseTimetags, (nPoints+4)*
				sizeof(F_TYPE)))==NULL)
			{
				AllocErrorMessage();
				// The best thing to do now is to clear the phase timetags
				ClearTimetagArray(PHASE_DATA);
				bPhaseTimetags=FALSE;
				return 0;
			}
			else
			{
				fPhaseTimetags=fNew;
			}
			fTags=fPhaseTimetags;

			// Transfer timetags
			j=3;

			#if(0)
			// Create a new last phase timetag:
			fPhaseTimetags[(int)fFreqData[2]+3]=
				fFreqTimetags[(int)fFreqData[2]+2] +
				(fFreqTimetags[(int)fFreqData[2]+2] -
				fFreqTimetags[(int)fFreqData[2]+1]);
			#endif

			// Get freq timetag increment from 1st two freq timetags
			fDelta=fFreqTimetags[(int)fFreqData[1]+3]-fFreqTimetags[(int)fFreqData[1]+2];
			
			for(i=(int)fFreqData[1]+2; i<(int)fFreqData[2]+3; i++)
			{
				// New code 03/19/08
				// Original code was FTAG_FIRST type only
				// New freq timetag type code and macros
				// Choose freq timetag type
				switch(nFTag)
				{
					case FTAG_FIRST:
					{
						// Phase timetag is freq timetag
						fPhaseTimetags[j]=fFreqTimetags[i];
					}
					break;

					case FTAG_MID:
					{
						// Freq timetag is avg of phase timetags
						// Phase timetag is next freq timetag minus one-half of increment
						fPhaseTimetags[j]=fFreqTimetags[i]-(fDelta/2);
					}
					break;

					case FTAG_LAST:
					{
						// Freq timetag is 2nd phase timetag
						// Phase timetag is freq timetag minus increment
						fPhaseTimetags[j]=fFreqTimetags[i]-fDelta;
					}
					break;
				}
				j++;
			}

			// Set last phase timetag
			switch(nFTag)
			{
				case FTAG_FIRST:
				{
					// Last phase timetag is last freq timetag plus delta
					fPhaseTimetags[(int)fFreqData[2]+3]=
						fFreqTimetags[(int)fFreqData[2]+2]+fDelta;
				}
				break;

				case FTAG_MID:
				{
					// Last phase timetag is last freq timetag plus one-half of increment
					fPhaseTimetags[(int)fFreqData[2]+3]=
						fFreqTimetags[(int)fFreqData[2]+2]+fDelta/2;
				}
				break;

				case FTAG_LAST:
				{
					// Last phase timetag is last freq timetag
					fPhaseTimetags[(int)fFreqData[2]+3]=
						fFreqTimetags[(int)fFreqData[2]+2];
				}
				break;
			}

			//  Write #, start and end values
			fPhaseTimetags[0]=fPhaseData[0];
			fPhaseTimetags[1]=fPhaseData[1];
			fPhaseTimetags[2]=fPhaseData[2]; // Error fixed 08/15/98

			// Set phase timetag flag
			bPhaseTimetags=TRUE;
		}

		if(bUpdate)
		{
			// Set phase redraw flag
			bPhaseRedraw=TRUE;

			// Redraw phase status plot from new data
			UpdateStatusBar(hwndMain, NEW_DATA);
		}
	}
	else if(wConvType==NO_CONVERSION)
	{
		MessageBeep(0);
		return 1; // OK
	}

	return 1; // OK
}

/*****************************************************************************/
/*                                                                           */
/*                    Stats Dialog Procedure                                 */
/*                                                                           */
/*  Revision record:                                                         */
/*      11/02/96        Added plot                                           */
/*      11/04/96        Added WM_PAINT processing to repaint plot            */
/*      11/15/96        Changed plot so it uses analysis limits              */
/*      12/21/96        Added display of full filename                       */
/*      02/18/97        Improved gap plotting                                */
/*		01/24/98		Added data readout with mouse position               */
/*		01/26/98		Added zoom in/out with mouse buttons                 */
/*		09/09/98		Added faster plotting for large # freq points        */
/*		05/11/01		Added scrollbar                                      */
/*		10/13/02		Added copy feature                                   */
/*		09/16/03		Changed to lag 1 autocorrelation noise ID method     */
/*		08/24/08		Added progress messages                              */
/*		12/29/11		Added X button to delete selected data point         */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK StatsDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local macros
	#define POINTLIMIT 512

    // Local variables
    // Ints
	static int nPoints;             // # data points
	static int nTagType=0;			// Timetag type
    int nGaps;                      // # gaps in data
	int nAlpha;						// Noise type
	static int nAdj;				// Adjust phase plot scale near start
	static int nSelect;				// Index of selected point
	static int nRemove;				// Index of point to remove
	// BOOLS
	static BOOL bTrack=TRUE;		// Flag to track scrollbar motion
	static BOOL bScale=TRUE;		// Flag for "nice" scale factor
									// Tradeoff for using "nice" scale factor
									// is that it changes as data is scrolled
	static BOOL bTags=FALSE;		// Have timetags flag
	static BOOL bUpdate=FALSE;		// Flag to update status bar
	static BOOL bSaveDataType;		// Save original data type
	// F_TYPES
    static F_TYPE fMin;             // Minimum data value
    static F_TYPE fMax;             // Maximum data value
	static F_TYPE fAvg;             // Average data value
	static F_TYPE fSaveStart;		// Save original analysis start point
	static F_TYPE fSaveEnd;			// Save original analysis end point
	static F_TYPE fSaveFreqStart;	// Save original freq analysis start point
	static F_TYPE fSaveFreqEnd;		// Save original freq analysis end point
	static F_TYPE fSavePhaseStart;	// Save original phase analysis start point
	static F_TYPE fSavePhaseEnd;	// Save original phase analysis end point
	static F_TYPE fPlotStart;		// Current plot start data index
	static F_TYPE fPlotEnd;			// Current plot end data index		

    F_TYPE fStdDev;                 // Standard deviation value
    F_TYPE fSigma;                  // Normal Allan deviation value
	F_TYPE fTau;                    // Tau value
    F_TYPE fMedian;                 // Median value
	F_TYPE fZoom;					// Zoom factor
	// Chars
	char szBuffer[BUFFER_SIZE+1];   // Text buffer
	char szName[FILENAMESIZE];		// File name (title w/o ext)
    // Plot variables
    static HWND hStatPlot=NULL;		// Handle to plot window
	static HDC hdcPlot;             // Handle to plot device context
    static RECT rect;						// Plot rectangle
    int i;                          // Data index
    int j;			                // X-axis index
    int nLastY;
    static F_TYPE fRange;           // Plot range
	static F_TYPE fXScale, fYScale; // Plot scale factors
	static F_TYPE fScaleMin;		// Plot scale min
	static F_TYPE fScaleMax;		// Plot scale max
	static int nTicks;				// # plot ticks
	POINT MousePoint;				// Coordinates of mouse
	// Struts
	static SCROLLINFO si;			// Scrollbar info
	// Timetag variables
	// Ints
	int nYear;
	int nDOY;
	int nMonth;
	int nDay;
	int nHour;
	int nMin;
	int nSec;
	static int nSum[] = { 0, 31, 59, 90, 120, 151, 181, 212,
						  243, 273, 304, 334, 365 };
	// Longs
	long lnMJD;
	// F_TYPEs
	F_TYPE fMJD;
	F_TYPE fIntMJD;
	F_TYPE fFractMJD;
	// Peek message
	MSG msg;					    // Message structure for local peek
	// ACF noise ID variables
	float fR1;						// Lag 1 ACF for original data
	float fAlpha;					// Estimated alpha as decimal value

	// Start of code
    LoadIcon(hInst, "FlatStatIcon");

	switch(message)
    {
        case WM_INITDIALOG:
        {
			// Put info into log file
			WriteLog(36, "");

 			// Do this 1st time only
			if(hStatPlot==NULL)
			{
				// Save original data type
				bSaveDataType=bDataType;

				// Save original analysis limits
				fSaveStart=fData[1];
				fSaveEnd=fData[2];
				fSaveFreqStart=fFreqData[1];
				fSaveFreqEnd=fFreqData[2];
				fSavePhaseStart=fPhaseData[1];
				fSavePhaseEnd=fPhaseData[2];
			}

            // Get handle and device context to plot
            hStatPlot=GETHCTL(IDC_STATS_PLOT);
            hdcPlot=GetDC(hStatPlot);

            // Display filename
			// Not enough room for a very long full filename
			// Do best possible by showing it w/o extension
			_splitpath(szFile, NULL, NULL, szName, NULL);
			SetWindowText(GETHCTL(IDC_STATS_FILE), szName);

			// Initialize the track checkbox
			Button_SetCheck(GETHCTL(IDC_STATS_TRACK), bTrack);

			// Disable all button if all data selected
			EnableWindow(GETHCTL(IDC_STATS_ALL),
				!((fData[1]==1) && (fData[2]==fData[0])));

			// Disable swap button if don't have equivalent data
			EnableWindow(GETHCTL(IDC_STATS_SWAP), bSynch);

			// Fill up the timetag type combo box list
            nDummy=ComboBox_ResetContent(GETHCTL(IDC_STATS_TAGTYPE));
            nDummy=ComboBox_InsertString(GETHCTL(IDC_STATS_TAGTYPE), 0,
                    "None");
            nDummy=ComboBox_InsertString(GETHCTL(IDC_STATS_TAGTYPE), 1,
                    "MJD");
            nDummy=ComboBox_InsertString(GETHCTL(IDC_STATS_TAGTYPE), 2,
                    "DOY");
            nDummy=ComboBox_InsertString(GETHCTL(IDC_STATS_TAGTYPE), 3,
                    "Date");
            nDummy=ComboBox_InsertString(GETHCTL(IDC_STATS_TAGTYPE), 4,
                    "Exp");

            // Show selected timetag format
            nDummy=ComboBox_SetCurSel(GETHCTL(IDC_STATS_TAGTYPE), nTagType);

			// Calc and display statistics
            nPoints=(int)(fData[2]-fData[1]+1);

            _snprintf(szBuffer, sizeof(szBuffer), "%d-%d", (int)fData[1],
				(int)fData[2]);
			SetWindowText(GETHCTL(IDC_STATS_POINTS), szBuffer);

            _snprintf(szBuffer, sizeof(szBuffer), "%d", nPoints);
			SetWindowText(GETHCTL(IDC_STATS_PTS), szBuffer);

            nGaps=CountGaps(fData, bDataType);
            _snprintf(szBuffer, sizeof(szBuffer), "%d", nGaps);
			SetWindowText(GETHCTL(IDC_STATS_GAPS), szBuffer);

            FindMinMax(fData, &fMin, &fMax, bDataType);
			_snprintf(szBuffer, sizeof(szBuffer), "%+10.6e", fMin);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_STATS_MIN), szBuffer);
            _snprintf(szBuffer, sizeof(szBuffer), "%+10.6e", fMax);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_STATS_MAX), szBuffer);

            CalcMean(fData, &fAvg, bDataType);
            _snprintf(szBuffer, sizeof(szBuffer), "%+10.6e", fAvg);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_STATS_AVG), szBuffer);

            // Show message
			WriteMessage("Finding Median - Please Wait");

			// Note 09/14/98: FindMedian() of FrequenC DLL alters data
			// when it has a bunch of gaps in the middle
			// So access it via a wrapper function that saves & restores data
			// Part of FrequenC DLL as of 03/18/03
			FindMedian(fData, bDataType, &fMedian);
			_snprintf(szBuffer, sizeof(szBuffer), "%+10.6e", fMedian);

			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_STATS_MED), szBuffer);

            // Show message
			WriteMessage("Median Found");

			// Get std dev & sigma
            if(bDataType==FREQ_DATA)
            {
                CalcFreqStdDev(fFreqData, &fStdDev);
                CalcFreqSigma(fFreqData, &fSigma);
            }
            else // Phase data
            {
				// Get tau of phase data
                GetWindowText(hwndPhaseTau, szBuffer, BUFFER_SIZE);
                fTau=(F_TYPE)atof(szBuffer);

                CalcPhaseStdDev(fPhaseData, &fStdDev, fTau);
                CalcPhaseSigma(fPhaseData, &fSigma, fTau);
            }

            _snprintf(szBuffer, sizeof(szBuffer), "%10.6e", fStdDev);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_STATS_SD), szBuffer);
            _snprintf(szBuffer, sizeof(szBuffer), "%10.6e", fSigma);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_STATS_SIG), szBuffer);

            // Show message
            WriteMessage("Finding Noise Type - Please Wait");

			// ID & show noise type
			// Call ACF noise ID function for AF=1
			// No sigma type applies, so set dmax to 3
			// Has additional 2nd arg
			ACFNoiseID(fData, bDataType, 1, &fR1, &fAlpha, &nAlpha, 3, 0);

			// Trap alpha<-2
			if(nAlpha<-2)
			{
				nAlpha=-2;
			}

            // Display noise type
			_snprintf(szBuffer, sizeof(szBuffer), "%d", nAlpha);
			LoadString(hInst, IDS_STATS_NOISE_0+nAlpha+3, szBuffer,
				BUFFER_SIZE);
			SetWindowText(GETHCTL(IDC_STATS_NOISE), szBuffer);
				
            // Show message
			WriteMessage("Noise Type Found");

			if(bScale)
			{
				// Use FrequenC "nice" plot scale
				nTicks=FindPlotScale(fMin, fMax, &fScaleMin, &fScaleMax);

				// Make scale adjustment to avoid just 2 or 3 divisions
				// This looks better and helps to avoid scale changes
				if(nTicks==3) // Avoid 75/div
				{
					fRange=fScaleMax-fScaleMin;
					fScaleMin-=fRange/6;
					fScaleMax+=fRange/6;
				}
				
				if(nTicks<4)
				{
					nTicks=4;
				}

				// Set scale factors
				fRange=fScaleMax-fScaleMin;
			}
			else // Fixed scale factor
			{
				// Calc plot full scale
				fScaleMax=fMax;
				fScaleMin=fMin;
				fRange=fScaleMax-fScaleMin;

				// Use fixed # ticks
				nTicks=4;
			}

            // Display plot title
			if(bDataType==FREQ_DATA)
			{
				LoadString(hInst, IDS_FORMAT_30, szName, 11);
			}
			else // Phase data
			{
				LoadString(hInst, IDS_FORMAT_31, szName, 12);
			}

			// Add per div scale factor scale to title
			if(bScale)
			{
				_snprintf(szBuffer, sizeof(szBuffer), "  (%1.0e/div)",
					fRange/nTicks);
			}
			else // Fixed scale needs to show more digits
			{
				_snprintf(szBuffer, sizeof(szBuffer), "  (%3.2e/div)",
					fRange/nTicks);
			}
			 
			ShortenExp(szBuffer);
			strlcat(szName, szBuffer, sizeof(szName));
			SetWindowText(GETHCTL(IDC_STATS_TITLE), szName);

			// Disable timetag type combo box if timetag data doesn't exist
			if(bDataType==FREQ_DATA)
			{
				bTags=bFreqTimetags;
			}
			else
			{
				bTags=bPhaseTimetags;
			}
			EnableWindow(GETHCTL(IDC_STATS_TAGTYPE), bTags);

			// Setup the horizontal scrollbar
			si.cbSize=sizeof(si);
			si.fMask=SIF_ALL;
			// The range of the horizontal scrollbar for the data plot
			// extends from 1 to the # of data points
			si.nMin=1;
			si.nMax=(int)fData[0];
			// The page parameter determines the size of the scroll box (thumb)
			// It is set to the plot width (# points in plot)  
			si.nPage=(int)(fData[2]-fData[1]+1);
			// Start with the scroll box in the center
			// The position can be from 1 to the total # data points - the size
			// of the plot plus 1 - it is set to the 1st analysis point #
			si.nPos=(int)fData[1];
				
			// Put info into scrollbar
			SetScrollInfo(GETHCTL(IDC_STATS_SCROLL), SB_CTL, &si, TRUE);

			// Show the zoom factor
			fZoom=fData[0]/si.nPage;
			if(fZoom<1000)
			{
				_snprintf(szBuffer, sizeof(szBuffer), "Zoom: %3.1f X", fZoom);
			}
			else
			{
				_snprintf(szBuffer, sizeof(szBuffer), "Zoom: %4.0f X", fZoom);
			}
			SetWindowText(GETHCTL(IDC_STATS_ZOOM), szBuffer);

			// Write prompt message
			WritePromptMessage(TB_STAT);
		}
		return TRUE;

        // Repaint plot when necessary (such as after invoking help)
        // Ref: C. Petzold "Programming Windows 3.1", p.434
        case WM_PAINT:
        {
            InvalidateRect(hStatPlot, NULL, TRUE);
            UpdateWindow(hStatPlot);
			SendMessage(hDlg, WM_COMMAND,
				GET_WM_COMMAND_MPS(IDC_STATS_PLOTDATA, NULL, 0));

			// Write prompt message
			WritePromptMessage(TB_STAT);
        }
        break;

		// Respond to left mouse button to zoom out
		case WM_LBUTTONDOWN:
		{
            // Get plot window screen coordinates
            GetWindowRect(hStatPlot, &rect);

			// Get mouse cursor position in screen coordinates
			GetCursorPos(&MousePoint);

			// Is mouse in plot region?
			if(PtInRect(&rect, MousePoint))
			{
	            // Get plot location in client coordinates
				// wrt top left = (0,0)
				GetClientRect(hStatPlot, &rect);
					
				// Convert mouse position to plot window client coordinates
				ScreenToClient(hStatPlot, &MousePoint);
				
				// Calc point # at mouse position
				nPoints=(int)(fData[2]-fData[1]+1);
				fXScale=(F_TYPE)(rect.right-rect.left);
				i=(int)(MousePoint.x*nPoints/fXScale)+(int)(fData[1]);
				
				// Zoom out phase data analysis limits by factor of 2
				if( (fData[1]>1) || (fData[2]<fData[0]) )
				{
					// Center zoom range on mouse position
					fData[1]=max((F_TYPE)(i-nPoints), 1);
					fData[2]=min((F_TYPE)(i+nPoints), fData[0]);
				}
				else
				{
					MessageBeep(1);
					break;
				}

				if(bUpdate)
				{
					if(bDataType==FREQ_DATA)
					{
						// Update freq analysis limits
						_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
							(int)fData[1]);
						SetWindowText(hwndFreqStart, szBuffer);
						_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
							(int)fData[2]);
						SetWindowText(hwndFreqEnd, szBuffer);

						// Set freq redraw flag
						bFreqRedraw=TRUE;
					}
					else // Phase data
					{
						// Update analysis limits
						_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
							(int)fData[1]);
						SetWindowText(hwndPhaseStart, szBuffer);
						_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
							(int)fData[2]);
						SetWindowText(hwndPhaseEnd, szBuffer);

						// Set phase redraw flag
						bPhaseRedraw=TRUE;
					}

					// Update status bar
					UpdateStatusBar(hwndMain, NEW_DATA);
				}

				// Move focus away from scrollbar
				// This avoids blinking mode problem
				SetFocus(GETHCTL(IDC_STATS_TRACK));

				// Update stats and plot
				SendMessage(hDlg, WM_INITDIALOG, (WPARAM)0, (LPARAM)0);
				SendMessage(hDlg, WM_COMMAND,
					GET_WM_COMMAND_MPS(IDC_STATS_PLOTDATA, NULL, 0));

				// Write prompt message
				WritePromptMessage(TB_STAT);
			}
 		}
		break;

		// Respond to right mouse button to zoom in
		case WM_RBUTTONDOWN:
		{
            // Get plot window screen coordinates
            GetWindowRect(hStatPlot, &rect);

			// Get mouse cursor position in screen coordinates
			GetCursorPos(&MousePoint);

			// Is mouse in plot region?
			if(PtInRect(&rect, MousePoint))
			{
	            // Get plot location in client coordinates
				// wrt top left = (0,0)
				GetClientRect(hStatPlot, &rect);
					
				// Convert mouse position to plot window client coordinates
				ScreenToClient(hStatPlot, &MousePoint);
				
				// Calc point # at mouse position
				nPoints=(int)(fData[2]-fData[1]+1);
				fXScale=(F_TYPE)(rect.right-rect.left);
				i=(int)(MousePoint.x*nPoints/fXScale)+(int)(fData[1]);
				
				// Zoom in phase data analysis limits by factor of 2
				// Must have least 8 points to give least 4 zoomed points
				if(nPoints>=8)
				{
					// Center zoom range on mouse position
					fData[1]=max((F_TYPE)(i-nPoints/4), 1);
					fData[2]=min((F_TYPE)(i+nPoints/4), fData[0]);
				}
				else
				{
					MessageBeep(1);
					break;
				}

				if(bUpdate)
				{
					if(bDataType==FREQ_DATA)
					{
						// Update freq analysis limits
						_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
							(int)fData[1]);
						SetWindowText(hwndFreqStart, szBuffer);
						_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
							(int)fData[2]);
						SetWindowText(hwndFreqEnd, szBuffer);

						// Set freq redraw flag
						bFreqRedraw=TRUE;
					}
					else // Phase data
					{
						// Update analysis limits
						_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
							(int)fData[1]);
						SetWindowText(hwndPhaseStart, szBuffer);
						_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
							(int)fData[2]);
						SetWindowText(hwndPhaseEnd, szBuffer);

						// Set phase redraw flag
						bPhaseRedraw=TRUE;
					}

					// Update status bar
					UpdateStatusBar(hwndMain, NEW_DATA);
				}

				// Move focus away from scrollbar
				// This avoids blinking mode problem
				SetFocus(GETHCTL(IDC_STATS_TRACK));

				// Update stats and plot
				SendMessage(hDlg, WM_INITDIALOG, (WPARAM)0, (LPARAM)0);
				SendMessage(hDlg, WM_COMMAND,
					GET_WM_COMMAND_MPS(IDC_STATS_PLOTDATA, NULL, 0));

				// Write prompt message
				WritePromptMessage(TB_STAT);
			}
		}
		break;

		// Respond to mouse to display data value
		case WM_MOUSEMOVE:
		{
			// Get plot window screen coordinates
            GetWindowRect(hStatPlot, &rect);

			// Get mouse cursor position in screen coordinates
			GetCursorPos(&MousePoint);

			// Is mouse in plot region?
			if(PtInRect(&rect, MousePoint))
			{
	            // Get plot location in client coordinates
				// wrt top left = (0,0)
				GetClientRect(hStatPlot, &rect);
					
				// Convert mouse position to plot window client coordinates
				ScreenToClient(hStatPlot, &MousePoint);
				
				// Calc point #
				nPoints=(int)(fData[2]-fData[1]+1);
				fXScale=(F_TYPE)(rect.right-rect.left);
				// 1.005 factor insures complete span
				i=(int)(MousePoint.x*nPoints*1.005/fXScale);
				
				// Start at analysis start
				i+=(int)(fData[1]); // Was fData[1]-1 until 5/20/01
				
				// Bound points
				if(i<(int)fData[1])
				{
					i=(int)fData[1];
				}
				if(i>fData[2])
				{
					i=(int)fData[2];
				}

				// Display point # and value
				_snprintf(szBuffer, sizeof(szBuffer),
					"Point=%d           Value=%+10.6e           ",
					i, fData[i+ARRAY_OFFSET-1]);
				ShortenExp(szBuffer);

				// Save index of selected data point
				// for possible later use or deletion
				nSelect=i;

				// Do we have timetags?
				if( (bDataType==PHASE_DATA && bPhaseTimetags) ||
					(bDataType==FREQ_DATA && bFreqTimetags) )
				{
					// Set tags pointer
					if(bDataType==FREQ_DATA)
					{
						fTags=fFreqTimetags;
					}
					else
					{
						fTags=fPhaseTimetags;
					}

					switch(nTagType)
					{
						case TAGTYPE_NONE:
						{
							strlcpy(szName, "", sizeof(szName));
						}
						break;

						case TAGTYPE_MJD:
						{
							// Format: MJD=00000.00000000
							_snprintf(szName, sizeof(szName), "MJD=%14.8f",
								fTags[i+ARRAY_OFFSET-1]);
							ShortenExp(szName);
						}
						break;

						case TAGTYPE_DOY:
						{
							// MJD to date conversion
							// Get full MJD
							fMJD=fTags[i+ARRAY_OFFSET-1];

							// Round the MJD up by 0.5 sec
							fMJD+=5.78704e-6;

							// Split MJD into integer and fractional parts
							fFractMJD=modf(fMJD, &fIntMJD);
							lnMJD=(long)fIntMJD;

							// Convert integer MJD into date
							MJDToDate(lnMJD, &nDay, &nMonth, &nYear);
							nDOY=nSum[nMonth-1]+nDay;
							if(nYear%4==0 && nYear%100!=0 || nYear%400==0)
							{
								if(nMonth>2)
								{
									nDOY++;
								}
							}

							// Convert fractional MJD into time
							fFractMJD*=24.0;
							nHour=(int)fFractMJD;
							fFractMJD-=nHour;
							fFractMJD*=60.0;
							nMin=(int)fFractMJD;
							fFractMJD-=nMin;
							fFractMJD*=60.0;
							nSec=(int)(fFractMJD);

							// Format: DOY=YYYY:DDD Time=HH:MM:SS
							_snprintf(szName, sizeof(szName),
								"DOY=%04d:%03d Time=%02d:%02d:%02d",
								nYear, nDOY, nHour, nMin, nSec);
							ShortenExp(szName);
						}
						break;

						case TAGTYPE_DATE:
						{
							// MJD to date conversion
							// Get full MJD
							fMJD=fTags[i+ARRAY_OFFSET-1];

							// Round the MJD up by 0.5 sec
							fMJD+=5.78704e-6;

							// Split MJD into integer and fractional parts
							fFractMJD=modf(fMJD, &fIntMJD);
							lnMJD=(long)fIntMJD;

							// Convert integer MJD into date
							MJDToDate(lnMJD, &nDay, &nMonth, &nYear);

							// Convert fractional MJD into time
							fFractMJD*=24.0;
							nHour=(int)fFractMJD;
							fFractMJD-=nHour;
							fFractMJD*=60.0;
							nMin=(int)fFractMJD;
							fFractMJD-=nMin;
							fFractMJD*=60.0;
							nSec=(int)(fFractMJD);

							// Format: Date=YYYY:MM:DD Time=HH:MM:SS
							_snprintf(szName, sizeof(szName),
								"Date=%02d:%02d:%02d Time=%02d:%02d:%02d",
								nYear, nMonth, nDay, nHour, nMin, nSec);
							ShortenExp(szName);
						}
						break;

						case TAGTYPE_MISC:
						{
							// Format: Timetag=-1.000000000000e+00
							_snprintf(szName, sizeof(szName),
								"Timetag=%17.12e", fTags[i+ARRAY_OFFSET-1]);
							ShortenExp(szName);
						}
						break;
					}
				}
				else  // No timetags
				{
					strlcpy(szName, "", sizeof(szName));
				}

				// Add timetag info
				strlcat(szBuffer, szName, sizeof(szBuffer));

				// Display data & timetag info
				SetWindowText(GETHCTL(IDC_STATS_READOUT), szBuffer);
			}
		}
		break;

        // Respond to messages from horizontal scrollbar
		case WM_HSCROLL:
		{
			// Did user press home key?
			if(LOWORD(wParam)==SB_TOP)
			{
				// Move to last point
				fData[1]=fData[0]-(si.nPage-1);
				fData[2]=fData[0];

				// Show position
				_snprintf(szBuffer, sizeof(szBuffer), "Points %d-%d",
					(int)fData[1], (int)fData[2]);
				SetWindowText(GETHCTL(IDC_STATS_READOUT), szBuffer);

			}
			// Did user press end key?
			if(LOWORD(wParam)==SB_BOTTOM)
			{
				// Move to 1st point
				fData[1]=1;
				fData[2]=si.nPage;

				// Show position
				_snprintf(szBuffer, sizeof(szBuffer), "Points %d-%d",
					(int)fData[1], (int)fData[2]);
				SetWindowText(GETHCTL(IDC_STATS_READOUT), szBuffer);

			}
			// Did user click left arrow or press left or up arrow key?
			if(LOWORD(wParam)==SB_LINELEFT)
			{
				// Move 1 point to left
				fData[1]=max(fData[1]-1, 1);
				fData[2]=max(fData[2]-1, si.nPage);

				// Show position
				_snprintf(szBuffer, sizeof(szBuffer), "Points %d-%d",
					(int)fData[1], (int)fData[2]);
				SetWindowText(GETHCTL(IDC_STATS_READOUT), szBuffer);

			}

			// Did user click right arrow or press right or down arrow?
			if(LOWORD(wParam)==SB_LINERIGHT)
			{
				// Move 1 point to right
				fData[1]=min(fData[1]+1, fData[0]-si.nPage+1);
				fData[2]=min(fData[2]+1, fData[0]);

				// Show position
				_snprintf(szBuffer, sizeof(szBuffer), "Points %d-%d",
					(int)fData[1], (int)fData[2]);
				SetWindowText(GETHCTL(IDC_STATS_READOUT), szBuffer);

			}


			// Did user click left page area or press page down key?
			if(LOWORD(wParam)==SB_PAGELEFT)
			{
				// Move 1 page to left
				fData[1]=max(fData[1]-si.nPage, 1);
				fData[2]=max(fData[2]-si.nPage, si.nPage);

				// Show position
				_snprintf(szBuffer, sizeof(szBuffer), "Points %d-%d",
					(int)fData[1], (int)fData[2]);
				SetWindowText(GETHCTL(IDC_STATS_READOUT), szBuffer);

			}

			// Did user click right page area or press page up key?
			if(LOWORD(wParam)==SB_PAGERIGHT)
			{
				// Move 1 page to right
				fData[1]=min(fData[1]+si.nPage, fData[0]-si.nPage+1);
				fData[2]=min(fData[2]+si.nPage, fData[0]);

				// Show position
				_snprintf(szBuffer, sizeof(szBuffer), "Points %d-%d",
					(int)fData[1], (int)fData[2]);
				SetWindowText(GETHCTL(IDC_STATS_READOUT), szBuffer);

			}

			// Is user moving scroll box (thumb)?
			if(LOWORD(wParam)==SB_THUMBTRACK)
			{
				// Set up SCROLLINFO struct to get position
				si.fMask=SIF_TRACKPOS;
			
				// Get info from scrollbar
				// Note: nTrackPos is the point # at the left end
				// of the scroll box
				// Thus the point #s go from nTrackPos to nTrackPos+nPage-1
				GetScrollInfo(GETHCTL(IDC_STATS_SCROLL), SB_CTL, &si);
				
				// Show position
				_snprintf(szBuffer, sizeof(szBuffer), "Points %d-%d",
					si.nTrackPos, si.nTrackPos+si.nPage-1);
				SetWindowText(GETHCTL(IDC_STATS_READOUT), szBuffer);

				// Do we want to track the scroll box as it moves?
				if(bTrack)
				{
					// Set new start point
					fData[1]=si.nTrackPos;

					// Set new end point
					fData[2]=si.nTrackPos+si.nPage-1;
				}
				else // Don't track
				{
					break;
				}
			}

			// Has user released scroll box (thumb) after dragging it?
			if(LOWORD(wParam)==SB_THUMBPOSITION)
			{
				// Set new start point
				fData[1]=si.nTrackPos;

				// Set new end point
				fData[2]=si.nTrackPos+si.nPage-1;

			}

			if(bUpdate)
			{
				// Refresh display
				if(bDataType==FREQ_DATA)
				{
					// Update freq analysis limits
					_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
						(int)fData[1]);
					SetWindowText(hwndFreqStart, szBuffer);
					_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
						(int)fData[2]);
					SetWindowText(hwndFreqEnd, szBuffer);

					// Set freq redraw flag
					bFreqRedraw=TRUE;
				}
				else // Phase data
				{
					// Update analysis limits
					_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
						(int)fData[1]);
					SetWindowText(hwndPhaseStart, szBuffer);
					_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
						(int)fData[2]);
					SetWindowText(hwndPhaseEnd, szBuffer);

					// Set phase redraw flag
					bPhaseRedraw=TRUE;
				}

				// Update status bar
				UpdateStatusBar(hwndMain, NEW_DATA);
			}

			// Update stats and plot
			SendMessage(hDlg, WM_INITDIALOG, (WPARAM)0, (LPARAM)0);
			SendMessage(hDlg, WM_COMMAND,
				GET_WM_COMMAND_MPS(IDC_STATS_PLOTDATA, NULL, 0));

			// Write prompt message
			WritePromptMessage(TB_STAT);
		}
		break;

		case WM_COMMAND:
        {
            switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
                case IDHELP:
                {
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::STATISTICS_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::STATISTICS_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "STATISTICS_FUNCTION");
					#endif
                }
                break;

				// Respond to all button
				case IDC_STATS_ALL:
				{
					// Select all data
					fData[1]=1;
					fData[2]=fData[0];

					// Display message
					SetWindowText(GETHCTL(IDC_STATS_READOUT), "All Data");

					if(bUpdate)
					{
						// Refresh display
						if(bDataType==FREQ_DATA)
						{
							// Update freq analysis limits
							_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
								(int)fData[1]);
							SetWindowText(hwndFreqStart, szBuffer);
							_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
								(int)fData[2]);
							SetWindowText(hwndFreqEnd, szBuffer);

							// Set freq redraw flag
							bFreqRedraw=TRUE;
						}
						else // Phase data
						{
							// Update analysis limits
							_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
								(int)fData[1]);
							SetWindowText(hwndPhaseStart, szBuffer);
							_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
								(int)fData[2]);
							SetWindowText(hwndPhaseEnd, szBuffer);

							// Set phase redraw flag
							bPhaseRedraw=TRUE;
						}

						// Update status bar
						UpdateStatusBar(hwndMain, NEW_DATA);
					}

					// Update stats and plot
					SendMessage(hDlg, WM_INITDIALOG, (WPARAM)0, (LPARAM)0);
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_STATS_PLOTDATA, NULL, 0));

					// Write prompt message
					WritePromptMessage(TB_STAT);
				}
				break;

                // Detect timetag type change
                case IDC_STATS_TAGTYPE:
                {
                    if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_SELCHANGE) 
                    {
						// Get the combo box selection
						nTagType=
							ComboBox_GetCurSel(GETHCTL(IDC_STATS_TAGTYPE));
                    }
                }
                break;

				// Respond to track checkbox
				case IDC_STATS_TRACK:
				{
					bTrack=Button_GetCheck(GETHCTL(IDC_STATS_TRACK));
				}
				break;

				// Respond to swap button
				case IDC_STATS_SWAP:
				{
                    if(bDataType==FREQ_DATA)
                    {
						bDataType=PHASE_DATA;
						fData=fPhaseData;
						fData[1]=fFreqData[1];
						fData[2]=fFreqData[2]+1;
					}
					else // Phase data
					{
						bDataType=FREQ_DATA;
						fData=fFreqData;
						fData[1]=fPhaseData[1];
						fData[2]=fPhaseData[2]-1;
					}

					if(bUpdate)
					{
						// Refresh display
						if(bDataType==FREQ_DATA)
						{
							// Update freq analysis limits
							_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
								(int)fData[1]);
							SetWindowText(hwndFreqStart, szBuffer);
							_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
								(int)fData[2]);
							SetWindowText(hwndFreqEnd, szBuffer);

							// Set freq redraw flag
							bFreqRedraw=TRUE;
						}
						else // Phase data
						{
							// Update analysis limits
							_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
								(int)fData[1]);
							SetWindowText(hwndPhaseStart, szBuffer);
							_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
								(int)fData[2]);
							SetWindowText(hwndPhaseEnd, szBuffer);

							// Set phase redraw flag
							bPhaseRedraw=TRUE;
						}

						// Update status bar
						UpdateStatusBar(hwndMain, NEW_DATA);
					}

					// Update stats and plot
					SendMessage(hDlg, WM_INITDIALOG, (WPARAM)0, (LPARAM)0);
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_STATS_PLOTDATA, NULL, 0));

					// Write prompt message
					WritePromptMessage(TB_STAT);
				}
				break;

				#if(1) // New code 12/29/11
				// Respond to delete button
				case IDC_STATS_DELETE:
				{
					// Save selected point as point to remove
					// This is done in case mouse moves to another point
					nRemove=nSelect;

					// Compose and display warning message
					sprintf(szBuffer, "Delete point # %d ?", nRemove);
					nDummy=MessageBox(hwndMain, szBuffer,
						"Delete Data Point", MB_OKCANCEL);

					// Abort if user wants to
					if(nDummy==IDCANCEL)
					{
						// Abort
						break;
					}
					else // Proceed with deletion
					{
                        // Create tab to save previous data if requested
						if(bTabs && bTabChange)
						{
							// Save current plot limits
							fPlotStart=fData[1];
							fPlotEnd=fData[2];

							if(bDataType==FREQ_DATA)
							{
								// Restore original analysis limits
								fFreqData[1]=fSaveFreqStart;
								fFreqData[2]=fSaveFreqEnd;
							}
							else // Phase data
							{
								// Restore original analysis limits
								fPhaseData[1]=fSavePhaseStart;
								fPhaseData[2]=fSavePhaseEnd;
							}

							// Save original data in tab
							CreateTab();

							// Restore current plot limits
							fData[1]=fPlotStart;
							fData[2]=fPlotEnd;
						}
						
						// Delete selected point
						fData[nRemove+ARRAY_OFFSET-1]=0.0;

						// Update stats and plot
						SendMessage(hDlg, WM_INITDIALOG, (WPARAM)0, (LPARAM)0);
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_STATS_PLOTDATA, NULL, 0));

						// Update main status info and plot
						if(bDataType==FREQ_DATA)
						{
							// Save current plot limits
							fPlotStart=fData[1];
							fPlotEnd=fData[2];

							// Restore original analysis limits
							fFreqData[1]=fSaveFreqStart;
							fFreqData[2]=fSaveFreqEnd;

							// Update status display
							_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
								(int)(fSaveFreqEnd-fSaveFreqStart+1));
							SetWindowText(hwndFreqNum, szBuffer);
							_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
								(int)(fSaveFreqEnd));
							SetWindowText(hwndFreqEnd, szBuffer);
							_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
								(int)(fSaveFreqStart));
							SetWindowText(hwndFreqStart, szBuffer);
							bFreqDataChanged=TRUE;
							bFreqDataUnsaved=TRUE;
							bFreqScaleChanged=TRUE;
							bFreqRedraw=TRUE;

							// Force new PSD plot scale
							sPSPlot.y_tic=0;

							// Increment filename
							if(bIncExtension)
							{
								IncExtension(szFile, FREQ_DATA);
								IncExtension(szFileTitle, FREQ_DATA);
								IncExtension(szFreqFile, FREQ_DATA);
								IncExtension(szFreqFileTitle, FREQ_DATA);
								SetWindowText(hwndFreqFilename,
									szFileTitle);
							}

							// Set redraw flag
							bFreqRedraw=TRUE;

							// Clear data synch flag
							bSynch=FALSE;

							// Redraw freq status plot from data
							UpdateStatusBar(hwndMain, NEW_DATA);

							// Restore current plot limits
							fData[1]=fPlotStart;
							fData[2]=fPlotEnd;

							// Compose log text
							_snprintf(szBuffer, sizeof(szBuffer), "#=%d",
								nRemove);

							// Put info into log file
							WriteLog(84, szBuffer);
						}
						else // Phase data
						{
							// Save current plot limits
							fPlotStart=fData[1];
							fPlotEnd=fData[2];

							// Restore original analysis limits
							fPhaseData[1]=fSavePhaseStart;
							fPhaseData[2]=fSavePhaseEnd;

							// Update status display
							_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
								(int)(fSavePhaseEnd-fSavePhaseStart+1));
							SetWindowText(hwndPhaseNum, szBuffer);
							_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
								(int)(fSavePhaseEnd));
							SetWindowText(hwndPhaseEnd, szBuffer);
							_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
								(int)(fSavePhaseStart));
							SetWindowText(hwndPhaseStart, szBuffer);
							bPhaseDataChanged=TRUE;
							bPhaseDataUnsaved=TRUE;
							bPhaseScaleChanged=TRUE;
							bPhaseRedraw=TRUE;

							// Force new PSD plot scale
							sPSPlot.y_tic=0;

							// Increment filename
							if(bIncExtension)
							{
								IncExtension(szFile, PHASE_DATA);
								IncExtension(szFileTitle, PHASE_DATA);
								IncExtension(szPhaseFile, PHASE_DATA);
								IncExtension(szPhaseFileTitle, PHASE_DATA);
								SetWindowText(hwndPhaseFilename,
									szFileTitle);
							}

							// Set redraw flag
							bPhaseRedraw=TRUE;
	
							// Clear data synch flag
							bSynch=FALSE;

							// Redraw phase status plot from data
							UpdateStatusBar(hwndMain, NEW_DATA);

							// Restore current plot limits
							fData[1]=fPlotStart;
							fData[2]=fPlotEnd;

							// Compose log text
							_snprintf(szBuffer, sizeof(szBuffer), "#=%d",
								nRemove);

							// Put info into log file
							WriteLog(83, szBuffer);
						}
					}
 				}
				break;
				#endif

               // Plot data
                case IDC_STATS_PLOTDATA:
                {
					// Get size of plot area
                    GetClientRect(hStatPlot, &rect);

					// Make plot background white
					FillRect(hdcPlot, &rect, GetStockObject(WHITE_BRUSH));
					
					// Get min & max of adjusted range
					if( (fData[1]==1) && (fData[2]!=fData[0]) &&
						(bDataType==PHASE_DATA) )
					{
						fData[2]++;
						FindMinMax(fData, &fMin, &fMax, bDataType);
						fData[2]--;
					}

					// Calc plot scales
					if(bScale)
					{
						// Use FrequenC "nice" plot scale
						nTicks=FindPlotScale(fMin, fMax, &fScaleMin,
							&fScaleMax);

						// Make scale adjustment to avoid just 2 or 3 divisions
						// This looks better and helps to avoid scale changes
						if(nTicks==3) // Avoid 75/div
						{
							fRange=fScaleMax-fScaleMin;
							fScaleMin-=fRange/6;
							fScaleMax+=fRange/6;
						}

						if(nTicks<4)
						{
							nTicks=4;
						}

						// Set scale factors
						fRange=fScaleMax-fScaleMin;
					}
					else // Use fixed scale
					{
						nTicks=4;
						fScaleMax=fMax;
						fScaleMin=fMin;
						fRange=fMax-fMin;
					}

                    // Check for zero range
                    if(fRange)
                    {
						// Plot points on screen
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_STATS_PLOTPOINTS, NULL, 0));
					}
                    else
                    {
                        // Display error message instead of plot
						SetWindowText(GETHCTL(IDC_STATS_PLOT),
							"\n\nZero Range");
					}
				}
				break;

				// Internal subroutine to plot data points on screen
				case IDC_STATS_PLOTPOINTS:
				{
		            // Set scales
					// The -1 avoids stary overrange pixels at bottom
					fYScale=(F_TYPE)(rect.bottom-rect.top-1);
		            fXScale=(F_TYPE)(rect.right-rect.left-1);

                    // Create & select red pen
                    SelectObject(hdcPlot, CreatePen(PS_SOLID, 1,
                        0x000000FF));

					// Initialize for plot
					j=0;
					nLastY=0;

                    // Plot data points
                    for(i=(int)fData[1]-1+nAdj; i<(int)fData[2]-1+nAdj; i++)
                    {
						// Skip gaps
                        if( (fData[i+ARRAY_OFFSET] &&
							fData[i+ARRAY_OFFSET+1]) ||
							(bDataType==PHASE_DATA && 
							(i==(int)fData[1]-1+nAdj ||
							i==(int)fData[2]-2+nAdj)) )
                        {
                            if(bDataType==FREQ_DATA)
                            {
								if(nPoints<POINTLIMIT)
								{
									// Plot freq data points as freq data
									// with horizontal lines
									// Move to current point
									MoveToEx(hdcPlot,
										(int)(((F_TYPE)j/(F_TYPE)nPoints)*
										fXScale), (int)
										(((fScaleMax-fData[i+ARRAY_OFFSET])/
										(fRange))*(fYScale)), NULL);
									// Draw horiz line from there to next point
									LineTo(hdcPlot,
										(int)(((F_TYPE)(j+1)/(F_TYPE)nPoints)*
										fXScale), (int)
										(((fScaleMax-fData[i+ARRAY_OFFSET])/
										(fRange))*(fYScale)));
									// Draw vert line from there to next point
									nLastY=(int)
										(((fScaleMax-fData[i+ARRAY_OFFSET+1])/
										(fRange))*(fYScale));
									LineTo(hdcPlot,
										(int)(((F_TYPE)(j+1)/(F_TYPE)nPoints)*
										fXScale), nLastY);
								}
								else
								{
									// Plot freq data as phase data
									// if # points>POINTLIMIT
									// This speeds up freq data plotting by
									// x2 & looks same
									// Move to current point
									MoveToEx(hdcPlot,
										(int)(((F_TYPE)j/(F_TYPE)(nPoints))*
										fXScale), (int)
										(((fScaleMax-fData[i+ARRAY_OFFSET])/
										(fRange))*(fYScale)), NULL);
									// Draw line from there to next point
									LineTo(hdcPlot,
										(int)(((F_TYPE)(j+1)/
										(F_TYPE)(nPoints))*fXScale), (int)
										(((fScaleMax-fData[i+ARRAY_OFFSET+1])/
										(fRange))*(fYScale)));
								}
							}
							else // Phase data
                            {
                                // Move to current point
                                MoveToEx(hdcPlot,
                                    (int)(((F_TYPE)j/(F_TYPE)(nPoints-1))*
                                    fXScale), (int)
									(((fScaleMax-fData[i+ARRAY_OFFSET])/
                                    (fRange))*(fYScale)), NULL);
                                // Draw line from there to next point
                                LineTo(hdcPlot,
                                    (int)(((F_TYPE)(j+1)/
                                    (F_TYPE)(nPoints-1))*fXScale), (int)
									(((fScaleMax-fData[i+ARRAY_OFFSET+1])/
									(fRange))*(fYScale)));
                            }
                        }
                        else // Gap
                        {
							nLastY=0;
							if( (bDataType==FREQ_DATA) &&
                                (fData[i+ARRAY_OFFSET]) &&
								(nPoints<POINTLIMIT) )
                            {
								// Draw horiz line from there to next point
                                LineTo(hdcPlot,
                                    (int)(((F_TYPE)(j+1)/(F_TYPE)nPoints)*
                                    fXScale), (int)
									(((fScaleMax-fData[i+ARRAY_OFFSET])/
                                    (fRange))*(fYScale)));
                            }
						}
                        j++;
					}

                    if((bDataType==FREQ_DATA)&&(nPoints<POINTLIMIT))
                    {
                        // Draw final horiz line - test added 09/14/98
						// Avoids trouble with zoomed gaps
						if(nLastY)
                        {
                            LineTo(hdcPlot,
                                (int)(((F_TYPE)(j+1)/
                                (F_TYPE)nPoints)*fXScale), nLastY);
                        }
                    }

                    // Select black pen & delete red one
                    // Ref: C. Petzold "Programming Windows 3.1", p.548
                    DeleteObject(SelectObject(hdcPlot,
                        GetStockObject(BLACK_PEN)));

					// Draw horizontal grid
                    for(i=1; i<nTicks; i++)
					{
                        MoveToEx(hdcPlot, 0, (int)(i*fYScale/nTicks),
                            NULL);
                        LineTo(hdcPlot, (int)fXScale,
                            (int)(i*fYScale/nTicks));
                    }

					// Draw vertical grid
                    for(i=1; i<4; i++)
                    {
                        MoveToEx(hdcPlot, (int)((i/4.0)*fXScale), 0, NULL);
                        LineTo(hdcPlot, (int)((i/4.0)*fXScale),
                            (int)fYScale);
                    }

					// Draw green line at average for freq data
                    // Create & select green pen
                    if(bDataType==FREQ_DATA)
                    {
	                    SelectObject(hdcPlot, CreatePen(PS_SOLID, 1,
		                    0x0000FF00));

						// Move to left point
						MoveToEx(hdcPlot, 0,
							(int)(((fScaleMax-fAvg)/(fRange))*(fYScale)),
							NULL);
						// Draw horiz line from there to right point
						LineTo(hdcPlot, (int)(fXScale),
							(int)(((fScaleMax-fAvg)/(fRange))*(fYScale)));

	                    // Select black pen & delete red one
		                // Ref: C. Petzold "Programming Windows 3.1", p.548
			            DeleteObject(SelectObject(hdcPlot,
				            GetStockObject(BLACK_PEN)));
					}
				}
				break;
               
				case IDC_STATS_COPY:
                {
					// Hide swap button
					ShowWindow(GETHCTL(IDC_STATS_SWAP), SW_HIDE);

                    // Redisplay dialog box
                    GetClientRect(hDlg, &rect);
                    InvalidateRect(hDlg, &rect, FALSE);

					// Let system update display & get messages
					while(PeekMessage(&msg, NULL, 0, 0, PM_REMOVE))
					{
						if(!IsDialogMessage(hDlg, &msg))
						{
							TranslateMessage(&msg);
							DispatchMessage(&msg);
						}
					}

					// Copy stats bitmap to clipboard
					CopyDialog(hDlg, 995, 740);

					// Show swap button
					ShowWindow(GETHCTL(IDC_STATS_SWAP), SW_SHOWNORMAL);

                    // Redisplay dialog box
                    GetClientRect(hDlg, &rect);
                    InvalidateRect(hDlg, &rect, FALSE);
				}
				break;

				case IDCANCEL:
				{
					// If status bar not being updated
					if(!bUpdate)
					{
						// Restore original data type
						bDataType=bSaveDataType;

						// Restore data & timetag pointers
						if(bDataType==FREQ_DATA)
						{
							fData=fFreqData;
							fTags=fFreqTimetags;
							SendMessage(hwndMain, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_FREQSELECT, 0, 0));
						}
						else // Phase data
						{
							fData=fPhaseData;
							fTags=fPhaseTimetags;
							SendMessage(hwndMain, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_PHASESELECT, 0, 0));
						}

						// Restore original analysis limits
						fData[1]=fSaveStart;
						fData[2]=fSaveEnd;
						fFreqData[1]=fSaveFreqStart;
						fFreqData[2]=fSaveFreqEnd;
						fPhaseData[1]=fSavePhaseStart;
						fPhaseData[2]=fSavePhaseEnd;
					}

					hStatPlot=NULL;
					ReleaseDC(hStatPlot, hdcPlot);
					EndDialog (hDlg, 0);
				}
				return TRUE;
			}
		}
		break;
	 }
	 return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*                   Scale Dialog Procedure                                  */
/*                                                                           */
/*  Revision record:                                                         */
/*      10/29/96    Removed default button - Added edit CR processing        */
/*                  Added slope processing                                   */
/*      11/03/96    Added increment file extension logic                     */
/*      03/25/97    Added first, average & line removal code                 */
/*      04/12/97    Fixed gap handling for slope                             */
/*      06/07/97    Grey certain controls if only 1 analysis point           */
/*		11/18/06	Added CreateTab() call                                   */
/*		03/01/08	Added reverse button and functionality                   */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK ScaleDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam)
{
    // Local variables
    // Chars
	char szBuffer[BUFFER_SIZE+1];   // Text buffer
    // Ints
    int i;                      // Index
    int nStart=(int)fData[1];   // Analysis start
    int nEnd=(int)fData[2];     // Analysis end
    // F_TYPEs
    F_TYPE fA, fB, fV;          // Fit parameters
	static F_TYPE fAdd;         // Addend value
    static F_TYPE fMult;        // Multiplier value
    static F_TYPE fSlope;       // Slope value
    static F_TYPE fAvg;         // Average value
	static F_TYPE fStart, fEnd;	// Timetag array analysis limits
    // BOOLs
    static BOOL bFirst=FALSE;   // Flag for first value removed
    static BOOL bAvg=FALSE;     // Flag for avg value removed
    static BOOL bLine=FALSE;    // Flag for line removed

    LoadIcon(hInst, "FlatScaleIcon");

    switch(message)
    {
        case WM_INITDIALOG:
        {
            // Write prompt message
            WritePromptMessage(TB_SCALE);

			// Note:  These defaults restored every time as safety measure

			// Put default value from INI file into addend
			// Tests for previous scaling added 9/9/00
			if(bDataType==FREQ_DATA)
			{
				if(!bFreqScaled)
				{
					_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
						fFreqAddendInput);
				}
				else  // Use default
				{
					_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e", 0.0);
				}
			}
			else // Phase data
			{
				if(!bPhaseScaled)
				{
					_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
						fPhaseAddendInput);
				}
				else // Use default
				{
					_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e", 0.0);
				}
			}

			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_SCALE_ADD), szBuffer);

			// Put default value from INI file into multiplier
			if(bDataType==FREQ_DATA)
			{
				if(!bFreqScaled)
				{
					_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
						fFreqMultiplierInput);
				}
				else // Use default
				{
					_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e", 1.0);
				}
			}
			else // Phase data
			{
				if(!bPhaseScaled)
				{
					_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
						fPhaseMultiplierInput);
				}
				else // Use default
				{
					_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e", 1.0);
				}
			}

			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_SCALE_MULT), szBuffer);

            // Put default value into slope
            _snprintf(szBuffer, sizeof(szBuffer), "%+20.13e", 0.0);
			ShortenExp(szBuffer);
            SetWindowText(GETHCTL(IDC_SCALE_SLOPE), szBuffer);

			// Grey line & avg buttons and slope value if <2 analysis points
			if(nEnd<nStart+1)
			{
				EnableWindow(GETHCTL(IDC_SCALE_LINE), FALSE);
				EnableWindow(GETHCTL(IDC_SCALE_AVG), FALSE);
				EnableWindow(GETHCTL(IDC_SCALE_SLOPE), FALSE);
			}
			else
			{
				EnableWindow(GETHCTL(IDC_SCALE_LINE), TRUE);
				EnableWindow(GETHCTL(IDC_SCALE_AVG), TRUE);
				EnableWindow(GETHCTL(IDC_SCALE_SLOPE), TRUE);
			}

			// Reset all flags
			bFirst=FALSE;
			bAvg=FALSE;
            bLine=FALSE;
        }
        return TRUE;

        case WM_COMMAND:
        {
            switch(GET_WM_COMMAND_ID(wParam, lParam))
            {
                case IDHELP:
                {
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::SCALE_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::SCALE_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "SCALE_FUNCTION");
					#endif
                }
                break;

                case IDC_SCALE_FIRST:
				{
                    // Set first flag
                    bFirst=TRUE;

                    // Reset other flags
                    bAvg=FALSE;
                    bLine=FALSE;

                    // Set addend to -1st data point value
                    fAdd=-fData[ARRAY_OFFSET];

                    // Store addend
                    _snprintf(szBuffer, sizeof(szBuffer), "%+20.13e", fAdd);
					ShortenExp(szBuffer);
                    SetWindowText(GETHCTL(IDC_SCALE_ADD), szBuffer);
                }
				break;

                case IDC_SCALE_AVG:
                {
                    // Set avg flag
                    bAvg=TRUE;

                    // Reset other flags
                    bFirst=FALSE;
                    bLine=FALSE;

                    // Find the average value
                    CalcMean(fData, &fAvg, bDataType);

                    // Set addend to -average value
                    fAdd=-fAvg;

                    // Store addend
                    _snprintf(szBuffer, sizeof(szBuffer), "%+20.13e", fAdd);
					ShortenExp(szBuffer);
                    SetWindowText(GETHCTL(IDC_SCALE_ADD), szBuffer);
                }
                break;

				case IDC_SCALE_LINE:
                {
                    // Set line flag
                    bLine=TRUE;

					// Reset other flags
                    bFirst=FALSE;
                    bAvg=FALSE;

                    if(bDataType==FREQ_DATA)
                    {
                        // Calc linear freq fit
                        // Slope is per data point interval
                        CalcLinFreqDrift(fFreqData, &fA, &fB, &fV);

                        // Set slope to -linear fit slope
                        fSlope=-fB;
                    }
					else // Phase data
                    {
                        // Calc linear phase fit
                        // Slope is per data point interval
                        CalcFreqOffset(fPhaseData, &fA, &fB, &fV);

                        // Set slope to -linear fit slope
                        fSlope=-fB;
                    }

					// Store slope
                    _snprintf(szBuffer, sizeof(szBuffer), "%+20.13e", fSlope);
					ShortenExp(szBuffer);
                    SetWindowText(GETHCTL(IDC_SCALE_SLOPE), szBuffer);
                }
                break;

                case IDC_SCALE_ADD:
                {
                    // Respond to edit control when it loses the input focus
                    // unless it loses it to the cancel button
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_SCALE_CANCEL)))
                    {
                        // Get addend
						GetWindowText(GETHCTL(IDC_SCALE_ADD), szBuffer,
							BUFFER_SIZE);
                        fAdd=(F_TYPE)atof(szBuffer);

						// Redisplay addend
                        _snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
							fAdd);
						ShortenExp(szBuffer);
                        SetWindowText(GETHCTL(IDC_SCALE_ADD), szBuffer);

                        // Reset addend flags
                        bFirst=FALSE;
                        bAvg=FALSE;
                    }
                }
                break;

                case IDC_SCALE_MULT:
                {
                    // Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_SCALE_CANCEL)))
                    {
                        // Get multiplier
						GetWindowText(GETHCTL(IDC_SCALE_MULT), szBuffer,
							BUFFER_SIZE);
                        fMult=(F_TYPE)atof(szBuffer);

                        // Redisplay multiplier
                        _snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
							fMult);
						ShortenExp(szBuffer);
                        SetWindowText(GETHCTL(IDC_SCALE_MULT), szBuffer);
					}
                }
                break;

                case IDC_SCALE_SLOPE:
                {
                    // Respond to edit control when it loses the input focus
                    // unless it loses it to the cancel button
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_SCALE_CANCEL)))
                    {
                        // Get slope
						GetWindowText(GETHCTL(IDC_SCALE_SLOPE),	szBuffer,
							BUFFER_SIZE);
                        fSlope=(F_TYPE)atof(szBuffer);

                        // Redisplay slope
                        _snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
							fSlope);
						ShortenExp(szBuffer);
                        SetWindowText(GETHCTL(IDC_SCALE_SLOPE), szBuffer);

                        // Reset slope flag
                        bLine=FALSE;
					 }
                }
                break;

                // Immediately execute data reversal
				// and close scale dialog box
				// Can undo by doing it again
				// Analysis limits apply to both data and timetags
				case IDC_SCALE_REVERSE:
                {
                    // Set data changes flag
                    if(bDataType==FREQ_DATA)
                    {
						// Put info into log file
						_snprintf(szBuffer, sizeof(szBuffer),
							"Freq Data Reversed");
						WriteLog(17, szBuffer);
							
                        bFreqDataChanged=TRUE;
						bFreqDataUnsaved=TRUE;
						sFPlot.new_file=TRUE;
                        bFreqScaleChanged=TRUE;
						bFreqRedraw=TRUE;

						// Reverse order of freq data
						ReverseData(fFreqData);

						// Do we have freq timetags?
						if(bFreqTimetags)
						{
							// Save freq timeatg analysis limits
							fStart=fFreqTimetags[1];
							fEnd=fFreqTimetags[2];

							// Set freq timetag array limits
							fFreqTimetags[1]=fFreqData[1];
							fFreqTimetags[2]=fFreqData[2];
							
							// Reverse order of freq timetags
							ReverseData(fFreqTimetags);

							// Restore freq time analysis limits
							fFreqTimetags[1]=fStart;
							fFreqTimetags[2]=fEnd;
						}

                        // Increment filename
                        if(bIncExtension)
                        {
                            IncExtension(szFile, FREQ_DATA);
                            IncExtension(szFileTitle, FREQ_DATA);
                            IncExtension(szFreqFile, FREQ_DATA);
                            IncExtension(szFreqFileTitle, FREQ_DATA);
                            SetWindowText(hwndFreqFilename, szFileTitle);
                        }
                    }
					else // Phase data
                    {
						// Put info into log file
						_snprintf(szBuffer, sizeof(szBuffer),
							"Phase Data Reversed");
						WriteLog(16, szBuffer);
								
                        bPhaseDataChanged=TRUE;
						bPhaseDataUnsaved=TRUE;
                        bPhaseScaleChanged=TRUE;
						bPhaseRedraw=TRUE;

						// Reverse order of phase data
						ReverseData(fPhaseData);

						// Do we have phase timetags?
						if(bPhaseTimetags)
						{
							// Save phase timeatg analysis limits
							fStart=fPhaseTimetags[1];
							fEnd=fPhaseTimetags[2];

							// Set phase timetag array limits
							fPhaseTimetags[1]=fPhaseData[1];
							fPhaseTimetags[2]=fPhaseData[2];
							
							// Reverse order of phase timetags
							ReverseData(fPhaseTimetags);

							// Restore phase time analysis limits
							fPhaseTimetags[1]=fStart;
							fPhaseTimetags[2]=fEnd;
						}

                        // Increment filename
                        if(bIncExtension)
                        {
                            IncExtension(szFile, PHASE_DATA);
                            IncExtension(szFileTitle, PHASE_DATA);
                            IncExtension(szPhaseFile, PHASE_DATA);
                            IncExtension(szPhaseFileTitle, PHASE_DATA);
                            SetWindowText(hwndPhaseFilename, szFileTitle);
                        }
                    }

					// Force new PSD plot scale
					sPSPlot.y_tic=0;

					// Redraw status plots from new data
					UpdateStatusBar(hwndMain, NEW_DATA);

					// Reset redraw flags
					bPhaseRedraw=FALSE;
					bFreqRedraw=FALSE;

					// Clear plot lines
					ClearLines();

					// Clear synch flag
					bSynch=FALSE;

					// Close scale dialog box
					EndDialog (hDlg, 0);
					return TRUE;
                }
                break;

                // Respond to CR in an edit control
				// Note: No button is a DEFPUSHBUTTON
                case IDOK:
                {
                    // Does add edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_SCALE_ADD))
                    {
						// Send EN_KILLFOCUS message to add edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_SCALE_ADD, 0,
							EN_KILLFOCUS));
					}

					// Does multiplier edit control have focus?
					if(GetFocus()==GETHCTL(IDC_SCALE_MULT))
					{
						// Send EN_KILLFOCUS message to multiplier edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_SCALE_MULT, 0,
							EN_KILLFOCUS));
					}

					// Does slope edit control have focus?
					if(GetFocus()==GETHCTL(IDC_SCALE_SLOPE))
					{
						// Send EN_KILLFOCUS message to slope edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_SCALE_SLOPE, 0,
							EN_KILLFOCUS));
					}
				}
				break;

				// Respond to OK button - accept changes
				// Scale data and close dialog box
				case IDC_SCALE_ACCEPT:
				{
					// Get addend
					GetWindowText(GETHCTL(IDC_SCALE_ADD), szBuffer,
						BUFFER_SIZE);
                    fAdd=(F_TYPE)atof(szBuffer);

                    // Get multiplier
					GetWindowText(GETHCTL(IDC_SCALE_MULT), szBuffer,
						BUFFER_SIZE);
                    fMult=(F_TYPE)atof(szBuffer);

					// Get slope
					GetWindowText(GETHCTL(IDC_SCALE_SLOPE), szBuffer,
						BUFFER_SIZE);
                    fSlope=(F_TYPE)atof(szBuffer);

                    // Note: Does not have any error checking
                    if(fAdd!=0.0 || fMult!=1.0 || fSlope!=0.0)
                    {
                        // Display wait cursor
                        SetCursor(hWait);

                        // Create tab to save previous data if requested
						if(bTabs && bTabChange)
						{
							CreateTab();
						}
						
						// Scale data
                        // Note:  The value added is always the slope
						// times the data point #.  This adds an increment
                        // to the 1st point, and adds an offset in the case
                        // of a restricted analysis starting point
                        ScaleData(fData, fAdd, fMult, bDataType);

                        // Add slope
                        for(i=nStart; i<=nEnd; i++)
                        {
							if(bDataType==FREQ_DATA)
							{
									if(fData[i+ARRAY_OFFSET-1])
									{
										fData[i+ARRAY_OFFSET-1]+=fSlope*i;
									}
							}
							else // Phase data
							{
									if( (fData[i+ARRAY_OFFSET-1]) ||
										(i==1)  || (i==fData[0]) )
									{
										fData[i+ARRAY_OFFSET-1]+=fSlope*i;
									}
							}
						}

                        // Set data changes flag
                        if(bDataType==FREQ_DATA)
                        {
							// Put info into log file
							_snprintf(szBuffer, sizeof(szBuffer),
								"Addend=%e, Mult=%e, Slope=%e",
								fAdd, fMult, fSlope);
							ShortenExp(szBuffer);
							WriteLog(17, szBuffer);
								
                            bFreqDataChanged=TRUE;
							bFreqDataUnsaved=TRUE;
							sFPlot.new_file=TRUE;
                            bFreqScaleChanged=TRUE;
							bFreqRedraw=TRUE;

                            if(fAdd!=0.0) // Addend added
							{
								// Set global freq addend added flag
								bFreqAddend=TRUE;

								// Save value of freq addend
								fFreqAddend=fAdd;
							}

                            if(fMult!=1.0) // Data scaled
							{
								// Set global freq scaled flag
								bFreqScaled=TRUE;

								// Save value of freq scaling factor
								fFreqScaled=fMult;
							}

							if(bFirst)
                            {
                                // Save freq offset removed
                                fFreqOffsetRemoved=fAvg;
                            }

							if(bAvg)
                            {
                                // Set global normalized flag
                                bFreqNorm=TRUE;

                                // Save freq offset removed
                                fFreqOffsetRemoved=fAvg;
                            }

                            if(bLine)
                            {
                                // Set global freq line removed flag
                                bLinDriftRem=TRUE;

                                // Save freq slope removed from freq data
                                fFreqSlopeRemoved=fSlope;
                            }

                            // Increment filename
                            if(bIncExtension)
                            {
                                IncExtension(szFile, FREQ_DATA);
                                IncExtension(szFileTitle, FREQ_DATA);
                                IncExtension(szFreqFile, FREQ_DATA);
                                IncExtension(szFreqFileTitle, FREQ_DATA);
                                SetWindowText(hwndFreqFilename, szFileTitle);
                            }
                        }
						else // Phase data
                        {
							// Put info into log file
							_snprintf(szBuffer, sizeof(szBuffer),
								"Addend=%e, Mult=%e, Slope=%e",
								fAdd, fMult, fSlope);
							ShortenExp(szBuffer);
							WriteLog(16, szBuffer);
								
                            bPhaseDataChanged=TRUE;
							bPhaseDataUnsaved=TRUE;
                            bPhaseScaleChanged=TRUE;
							bPhaseRedraw=TRUE;

                            if(fAdd!=0.0) // Addend added
							{
								// Set global phase addend added flag
								bPhaseAddend=TRUE;

								// Save value of phase addend
								fPhaseAddend=fAdd;
							}

                            if(fMult!=1.0) // Data scaled
							{
								// Set global phase scaled flag
								bPhaseScaled=TRUE;

								// Save value of phase scaling factor
								fPhaseScaled=fMult;
							}

                            if(bFirst)
                            {
                                // Save phase offset removed
                                fPhaseOffsetRemoved=fAvg;
                            }

                            if(bAvg)
                            {
								// Set global normalized flag
                                bPhaseNorm=TRUE;

                                // Save phase offset removed
                                fPhaseOffsetRemoved=fAvg;
                            }

                            if(bLine)
                            {
                                // Set global phase slope removed flag
                                bFreqOffsetRem=TRUE;

                                // Save freq slope removed from phase data
                                fPhaseSlopeRemoved=fSlope;

							}

                            // Increment filename
                            if(bIncExtension)
                            {
                                IncExtension(szFile, PHASE_DATA);
                                IncExtension(szFileTitle, PHASE_DATA);
                                IncExtension(szPhaseFile, PHASE_DATA);
                                IncExtension(szPhaseFileTitle, PHASE_DATA);
                                SetWindowText(hwndPhaseFilename, szFileTitle);
                            }
                        }

						// Force new PSD plot scale
						sPSPlot.y_tic=0;

						// Redraw status plots from new data
						UpdateStatusBar(hwndMain, NEW_DATA);

						// Reset redraw flags
						bPhaseRedraw=FALSE;
						bFreqRedraw=FALSE;

						// Clear plot lines
						ClearLines();

						// Clear synch flag
						bSynch=FALSE;

                        // Display normal cursor
                        SetCursor(hArrow);
                    }
                }

                // Fall right into EndDialog()
                // Reject changes - don't scale data - just close dialog box
                // Respond to esc key or cancel button
                case IDCANCEL:
                case IDC_SCALE_CANCEL:
				{
                    EndDialog (hDlg, 0);
                }
                return TRUE;
            }
        }
        break;
     }
     return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*                   Check Dialog Procedure                                  */
/*                                                                           */
/*  Revision record:                                                         */
/*      10/30/96    Added edit control CR logic                              */
/*      12/17/96    Added logic to handle case where data has changed        */
/*      03/18/97    Added autocalc logic                                     */
/*      06/17/97    Clear results in basic dlg box when sigma factor changes */
/*		02/19/98	Added code for printing outliers                         */
/*		02/21/98	Updated printing code for Win32 API                      */
/*		09/08/00	Added logic to disable remove selected outlier radio     */
/*					button if there are no outliers in listbox               */
/*		05/29/01	Changed # field from 5 to 7 characters                   */
/*		09/19/01	Allow chaining of largest removal if sigma factor = 0    */
/*		05/11/02	Changed to faster MAD calc using NewMedDev()             */
/*		10/13/02	Added copy feature                                       */
/*		11/18/06	Added CreateTab() calls                                  */
/*		08/24/07	Added nClip usage                                        */
/*		08/24/08	Added progress message                                   */
/*		06/02/13	Added writing of outlier list to disk file               */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK CheckDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam)
{
    // Local macros
    #define SORT_SIZE   0
	#define SORT_NUM    1
    #define REMOVE_NONE 0
    #define REMOVE_ALL  1
    #define REMOVE_LRG  2
    #define REMOVE_SEL  3

	// Local printing macros
	#define LINES_PER_COLUMN 80     // # data lines/column - was 55
	#define PRINT_LINES 0           // Control printing of lines (0 or 1)

    // Local variables
    // Chars
    char szBuffer[BUFFER_SIZE];     // Text buffer
	char szOutlier[BIG_BUFFER_SIZE];// Outlier file path
    // Ints
	int i;                          // General index
    int j;                          // Outlier array index
	int nRow;                       // Current row #
    static int *nOutArray;          // Pointer to outlier array
									// This is an array of freq data point #s
                                    // that are outliers
    static int nNumRows=1;          // Initialization for testing
    static int nSort=SORT_NUM;      // Sorting choice: SORT_SIZE or SORT_NUM
    static int nRemove=REMOVE_NONE; // Removing choice
    static int nLargest;            // Index of largest outlier
    static int nOutliers=0;         // # outliers
	static int nRemoved=0;			// # outliers removed
    // BOOLs
    static BOOL bArrayExists=FALSE; // Outlier array allocation flag
    static BOOL bSelRemoved=FALSE;  // Selected outlier removed flag
    static BOOL bAllRemoved=FALSE;  // All outliers removed flag
    static BOOL bLrgRemoved=FALSE;  // Largest outlier removed flag
    static BOOL bRemoveOutliers=FALSE;  // Remove outliers flag
	static BOOL bDataChanged=FALSE; // Freq data changed flag (outlier removed)
	static BOOL bTabCreated=FALSE;	// Flag to limit tab creations to one
	static int nClip;				// Size of szClipboard (chars)
    // Floats
    static float fMedAbsDev;        // Median absolute deviation
    // F_TYPEs
    static F_TYPE fFactor=5.0;      // Sigma multiplier factor
    static F_TYPE fMed;             // Median value
    static F_TYPE fUpperLimit;      // Upper outlier limit
    static F_TYPE fLowerLimit;      // Lower outlier limit
    static F_TYPE fLargest;         // Largest outlier
    // Misc
	DTCOLORSTRUCT Color;            // Color structure
    static HWND hOutTbl=NULL;       // Handle to data table
    LPVMSTRUCT lpVMData;            // Pointer to VMSTRUCT
	PENSTRUCT Pen;                  // Pen structure
	// Printing variables
	// Chars
	static char szLabel[BUFFER_SIZE+1];     // "Phase" or "Frequency" label

	#ifndef LITE_VER
	char szFormat[BUFFER_SIZE+1];   // Format string
	// Clipboard variables
	HGLOBAL hClipboard;				// Handle to clipboard text buffer
	LPSTR	szClipboard;			// Ptr to clipboard text string
	// Misc
	static FILE *hFile;           	// DOS file handle
	#endif
	
	// Shorts
	static short yChar;             // Text character vertical size
	static short xChar;             // Text character horizontal size
	static short xPage, yPage;      // Graphic page dims in pixels
	// Ints
	static int nLine;             	// Line #
	static int nCol;                // Column #
	static int nPage;               // Page #
	static int nPages;              // # Pages
	static int nFull;               // Max # data points per page
	static int nStart;              // Analysis start index
	static int nEnd;                // Analysis end index
	static int nSize;               // # data points
	// BOOLs
	static BOOL bNewPage;           // New page flag
	static BOOL bFont=FALSE;        // Flag for font created
	// Handles
	static HDC hdcPrn;                     // Handle to printer device context

	#ifndef LITE_VER
	// Function Pointers
	FARPROC lpfnAbortProc;          // Pointer to AbortProc()
	FARPROC lpfnPrintDlgProc;       // Pointer to PrintDlgProc()

	// Structs
	TEXTMETRIC tm;                  // Text metrics structure
	// Win32 API printing structs
	PRINTDLG pd;
	DOCINFO di;
	// Printer font variables
	LOGFONT logfont;                // Printer logical font structure
	static HFONT hPrnFont;          // Printer font handle
	#endif

    // Start of code
    LoadIcon(hInst, "FlatCheckIcon");

    // Set color parameters
    Color.BkgrdColor=GetSysColor(COLOR_HIGHLIGHT);
    Color.TextColor=GetSysColor(COLOR_HIGHLIGHTTEXT);
	Color.SelBkgrdColor=DEFAULTCOLOR;
    Color.SelTextColor=DEFAULTCOLOR;

    // Set pen parameters
	Pen.fPenStyle=PS_SOLID;
    Pen.nWidth=2;
    Pen.clr=GetSysColor(COLOR_HIGHLIGHT); // Makes black

    switch(message)
    {
        case WM_INITDIALOG:
        {
            // Get dialog box title
            GetWindowText(hDlg, szBoxTitle, TITLESIZE);

            // Set global dialog box handle
            hDialog=hDlg;

            // Clear outlier array flag
            bArrayExists=FALSE;

			// Clear tab creation flag
			bTabCreated=FALSE;

			// Clear # outliers
			nOutliers=0;
           
			// Write prompt message
            WritePromptMessage(TB_CHECK);

			// Set analysis limits
			nSize=(int)fFreqData[0];
			nStart=(int)fFreqData[1];
			nEnd=(int)fFreqData[2];
			
			// Initialize the sort order radio buttons
			Button_SetCheck(GETHCTL(IDC_CHECK_SIZE), !nSort);
			Button_SetCheck(GETHCTL(IDC_CHECK_NUM), nSort);

			// Restore the Show Details checkbox state
			Button_SetCheck(GETHCTL(IDC_CHECK_SHOW), bCheckDetails);

			// Initialize the remove method radio buttons
			nRemove=REMOVE_NONE;
			Button_SetCheck(GETHCTL(IDC_CHECK_NONE), TRUE);
			Button_SetCheck(GETHCTL(IDC_CHECK_ALL), FALSE);
			Button_SetCheck(GETHCTL(IDC_CHECK_LRG), FALSE);
			Button_SetCheck(GETHCTL(IDC_CHECK_SEL), FALSE);

			// Disable remove selected radio button
			// Do not enable this choice unless there are outliers
			// in the listbox
			EnableWindow(GETHCTL(IDC_CHECK_SEL), FALSE);

			// Disable print button
			EnableWindow(GETHCTL(IDC_CHECK_PRINT), FALSE);

			// Disable copy button
			EnableWindow(GETHCTL(IDC_CHECK_COPY), FALSE);

			// Show sigma multiplier factor
			_snprintf(szBuffer, sizeof(szBuffer), "%5.3f", fFactor);
			SetWindowText(GETHCTL(IDC_CHECK_FACTOR), szBuffer);

			// Set up outlier table if details flag is true
			if(bCheckDetails)
			{
				// Get handle for outlier table
				hOutTbl=GETHCTL(IDC_CHECK_TABLE);

				// Allow global access to outlier table's handle
				hDialog=hOutTbl;

				// Allocate initialized memory for outlier array
				// Outlier array is an array of ints representing the
				// frequency data point #s of the outliers
				// The size of this outlier array is equal to that of
				// the actual data part of the frequency data array
				// It is accessed w/o ARRAY_OFFSET
				if((nOutArray=(int*)calloc(((int)fFreqData[0]),
					sizeof(int)))==NULL)
				{
					// Announce error and bail out
					AllocErrorMessage();
					EndDialog(hDlg, 0);
					return TRUE;
				}

				#if(0) // For testing
				TRACE_INT(nOutArray);
				#endif

				bArrayExists=TRUE;

				// Create two columns
				SendMessage(hOutTbl, DTM_SETCOLCOUNT, (WPARAM)OT_NUM_COLS,
					(LPARAM)0);

				// configure the outlier point # column to a string
				SendMessage(hOutTbl, DTM_SETCOLTYPE, (WPARAM)OT_NUM_COL_NUM,
					(LPARAM)DTT_ZSTRING);

				// configure the outlier data column to a string
				SendMessage(hOutTbl, DTM_SETCOLTYPE, (WPARAM)OT_OUT_COL_NUM,
					(LPARAM)DTT_ZSTRING);

				// So we will use 7-digit integer format for point #
				// This requires 7 characters
				SendMessage(hOutTbl, DTM_SETCOLDATALEN, (WPARAM)OT_NUM_COL_NUM,
					(LPARAM)OT_NUM_NUM_CHARS);

				// Column width is in dialog units (4/char)
				// So need 7*4=28
				SendMessage(hOutTbl, DTM_SETCOLWIDTH, (WPARAM)OT_NUM_COL_NUM,
					(LPARAM)(4*OT_NUM_NUM_CHARS));

				// We will use 14-digit exponential format
				// This requires 20 characters + 1 for EOS
				SendMessage(hOutTbl, DTM_SETCOLDATALEN, (WPARAM)OT_OUT_COL_NUM,
				(LPARAM)(OT_NUM_OUT_CHARS+1));

				// Column width is in dialog units (4/char)
				// So need 20*4=80
				SendMessage(hOutTbl, DTM_SETCOLWIDTH, (WPARAM)OT_OUT_COL_NUM,
					(LPARAM)(4*OT_NUM_OUT_CHARS));

				// label the column headings
					SendMessage(hOutTbl, DTM_SETCOLHEAD,
						(WPARAM)OT_NUM_COL_NUM, (LPARAM)(LPSTR)"#");
					SendMessage(hOutTbl, DTM_SETCOLHEAD,
						(WPARAM)OT_OUT_COL_NUM,
						(LPARAM)(LPSTR)"Frequency Outlier");

				// Center point # column heading, no data editing, and make
				// column width fixed
				SendMessage(hOutTbl, DTM_SETCOLSTYLE, (WPARAM)OT_NUM_COL_NUM,
					(LPARAM)(DTCS_HEADCENTER | DTCS_FIXED));

				// Center outlier column heading , no data editing, and make
				// column width fixed
				SendMessage(hOutTbl, DTM_SETCOLSTYLE, (WPARAM)OT_OUT_COL_NUM,
					(LPARAM)(DTCS_HEADCENTER | DTCS_FIXED));

				// Set color for currently selected cell
				SendMessage(hOutTbl, DTM_SETCURCELLCOLOR, (WPARAM)0,
					(LPARAM)(LPDTCOLORSTRUCT)&Color);

				// Change pen used for focus rectangle for better visibility
				SendMessage(hOutTbl, DTM_SETFOCUSPEN, (WPARAM)0,
					(LPARAM)(LPPENSTRUCT)&Pen);

				// Do not initiate communications with data table yet
			}

			// Autocalc check
			// Doing this gives immediate result for current params
			if(bAutoCalc)
			{
				PostMessage(hDlg, WM_COMMAND,
					GET_WM_COMMAND_MPS(IDC_CHECK_CALC, NULL, 0));
			}
		}
		return TRUE;

		// DataTable virtual memory messages
		// Get the first row of data
		case DTM_VM_GETFIRST:
		{
			// Get pointer to VMSTRUCT
			lpVMData=(LPVMSTRUCT)lParam;

			// Set index to begining
			lpVMData->dwKey=0;

			// Get row data
			lpVMData->nStatus=(short)GetOutlierData(lpVMData, nOutArray,
				nNumRows);
		}
		break;

		case DTM_VM_GETLAST:
		{
			// Get pointer to VMSTRUCT
			lpVMData=(LPVMSTRUCT)lParam;

			// Set index to last row
			lpVMData->dwKey=nNumRows-1; // Always OK

			// Get row data
			lpVMData->nStatus=(short)GetOutlierData(lpVMData, nOutArray,
				nNumRows);
		}
		break;

		// Get the next row of data (data after row=dwKey)
		case DTM_VM_GETNEXT:
		{
			// Get pointer to VMSTRUCT
			lpVMData=(LPVMSTRUCT)lParam;

			// Increment index
			lpVMData->dwKey+=1;

			// Get row data
			lpVMData->nStatus=(short)GetOutlierData(lpVMData, nOutArray,
				nNumRows);
		}
		break;

		// Get the previous row of data (data before row=dwKey)
		case DTM_VM_GETPREV:
		{
			// Get pointer to VMSTRUCT
			lpVMData=(LPVMSTRUCT)lParam;

			// Decrement index
			lpVMData->dwKey-=1;

			// Get row data
			lpVMData->nStatus=(short)GetOutlierData(lpVMData, nOutArray,
				nNumRows);
		}
		break;

		// Get the row of data that is specified % down table
		case DTM_VM_GETPERCENT:
		{
			// Get pointer to VMSTRUCT
			lpVMData=(LPVMSTRUCT)lParam;

			// Calc index
			lpVMData->dwKey=(lpVMData->dwKey)*(long)nNumRows/100L;

			// Get row data
			lpVMData->nStatus=(short)GetOutlierData(lpVMData, nOutArray,
				nNumRows);
		}
		break;

		// Get the row of data at dwKey
		case DTM_VM_GETROWDATA:
		{
			// Get pointer to VMSTRUCT
			lpVMData=(LPVMSTRUCT)lParam;

			// Get row data
			lpVMData->nStatus=(short)GetOutlierData(lpVMData, nOutArray,
				nNumRows);
		}
		break;

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::CHECK_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::CHECK_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "CHECK_FUNCTION");
					#endif
				}
				break;

				case IDC_CHECK_SHOW:
				{
					// Get the state of the Show Details checkbox
					bCheckDetails=
						(BOOL)Button_GetCheck(GETHCTL(IDC_CHECK_SHOW));

					// Free outlier array
					if(bArrayExists)
					{
						// Free outlier array
						free(nOutArray);
						bArrayExists=FALSE;
					}

					// Clear the table handle
					hOutTbl=0;

					// Change to other Check dialog box template
					// Note: hwmd & cmd args not needed
					PostMessage(hwndMain, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDM_CHECK, NULL, 0));

					EndDialog(hDlg, 0);
					return TRUE;
                }

                // Respond to change in display order
                case IDC_CHECK_NUM:
                case IDC_CHECK_SIZE:
                {
					// Recalculate with new display order
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_CHECK_CALC, NULL, 0));
                }
                break;

                case IDC_CHECK_FACTOR:
                {
                    // Respond to change in sigma factor by clearing results
                    // Note:  Added hOutTbl test on advice of Bounds Checker
                    // & added nOutliers test in response to VC++ debugging
                    if(GET_WM_COMMAND_CMD(wParam, lParam)==EN_CHANGE)
                    {
                        // Clear the # outliers result
						SetWindowText(GETHCTL(IDC_CHECK_OUTLIERS),	"");

					   if(hOutTbl && nOutliers)
                       {
                            // Clear the outlier table
							SendMessage(hOutTbl, DTM_VM_INITIALIZE,
								(WPARAM)FALSE, (LPARAM)1);
							SendMessage(hOutTbl, DTM_SETACCESSPOS, (WPARAM)0,
								(WPARAM)0);
							SendMessage(hOutTbl, DTM_UPDATECELL,
								(WPARAM)DTA_ACCESS, (LPARAM)(LPSTR)NULL);
							SendMessage(hOutTbl, DTM_SETACCESSPOS,
								(WPARAM)1, (LPARAM)0);
							SendMessage(hOutTbl, DTM_UPDATECELL,
								(WPARAM)DTA_ACCESS, (LPARAM)(LPSTR)NULL);

							// Disable remove selected radio button
							EnableWindow(GETHCTL(IDC_CHECK_SEL), FALSE);

							// Disable print and copy buttons
							EnableWindow(GETHCTL(IDC_CHECK_PRINT), FALSE);
							EnableWindow(GETHCTL(IDC_CHECK_COPY), FALSE);
						}
					}

					// Respond to edit control when it loses the input focus
                    // unless it loses it to the close button
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_CHECK_CLOSE)))
                    {
                        // Get sigma factor
						GetWindowText(GETHCTL(IDC_CHECK_FACTOR), szBuffer,
							BUFFER_SIZE-1);
                        fFactor=fabs(atof(szBuffer)); // must be +
                        _snprintf(szBuffer, sizeof(szBuffer), "%5.3f",
							fFactor);
						SetWindowText(GETHCTL(IDC_CHECK_FACTOR), szBuffer);

						// Special case if sigma factor = 0
						if(fFactor==0.0)
						{
	                        _snprintf(szBuffer, sizeof(szBuffer),
								"%5.3f (All)", fFactor);
							SetWindowText(GETHCTL(IDC_CHECK_FACTOR), szBuffer);
						}
                    }
                }
                break;

				// Respond to CR in an edit control
				// Note: No button is a DEFPUSHBUTTON
				case IDOK:
				{
					// Does factor edit control have focus?
					if(GetFocus()==GETHCTL(IDC_CHECK_FACTOR))
					{
						// Send EN_KILLFOCUS message to start edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_CHECK_FACTOR, 0,
							EN_KILLFOCUS));
					}
				}
				break;

                case IDC_CHECK_CALC:
                {
                    // Display wait cursor
                    SetCursor(hWait);

					// Set busy flag
					bBusy=TRUE;

                    // Get sigma multiplier factor
					GetWindowText(GETHCTL(IDC_CHECK_FACTOR), szBuffer,
						BUFFER_SIZE-1);
                    fFactor=(F_TYPE)atof(szBuffer);

                    // Note:  bRemoveOutliers is used for simple CheckBox and
                    // nRemove is used for DetailedCheckBox, as indicated by
                    // bCheckDetails flag

                    // Reset bRemoveOutliers flag
                    bRemoveOutliers=FALSE;

                    // Read remove flag
                    if(!bCheckDetails)
					{
						bRemoveOutliers=
							(BOOL)Button_GetCheck(GETHCTL(IDC_CHECK_REMOVE));

						// Clear remove flag - don't want to do it twice
						Button_SetCheck(GETHCTL(IDC_CHECK_REMOVE),	FALSE);
					}

					// Reset nRemove unless sigma factor = 0
					// Sigma factor = 0 is code to allow chaining of calc
					if(fFactor!=0.0)
					{
						nRemove=REMOVE_NONE;
					}

					if(bCheckDetails)
					{
						// Read sort type
						if(Button_GetCheck(GETHCTL(IDC_CHECK_NUM)))
						{
							nSort=SORT_NUM;
						}

						if(Button_GetCheck(GETHCTL(IDC_CHECK_SIZE)))
						{
							nSort=SORT_SIZE;
						}

						// Read remove type
						if(Button_GetCheck(GETHCTL(IDC_CHECK_ALL)))
						{
							nRemove=REMOVE_ALL;
						}

						if(Button_GetCheck(GETHCTL(IDC_CHECK_LRG)))
						{
							nRemove=REMOVE_LRG;
						}

						if(Button_GetCheck(GETHCTL(IDC_CHECK_SEL)))
						{
							nRemove=REMOVE_SEL;
						}
					}

					// Write message
					WriteMessage("Calculating MAD - Please Wait");
					
					// Calc median value (via wrapper function)
					// Part of FrequenC DLL as of 03/18/03
					FindMedian(fFreqData, FREQ_DATA, &fMed);

					// Find median absolute deviation
					// Note: Changed from MedDev() to faster NewMedDev()
					MedDev(fFreqData, &fMedAbsDev);

					// Display MAD
					_snprintf(szBuffer, sizeof(szBuffer), "%e", fMedAbsDev);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_CHECK_DEV), szBuffer);

					// Write message
					WriteMessage("MAD Found");
					
					// Calc outlier limits
					fLowerLimit=fMed-fMedAbsDev*fFactor;
					fUpperLimit=fMed+fMedAbsDev*fFactor;

					// If we are removing the selected outlier, get its
					// index and set its value to 0
					if(nRemove==REMOVE_SEL)
					{
						// Create tab to save previous data if requested
						if(bTabs && bTabChange &&!bTabCreated)
						{
							CreateTab();
							bTabCreated=TRUE;
						}
						
						// Get index of selected outlier
						nRow=(int)SendMessage(hOutTbl, DTM_GETCURROW,
							(WPARAM)0, (LPARAM)0);
						i=nOutArray[nRow];

						// Make this point a gap
						fFreqData[i+ARRAY_OFFSET]=0.0;

						// Set flags
						bSelRemoved=TRUE;
						bDataChanged=TRUE;
						bFreqRedraw=TRUE;
					}

					// Initialize nOutArray index
					j=0;

					// Initialize flargest & nLargest to -1 = no outlier
					fLargest=0.0;
					nLargest=-1;

					// Search through freq data array for outliers, and, if in
					// detailed mode, store their point #s in the nOutArray

					// Search only between analysis limits
					for(i=nStart-1; i<nEnd; i++)
					{
						// Skip gaps
						if(fFreqData[i+ARRAY_OFFSET])
						{
							// Check for outlier
							if((fFreqData[i+ARRAY_OFFSET]<fLowerLimit) ||
							   (fFreqData[i+ARRAY_OFFSET]>fUpperLimit))
							{
								// If we are removing all outliers, set the
								// outlier value to 0 here and don't put it
								// in the outlier array
								if((bRemoveOutliers) || (nRemove==REMOVE_ALL))
								{
									// Create tab to save previous data 
									// if requested
									if(bTabs && bTabChange && !bTabCreated)
									{
										CreateTab();
										bTabCreated=TRUE;
									}
						
									// Remove outlier
									fFreqData[i+ARRAY_OFFSET]=0.0;

									// Set outlier removed flags
									bAllRemoved=TRUE;
									bDataChanged=TRUE;
									bFreqRedraw=TRUE;
								}
								else if(bCheckDetails)
								{
									// Store point # in outlier array
									nOutArray[j]=i;
								}

								// Keep track of which outlier is the largest
								// and store its index as nLargest
								if(fabs(fFreqData[i+ARRAY_OFFSET]-fMed)>
									fLargest)
								{
									fLargest=fabs(fFreqData[i+ARRAY_OFFSET]-
										fMed);
									nLargest=j;
									// Index j refers to outlier array,
									// not overall data array
								}

								// Increment outlier array index
								j++;
							}
						}
					}

					nNumRows=j;
					nOutliers=j;

					// If we are removing largest outlier, set its value to 0
					// and remove it from the outlier array
					if((bCheckDetails) && (nRemove==REMOVE_LRG) &&
						(nLargest>-1))
					{
						// Create tab to save previous data if requested
						if(bTabs && bTabChange &&!bTabCreated)
						{
							CreateTab();
							bTabCreated=TRUE;
						}
						
						// Set outlier data value to zero
						fFreqData[nOutArray[nLargest]+ARRAY_OFFSET]=0.0;

						// Eliminate removed point from the outlier array
						// and move all others up one place
						for(i=nLargest; i<nOutliers-1; i++)
						{
							nOutArray[i]=nOutArray[i+1];
						}

						// Decrement # outliers and table rows
						nOutliers--;
						nNumRows--;

						// Set flags
						bLrgRemoved=TRUE;
						bDataChanged=TRUE;
						bFreqRedraw=TRUE;

						// Reset nRemove to none to avoid multiple calcs
						// unless sigma factor = 0
						// Sigma factor = 0 is code to allow chaining of calc
						if(fFactor!=0.0)
						{
							nRemove=REMOVE_NONE;

							if(bCheckDetails)
							{
								Button_SetCheck(GETHCTL(IDC_CHECK_NONE), TRUE);
								Button_SetCheck(GETHCTL(IDC_CHECK_LRG), FALSE);
							}
						}
					}

					// Outlier table is arranged by outlier index (place)
					// If we want it to be arranged by outlier size, do a
					// sort with an appropriate comparison function here
					// This qsort will rearrange the outlier table of freq
					// data array indices in order of decreasing outlier size
					// The quantity to compare is fabs(fFreqData - fMed)
					if(nSort==SORT_SIZE)
					{
						// Set file scope median value
						fMedVal=fMed;
						
						// Sort outlier data by outlier size
						// qsort() args are:
						//    (1)  pointer to nOutArray[] array to be sorted
						//    (2)  # of array elements = nOutliers
						//    (3)  size of array elements = sizeof(int)
						//    (4)  comparison function
						qsort((void *)nOutArray, (size_t)nOutliers,
							sizeof(int), OutlierCompare);
					}
					
					// Display # outliers
					if(bAllRemoved)
					{
						// Display # outliers that were removed
						_snprintf(szBuffer, sizeof(szBuffer),
							"%d (All Removed)", nOutliers);

						// Save # outliers removed
						nRemoved=nOutliers;

						// Set # outliers and # table rows to zero
						nOutliers=0;
						nNumRows=0;

						// Reset nRemove to none
						nRemove=REMOVE_NONE;

						if(bCheckDetails)
						{
							Button_SetCheck(GETHCTL(IDC_CHECK_NONE), TRUE);
							Button_SetCheck(GETHCTL(IDC_CHECK_ALL), FALSE);
						}
					}
					else if(bLrgRemoved)
					{
						// Save # outliers removed
						nRemoved=1;

						// Display # outliers
						_snprintf(szBuffer, sizeof(szBuffer),
							"%d (Lrg Removed)", nOutliers);

						// Reset flag
						bLrgRemoved=FALSE;

						// Reset nRemove to none unless sigma factor is 0
						// Sigma factor = 0 is code to allow chaining of calc
						if(fFactor!=0.0)
						{
							nRemove=REMOVE_NONE;

							if(bCheckDetails)
							{
								Button_SetCheck(GETHCTL(IDC_CHECK_NONE), TRUE);
								Button_SetCheck(GETHCTL(IDC_CHECK_LRG), FALSE);
							}
						}
					}
					else if(bSelRemoved)
					{
						// Save # outliers removed
						nRemoved=1;

						// Display # outliers
						_snprintf(szBuffer, sizeof(szBuffer),
							"%d (Sel Removed)", nOutliers);

						// Reset flag
						bSelRemoved=FALSE;

						// Reset nRemove to none
						nRemove=REMOVE_NONE;

						if(bCheckDetails)
						{
							Button_SetCheck(GETHCTL(IDC_CHECK_NONE), TRUE);
							Button_SetCheck(GETHCTL(IDC_CHECK_SEL), FALSE);
						}
					}
					else
					{
						_snprintf(szBuffer, sizeof(szBuffer),
							"%d", nOutliers);
					}

					SetWindowText(GETHCTL(IDC_CHECK_OUTLIERS), szBuffer);

					// Initiate communications with data table
					if(bCheckDetails)
					{
						SendMessage(hOutTbl, DTM_VM_INITIALIZE, (WPARAM)FALSE,
							(LPARAM)nNumRows);
					}

					// Set state of print button
					if(nOutliers && !bAllRemoved)
					{
						// Enable print and copy buttons
						EnableWindow(GETHCTL(IDC_CHECK_PRINT), TRUE);
						EnableWindow(GETHCTL(IDC_CHECK_COPY), TRUE);
					}
					else
					{
						// Disable print and copy buttons
						EnableWindow(GETHCTL(IDC_CHECK_PRINT), FALSE);
						EnableWindow(GETHCTL(IDC_CHECK_COPY), FALSE);
					}
					
					// Reset flag
					bAllRemoved=FALSE;

					// Display normal cursor
					SetCursor(hArrow);

					if(bFreqRedraw) // Outliers removed
					{
						// Put info into log file
						_snprintf(szBuffer, sizeof(szBuffer),
							"Sig Factor=%e, #=%d", fFactor, nRemoved);
						ShortenExp(szBuffer);
						WriteLog(28, szBuffer);
					}
					else // Outliers not removed
					{
						// Put info into log file
						_snprintf(szBuffer, sizeof(szBuffer),
							"Sig Factor=%e, #=%d", fFactor, nOutliers);
						ShortenExp(szBuffer);
						WriteLog(29, szBuffer);
					}
								
 					// Update status bar plot after outlier(s) removed
					UpdateStatusBar(hwndMain, NEW_DATA);

					// Enable remove selected radio button
					// only if there are outliers in the listbox
					if(nOutliers)
					{
						EnableWindow(GETHCTL(IDC_CHECK_SEL), TRUE);
					}
					else
					{
						EnableWindow(GETHCTL(IDC_CHECK_SEL), FALSE);
					}
					
					#if(0) // New code 06/02/13
					// Write outlier list to disk file
					#ifndef LITE_VER
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_CHECK_WRITE, NULL, 0));
					#endif
					#endif

					#if(1) // New code 06/02/13
					// Skip if details not shown
					if(!bCheckDetails)
					{
						// Reset busy flag
						bBusy=FALSE;
						break;
					}

					// Write outlier list to disk file
					// Compose outlier file path
					strlcpy(szOutlier, szPath, sizeof(szOutlier));
					strlcat(szOutlier, "Outlier.dat", sizeof(szOutlier));

					#if(0) // For testing
					TRACE_STR(szOutlier);
					#endif

					// Open outlier file
					if((hFile=fopen(szOutlier, "w"))==NULL)
					{
						// Error - couldn't open outlier file
	                    MessageBox(hDlg,"Could not open outlier file.\r\nIs it open in another application?",
							"Check",	MB_ICONEXCLAMATION);
						break;
					}

					// Write title to outlier file
					LoadString(hInst, IDS_FORMAT_21, szFormat, BUFFER_SIZE);
					_snprintf(szBuffer, sizeof(szBuffer), szFormat, szFileTitle);
					strlcat(szBuffer, "\r\n", sizeof(szBuffer));
					fputs(szBuffer, hFile);

					// Write sub-title to outlier file
					_snprintf(szBuffer, sizeof(szBuffer),
						"Points %d thru %d of %d", nStart, nEnd, nSize);
					strlcat(szBuffer, "\r\n", sizeof(szBuffer));
					fputs(szBuffer, hFile);

					// Write MAD to outlier file
					_snprintf(szBuffer, sizeof(szBuffer),
						"Median Absolute Deviation: %e", fMedAbsDev);
					ShortenExp(szBuffer);
					strlcat(szBuffer, "\r\n", sizeof(szBuffer));
					fputs(szBuffer, hFile);

					// Write sigma factor to outlier file
					_snprintf(szBuffer, sizeof(szBuffer),
						"Sigma Factor: %12.5e", fFactor);
					ShortenExp(szBuffer);
					strlcat(szBuffer, "\r\n", sizeof(szBuffer));
					fputs(szBuffer, hFile);

					// Write # outliers to outlier file
					_snprintf(szBuffer, sizeof(szBuffer),
						"# Outliers: %3d", nOutliers);
					strlcat(szBuffer, "\r\n", sizeof(szBuffer));
					fputs(szBuffer, hFile);

					#if(0) // For testing
					TRACE_INT(nOutliers);
					#endif

					if(nOutliers) // Do we have any outliers?
					{
						#if(0) // For testing
						TRACE_INT(nOutArray);
						TRACE_INT(nOutArray[0]+1);
						TRACE_EXP(fFreqTimetags[nOutArray[0]+ARRAY_OFFSET]);
						TRACE_EXP(fFreqData[nOutArray[0]+ARRAY_OFFSET]);
						#endif

						// Write heading to outlier file
						if(bFreqTimetags) // Have timetags
						{
							// Write heading
							strlcpy(szBuffer, "#       MJD             Frequency",
								sizeof(szBuffer));
							strlcat(szBuffer, "\r\n", sizeof(szBuffer));
							fputs(szBuffer, hFile);
						}
						else // No timetags
						{
							// Write heading
							strlcpy(szBuffer, "#       Frequency",
								sizeof(szBuffer));
							strlcat(szBuffer, "\r\n", sizeof(szBuffer));
							fputs(szBuffer, hFile);
						}
						
						// Write outliers to outlier file
						for(i=0; i<nOutliers; i++)
						{
							if(bFreqTimetags) // Have timetags
							{
								// Write #
								_snprintf(szBuffer, sizeof(szBuffer),
									"%06d", nOutArray[i]+1);
								fputs(szBuffer, hFile);

								// Write MJD value
								_snprintf(szBuffer, sizeof(szBuffer), "  %14.8f",
									fFreqTimetags[nOutArray[i]+ARRAY_OFFSET]);
								fputs(szBuffer, hFile);

								// Write outlier value
								_snprintf(szBuffer, sizeof(szBuffer), "  %+20.13e",
									fFreqData[nOutArray[i]+ARRAY_OFFSET]);
								ShortenExp(szBuffer);
								strlcat(szBuffer, "\r\n", sizeof(szBuffer));
								fputs(szBuffer, hFile);
							}
							else // No timetags
							{
								// Write #
								_snprintf(szBuffer, sizeof(szBuffer),
									"%06d", nOutArray[i]+1);
								fputs(szBuffer, hFile);

								// Write outlier value
								_snprintf(szBuffer, sizeof(szBuffer), "  %+20.13e",
									fFreqData[nOutArray[i]+ARRAY_OFFSET]);
								ShortenExp(szBuffer);
								strlcat(szBuffer, "\r\n", sizeof(szBuffer));
								fputs(szBuffer, hFile);
							}
						}
					}
					#endif

					// Close outlier file
					fclose(hFile);

					// Reset busy flag
					bBusy=FALSE;
				}
				break;

				#ifndef LITE_VER
				case IDC_CHECK_PRINT:
				{
					// Let user choose printer with print dialog box
					// Initialize PRINTDLG structure
					memset(&pd, 0, sizeof(PRINTDLG));
					pd.lStructSize=sizeof(PRINTDLG);
					pd.hwndOwner=hDlg;
					pd.Flags=PD_RETURNDEFAULT; // Don't show dialog box

					// 1st (hidden) call to PrintDlg()
					// To set up hDevNames & hDevMode
 					if(!PrintDlg(&pd))
					{
						// PrintDlg() called failed
						MessageBox(hwndMain, "Printer Not Found", "Run Print",
							MB_ICONEXCLAMATION);
						break;
					}

					// Reinitialize PRINTDLG structure
					// Get DC & no selection of text & no page #s
					pd.Flags&= ~PD_RETURNDEFAULT;
					pd.Flags|=PD_RETURNDC | PD_NOSELECTION | PD_NOPAGENUMS |
						PD_USEDEVMODECOPIES;

					// 2nd (visible) call to PrintDlg()
					if(PrintDlg(&pd))
					{
						// Get printer device context
						hdcPrn=pd.hDC;
					}
					else
					{
						if(CommDlgExtendedError())
						{
							// Printer error
							MessageBox(hwndMain, "Printer Error", "Run Print",
							MB_ICONEXCLAMATION);
						}
						else // Error code 0 - User hit cancel button
						{
							break;
						}
					}

					// Determine logfont.lfHeight from point size = nPointSize
					// where nPointSize is global variable that user can enter
					// in General page of Configure property sheet
					// Win32 documentation gives the formula:
					// lfHeight = -MulDiv(PointSize,
					// GetDeviceCaps(hDC, LOGPIXELSY), 72);
					// which becomes the following for our variables:
					// nFontHeight = -MulDiv(nPointSize,
					// GetDeviceCaps(hdcPrn, LOGPIXELSY), 72);
					// Both nPointSize and nFontHeight are global variables
					// A couple of typical values are nPointSize=9,
					// nFontHeight=-75
					// and nPointSize=10,
					// nFontHeight=-83 (the abs value of nFontHeight is used)
					nFontHeight = -MulDiv(nPointSize,
						GetDeviceCaps(hdcPrn, LOGPIXELSY), 72);
					
					// Set font attributes
					// Fixed pitch simplify alignment
					// Size to fit across std 8.5"x11" portrait page
					logfont.lfHeight=nFontHeight;
					logfont.lfWidth=0;
					logfont.lfEscapement=0;
					logfont.lfOrientation=0;
					logfont.lfWeight=0;
					logfont.lfItalic=0;
					logfont.lfUnderline=0;
					logfont.lfStrikeOut=0;
					logfont.lfCharSet=OEM_CHARSET;
					logfont.lfOutPrecision=OUT_DEFAULT_PRECIS;
					logfont.lfClipPrecision=CLIP_DEFAULT_PRECIS;
					logfont.lfQuality=PROOF_QUALITY;
					logfont.lfPitchAndFamily=FIXED_PITCH | FF_DONTCARE;
					strlcpy(logfont.lfFaceName,"", LF_FACESIZE);

					// Create printer font
					hPrnFont=CreateFontIndirect(&logfont);
					bFont=TRUE;

					// Select font into printer device
					SelectObject(hdcPrn, hPrnFont);

					// Get text metrics
					GetTextMetrics(hdcPrn, &tm);
					yChar=(short)(tm.tmHeight+tm.tmExternalLeading);
					xChar=(short)tm.tmAveCharWidth;

					// Get page dimensions
					xPage=(short)GetDeviceCaps(hdcPrn, HORZRES);
					yPage=(short)GetDeviceCaps(hdcPrn, VERTRES);

					// Compose Print Manager message
					LoadString(hInst, IDS_MESSAGE_DATA, szPrnMsg,
						BUFFER_SIZE);

					// Set up DOCINFO structure
					memset(&di, 0, sizeof(DOCINFO));
					di.cbSize=sizeof(DOCINFO);
					di.lpszDocName=szPrnMsg;
					
					// Start printing
					if(hdcPrn != NULL)
					{
						// Disable program window
						EnableWindow(hDlg, FALSE);

						// Set up abort procedure
						bUserAbort=FALSE;
						lpfnPrintDlgProc=(FARPROC)PrintDlgProc;
						hDlgPrint=CreateDialog(hInst, "PrintAbortBox",
							hDlg, (DLGPROC)lpfnPrintDlgProc);
						lpfnAbortProc=(FARPROC)AbortProc;
						Escape(hdcPrn, SETABORTPROC, 0,
							(LPSTR)lpfnAbortProc, NULL);

						// Overall print if statement
						if(StartDoc(hdcPrn, &di) != SP_ERROR)
						{
							// Actual printing code starts here
							StartPage(hdcPrn);

							// Initialize newpage flag
							bNewPage=TRUE;

							// Initialize page #, line # & data point index
							nPage=0;
							nLine=0;
							i=0;

							// Determine total # pages
							// Determine page capacity
							nFull=4*LINES_PER_COLUMN;

							// Note:  The 1.0 forces a float calc
							nPages=(int)ceil((nEnd-nStart+1.0)/nFull);

							// Print while loop
							while(i<nOutliers)
							{
								if(bNewPage)
								{
									// Clear new page flag
									bNewPage=FALSE;

									// Select font into printer device
									// Note: Have to do this for each page
									SelectObject(hdcPrn, hPrnFont);

									// Annotate printout
									nCol=0;
									SetTextAlign(hdcPrn, TA_LEFT || TA_TOP);

									// Write title
									nLine=0;
									LoadString(hInst, IDS_FORMAT_21,
										szFormat, BUFFER_SIZE);
									_snprintf(szBuffer, sizeof(szBuffer),
										szFormat, szFileTitle);
									TextOut(hdcPrn, (int)(xChar/2),
										(int)((nLine+0.5)*yChar), szBuffer,
										strlen(szBuffer));

									// Compose label
									strlcpy(szLabel,
										"        Frequency", sizeof(szLabel));

									// Write sub-title
									nLine=1;
									_snprintf(szBuffer, sizeof(szBuffer),
										"Points %d thru %d of %d", nStart,
										nEnd, nSize);
									TextOut(hdcPrn, (int)(xChar/2),
										(int)((nLine+0.5)*yChar), szBuffer,
										strlen(szBuffer));

									// Write page #
									nLine=0;
									_snprintf(szBuffer, sizeof(szBuffer),
										"Page %d of %d ",
										nPage+1, nPages);
									TextOut(hdcPrn, (int)(xPage/2),
										(int)((nLine+0.5)*yChar), szBuffer,
										strlen(szBuffer));

									// Write date
									nLine=1;
									TextOut(hdcPrn, (int)(xPage/2),
										(int)((nLine+0.5)*yChar),
										szDate, strlen(szDate));

									// Write MAD
									nLine=2;
									_snprintf(szBuffer, sizeof(szBuffer),
										"Median Absolute Deviation: %20.13e",
										fMedAbsDev);
									ShortenExp(szBuffer);
									TextOut(hdcPrn, (int)(xChar/2),
										(int)((nLine+0.5)*yChar), szBuffer,
										strlen(szBuffer));

									// Write sigma factor
									nLine=2;
									_snprintf(szBuffer, sizeof(szBuffer),
										"Sigma Factor: %12.5e",
										fFactor);
									ShortenExp(szBuffer);
									TextOut(hdcPrn, (int)(xPage/2),
										(int)((nLine+0.5)*yChar), szBuffer,
										strlen(szBuffer));

									// Write headings
									nLine=4;

									// 4 # labels
									strlcpy(szBuffer,
										"   #", sizeof(szBuffer));
									TextOut(hdcPrn, (int)((0*xPage/4)+
										xChar/2),
										(int)((nLine+0.5)*yChar), szBuffer,
										strlen(szBuffer));
									TextOut(hdcPrn, (int)((1*xPage/4)+xChar/2),
										(int)((nLine+0.5)*yChar), szBuffer,
										strlen(szBuffer));
									TextOut(hdcPrn, (int)((2*xPage/4)+xChar/2),
										(int)((nLine+0.5)*yChar), szBuffer,
										strlen(szBuffer));
									TextOut(hdcPrn, (int)((3*xPage/4)+xChar/2),
										(int)((nLine+0.5)*yChar), szBuffer,
										strlen(szBuffer));

									// 4 value labels
									TextOut(hdcPrn, (int)((0*xPage/4)+
										(7*xChar)+
										xChar/2), (int)((nLine+0.5)*yChar),
										szLabel, strlen(szLabel));
									TextOut(hdcPrn, (int)((1*xPage/4)+
										(7*xChar)+
										xChar/2), (int)((nLine+0.5)*yChar),
										szLabel, strlen(szLabel));
									TextOut(hdcPrn, (int)((2*xPage/4)+
										(7*xChar)+
										xChar/2), (int)((nLine+0.5)*yChar),
										szLabel, strlen(szLabel));
									TextOut(hdcPrn, (int)((3*xPage/4)+
										(7*xChar)+
										xChar/2), (int)((nLine+0.5)*yChar),
										szLabel, strlen(szLabel));

									// Initialize line # and data point index
									nLine=6;

								} // End of new page code

								// Compose 1 line of data
								// Determine column #
								nCol=(int)floor(i/LINES_PER_COLUMN)%4;

								// Determine line #
								nLine=((nLine-5)%LINES_PER_COLUMN)+5;

								// Write #
								_snprintf(szBuffer, sizeof(szBuffer),
									" %06d", nOutArray[i]+1);
								TextOut(hdcPrn, (int)((xChar/2)+
									(nCol*xPage/4)),
									(int)((nLine+0.4)*yChar), szBuffer,
									strlen(szBuffer));

								// Compose outlier value
								_snprintf(szBuffer, sizeof(szBuffer),
									"  %+20.13e",
									fFreqData[nOutArray[i]+ARRAY_OFFSET]);
								ShortenExp(szBuffer);

								// Write outlier value
								TextOut(hdcPrn,
									(int)((7*xChar)+(xChar/2)+
									(nCol*xPage/4)),
									(int)((nLine+0.4)*yChar), szBuffer,
									strlen(szBuffer));

								// Increment data index and line #
								i++;
								nLine++;

								// Check if page full
								if(i%nFull==0)
								{
									EndPage(hdcPrn);
									nPage++;
									bNewPage=TRUE;
								}
							} // End of printing while loop
						} // End of print if statement

						// End printing
						// End last page
						EndPage(hdcPrn);

						// End document
						EndDoc(hdcPrn);

						// Check for user abort
						if(!bUserAbort)
						{
							// Reenable program window
							EnableWindow(hDlg, TRUE);
							// Destroy print abort dialog box
							DestroyWindow(hDlgPrint);
						}

						// Release device context
						DeleteDC(hdcPrn);
					}
					else // hdcPrn==NULL
					{
						;
					}
					// Delete printer logical font
					DeleteObject(hPrnFont);
				}
				break;

				// Respond to copy button
				case IDC_CHECK_COPY:
				{
					// Get size of clipboard memory allocation
					nClip=(5+nOutliers)*80;
					
					// Allocate global memory for 5 + nOutliers lines of info
					hClipboard=GlobalAlloc(GMEM_DDESHARE,
						(DWORD)nClip);
					szClipboard=GlobalLock(hClipboard);

					// Write title
					LoadString(hInst, IDS_FORMAT_21, szFormat, BUFFER_SIZE);
					_snprintf(szClipboard, nClip, szFormat, szFileTitle);
					strlcat(szClipboard, "\r\n", nClip);

					// Write sub-title
					_snprintf(szBuffer, sizeof(szBuffer),
						"Points %d thru %d of %d", nStart, nEnd, nSize);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);

					// Write MAD
					_snprintf(szBuffer, sizeof(szBuffer),
						"Median Absolute Deviation: %e", fMedAbsDev);
					ShortenExp(szBuffer);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);

					// Write sigma factor
					_snprintf(szBuffer, sizeof(szBuffer),
						"Sigma Factor: %12.5e", fFactor);
					ShortenExp(szBuffer);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);

					// Write heading
					strlcpy(szBuffer, "  #        Frequency",
						sizeof(szBuffer));
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);

					// Write outliers
					for(i=0; i<nOutliers; i++)
					{
						// Write #
						_snprintf(szBuffer, sizeof(szBuffer),
							"%06d", nOutArray[i]+1);
						strlcat(szClipboard, szBuffer, nClip);

						// Compose outlier value
						_snprintf(szBuffer, sizeof(szBuffer), "  %+20.13e",
							fFreqData[nOutArray[i]+ARRAY_OFFSET]);
						ShortenExp(szBuffer);
						strlcat(szClipboard, szBuffer, nClip);
						strlcat(szClipboard, "\r\n", nClip);
					}

					// Write info to clipboard
					GlobalUnlock(hClipboard);
					OpenClipboard(NULL);
					EmptyClipboard();
					SetClipboardData(CF_TEXT, hClipboard);
					CloseClipboard();
				}
				break;

				#if(0) // New code 06/02/13
				// Note:  This code was moved in-line
				// so this subroutine is not used
				// Subroutine to write outlier list to disk file
				case IDC_CHECK_WRITE:
				{
					// Compose outlier file path
					strlcpy(szOutlier, szPath, sizeof(szOutlier));
					strlcat(szOutlier, "Outlier.dat", sizeof(szOutlier));

					#if(1) // For testing
					TRACE_STR(szOutlier);
					#endif

					// Open outlier file
					if((hFile=fopen(szOutlier, "w"))==NULL)
					{
						// Error - couldn't open outlier file
	                    MessageBox(hDlg,"Could Not Open Outlier File",
							"Check",	MB_ICONEXCLAMATION);
						break;
					}

					// Write title to outlier file
					LoadString(hInst, IDS_FORMAT_21, szFormat, BUFFER_SIZE);
					_snprintf(szBuffer, sizeof(szBuffer), szFormat, szFileTitle);
					strlcat(szBuffer, "\r\n", sizeof(szBuffer));
					fputs(szBuffer, hFile);

					// Write sub-title to outlier file
					_snprintf(szBuffer, sizeof(szBuffer),
						"Points %d thru %d of %d", nStart, nEnd, nSize);
					strlcat(szBuffer, "\r\n", sizeof(szBuffer));
					fputs(szBuffer, hFile);

					// Write MAD to outlier file
					_snprintf(szBuffer, sizeof(szBuffer),
						"Median Absolute Deviation: %e", fMedAbsDev);
					ShortenExp(szBuffer);
					strlcat(szBuffer, "\r\n", sizeof(szBuffer));
					fputs(szBuffer, hFile);

					// Write sigma factor to outlier file
					_snprintf(szBuffer, sizeof(szBuffer),
						"Sigma Factor: %12.5e", fFactor);
					ShortenExp(szBuffer);
					strlcat(szBuffer, "\r\n", sizeof(szBuffer));
					fputs(szBuffer, hFile);

					// Write # outliers to outlier file
					_snprintf(szBuffer, sizeof(szBuffer),
						"# Outliers: %3d", nOutliers);
					strlcat(szBuffer, "\r\n", sizeof(szBuffer));
					fputs(szBuffer, hFile);

					#if(1) // For testing
					TRACE_INT(nOutliers);
					#endif

					if(nOutliers) // Do we have any outliers?
					{
						#if(1) // For testing
						TRACE_INT(nOutArray);
						TRACE_INT(nOutArray[0]+1);
						TRACE_EXP(fFreqTimetags[nOutArray[0]+ARRAY_OFFSET]);
						TRACE_EXP(fFreqData[nOutArray[0]+ARRAY_OFFSET]);
						#endif

						// Write heading to outlier file
						if(bFreqTimetags) // Have timetags
						{
							// Write heading
							strlcpy(szBuffer, "#       MJD             Frequency",
								sizeof(szBuffer));
							strlcat(szBuffer, "\r\n", sizeof(szBuffer));
							fputs(szBuffer, hFile);
						}
						else // No timetags
						{
							// Write heading
							strlcpy(szBuffer, "#       Frequency",
								sizeof(szBuffer));
							strlcat(szBuffer, "\r\n", sizeof(szBuffer));
							fputs(szBuffer, hFile);
						}
						
						#if(1)
						// Write outliers to outlier file
						for(i=0; i<nOutliers; i++)
						{
							if(bFreqTimetags) // Have timetags
							{
								// Write #
								_snprintf(szBuffer, sizeof(szBuffer),
									"%06d", nOutArray[i]+1);
								fputs(szBuffer, hFile);

								// Write MJD value
								_snprintf(szBuffer, sizeof(szBuffer), "  %14.8f",
									fFreqTimetags[nOutArray[i]+ARRAY_OFFSET]);
								fputs(szBuffer, hFile);

								// Write outlier value
								_snprintf(szBuffer, sizeof(szBuffer), "  %+20.13e",
									fFreqData[nOutArray[i]+ARRAY_OFFSET]);
								ShortenExp(szBuffer);
								strlcat(szBuffer, "\r\n", sizeof(szBuffer));
								fputs(szBuffer, hFile);
							}
							else // No timetags
							{
								// Write #
								_snprintf(szBuffer, sizeof(szBuffer),
									"%06d", nOutArray[i]+1);
								fputs(szBuffer, hFile);

								// Write outlier value
								_snprintf(szBuffer, sizeof(szBuffer), "  %+20.13e",
									fFreqData[nOutArray[i]+ARRAY_OFFSET]);
								ShortenExp(szBuffer);
								strlcat(szBuffer, "\r\n", sizeof(szBuffer));
								fputs(szBuffer, hFile);
							}
						}
						#endif
					}
					// Close outlier file
					fclose(hFile);
				}
				break;
				#endif

				#endif

				// Respond to esc key or close button
				case IDCANCEL:
				case IDC_CHECK_CLOSE:
				{
					// Has data changed?
					if(bDataChanged)
					{
						// Set data changes flag (always freq data)
						bFreqDataChanged=TRUE;
						bFreqDataUnsaved=TRUE;
						sFPlot.new_file=TRUE;
						bFreqScaleChanged=TRUE;
						bOutRem=TRUE;
						nOutliersRemoved=nOutliers;
						bFreqRedraw=TRUE;
						bSynch=FALSE;

						// Force new PSD plot scale
						sPSPlot.y_tic=0;

						// Increment filename
						if(bIncExtension)
						{
							IncExtension(szFile, FREQ_DATA);
							IncExtension(szFileTitle, FREQ_DATA);
							IncExtension(szFreqFile, FREQ_DATA);
							IncExtension(szFreqFileTitle, FREQ_DATA);
							SetWindowText(hwndFreqFilename, szFileTitle);
						}
					}

					// Clear plot lines
					ClearLines();

					// Clear the table handle
					hOutTbl=0;

					if(bArrayExists)
					{
						// Free outlier array
						free(nOutArray);
						bArrayExists=FALSE;
					}
					EndDialog (hDlg, nDummy);
				}
				return TRUE;
			}
		}
		break;
	 }
	 return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*      Function to put outlier data point into row of data table            */
/*                                                                           */
/*      There is a VMSTRUCT inside the DataTable control that contains the   */
/*      elements nStatus, dwKey and lpData.  A pointer to it is passed to    */
/*      us via the lParam of each DTM message.  We assign this to a          */
/*      LPVMSTRUCT pointer called lpVMData.  We then use dwKey to access our */
/*      nOutArray[] to get the data point index for that outlier, and assign */
/*      it to nPoint (which is shown as nPoint+1).  We then use nPoint to    */
/*      access the main frequency data array fFreqData[] to get the value of */
/*      the outlier.  These values are then formatted as a row string for    */
/*      display.                                                             */
/*                                                                           */
/*      Parameters:                                                          */
/*          LPVMSTRUCT  *lpData         Pointer to row data structure        */
/*          int         nOutArray[]     Outlier array                        */
/*          int         nNumRows        # rows in table                      */
/*                                                                           */
/*      Revision record:                                                     */
/*          09/28/96    Rewritten per EditDlgProc()                          */
/*			01/16/98	Added call to ShortenExp() to elim 3-digit exp       */
/*			05/29/01	Changed # field from 5 to 7 digits                   */
/*                                                                           */
/*****************************************************************************/

int WINAPI GetOutlierData(LPVMSTRUCT lpData, int nOutArray[],
	int nNumRows)
{
	// Local variables
	int nRow=(int)lpData->dwKey; // Row # of outlier table
	int nPoint=nOutArray[nRow];  // Index of outlier array

	// Check that row # is valid
	if(nRow<0 || nRow>=nNumRows)
	{
		// Return error code
		return (int) DTE_ROWOUTOFRANGE;
	}

	// Load data point # and outlier value into row of table for display
	// Note: The row data is one big string lpData->lpData
	// The width of the point # must always be the same
	// Format = %7d= XXXXXXX
	// The outlier data point # displayed is nOutArray[nRow]+1
	// The outlier value is fFreqData[nOutArray[nRow]+ARRAY_OFFSET]
	// Data width set by format: 7+20+EOS=28
	_snprintf(lpData->lpData, 28, "%7d%+20.13e", nPoint+1,
		fFreqData[nPoint+ARRAY_OFFSET]);
	ShortenExp(lpData->lpData);

   // Return success
   return DTE_OKAY;
}

/*****************************************************************************/
/*                                                                           */
/*      Comparison function for outlier qsort()                              */
/*                                                                           */
/*      Two pointers to nOutArray[] array elements are passed to this        */
/*      comparison function.  The nOutArray[] contains indices into the      */
/*      fFreqData[] array.  The two corresponding fFreqData[] array values   */
/*      are compared, and an integer denoting the results of the comparison  */
/*      is returned: b<a:<0, b=a:0, b>a:>0.                                  */
/*                                                                           */
/*      Revision record:                                                     */
/*          09/29/96    Written                                              */
/*			08/12/02	Changed comparison to rank by absolute value         */
/*                                                                           */
/*****************************************************************************/

int OutlierCompare(const void *a, const void *b)
{
	// Compare absolute frequency differences from median value
	F_TYPE x=fabs((fFreqData[*(int*)b+ARRAY_OFFSET])-fMedVal)-
		fabs((fFreqData[*(int*)a+ARRAY_OFFSET])-fMedVal);

	return (x>0) ? 1 : (x<0) ? -1 : 0;
}

/*****************************************************************************/
/*                                                                           */
/*                   Drift Dialog Procedure                                  */
/*                                                                           */
/*  Revision record:                                                         */
/*                                                                           */
/*      11/03/96    Added increment filename extension logic                 */
/*      11/16/96    Changed to stringtable usage                             */
/*      01/01/97    Added storage of freq slope removed                      */
/*      01/03/97    Fixed logic for showing/hiding remove drift checkbox     */
/*      01/10/97    Quadratic drift tau made 1.0 for slope per data interval */
/*      01/12/97    Added flag to avoid unnecessary log drift recalculation  */
/*      01/22/97    Added "(Removed)" note after slope when it is removed    */
/*      02/22/97    Added linear phase (freq offset) drift type              */
/*      02/24/97    Changed to NewRemoveQuadraticDrift()                     */
/*      02/27/97    Added endpoints drift type for phase data                */
/*      03/18/97    Added autocalc logic                                     */
/*      05/03/97    Reverted to original log fit calc w/o progress indicator */
/*		12/18/98	Added copy button to copy results to Windows clipboard   */
/*		01/14/99	Added global drift type usage                            */
/*		11/18/06	Added CreateTab() call                                   */
/*		01/10/06	Added AF for log freq drift calc                         */
/*		01/11/06	Added AF for diffusion freq drift calc                   */
/*		03/12/07	Added AF to copy info for log & diffusion fits           */
/*		08/24/07	Added nClip usage                                        */
/*		02/12/08	Added autoregression calc & removal for freq data        */
/*		11/24/11	Added Greenhall drift calc for phase data                */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK DriftDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	// Ints
	int i;							// Index
	int nPoints;                    // # data points
	int nEntry;                     // User avg factor entry to be validated
	int nPrev;                      // Previous avg factor value
	int nMax;						// Max allowable AF
	static int nAlpha;				// Noise type alpha as int
	static int nDriftType=0;		// Type of drift selected
	static int nAvgFactor=1;        // Averaging factor
	static int nNum;                // # data points
	static int nClip;				// Size of szClipboard (chars)
	// BOOLs
	static BOOL bErrorTrap=FALSE;   // Flag for entry error
	static BOOL bRemoveDrift=FALSE; // Remove drift flag
	static BOOL bHaveLogFit=FALSE;  // Flag that valid log fit already done
	static BOOL bHaveDiffFit=FALSE; // Flag that valid diff fit already done
	// Floats
	static float fR1;				// Lag 1 autocorrelation
	static float fAlpha;			// Estimated alpha
	// F_TYPEs
	static F_TYPE fSlope;			// Drift fit slope
	static F_TYPE fTau;				// Tau value
	static F_TYPE fA;				// Drift fit a term value
	static F_TYPE fB;				// Drift fit b term value
	static F_TYPE fC;				// Drift fit c term value
	static F_TYPE fD;				// Drift fit drift term value
	static F_TYPE fV;				// Drift fit variance
	static F_TYPE fT;				// # of last analysis point
	static F_TYPE *fTempData;       // Temporary data array
	// Chars
	// Noise type array: index=alpha+4
	static char *szNoiseType[]=
		{"RR FM", "FW FM","RW FM","F FM","W FM","F PM","W PM"};
	char szBuffer[BUFFER_SIZE+1];   // Text buffer
	// Clipboard variables
	char szFormat[BUFFER_SIZE+1];   // Format string
	HGLOBAL hClipboard;				// Handle to clipboard text buffer
	LPSTR	szClipboard;			// Ptr to clipboard text string

	LoadIcon(hInst, "FlatDriftIcon");

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Write prompt message
			WritePromptMessage(TB_DRIFT);

			// Set local drift type to global value
			if(bDataType==FREQ_DATA)
			{
				nDriftType=nGlobalFreqDriftType;
			}
			else // Phase data
			{
				nDriftType=nGlobalPhaseDriftType;
			}

			// Set global dialog box handle
			hDialog=hDlg;

			// Initialize the averaging factor to 1
			// Want to do this every time as a default safety measure
			SetWindowText(GETHCTL(IDC_DRIFT_AF), "1");

			// Hide the avg factor edit box & label unless
			// log, diffusion or autoregression fit for freq data selected
			// May eventually want averaging to apply to more cases
			if(bDataType==PHASE_DATA)
			{
				ShowWindow(GETHCTL(IDC_DRIFT_AF), SW_HIDE);
				ShowWindow(GETHCTL(IDC_DRIFT_AFLABEL), SW_HIDE);
			}
			else // Freq data
			{
				if(nDriftType!=LOG_DRIFT && nDriftType!=DIFFUSION_DRIFT &&
					nDriftType!=AR_DRIFT)
				{
					ShowWindow(GETHCTL(IDC_DRIFT_AF), SW_HIDE);
					ShowWindow(GETHCTL(IDC_DRIFT_AFLABEL), SW_HIDE);
				}
			}

			// Reset the log fit flag
			bHaveLogFit=FALSE;
			bHaveDiffFit=FALSE;

			// Set the AF to 1
			nAvgFactor=1;

			// Restore the Show Details checkbox state
			Button_SetCheck(GETHCTL(IDC_DRIFT_SHOW), bDriftDetails);

			if(bDriftDetails)
			{
				ShowWindow(GETHCTL(IDC_DRIFT_PROMPT2), SW_HIDE);
				ShowWindow(GETHCTL(IDC_DRIFT_PROMPT), SW_SHOWNORMAL);
			}
			else
			{
				ShowWindow(GETHCTL(IDC_DRIFT_PROMPT), SW_HIDE);
				ShowWindow(GETHCTL(IDC_DRIFT_PROMPT2), SW_SHOWNORMAL);
			}

			// Disable the copy button until there are results
			EnableWindow(GETHCTL(IDC_DRIFT_COPY), FALSE);

			// Fill up the list box
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_DRIFT_TYPE));

			if(bDataType==FREQ_DATA)
			{
				for(i=0; i<5; i++)
				{
					LoadString(hInst, IDS_FDRIFT_TYPE_0+i, szBuffer,
						BUFFER_SIZE);
					nDummy=ComboBox_InsertString(GETHCTL(IDC_DRIFT_TYPE), i,
						szBuffer);
				}

				// Disallow nDriftType>4 from freq data
				if((nDriftType>AR_DRIFT) && (bDataType==FREQ_DATA))
				{
					nDriftType=LINEAR_DRIFT;
				}

				// Load drift type
				nDummy=ComboBox_SetCurSel(GETHCTL(IDC_DRIFT_TYPE),
					nDriftType);

				// Hide drift remove checkbox if it doesn't apply
				if(nDriftType==BISECTION_DRIFT)
				{
                    ShowWindow(GETHCTL(IDC_DRIFT_REMOVE), SW_HIDE);
                }

                // Load frequency drift model & equations
                LoadString(hInst, IDS_FDRIFT_MODEL_0+nDriftType, szBuffer,
                    BUFFER_SIZE);
                SetWindowText(GETHCTL(IDC_DRIFT_MODEL), szBuffer);
                LoadString(hInst, IDS_FDRIFT_EQN_0+nDriftType, szBuffer,
                    BUFFER_SIZE);
                SetWindowText(GETHCTL(IDC_DRIFT_EQNS), szBuffer);

				// Change some labels, etc if AR_DRIFT
				if(nDriftType==AR_DRIFT)
				{
					// Change avg factor edit box label
	               SetWindowText(GETHCTL(IDC_DRIFT_ALABEL), "r(1):");

					// Change remove drift checkbox label
	               SetWindowText(GETHCTL(IDC_DRIFT_REMOVE), "&Remove AR");

					// Change info text
	               SetWindowText(GETHCTL(IDC_DRIFT_PROMPT),
					   "Press Calc to find or remove AR.");
	               SetWindowText(GETHCTL(IDC_DRIFT_PROMPT2),
					   "Press Calc to find or remove AR.");

				   // Change slope label
	               SetWindowText(GETHCTL(IDC_DRIFT_SLABEL), "Noise:");
				}
				else // Normal labels
				{
					// Change avg factor edit box label
	               SetWindowText(GETHCTL(IDC_DRIFT_ALABEL), "a:");

					// Change remove drift checkbox label
	               SetWindowText(GETHCTL(IDC_DRIFT_REMOVE), "&Remove Drift");

					// Change info text
	               SetWindowText(GETHCTL(IDC_DRIFT_PROMPT),
					   "Press Calc to find or remove drift.");
	               SetWindowText(GETHCTL(IDC_DRIFT_PROMPT2),
					   "Press Calc to find or remove drift.");

				   // Change slope label
	               SetWindowText(GETHCTL(IDC_DRIFT_SLABEL), "Slope:");
				}
            }
            else if(bDataType==PHASE_DATA)
            {
				for(i=0; i<7; i++) // Was i<5; made i<6 to add FIRSTDIFF type
				// Made i<7 to add GREENHALL type 11/24/11
				{
					LoadString(hInst, IDS_PDRIFT_TYPE_0+i, szBuffer,
						BUFFER_SIZE);
					nDummy=ComboBox_InsertString(GETHCTL(IDC_DRIFT_TYPE), i,
						szBuffer);
				}

				// Load drift type
				nDummy=ComboBox_SetCurSel(GETHCTL(IDC_DRIFT_TYPE), nDriftType);

				if(nDriftType==FREQ_OFFSET || nDriftType==FIRSTDIFF || nDriftType==ENDPOINTS)
				{
						strlcpy(szBuffer, "&Remove Freq Offset", sizeof(szBuffer));
				}
				else
				{
					strlcpy(szBuffer, "&Remove Drift", sizeof(szBuffer));
				}
				SetWindowText(GETHCTL(IDC_DRIFT_REMOVE), szBuffer);

				// Hide drift remove checkbox if it doesn't apply
				if(nDriftType==SECDIFF_DRIFT || nDriftType==THREEPT_DRIFT ||
					nDriftType==GREENHALL_DRIFT)
				{
					ShowWindow(GETHCTL(IDC_DRIFT_REMOVE), SW_HIDE);
				}

				// Load phase drift model & equations
				LoadString(hInst, IDS_PDRIFT_MODEL_0+nDriftType, szBuffer,
					BUFFER_SIZE);
				SetWindowText(GETHCTL(IDC_DRIFT_MODEL), szBuffer);
                LoadString(hInst, IDS_PDRIFT_EQN_0+nDriftType, szBuffer,
                    BUFFER_SIZE);
                SetWindowText(GETHCTL(IDC_DRIFT_EQNS), szBuffer);
            }

			// Autocalc drift
			// Doing this gives immediate result for current drift type
			// Handy, both in general & as part of automation script
			// Controlled with bAutoCalc flag set in Config box
			if(bAutoCalc)
			{
				PostMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDOK, NULL,
					0));
			}
        }
        return TRUE;

        case WM_COMMAND:
        {
            switch(GET_WM_COMMAND_ID(wParam, lParam))
            {
                case IDHELP:
                {
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::DRIFT_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
 					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::DRIFT_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "DRIFT_FUNCTION");
					#endif
               }
                break;

                case IDC_DRIFT_SHOW:
                {
					// Get the state of the Show Details checkbox
					bDriftDetails=
						(BOOL)Button_GetCheck(GETHCTL(IDC_DRIFT_SHOW));

					// Change to other Drift dialog box template
					// Note: hwmd & cmd args not needed
					PostMessage(hwndMain, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDM_DRIFT, NULL, 0));

					EndDialog(hDlg, 0);
					return TRUE;
				}

				case IDC_DRIFT_TYPE:
				{
					// Detect change in drift type selection
                    if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_SELCHANGE)
                    {
                        // Reset the log fit flag
                        bHaveLogFit=FALSE;
						bHaveDiffFit=FALSE;

                        // Clear the slope and coefficient displays
						SetWindowText(GETHCTL(IDC_DRIFT_SLOPE), "");
						SetWindowText(GETHCTL(IDC_DRIFT_A), "");
						SetWindowText(GETHCTL(IDC_DRIFT_B), "");
						SetWindowText(GETHCTL(IDC_DRIFT_C), "");

						// Disable the copy button until there are results
						EnableWindow(GETHCTL(IDC_DRIFT_COPY), FALSE);

						// Get the new selection and update noise model
						// and equation displays
						if(bDataType==FREQ_DATA)
						{
							// Get drift type
							nDriftType=
								ComboBox_GetCurSel(GETHCTL(IDC_DRIFT_TYPE));

							// Hide drift remove checkbox if it doesn't apply
                            if(nDriftType==BISECTION_DRIFT)
                            {
                                ShowWindow(GETHCTL(IDC_DRIFT_REMOVE), SW_HIDE);
                            }
                            else
                            {
                                ShowWindow(GETHCTL(IDC_DRIFT_REMOVE),
                                    SW_SHOWNORMAL);
                            }

							// Change some labels, etc if AR_DRIFT
							if(nDriftType==AR_DRIFT)
							{
								// Change avg factor edit box label
							   SetWindowText(GETHCTL(IDC_DRIFT_ALABEL),
								   "r(1):");

								// Change remove drift checkbox label
							   SetWindowText(GETHCTL(IDC_DRIFT_REMOVE),
								   "&Remove AR");

								// Change info text
							   SetWindowText(GETHCTL(IDC_DRIFT_PROMPT),
								   "Press Calc to find or remove AR.");
							   SetWindowText(GETHCTL(IDC_DRIFT_PROMPT2),
								   "Press Calc to find or remove AR.");

							   // Change slope label
							   SetWindowText(GETHCTL(IDC_DRIFT_SLABEL),
								   "Noise:");
							}
							else // Normal labels
							{
								// Change avg factor edit box label
							   SetWindowText(GETHCTL(IDC_DRIFT_ALABEL), "a:");

								// Change remove drift checkbox label
							   SetWindowText(GETHCTL(IDC_DRIFT_REMOVE),
								   "&Remove Drift");

								// Change info text
							   SetWindowText(GETHCTL(IDC_DRIFT_PROMPT),
								   "Press Calc to find or remove drift.");
							   SetWindowText(GETHCTL(IDC_DRIFT_PROMPT2),
								   "Press Calc to find or remove drift.");

							   // Change slope label
							   SetWindowText(GETHCTL(IDC_DRIFT_SLABEL),
								   "Slope:");
							}

                            // Load frequency drift model & equations
                            LoadString(hInst, IDS_FDRIFT_MODEL_0+nDriftType,
                                szBuffer, BUFFER_SIZE);
                            SetWindowText(GETHCTL(IDC_DRIFT_MODEL), szBuffer);
                            LoadString(hInst, IDS_FDRIFT_EQN_0+nDriftType,
                                szBuffer, BUFFER_SIZE);
                            SetWindowText(GETHCTL(IDC_DRIFT_EQNS), szBuffer);
                        }
                        else if(bDataType==PHASE_DATA)
                        {
                            // Get drift type
							nDriftType=
								ComboBox_GetCurSel(GETHCTL(IDC_DRIFT_TYPE));
							
							// Hide drift remove checkbox if it doesn't apply
                            if(nDriftType==SECDIFF_DRIFT ||
                               nDriftType==THREEPT_DRIFT ||
							   nDriftType==GREENHALL_DRIFT)
                            {
                                ShowWindow(GETHCTL(IDC_DRIFT_REMOVE),
                                    SW_HIDE);
                            }
                            else
                            {
                                ShowWindow(GETHCTL(IDC_DRIFT_REMOVE),
                                    SW_SHOWNORMAL);
                            }

                            // Load phase drift model & equations
                            LoadString(hInst, IDS_PDRIFT_MODEL_0+nDriftType,
                                szBuffer, BUFFER_SIZE);
                            SetWindowText(GETHCTL(IDC_DRIFT_MODEL),
                                szBuffer);
                            LoadString(hInst, IDS_PDRIFT_EQN_0+nDriftType,
                                szBuffer, BUFFER_SIZE);
                            SetWindowText(GETHCTL(IDC_DRIFT_EQNS),
                                szBuffer);

							if(nDriftType==FREQ_OFFSET || nDriftType==FIRSTDIFF || nDriftType==ENDPOINTS)
							{
									strlcpy(szBuffer, "&Remove Freq Offset", sizeof(szBuffer));
							}
							else
							{
								strlcpy(szBuffer, "&Remove Drift", sizeof(szBuffer));
							}
							SetWindowText(GETHCTL(IDC_DRIFT_REMOVE), szBuffer);

							// Hide drift remove checkbox if it doesn't apply
							if(nDriftType==SECDIFF_DRIFT || nDriftType==THREEPT_DRIFT ||
								nDriftType==GREENHALL_DRIFT)
							{
								ShowWindow(GETHCTL(IDC_DRIFT_REMOVE), SW_HIDE);
							}
						}

 						// Hide the avg factor edit box & label
						// unless log, diffusion or autoregression fit
						// for freq data selected
						if(bDataType==PHASE_DATA)
						{
							ShowWindow(GETHCTL(IDC_DRIFT_AF), SW_HIDE);
							ShowWindow(GETHCTL(IDC_DRIFT_AFLABEL), SW_HIDE);
						}
						else // Freq data
						{
							if(nDriftType!=LOG_DRIFT &&
								nDriftType!=DIFFUSION_DRIFT &&
								nDriftType!=AR_DRIFT)
							{
								ShowWindow(GETHCTL(IDC_DRIFT_AF), SW_HIDE);
								ShowWindow(GETHCTL(IDC_DRIFT_AFLABEL),
									SW_HIDE);
							}
							else //Log, diffusion or autogression freq drift
							{
								ShowWindow(GETHCTL(IDC_DRIFT_AF),
									SW_SHOWNORMAL);
								ShowWindow(GETHCTL(IDC_DRIFT_AFLABEL),
									SW_SHOWNORMAL);
							}
						}
                   }
                }
                break;

				// Respond to avg factor edit box
				case IDC_DRIFT_AF:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap)&&(GetFocus()!=GETHCTL(IDC_DRIFT_CLOSE)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Save previous value
						nPrev=nAvgFactor;

						// Get (new) avg factor
						GetWindowText(GETHCTL(IDC_DRIFT_AF), szBuffer,
							BUFFER_SIZE);
						nEntry=abs(atoi(szBuffer));

						// Get # data points
						if(bDataType==FREQ_DATA)
						{
							nPoints=(int)fFreqData[0];
						}
						else
						{
							nPoints=(int)fPhaseData[0];
						}

						// Check entry - must be between 1 and nPoints/10
						// unless this is AR_DRIFT case for freq data
						// where it can be as large as nPoints/2
						nMax=nPoints/10;
						if( (bDataType==FREQ_DATA && nDriftType==AR_DRIFT) )
						{
							nMax=nPoints/2;
						}

						// Validate AF entry
						if(ValidateInteger(hDlg, nEntry, 1, nMax)==TRUE)
						{
							// New value OK
							nAvgFactor=nEntry;
							_snprintf(szBuffer, sizeof(szBuffer), "%d",
								nAvgFactor);
							SetWindowText(GETHCTL(IDC_DRIFT_AF), szBuffer);
						}
						else
						{
							// Invalid entry - restore default value
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nPrev);
							SetWindowText(GETHCTL(IDC_DRIFT_AF), szBuffer);
							SetFocus(GETHCTL(IDC_DRIFT_AF));
						}

						// Reset log fit flag
						bHaveLogFit=FALSE;
					}
                    else
                    {
                        // Reset error flag
                        bErrorTrap=FALSE;
                    }
                }
                break;

                // Respond to CR in an edit control
				// Note: No button is a DEFPUSHBUTTON
                case IDOK:
                {
                    // Does avg factort control have focus?
                    if(GetFocus()==GETHCTL(IDC_DRIFT_AF))
                    {
						// Send EN_KILLFOCUS message to add edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DRIFT_AF, 0,
							EN_KILLFOCUS));
					}
				}
				break;

				// case IDOK: // Changed 01/10/07
				case IDC_DRIFT_CALC:
                {
                    // Display wait cursor
                    SetCursor(hWait);

					// Set busy flag
					bBusy=TRUE;

                    // Display calculating message
                    LoadString(hInst, IDS_MESSAGE_CALC, szBuffer, BUFFER_SIZE);
                    SetWindowText(GETHCTL(IDC_DRIFT_SLOPE), szBuffer);
                    UpdateWindow(GETHCTL(IDC_DRIFT_SLOPE));

                    // Clear the slope and coefficient displays
					SetWindowText(GETHCTL(IDC_DRIFT_A), "");
					UpdateWindow(GETHCTL(IDC_DRIFT_A));
					SetWindowText(GETHCTL(IDC_DRIFT_B), "");
					UpdateWindow(GETHCTL(IDC_DRIFT_B));
					SetWindowText(GETHCTL(IDC_DRIFT_C), "");
					UpdateWindow(GETHCTL(IDC_DRIFT_C));

                    // Read remove flag
					bRemoveDrift=
						(BOOL)Button_GetCheck(GETHCTL(IDC_DRIFT_REMOVE));

					// Create tab to save previous data
					// if removing drift & requested
					if(bRemoveDrift && bTabs && bTabChange)
					{
						CreateTab();
					}
						
                    // Note: Does not have any error checking
                    if(bDataType==FREQ_DATA)
                    {
						switch(ComboBox_GetCurSel(GETHCTL(IDC_DRIFT_TYPE)))
                        {
                            case LINEAR_DRIFT:
                            {
                                CalcLinFreqDrift(fFreqData, &fA, &fB, &fV);
                                fSlope=fB;
                                _snprintf(szBuffer, sizeof(szBuffer), "%10.6e",
									fA);
								ShortenExp(szBuffer);
								SetWindowText(GETHCTL(IDC_DRIFT_A), szBuffer);
								_snprintf(szBuffer, sizeof(szBuffer), "%10.6e",
									fB);
								ShortenExp(szBuffer);
								SetWindowText(GETHCTL(IDC_DRIFT_B), szBuffer);
								_snprintf(szBuffer, sizeof(szBuffer), "%10.6e",
									fA);
								ShortenExp(szBuffer);
								LoadString(hInst, IDS_MESSAGE_NA, szBuffer,
									BUFFER_SIZE);
								SetWindowText(GETHCTL(IDC_DRIFT_C), szBuffer);

                                // Load frequency drift model & equations
                                LoadString(hInst, IDS_FDRIFT_MODEL_0, szBuffer,
                                    BUFFER_SIZE);
                                SetWindowText(GETHCTL(IDC_DRIFT_MODEL),
                                    szBuffer);
                                LoadString(hInst, IDS_FDRIFT_EQN_0, szBuffer,
                                    BUFFER_SIZE);
                                SetWindowText(GETHCTL(IDC_DRIFT_EQNS),
                                    szBuffer);

                                if(bRemoveDrift)
                                {
                                    RemoveLinFreqDrift(fFreqData, fA, fB);
                                    // Clear remove flag
									Button_SetCheck(GETHCTL(IDC_DRIFT_REMOVE),
										FALSE);

                                    // Save freq slope removed from freq data
                                    fFreqSlopeRemoved=fB;

                                    // Set flags
                                    bFreqDataChanged=TRUE;
									bFreqDataUnsaved=TRUE;
									sFPlot.new_file=TRUE;
                                    bFreqScaleChanged=TRUE;
                                    bLinDriftRem=TRUE;
                                    bLogDriftRem=FALSE;
                                    bDiffDriftRem=FALSE;
									bFreqRedraw=TRUE;
									bSynch=FALSE;

									// Force new PSD plot scale
									sPSPlot.y_tic=0;

                                    // Increment filename
                                    if(bIncExtension)
                                    {
                                        IncExtension(szFile, FREQ_DATA);
                                        IncExtension(szFileTitle, FREQ_DATA);
                                        IncExtension(szFreqFile, FREQ_DATA);
                                        IncExtension(szFreqFileTitle,
                                            FREQ_DATA);
                                        SetWindowText(hwndFreqFilename,
                                            szFileTitle);
									}

									// Clear plot lines
									ClearLines();
}
							}
							break;

							case LOG_DRIFT:
							{
								// Calc log fit only if need to
								if(!bHaveLogFit)
								{
									// Does freq data have to be averaged?
									if(nAvgFactor>1)
									{
										// Set array size
										nNum=(int)fFreqData[0];

										// Allocate memory
										if((fTempData=(F_TYPE*)malloc(
											(nNum+ARRAY_OFFSET+EXTRA_MEM)*
											sizeof(F_TYPE)))==NULL)
										{
											// Display error message
											#ifdef MEM_DEBUG
											AllocErrorMessageEx(__FILE__,
												__LINE__,
												(nNum+ARRAY_OFFSET+EXTRA_MEM)*
												sizeof(F_TYPE));
											#else
											AllocErrorMessage();
											#endif

											// Close Drift dialog box
											EndDialog (hDlg, 0);
										}
										else
										{
											// Save data
											for(i=0; i<nNum+ARRAY_OFFSET; i++)
											{
												// Copy freq data
												// to working array
												fTempData[i]=fFreqData[i];
											}
										}

										// Average freq data
										AverageFreqData(fTempData, nAvgFactor);

										// Calc log fit for averaged freq data
										CalcLogFreqDrift(fTempData, &fA, &fB,
											&fC, &fV);

										// Scale fit for full data array
										fB/=(F_TYPE)nAvgFactor;

										// Free temporary memory
										free(fTempData);
									}
									else // No averaging
									{
										// Calc log fit for
										// full freq data array
										CalcLogFreqDrift(fFreqData, &fA, &fB,
											&fC, &fV);
									}

									// Set log fit flag
									bHaveLogFit=TRUE;
								}
							
								// Get end of freq data
                                GetWindowText(hwndFreqEnd, szBuffer,
                                    BUFFER_SIZE);
                                fT=(F_TYPE)atof(szBuffer);
                                fSlope=(fA*fB)/((fB*fT)+1.0);

								// Save slope in global variable
								fLogSlope=fSlope;

                                _snprintf(szBuffer, sizeof(szBuffer), "%10.6e",
									fA);
								ShortenExp(szBuffer);
								SetWindowText(GETHCTL(IDC_DRIFT_A), szBuffer);
								_snprintf(szBuffer, sizeof(szBuffer), "%10.6e",
									fB);
								ShortenExp(szBuffer);
								SetWindowText(GETHCTL(IDC_DRIFT_B), szBuffer);
								_snprintf(szBuffer, sizeof(szBuffer), "%10.6e",
									fC);
								ShortenExp(szBuffer);
								SetWindowText(GETHCTL(IDC_DRIFT_C), szBuffer);

                                // Load frequency drift model & equations
                                LoadString(hInst, IDS_FDRIFT_MODEL_1, szBuffer,
                                    BUFFER_SIZE);
                                SetWindowText(GETHCTL(IDC_DRIFT_MODEL),
                                    szBuffer);
                                LoadString(hInst, IDS_FDRIFT_EQN_1, szBuffer,
                                    BUFFER_SIZE);
                                SetWindowText(GETHCTL(IDC_DRIFT_EQNS),
                                    szBuffer);

								if(bRemoveDrift)
                                {
                                    RemoveLogFreqDrift(fFreqData, fA, fB, fC);
                                    // Clear remove flag
									Button_SetCheck(GETHCTL(IDC_DRIFT_REMOVE),
										FALSE);

                                    // Set flags
                                    bFreqDataChanged=TRUE;
									bFreqDataUnsaved=TRUE;
                                    bFreqScaleChanged=TRUE;
                                    bLinDriftRem=FALSE;
                                    bLogDriftRem=TRUE;
                                    bDiffDriftRem=FALSE;
									bHaveLogFit=FALSE;
									bFreqRedraw=TRUE;
									bSynch=FALSE;

									// Force new PSD plot scale
									sPSPlot.y_tic=0;

                                    // Increment filename
                                    if(bIncExtension)
                                    {
                                        IncExtension(szFile, FREQ_DATA);
                                        IncExtension(szFileTitle, FREQ_DATA);
                                        IncExtension(szFreqFile, FREQ_DATA);
                                        IncExtension(szFreqFileTitle,
                                            FREQ_DATA);
                                        SetWindowText(hwndFreqFilename,
                                            szFileTitle);
                                    }
									// Clear plot lines
									ClearLines();
								}
                            }
                            break;

                            case BISECTION_DRIFT:
                            {
                                fD=CalcBisectionDrift(fFreqData);
                                fSlope=fD;
                                LoadString(hInst, IDS_MESSAGE_NA, szBuffer,
                                    BUFFER_SIZE);
                                SetWindowText(GETHCTL(IDC_DRIFT_A),
                                    szBuffer);
                                SetWindowText(GETHCTL(IDC_DRIFT_B),
									szBuffer);
                                SetWindowText(GETHCTL(IDC_DRIFT_C),
                                    szBuffer);

                                // Load frequency drift model & equations
                                LoadString(hInst, IDS_FDRIFT_MODEL_2, szBuffer,
                                    BUFFER_SIZE);
                                SetWindowText(GETHCTL(IDC_DRIFT_MODEL),
                                    szBuffer);
                                LoadString(hInst, IDS_FDRIFT_EQN_2, szBuffer,
                                    BUFFER_SIZE);
                                SetWindowText(GETHCTL(IDC_DRIFT_EQNS),
									szBuffer);

                                // Note: No procedure for drift removal
                            }
                            break;

							case DIFFUSION_DRIFT:
							{
								if(!bHaveDiffFit)
								{
									// Does freq data have to be averaged?
									if(nAvgFactor>1)
									{
										// Set array size
										nNum=(int)fFreqData[0];

										// Allocate memory
										if((fTempData=(F_TYPE*)malloc(
											(nNum+ARRAY_OFFSET+EXTRA_MEM)*
											sizeof(F_TYPE)))==NULL)
										{
											// Display error message
											#ifdef MEM_DEBUG
											AllocErrorMessageEx(__FILE__,
												__LINE__,
												(nNum+ARRAY_OFFSET+EXTRA_MEM)*
												sizeof(F_TYPE));
											#else
											AllocErrorMessage();
											#endif

											// Close Drift dialog box
											EndDialog (hDlg, 0);
										}
										else
										{
											// Save data
											for(i=0; i<nNum+ARRAY_OFFSET; i++)
											{
												// Copy freq data
												// to working array
												fTempData[i]=fFreqData[i];
											}
										}

										// Average freq data
										AverageFreqData(fTempData, nAvgFactor);

										// Calc diffusion fit
										// for averaged freq data
										CalcDiffusionFreqDrift(fTempData, &fA,
											&fB, &fC, &fV);

										// Scale fit for full data array
										fB/=sqrt((double)nAvgFactor);
										fC*=(F_TYPE)nAvgFactor;

										// Free temporary memory
										free(fTempData);
									}
									else // No averaging
									{
										// Calc diffusion fit
										// for full freq data array
										CalcDiffusionFreqDrift(fFreqData, &fA,
											&fB, &fC, &fV);
									}

									// Set log fit flag
									bHaveDiffFit=TRUE;
								}

								// Get end of freq data
								GetWindowText(hwndFreqEnd, szBuffer,
									BUFFER_SIZE);
								fT=(F_TYPE)atof(szBuffer);
								fSlope=0.5*fB/sqrt(fT+fC);

								// Save slope in global variable
								fDiffusionSlope=fSlope;

								_snprintf(szBuffer, sizeof(szBuffer), "%10.6e",
									fA);
								ShortenExp(szBuffer);
								SetWindowText(GETHCTL(IDC_DRIFT_A), szBuffer);
								_snprintf(szBuffer, sizeof(szBuffer), "%10.6e",
									fB);
								ShortenExp(szBuffer);
								SetWindowText(GETHCTL(IDC_DRIFT_B), szBuffer);
								_snprintf(szBuffer, sizeof(szBuffer), "%10.6e",
									fC);
								ShortenExp(szBuffer);
								SetWindowText(GETHCTL(IDC_DRIFT_C), szBuffer);

								// Load frequency drift model & equations
								LoadString(hInst, IDS_FDRIFT_MODEL_3, szBuffer,
									BUFFER_SIZE);
								SetWindowText(GETHCTL(IDC_DRIFT_MODEL),
									szBuffer);
								LoadString(hInst, IDS_FDRIFT_EQN_3, szBuffer,
									BUFFER_SIZE);
								SetWindowText(GETHCTL(IDC_DRIFT_EQNS),
									szBuffer);

								if(bRemoveDrift)
								{
									RemoveDiffusionFreqDrift(fFreqData, fA,
										fB, fC);

									// Clear remove flag
									Button_SetCheck(GETHCTL(IDC_DRIFT_REMOVE),
										FALSE);

									// Set flags
									bFreqDataChanged=TRUE;
									bFreqDataUnsaved=TRUE;
									sFPlot.new_file=TRUE;
									bFreqScaleChanged=TRUE;
									bLinDriftRem=FALSE;
									bLogDriftRem=FALSE;
									bDiffDriftRem=TRUE;
									bHaveDiffFit=FALSE;
									bFreqRedraw=TRUE;
									bSynch=FALSE;

									// Force new PSD plot scale
									sPSPlot.y_tic=0;

									// Increment filename
									if(bIncExtension)
									{
										IncExtension(szFile, FREQ_DATA);
										IncExtension(szFileTitle, FREQ_DATA);
										IncExtension(szFreqFile, FREQ_DATA);
										IncExtension(szFreqFileTitle,
											FREQ_DATA);
										SetWindowText(hwndFreqFilename,
											szFileTitle);
									}

									// Clear plot lines
									ClearLines();
								}
							}
							break;

                            case AR_DRIFT:
                            {
								if(bRemoveDrift) // Remove AR(1) noise
								{
									// Remove AR(1) noise
									Prewhiten(fFreqData, fR1);

									// Note: Don't bother to realloc array size
									// Just 1 point smaller
									
									// Recalc r(1) etc
									ACFNoiseID(fFreqData, FREQ_DATA, 1, &fR1,
										&fAlpha, &nAlpha, 3, 0);

									// Display lag 1 autocorrelation
									_snprintf(szBuffer, sizeof(szBuffer),
										"%1.3f", fR1);
									SetWindowText(GETHCTL(IDC_DRIFT_A),
										szBuffer);
									SetWindowText(GETHCTL(IDC_DRIFT_B),
										"Not Applicable");
									SetWindowText(GETHCTL(IDC_DRIFT_C),
										"Not Applicable");

									// Display noise params
									_snprintf(szBuffer, sizeof(szBuffer),
										"Alpha=%5.3f (%s)",
										fAlpha, szNoiseType[nAlpha+4]);
									SetWindowText(GETHCTL(IDC_DRIFT_SLOPE),
										szBuffer);

									// Update status display
									_snprintf(szBuffer, sizeof(szBuffer), "%d",
									(int)fData[0]);
									SetWindowText(hwndFreqNum, szBuffer);
									SetWindowText(hwndFreqEnd, szBuffer);
									SetWindowText(hwndFreqStart, "1");

									// Clear remove flag
									Button_SetCheck(GETHCTL(IDC_DRIFT_REMOVE),
										FALSE);

									// Set flags
									bFreqDataChanged=TRUE;
									bFreqDataUnsaved=TRUE;
									sFPlot.new_file=TRUE;
									bFreqScaleChanged=TRUE;
									bLinDriftRem=FALSE;
									bLogDriftRem=FALSE;
									bDiffDriftRem=TRUE;
									bHaveDiffFit=FALSE;
									bFreqRedraw=TRUE;
									bSynch=FALSE;

									// Force new PSD plot scale
									sPSPlot.y_tic=0;

									// Increment filename
									if(bIncExtension)
									{
										IncExtension(szFile, FREQ_DATA);
										IncExtension(szFileTitle, FREQ_DATA);
										IncExtension(szFreqFile, FREQ_DATA);
										IncExtension(szFreqFileTitle,
											FREQ_DATA);
										SetWindowText(hwndFreqFilename,
											szFileTitle);
									}

									// Clear plot lines
									ClearLines();
								}
								else // Calc & display r(1)
								{
									// Do immediate Greenhall lag 1 noise ID
									// for AF=1
									// No sigma type applies, so allow dmax=3
									// 1st arg: data array
									// 2nd arg: Data type=FREQ_DATA
									// 3rd arg: AF
									// 4th arg: fA=r(1)
									// 5th arg: fB=alpha
									// 6th arg: nAlpha
									// 7th arg: dmax=3
									// 8th arg: dmin=1
									// Call ACF noise ID function
									ACFNoiseID(fFreqData, FREQ_DATA, nAvgFactor,
										&fR1, &fAlpha, &nAlpha, 3, 0);

									// Display lag 1 autocorrelation
									_snprintf(szBuffer, sizeof(szBuffer),
										"%1.3f", fR1);
									SetWindowText(GETHCTL(IDC_DRIFT_A),
										szBuffer);
									SetWindowText(GETHCTL(IDC_DRIFT_B),
										"Not Applicable");
									SetWindowText(GETHCTL(IDC_DRIFT_C),
										"Not Applicable");
									
									// Display noise params
									_snprintf(szBuffer, sizeof(szBuffer),
										"Alpha=%5.3f (%s)",
										fAlpha, szNoiseType[nAlpha+4]);
									SetWindowText(GETHCTL(IDC_DRIFT_SLOPE),
										szBuffer);
								}
							}
							break;
						}
					}
					else if(bDataType==PHASE_DATA)
					{
						// Get tau of phase data
						GetWindowText(hwndPhaseTau, szBuffer, BUFFER_SIZE);
                        fTau=(F_TYPE)atof(szBuffer);

						switch(ComboBox_GetCurSel(GETHCTL(IDC_DRIFT_TYPE)))
						{
							case QUADRATIC_DRIFT:
							{
                                // Tau made 1.0
                                // Slope is per data point interval
                                CalcQuadraticDrift(fPhaseData, 1.0, &fA, &fB,
									&fC, &fV);
                                fSlope=2*fC/fTau;

                                _snprintf(szBuffer, sizeof(szBuffer), "%10.6e",
									fA);
								ShortenExp(szBuffer);
								SetWindowText(GETHCTL(IDC_DRIFT_A), szBuffer);
								_snprintf(szBuffer, sizeof(szBuffer), "%10.6e",
									fB);
								ShortenExp(szBuffer);
								SetWindowText(GETHCTL(IDC_DRIFT_B), szBuffer);
								_snprintf(szBuffer, sizeof(szBuffer), "%10.6e",
									fC);
								ShortenExp(szBuffer);
								SetWindowText(GETHCTL(IDC_DRIFT_C), szBuffer);

								// Load phase drift model & equations
								LoadString(hInst, IDS_PDRIFT_MODEL_0, szBuffer,
                                    BUFFER_SIZE);
                                SetWindowText(GETHCTL(IDC_DRIFT_MODEL),
                                    szBuffer);
                                LoadString(hInst, IDS_PDRIFT_EQN_0, szBuffer,
                                    BUFFER_SIZE);
                                SetWindowText(GETHCTL(IDC_DRIFT_EQNS),
                                    szBuffer);

                                if(bRemoveDrift)
                                {
                                    RemoveQuadraticDrift(fPhaseData, fA, fB,
                                        fC);
                                    // Clear remove flag
									Button_SetCheck(GETHCTL(IDC_DRIFT_REMOVE),
										FALSE);

                                    // Save freq slope removed from phase data
                                    fPhaseSlopeRemoved=fSlope;

                                    // Set flags
                                    bPhaseDataChanged=TRUE;
									bPhaseDataUnsaved=TRUE;
                                    bPhaseScaleChanged=TRUE;
                                    bQuadDriftRem=TRUE;
									bPhaseRedraw=TRUE;
									bSynch=FALSE;

									// Force new PSD plot scale
									sPSPlot.y_tic=0;

                                    // Increment filename
                                    if(bIncExtension)
									{
										IncExtension(szFile, PHASE_DATA);
                                        IncExtension(szFileTitle, PHASE_DATA);
                                        IncExtension(szPhaseFile, PHASE_DATA);
                                        IncExtension(szPhaseFileTitle,
                                            PHASE_DATA);
                                        SetWindowText(hwndPhaseFilename,
                                            szFileTitle);
                                    }
									// Clear plot lines
									ClearLines();
								}
                            }
                            break;

                            case SECDIFF_DRIFT:
                            {
                                CalcSecondDiff(fPhaseData, &fD);
                                fSlope=fD;
                                LoadString(hInst, IDS_MESSAGE_NA, szBuffer,
                                    BUFFER_SIZE);
                                SetWindowText(GETHCTL(IDC_DRIFT_A),
                                    szBuffer);
                                SetWindowText(GETHCTL(IDC_DRIFT_B),
                                    szBuffer);
                                SetWindowText(GETHCTL(IDC_DRIFT_C),
									szBuffer);

								// Load phase drift model & equations
                                LoadString(hInst, IDS_PDRIFT_MODEL_1, szBuffer,
                                    BUFFER_SIZE);
                                SetWindowText(GETHCTL(IDC_DRIFT_MODEL),
                                    szBuffer);
                                LoadString(hInst, IDS_PDRIFT_EQN_1, szBuffer,
                                    BUFFER_SIZE);
                                SetWindowText(GETHCTL(IDC_DRIFT_EQNS),
                                    szBuffer);

                                // Note: No procedure for drift removal
                            }
                            break;

                            case THREEPT_DRIFT:
                            {
                                fD=CalcThreePointDrift(fPhaseData);
                                fSlope=fD;
                                LoadString(hInst, IDS_MESSAGE_NA, szBuffer,
                                    BUFFER_SIZE);
                                SetWindowText(GETHCTL(IDC_DRIFT_A),
                                    szBuffer);
                                SetWindowText(GETHCTL(IDC_DRIFT_B),
                                    szBuffer);
                                SetWindowText(GETHCTL(IDC_DRIFT_C),
                                    szBuffer);

                                // Load phase drift model & equations
								LoadString(hInst, IDS_PDRIFT_MODEL_2, szBuffer,
                                    BUFFER_SIZE);
                                SetWindowText(GETHCTL(IDC_DRIFT_MODEL),
                                    szBuffer);
                                LoadString(hInst, IDS_PDRIFT_EQN_2, szBuffer,
                                    BUFFER_SIZE);
                                SetWindowText(GETHCTL(IDC_DRIFT_EQNS),
                                    szBuffer);

                                // Note: No procedure for drift removal
                            }
                            break;
 
                            case GREENHALL_DRIFT:
                            {
								GreenhallDrift(fPhaseData, fTau, &fD);
                                fSlope=fD;
                                LoadString(hInst, IDS_MESSAGE_NA, szBuffer,
                                    BUFFER_SIZE);
                                SetWindowText(GETHCTL(IDC_DRIFT_A),
                                    szBuffer);
                                SetWindowText(GETHCTL(IDC_DRIFT_B),
                                    szBuffer);
                                SetWindowText(GETHCTL(IDC_DRIFT_C),
                                    szBuffer);

                                // Load phase drift model & equations
								LoadString(hInst, IDS_PDRIFT_MODEL_3, szBuffer,
                                    BUFFER_SIZE);
                                SetWindowText(GETHCTL(IDC_DRIFT_MODEL),
                                    szBuffer);
                                LoadString(hInst, IDS_PDRIFT_EQN_3, szBuffer,
                                    BUFFER_SIZE);
                                SetWindowText(GETHCTL(IDC_DRIFT_EQNS),
                                    szBuffer);

                                // Note: No procedure for drift removal
                            }
                            break;
                            case FREQ_OFFSET:
                            {
                                // Slope is per data point interval
                                CalcFreqOffset(fPhaseData, &fA, &fB, &fV);
                                fSlope=fB;
                                _snprintf(szBuffer, sizeof(szBuffer), "%10.6e",
									fA);
								ShortenExp(szBuffer);
								SetWindowText(GETHCTL(IDC_DRIFT_A), szBuffer);
								_snprintf(szBuffer, sizeof(szBuffer), "%10.6e",
									fB);
								ShortenExp(szBuffer);
								SetWindowText(GETHCTL(IDC_DRIFT_B), szBuffer);
								LoadString(hInst, IDS_MESSAGE_NA, szBuffer,
									BUFFER_SIZE);
								SetWindowText(GETHCTL(IDC_DRIFT_C), szBuffer);

								// Load phase drift model & equations
								LoadString(hInst, IDS_PDRIFT_MODEL_4, szBuffer,
									BUFFER_SIZE);
								SetWindowText(GETHCTL(IDC_DRIFT_MODEL),
									szBuffer);
								LoadString(hInst, IDS_PDRIFT_EQN_4, szBuffer,
									BUFFER_SIZE);
								SetWindowText(GETHCTL(IDC_DRIFT_EQNS),
									szBuffer);

								if(bRemoveDrift)
								{
									RemoveFreqOffset(fPhaseData, fA, fB,
										FALSE);

									// Clear remove flag
									Button_SetCheck(GETHCTL(IDC_DRIFT_REMOVE),
										FALSE);

									// Save freq slope removed from phase data
									fPhaseSlopeRemoved=fSlope;

									// Set flags
                                    bPhaseDataChanged=TRUE;
									bPhaseDataUnsaved=TRUE;
									bPhaseScaleChanged=TRUE;
                                    bFreqOffsetRem=TRUE;
									bPhaseRedraw=TRUE;
									bSynch=FALSE;

									// Force new PSD plot scale
									sPSPlot.y_tic=0;

                                    // Increment filename
                                    if(bIncExtension)
									{
                                        IncExtension(szFile, PHASE_DATA);
                                        IncExtension(szFileTitle, PHASE_DATA);
                                        IncExtension(szPhaseFile, PHASE_DATA);
                                        IncExtension(szPhaseFileTitle,
                                            PHASE_DATA);
                                        SetWindowText(hwndPhaseFilename,
                                            szFileTitle);
                                    }
									// Clear plot lines
									ClearLines();
								}
							}
							break;

							case ENDPOINTS:
							{
								// Get 1st phase point
								fA=fPhaseData[(int)fPhaseData[1]+2];

								// Calc slope between endpoints of phase data
								fB=(fPhaseData[(int)fPhaseData[2]+2]-
									fPhaseData[(int)fPhaseData[1]+2])/
									(fPhaseData[2]-fPhaseData[1]);
								fSlope=fB;

								// Display constant term
								_snprintf(szBuffer, sizeof(szBuffer), "%10.6e",
									fA);
								ShortenExp(szBuffer);
								SetWindowText(GETHCTL(IDC_DRIFT_A), szBuffer);

								// Display slope term
								_snprintf(szBuffer, sizeof(szBuffer), "%10.6e",
									fB);
								ShortenExp(szBuffer);
								SetWindowText(GETHCTL(IDC_DRIFT_B), szBuffer);

								// Quadratic term does not apply
								LoadString(hInst, IDS_MESSAGE_NA, szBuffer,
									BUFFER_SIZE);
								SetWindowText(GETHCTL(IDC_DRIFT_C), szBuffer);

								// Load phase drift model & equations
								LoadString(hInst, IDS_PDRIFT_MODEL_6, szBuffer,
									BUFFER_SIZE);
								SetWindowText(GETHCTL(IDC_DRIFT_MODEL),
									szBuffer);
								LoadString(hInst, IDS_PDRIFT_EQN_6, szBuffer,
									BUFFER_SIZE);
								SetWindowText(GETHCTL(IDC_DRIFT_EQNS),
									szBuffer);

								if(bRemoveDrift)
								{
									RemoveFreqOffset(fPhaseData, fA, fB, TRUE);

									// Clear remove flag
									Button_SetCheck(GETHCTL(IDC_DRIFT_REMOVE),
										FALSE);

									// Save freq slope removed from phase data
									fPhaseSlopeRemoved=fSlope;

									// Set flags
									bPhaseDataChanged=TRUE;
									bPhaseDataUnsaved=TRUE;
									bPhaseScaleChanged=TRUE;
									bQuadDriftRem=TRUE;
									bPhaseRedraw=TRUE;
									bSynch=FALSE;

									// Force new PSD plot scale
									sPSPlot.y_tic=0;

									// Increment filename
									if(bIncExtension)
									{
										IncExtension(szFile, PHASE_DATA);
										IncExtension(szFileTitle, PHASE_DATA);
										IncExtension(szPhaseFile, PHASE_DATA);
										IncExtension(szPhaseFileTitle,
											PHASE_DATA);
										SetWindowText(hwndPhaseFilename,
											szFileTitle);
									}
									// Clear plot lines
									ClearLines();
								}
							}
							break;

							case FIRSTDIFF:
							{
								// Calc first diff of phase = freq offset
								CalcFirstDiff(fPhaseData, &fB);
								fSlope=fB;

								// Check for zero frequency
								if(fB==0.0)
								{
			                       LoadString(hInst, IDS_MESSAGE_ZEROFREQ,
									   szBuffer, BUFFER_SIZE);
			                       MessageBox(hDlg, szBuffer, "Drift",
										MB_ICONEXCLAMATION);
								}

								// Constant term does not apply
								LoadString(hInst, IDS_MESSAGE_NA, szBuffer,
									BUFFER_SIZE);
								SetWindowText(GETHCTL(IDC_DRIFT_A), szBuffer);
								
								// Slope term does not apply
								// fB term is displayed in slope window
								LoadString(hInst, IDS_MESSAGE_NA, szBuffer,
									BUFFER_SIZE);
								SetWindowText(GETHCTL(IDC_DRIFT_B), szBuffer);

								// Quadratic term does not apply
								LoadString(hInst, IDS_MESSAGE_NA, szBuffer,
									BUFFER_SIZE);
								SetWindowText(GETHCTL(IDC_DRIFT_C), szBuffer);

								// Load phase drift model & equations
								LoadString(hInst, IDS_PDRIFT_MODEL_5, szBuffer,
									BUFFER_SIZE);
								SetWindowText(GETHCTL(IDC_DRIFT_MODEL),
									szBuffer);
								LoadString(hInst, IDS_PDRIFT_EQN_5, szBuffer,
									BUFFER_SIZE);
								SetWindowText(GETHCTL(IDC_DRIFT_EQNS),
									szBuffer);

								if(bRemoveDrift)
								{
									RemoveFreqOffset(fPhaseData, fA, fB, TRUE);

									// Clear remove flag
									Button_SetCheck(GETHCTL(IDC_DRIFT_REMOVE),
										FALSE);

									// Save freq slope removed from phase data
									fPhaseSlopeRemoved=fSlope;

									// Set flags
									bPhaseDataChanged=TRUE;
									bPhaseDataUnsaved=TRUE;
									bPhaseScaleChanged=TRUE;
									bQuadDriftRem=TRUE;
									bPhaseRedraw=TRUE;
									bSynch=FALSE;

									// Force new PSD plot scale
									sPSPlot.y_tic=0;

									// Increment filename
									if(bIncExtension)
									{
										IncExtension(szFile, PHASE_DATA);
										IncExtension(szFileTitle, PHASE_DATA);
										IncExtension(szPhaseFile, PHASE_DATA);
										IncExtension(szPhaseFileTitle,
											PHASE_DATA);
										SetWindowText(hwndPhaseFilename,
											szFileTitle);
									}
									// Clear plot lines
									ClearLines();
								}
							}
							break;
						}
					}

					// Enable the copy button - now there are results
					EnableWindow(GETHCTL(IDC_DRIFT_COPY), TRUE);

					// Put info into log file
					strlcpy(szBuffer, "Type=", sizeof(szBuffer));
					GetWindowText(GETHCTL(IDC_DRIFT_TYPE),
						szFormat, BUFFER_SIZE);
					strlcat(szBuffer, szFormat, sizeof(szBuffer));
					_snprintf(szFormat, sizeof(szFormat), ", Slope=%e",
						fSlope);
					strlcat(szBuffer, szFormat, sizeof(szBuffer));
					ShortenExp(szBuffer);
					if(bRemoveDrift)
					{
						if(bDataType==FREQ_DATA)
						{
							WriteLog(33, szBuffer);
						}
						else // Phase data
						{
							WriteLog(32, szBuffer);
						}
					}
					else // No drift removal
					{
						if(bDataType==FREQ_DATA)
						{
							WriteLog(31, szBuffer);
						}
						else // Phase data
						{
							WriteLog(30, szBuffer);
						}
					}

					if( !(bDataType==FREQ_DATA && nDriftType==AR_DRIFT) )
					{
						// Display slope
						_snprintf(szBuffer, sizeof(szBuffer), "%10.6e", fSlope);
						ShortenExp(szBuffer);

 						// Display frequency offset if applicable
						if((bDataType==PHASE_DATA) && (bDriftDetails) &&
							((ComboBox_GetCurSel(GETHCTL(IDC_DRIFT_TYPE))==
							FREQ_OFFSET) ||
							(ComboBox_GetCurSel(GETHCTL(IDC_DRIFT_TYPE))==
							ENDPOINTS) ||
							(ComboBox_GetCurSel(GETHCTL(IDC_DRIFT_TYPE))==
							FIRSTDIFF) ))
						{
							// Get tau of phase data
							GetWindowText(hwndPhaseTau, szBuffer, BUFFER_SIZE);
							fTau=(F_TYPE)atof(szBuffer);

							// Display slope and freq offset
							_snprintf(szBuffer, sizeof(szBuffer),
								"%10.6e  Freq Offset= %10.6e",
								fSlope, fSlope/fTau);
							ShortenExp(szBuffer);
						}

						if(bRemoveDrift)
						{
							strlcat(szBuffer, "  (Removed)", sizeof(szBuffer));
						}
						else if(bDataType==FREQ_DATA && (nDriftType==LOG_DRIFT ||
							nDriftType==DIFFUSION_DRIFT))
						{
							strlcat(szBuffer, "  (At End)", sizeof(szBuffer));
						}

						SetWindowText(GETHCTL(IDC_DRIFT_SLOPE), szBuffer);
					}

					// Display data changed bitmap if drift was removed
					UpdateStatusBar(hwndMain, NEW_DATA);

					// Display normal cursor
					SetCursor(hArrow);

					// Reset busy flag
					bBusy=FALSE;
                }
                break;

				// Respond to copy button
				case IDC_DRIFT_COPY:
				{
					// Allocate clipboard memory
					nClip=(10+sNormSigData.points)*80;
					hClipboard=GlobalAlloc(GMEM_DDESHARE,
						(DWORD)nClip);
					szClipboard=GlobalLock(hClipboard);

					// Heading
					LoadString(hInst, IDS_FORMAT_25, szFormat, BUFFER_SIZE);
					_snprintf(szBuffer, sizeof(szBuffer),
						szFormat, szFileTitle);
					strlcpy(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);

					// # points
					LoadString(hInst, IDS_FORMAT_3, szFormat, BUFFER_SIZE);

					if(bDataType==FREQ_DATA)
					{
						_snprintf(szBuffer, sizeof(szBuffer), szFormat,
							(int)fFreqData[1], (int)fFreqData[2],
							(int)fFreqData[0]);
						strlcat(szClipboard, szBuffer, nClip);
						strlcat(szClipboard, "\r\n", nClip);
					}
					else // Phase data
					{
						_snprintf(szBuffer, sizeof(szBuffer), szFormat,
							(int)fPhaseData[1],	(int)fPhaseData[2],
							(int)fPhaseData[0]);
						strlcat(szClipboard, szBuffer, nClip);
						strlcat(szClipboard, "\r\n", nClip);
					}

					// Drift Type
					strlcat(szClipboard, " Drift Type: ", nClip);
					GetWindowText(GETHCTL(IDC_DRIFT_TYPE), szBuffer,
						BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);

					// Show AF for log & diffusion fits
					if((nDriftType==LOG_DRIFT) ||
						(nDriftType==DIFFUSION_DRIFT))
					{
						_snprintf(szBuffer, sizeof(szBuffer),
							" Avg Factor: %d\r\n", nAvgFactor);
						strlcat(szClipboard, szBuffer, nClip);
					}

					// Drift parameters
					_snprintf(szBuffer, sizeof(szBuffer), " a=%e", fA);
					ShortenExp(szBuffer);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);
					_snprintf(szBuffer, sizeof(szBuffer), " b=%e", fB);
					ShortenExp(szBuffer);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);
					_snprintf(szBuffer, sizeof(szBuffer), " c=%e", fC);
					ShortenExp(szBuffer);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);
					_snprintf(szBuffer, sizeof(szBuffer), " Slope=%e", fSlope);
					ShortenExp(szBuffer);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);

					GlobalUnlock(hClipboard);
						OpenClipboard(NULL);
						EmptyClipboard();
						SetClipboardData(CF_TEXT, hClipboard);
						CloseClipboard();
				}
				break;

                case IDC_DRIFT_CLOSE:
				case IDCANCEL: // Removed 01/10/07 Why? Restored 05/22/10
                {
					// Set global drift type to local value
					if(bDataType==FREQ_DATA)
					{
						nGlobalFreqDriftType=nDriftType;
					}
					else // Phase data
					{
						nGlobalPhaseDriftType=nDriftType;
					}

                    EndDialog (hDlg, 0);
                }
                return TRUE;
            }
        }
        break;
     }
     return FALSE;
}

#ifndef LITE_VER
/*****************************************************************************/
/*                                                                           */
/*                   Noise Dialog Procedure                                  */
/*                                                                           */
/*  Revision record:                                                         */
/*      09/22/96    Added code to validate # points entry                    */
/*      10/30/96    Added edit control CR logic                              */
/*      11/25/96    Added code to update filenames; made all params static   */
/*      02/28/97    Added setting of new data flags                          */
/*		06/12/99	Added test for error code from GenerateNoise()           */
/*		02/17/01	Added sinusoidal term                                    */
/*		04/07/01	Added copy feature                                       */
/*					Added trap for zero tau                                  */
/*		03/17/02	Clear previous timetags before generating noise          */
/*		06/16/02	Added code to remove gaps in generated data              */
/*		11/17/06	Added tab usage                                          */
/*		08/24/07	Added nClip usage                                        */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK NoiseDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam)
{
    // Local variables
    // Chars
    char szBuffer[BUFFER_SIZE+1];   // Text buffer
    // Ints
    int nEntry;                     // Entry (to be validated)
	int nCode;						// Return code from GenerateNoise()
	int i;							// Index
	static int nCount=1;			// Count of # noise data sets generated
									// since Stable32 was launched
	static int nClip;				// Size of szClipboard (chars)
    // BOOLs
    static BOOL bErrorTrap=FALSE;   // Error trap flag
    // F_TYPES
    F_TYPE fPrev;                   // Previous value
    static F_TYPE fTau=1.0;         // Tau (independent of any other data)
    static F_TYPE fOffset=0.0;      // Freq offset
    static F_TYPE fDrift=0.0;       // Freq drift
	static F_TYPE fSine=0.0;		// Peak amplitude of sinusoidal freq term
	static F_TYPE fPeriod=0.0;		// Period (sec) of sinusoidal freq term
    static F_TYPE fSigma[5]={0.0, 0.0, 0.0, 0.0, 0.0};
                                    // Noise parameter array
                                    // fSigma[0]=RW FM noise parameter
                                    // fSigma[1]=F FM noise parameter
                                    // fSigma[2]=W FM noise parameter
                                    // fSigma[3]=F PM noise parameter
                                    // fSigma[4]=W PM noise parameter
	static F_TYPE fNum=513.0;       // # points

	// Clipboard variables
	HGLOBAL hClipboard;			// Handle to clipboard text buffer
	LPSTR	szClipboard;		// Ptr to clipboard text string

	// Start if code
    LoadIcon(hInst, "FlatNoiseIcon");

    switch(message)
    {
        case WM_INITDIALOG:
        {
            // Get dialog box title
            GetWindowText(hDlg, szBoxTitle, TITLESIZE);

            // Write prompt message
            WritePromptMessage(TB_NOISE);

			 // Check if copy S/B activated
			 SendMessage(hDlg, WM_COMMAND,
				GET_WM_COMMAND_MPS(IDC_NOISE_ACTIVE, NULL, 0));

			// Initialize the noise parameters
            _snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fSigma[0]);
			ShortenExp(szBuffer);
            SetWindowText(GETHCTL(IDC_NOISE_RWFM), szBuffer);
            _snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fSigma[1]);
			ShortenExp(szBuffer);
            SetWindowText(GETHCTL(IDC_NOISE_FFM), szBuffer);
            _snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fSigma[2]);
			ShortenExp(szBuffer);
            SetWindowText(GETHCTL(IDC_NOISE_WFM), szBuffer);
            _snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fSigma[3]);
			ShortenExp(szBuffer);
            SetWindowText(GETHCTL(IDC_NOISE_FPM), szBuffer);
            _snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fSigma[4]);
			ShortenExp(szBuffer);
            SetWindowText(GETHCTL(IDC_NOISE_WPM), szBuffer);

            // Initialize the freq parameters
            _snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fOffset);
			ShortenExp(szBuffer);
            SetWindowText(GETHCTL(IDC_NOISE_OFFSET), szBuffer);
            _snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fDrift);
 			ShortenExp(szBuffer);
           SetWindowText(GETHCTL(IDC_NOISE_DRIFT), szBuffer);
            _snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fSine);
			ShortenExp(szBuffer);
            SetWindowText(GETHCTL(IDC_NOISE_SINE), szBuffer);
            _snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fPeriod);
 			ShortenExp(szBuffer);
            SetWindowText(GETHCTL(IDC_NOISE_PERIOD), szBuffer);

            // Initialize the points parameters
            _snprintf(szBuffer, sizeof(szBuffer), "%d", (int)fNum);
            SetWindowText(GETHCTL(IDC_NOISE_NUM), szBuffer);
            _snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fTau);
			ShortenExp(szBuffer);
           SetWindowText(GETHCTL(IDC_NOISE_TAU), szBuffer);
        }
        return TRUE;

        case WM_COMMAND:
        {
            switch(GET_WM_COMMAND_ID(wParam, lParam))
            {
                case IDHELP:
                {
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::NOISE_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
 					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::NOISE_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif
 
					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "NOISE_FUNCTION");
					#endif
              }
                break;

                // Respond to rwfm edit control
                case IDC_NOISE_RWFM:
				{
                    // Respond to # points edit control when it loses the
                    // input focus (unless it loses it to the Cancel button)
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_NOISE_CANCEL)))
                    {
						// Redisplay rwfm value
                        GetWindowText(GETHCTL(IDC_NOISE_RWFM),
                            szBuffer, BUFFER_SIZE);
                        fSigma[0]=fabs(atof(szBuffer));
                        _snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							fSigma[0]);
						ShortenExp(szBuffer);
                        SetWindowText(GETHCTL(IDC_NOISE_RWFM),
                            szBuffer);
                    
						 // Check if copy S/B activated
						 SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_NOISE_ACTIVE, NULL, 0));
					}
                }
                break;

                // Respond to ffm edit control
                case IDC_NOISE_FFM:
                {
                    // Respond to # points edit control when it loses the
                    // input focus (unless it loses it to the Cancel button)
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_NOISE_CANCEL)))
                    {
                        // Redisplay ffm value
                        GetWindowText(GETHCTL(IDC_NOISE_FFM),
                            szBuffer, BUFFER_SIZE);
						fSigma[1]=fabs(atof(szBuffer));
                        _snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							fSigma[1]);
						ShortenExp(szBuffer);
                       SetWindowText(GETHCTL(IDC_NOISE_FFM),
                            szBuffer);
                   
						 // Check if copy S/B activated
						 SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_NOISE_ACTIVE, NULL, 0));
                    }
                }
				break;

                // Respond to wfm edit control
                case IDC_NOISE_WFM:
                {
                    // Respond to # points edit control when it loses the
                    // input focus (unless it loses it to the Cancel button)
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_NOISE_CANCEL)))
                    {
                        // Redisplay wfm value
                        GetWindowText(GETHCTL(IDC_NOISE_WFM),
                            szBuffer, BUFFER_SIZE);
                        fSigma[2]=fabs(atof(szBuffer));
                        _snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							fSigma[2]);
						ShortenExp(szBuffer);
                       SetWindowText(GETHCTL(IDC_NOISE_WFM),
                            szBuffer);
                   
						 // Check if copy S/B activated
						 SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_NOISE_ACTIVE, NULL, 0));
                    }
                }
                break;

                // Respond to fpm edit control
				case IDC_NOISE_FPM:
                {
                    // Respond to # points edit control when it loses the
                    // input focus (unless it loses it to the Cancel button)
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_NOISE_CANCEL)))
					{
                        // Redisplay fpm value
                        GetWindowText(GETHCTL(IDC_NOISE_FPM),
                            szBuffer, BUFFER_SIZE);
                        fSigma[3]=fabs(atof(szBuffer));
                        _snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							fSigma[3]);
						ShortenExp(szBuffer);
                       SetWindowText(GETHCTL(IDC_NOISE_FPM),
                            szBuffer);
                   
						 // Check if copy S/B activated
						 SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_NOISE_ACTIVE, NULL, 0));
                    }
                }
                break;

                // Respond to wpm edit control
                case IDC_NOISE_WPM:
                {
                    // Respond to # points edit control when it loses the
                    // input focus (unless it loses it to the Cancel button)
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_NOISE_CANCEL)))
                    {
                        // Redisplay wpm value
                        GetWindowText(GETHCTL(IDC_NOISE_WPM),
							szBuffer, BUFFER_SIZE);
						fSigma[4]=fabs(atof(szBuffer));
                        _snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							fSigma[4]);
						ShortenExp(szBuffer);
                       SetWindowText(GETHCTL(IDC_NOISE_WPM),
                            szBuffer);
                   
						 // Check if copy S/B activated
						 SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_NOISE_ACTIVE, NULL, 0));
                    }
				}
                break;

                // respond to changes in # points
                case IDC_NOISE_NUM:
                {
                    // Respond to # points edit control when it loses the
                    // input focus (unless it loses it to the Cancel button)
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (!bErrorTrap) &&
                        (GetFocus()!=GETHCTL(IDC_NOISE_CANCEL)))
                    {
                        // Set error flag to avoid multiple error messages
                        bErrorTrap=TRUE;

                        // Save previous value
                        fPrev=fNum;

                        // Get new # points
                        GetWindowText(GETHCTL(IDC_NOISE_NUM),
                            szBuffer, BUFFER_SIZE);
                        nEntry=abs(atoi(szBuffer));

						// Check entry
                        // It must be between 1 and nMaxSize
                        if(ValidateInteger(hDlg, nEntry, 1, nMaxSize)
                            ==TRUE)
                        {
							// New value OK
                            fNum=(F_TYPE)nEntry;
                            _snprintf(szBuffer, sizeof(szBuffer), "%d",
								(int)fNum);
                            SetWindowText(GETHCTL(IDC_NOISE_NUM),
                                szBuffer);
                        }
                        else
                        {
                            // Invalid entry - restore previous value
                            fNum=fPrev;
                            _snprintf(szBuffer, sizeof(szBuffer), "%d",
								(int)fNum);
                            SetWindowText(GETHCTL(IDC_NOISE_NUM),
                                szBuffer);
                            SetFocus(GETHCTL(IDC_NOISE_NUM));
                        }
                    }
                    else
                    {
                        // Reset error flag
                        bErrorTrap=FALSE;
                    }
                }
				break;

                // Respond to tau edit control
                case IDC_NOISE_TAU:
                {
                    // Respond to tau edit control when it loses the
					// input focus (unless it loses it to the Cancel button)
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_NOISE_CANCEL)))
                    {
                        // Redisplay tau value
                        GetWindowText(GETHCTL(IDC_NOISE_TAU),
                            szBuffer, BUFFER_SIZE);
                        fTau=fabs(atof(szBuffer));

						// Trap zero tau
						if(fTau==0.0)
						{
							fTau=1.0;
						}

                        _snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fTau);
						ShortenExp(szBuffer);
                       SetWindowText(GETHCTL(IDC_NOISE_TAU),
                            szBuffer);
                    }
                }
                break;

                // Respond to offset edit control
                case IDC_NOISE_OFFSET:
                {
                    // Respond to offset edit control when it loses the
                    // input focus (unless it loses it to the Cancel button)
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_NOISE_CANCEL)))
					{
						// Redisplay offset value
                        GetWindowText(GETHCTL(IDC_NOISE_OFFSET),
                            szBuffer, BUFFER_SIZE);
                        fOffset=atof(szBuffer);
                        _snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							fOffset);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_NOISE_OFFSET),
                            szBuffer);
                    }
                }
                break;

                // Respond to drift edit control
                case IDC_NOISE_DRIFT:
                {
                    // Respond to drift edit control when it loses the
                    // input focus (unless it loses it to the Cancel button)
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_NOISE_CANCEL)))
                    {
                        // Redisplay drift value
                        GetWindowText(GETHCTL(IDC_NOISE_DRIFT),
                            szBuffer, BUFFER_SIZE);
                        fDrift=atof(szBuffer);
                        _snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							fDrift);
						ShortenExp(szBuffer);
                       SetWindowText(GETHCTL(IDC_NOISE_DRIFT),
                            szBuffer);
                    }
				}
				break;

                // Respond to sine edit control
                case IDC_NOISE_SINE:
                {
                    // Respond to sine edit control when it loses the
                    // input focus (unless it loses it to the Cancel button)
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_NOISE_CANCEL)))
					{
						// Redisplay sine value
                        GetWindowText(GETHCTL(IDC_NOISE_SINE),
                            szBuffer, BUFFER_SIZE);
                        fSine=fabs(atof(szBuffer));
                        _snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fSine);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_NOISE_SINE),
                            szBuffer);
                    }
                }
                break;

                // Respond to period edit control
                case IDC_NOISE_PERIOD:
                {
                    // Respond to period edit control when it loses the
                    // input focus (unless it loses it to the Cancel button)
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_NOISE_CANCEL)))
					{
						// Redisplay period value
                        GetWindowText(GETHCTL(IDC_NOISE_PERIOD),
                            szBuffer, BUFFER_SIZE);
                        fPeriod=fabs(atof(szBuffer));
                        _snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
							fPeriod);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_NOISE_PERIOD),
                            szBuffer);
                    }
                }
                break;

				// Internal subroutine to activate copy button
				case IDC_NOISE_ACTIVE:
				{
					// Check for all noise parameters 0
                    if((fSigma[0]+fSigma[1]+fSigma[2]+fSigma[3]+fSigma[4])==0)
                    {
						// Disable the copy button until there are results
						EnableWindow(GETHCTL(IDC_NOISE_COPY), FALSE);
					}
					else // Have noise to generate
					{
						// Enable the copy button until there are results
						EnableWindow(GETHCTL(IDC_NOISE_COPY), TRUE);
					}
				}
				break;

				// Respond to CR in an edit control
				// Note: No button is a DEFPUSHBUTTON
				case IDOK:
				{
					// Does rwfm edit control have focus?
					if(GetFocus()==GETHCTL(IDC_NOISE_RWFM))
					{
						// Send EN_KILLFOCUS message to rwfm edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_NOISE_RWFM, 0,
							EN_KILLFOCUS));
					}

					// Does ffm edit control have focus?
					if(GetFocus()==GETHCTL(IDC_NOISE_FFM))
					{
						// Send EN_KILLFOCUS message to ffm edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_NOISE_FFM, 0,
							EN_KILLFOCUS));
					}

					// Does wfm edit control have focus?
					if(GetFocus()==GETHCTL(IDC_NOISE_WFM))
					{
						// Send EN_KILLFOCUS message to wfm edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_NOISE_WFM, 0,
							EN_KILLFOCUS));
					}

					// Does fpm edit control have focus?
					if(GetFocus()==GETHCTL(IDC_NOISE_FPM))
					{
						// Send EN_KILLFOCUS message to fpm edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_NOISE_FPM, 0,
							EN_KILLFOCUS));
					}

					// Does wpm edit control have focus?
					if(GetFocus()==GETHCTL(IDC_NOISE_WPM))
					{
						// Send EN_KILLFOCUS message to wpm edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_NOISE_WPM, 0,
							EN_KILLFOCUS));
					}

					// Does offset edit control have focus?
					if(GetFocus()==GETHCTL(IDC_NOISE_OFFSET))
					{
						// Send EN_KILLFOCUS message to offset edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_NOISE_OFFSET, 0,
							EN_KILLFOCUS));
					}

					// Does drift edit control have focus?
					if(GetFocus()==GETHCTL(IDC_NOISE_DRIFT))
					{
						// Send EN_KILLFOCUS message to drift edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_NOISE_DRIFT, 0,
							EN_KILLFOCUS));
					}

					// Does num edit control have focus?
					if(GetFocus()==GETHCTL(IDC_NOISE_NUM))
					{
						// Send EN_KILLFOCUS message to num edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_NOISE_NUM, 0,
							EN_KILLFOCUS));
					}

					// Does tau edit control have focus?
					if(GetFocus()==GETHCTL(IDC_NOISE_TAU))
					{
						// Send EN_KILLFOCUS message to tau edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_NOISE_TAU, 0,
							EN_KILLFOCUS));
					}

					// Does sine edit control have focus?
					if(GetFocus()==GETHCTL(IDC_NOISE_SINE))
					{
						// Send EN_KILLFOCUS message to sine edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_NOISE_SINE, 0,
							EN_KILLFOCUS));
					}

					// Does period edit control have focus?
					if(GetFocus()==GETHCTL(IDC_NOISE_PERIOD))
					{
						// Send EN_KILLFOCUS message to period edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_NOISE_PERIOD, 0,
							EN_KILLFOCUS));
					}
				}
				break;

				case IDC_NOISE_COPY:
				{
					// Allocate global memory for 15 lines of info
					nClip=15*80;
					hClipboard=GlobalAlloc(GMEM_DDESHARE, (DWORD)nClip);
					szClipboard=GlobalLock(hClipboard);

					// Main heading
					strlcpy(szClipboard, "Power-Law Noise Generation:",
						nClip);
					strlcat(szClipboard, "\r\n", nClip);

					// Points heading
					strlcat(szClipboard, "Points:", nClip);
					strlcat(szClipboard, "\r\n", nClip);

					// Num & tau
					strlcat(szClipboard, "Num=", nClip);
					GetWindowText(GETHCTL(IDC_NOISE_NUM), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);

					strlcat(szClipboard, "Tau=", nClip);
					GetWindowText(GETHCTL(IDC_NOISE_TAU), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);

					// Noise heading
					strlcat(szClipboard, "Noise Parameters:",
						nClip);
					strlcat(szClipboard, "\r\n", nClip);

					// Noise values
					strlcat(szClipboard, "RW FM=", nClip);
					GetWindowText(GETHCTL(IDC_NOISE_RWFM), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);

					strlcat(szClipboard, "F FM=", nClip);
					GetWindowText(GETHCTL(IDC_NOISE_FFM), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);

					strlcat(szClipboard, "W FM=", nClip);
					GetWindowText(GETHCTL(IDC_NOISE_WFM), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);

					strlcat(szClipboard, "F PM=", nClip);
					GetWindowText(GETHCTL(IDC_NOISE_FPM), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);

					strlcat(szClipboard, "W PM=", nClip);
					GetWindowText(GETHCTL(IDC_NOISE_WPM), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);

					// Freq heading
					strlcat(szClipboard, "Fractional Freq Parameters:",
						nClip);
					strlcat(szClipboard, "\r\n", nClip);

					// Freq values
					strlcat(szClipboard, "Offset=", nClip);
					GetWindowText(GETHCTL(IDC_NOISE_OFFSET), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);

					strlcat(szClipboard, "Drift/Tau=", nClip);
					GetWindowText(GETHCTL(IDC_NOISE_DRIFT), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);

					strlcat(szClipboard, "Sine=", nClip);
					GetWindowText(GETHCTL(IDC_NOISE_SINE), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);

					strlcat(szClipboard, "Period=", nClip);
					GetWindowText(GETHCTL(IDC_NOISE_PERIOD), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);

					// Write info to clipboard
					GlobalUnlock(hClipboard);
					OpenClipboard(NULL);
					EmptyClipboard();
					SetClipboardData(CF_TEXT, hClipboard);
					CloseClipboard();
				}
				break;

				case IDC_NOISE_ACCEPT:
				{
					// Save previous phase data, if any,
					// if tabs activated for noise data
					// Test for data existence, tab activation,
					// & noise selection
					// Also test that the phase # tabs is not at limit
					if(bPhaseData && bTabs && bTabNoise &&
						(nNumPhaseTabs<PTAB_NUMTABS))
					{
						// Get size of existing phase data array
						nEntry=(int)fPhaseData[0];
						
						// Allocate memory for existing phase data
						// using next sPTab[nNumPhaseTabs].fData pointer
						if((sPTab[nNumPhaseTabs].fData=
							(F_TYPE*)malloc((nEntry+ARRAY_OFFSET)*
							sizeof(F_TYPE)))==NULL)
						{
							AllocErrorMessage();
						}
						else // OK - save phase data
						{
							// Copy entire array, including header
							for(i=0; i<nEntry+ARRAY_OFFSET; i++)
							{
								sPTab[nNumPhaseTabs].fData[i]=fPhaseData[i];
							}
						}

						// Put filename into tab title
						// Because the generated phase noise
						// is always named NEW.DAT
						// we will use the title NoiseXX.phd,
						// where XX is the tab #
						_snprintf(szBuffer, sizeof(szBuffer), "Noise%02d.phd",
							nCount);
						strlcpy(sPTab[nNumPhaseTabs].szTitle, szBuffer,
							FILE_TITLE_SIZE);

						// Increment # phase tabs
						nNumPhaseTabs++;
					}

					// Save previous freq data, if any,
					// if tabs activated for noise data
					// Test for data existence, tab activation,
					// & noise selection
					// Also test that the # freq tabs is not at limit
					if(bFreqData && bTabs && bTabNoise &&
						(nNumFreqTabs<FTAB_NUMTABS))
					{
						// Get size of existing phase data array
						nEntry=(int)fFreqData[0];
						
						// Allocate memory for existing freq data
						// using next sFTab[nNumFreqTabs].fData pointer
						if((sFTab[nNumFreqTabs].fData=
							(F_TYPE*)malloc((nEntry+ARRAY_OFFSET)*
							sizeof(F_TYPE)))==NULL)
						{
							AllocErrorMessage();
						}
						else // OK - save freq data
						{
							// Copy entire array, including header
							for(i=0; i<nEntry+ARRAY_OFFSET; i++)
							{
								sFTab[nNumFreqTabs].fData[i]=fFreqData[i];
							}
						}

						// Put filename into tab title
						// Because the generated freq noise
						// is always named NEW.001
						// we will use the title NoiseXX.frd,
						// where XX is the tab #
						_snprintf(szBuffer, sizeof(szBuffer), "Noise%02d.frd",
							nCount);
						strlcpy(sFTab[nNumFreqTabs].szTitle, szBuffer,
							FILE_TITLE_SIZE);

						// Increment # freq tabs
						nNumFreqTabs++;

						// Increment data set count
						nCount++;
					}
					else // # tabs at limit
					{
						if(nNumPhaseTabs==PTAB_NUMTABS)
						{
							// Increment data set count
							// (even if not stored in a tab)
							nCount++;
							// Display message
							_snprintf(szBuffer, sizeof(szBuffer),
								"# tabs limit (%d) exceeded.\n"
								"Close an existing phase & freq tab pair "
								"to create new ones.", PTAB_NUMTABS);
							MessageBox(NULL, szBuffer, "Data Tabs",
								MB_OK | MB_ICONEXCLAMATION);
						}
					}

					// Update tab control
					UpdateTabControl();
					
					// Get noise parameters
					GetWindowText(GETHCTL(IDC_NOISE_RWFM), szBuffer,
						BUFFER_SIZE);
					fSigma[0]=atof(szBuffer);
					GetWindowText(GETHCTL(IDC_NOISE_FFM), szBuffer,
                        BUFFER_SIZE);
                    fSigma[1]=atof(szBuffer);
					GetWindowText(GETHCTL(IDC_NOISE_WFM), szBuffer,
                        BUFFER_SIZE);
                    fSigma[2]=atof(szBuffer);
                    GetWindowText(GETHCTL(IDC_NOISE_FPM), szBuffer,
                        BUFFER_SIZE);
                    fSigma[3]=atof(szBuffer);
                    GetWindowText(GETHCTL(IDC_NOISE_WPM), szBuffer,
                        BUFFER_SIZE);
                    fSigma[4]=atof(szBuffer);

                    // Get tau value
                    GetWindowText(GETHCTL(IDC_NOISE_TAU), szBuffer,
                        BUFFER_SIZE);
					fTau=atof(szBuffer);

                    // Get freq parameters
                    GetWindowText(GETHCTL(IDC_NOISE_OFFSET), szBuffer,
                        BUFFER_SIZE);
                    fOffset=atof(szBuffer);
                    GetWindowText(GETHCTL(IDC_NOISE_DRIFT), szBuffer,
                        BUFFER_SIZE);
                    fDrift=atof(szBuffer);

                    GetWindowText(GETHCTL(IDC_NOISE_SINE), szBuffer,
                        BUFFER_SIZE);
                    fSine=atof(szBuffer);
                    GetWindowText(GETHCTL(IDC_NOISE_PERIOD), szBuffer,
                        BUFFER_SIZE);
                    fPeriod=atof(szBuffer);

					// Get size
                    GetWindowText(GETHCTL(IDC_NOISE_NUM), szBuffer,
                        BUFFER_SIZE);
                    fNum=atof(szBuffer);

					// Check for all noise parameters 0
                    if((fSigma[0]+fSigma[1]+fSigma[2]+fSigma[3]+fSigma[4])==0)
                    {
                        LoadString(hInst, IDS_MESSAGE_NONOISE, szBuffer,
                            BUFFER_SIZE);
                        MessageBox(hDlg, szBuffer, szBoxTitle,
                            MB_ICONEXCLAMATION);
                        break;
                    }

                    // Display wait cursor
                    SetCursor(hWait);

					// Generate noise
                    nCode=GenerateNoise(fSigma, fOffset, fDrift, fTau,
						(int)fNum);

					// Add sinusoidal component to phase data
					// Phase is fractional frequency * time
					// where fractional freq is fSine
					// and time is period / 2 * pi
					// Subtraction makes freq component go as + sin()
					// Must have both non-zero fSine and fPeriod to apply
					if(fSine && fPeriod)
					{
						for(i=0; i<(int)fNum; i++)
						{
							fPhaseData[i+ARRAY_OFFSET]-=
								fSine*fPeriod*cos(2*PI*i*fTau/fPeriod)/(2*PI);
						}
					}

					#if(0) // For special testing
					// Add 2nd harmonic sinusoidal component to phase data
					// with half the amplitude
					// Phase is fractional frequency * time
					// where fundamental fractional freq is fSine
					// and time is period / 2 * pi
					// Subtraction makes freq component go as + sin()
					// Must have both non-zero fSine and fPeriod to apply
					if(fSine && fPeriod)
					{
						for(i=0; i<(int)fNum; i++)
						{
							fPhaseData[i+ARRAY_OFFSET]-=
								0.5*fSine*0.5*fPeriod*cos(2*PI*i*fTau/(0.5*fPeriod))/(2*PI);
						}
					}
					#endif

					#if(0) // For special testing
					// Add closely-spaced sinusoidal component to phase data
					// with same amplitude
					// As coded, 2nd component freq is 90% of 1st
					// Phase is fractional frequency * time
					// where fundamental fractional freq is fSine
					// and time is period / 2 * pi
					// Subtraction makes freq component go as + sin()
					// Must have both non-zero fSine and fPeriod to apply
					if(fSine && fPeriod)
					{
						for(i=0; i<(int)fNum; i++)
						{
							fPhaseData[i+ARRAY_OFFSET]-=
								fSine*0.9*fPeriod*cos(2*PI*i*fTau/(0.9*fPeriod))/(2*PI);
						}
					}
					#endif

					// Test error code
					if(nCode==-1)
					{
						// Noise generation error
						break;
					}

					if(nCode==-2)
					{
						// Memory allocation error
	                    LoadString(hInst, IDS_MESSAGE_NOISEMEM, szBuffer,
		                    BUFFER_SIZE);
			            MessageBox(hDlg, szBuffer, "Noise",
							MB_ICONEXCLAMATION);
						break;
					}

					// Clear timetag arrays
					// Don't want to have old timetag data that may have
					// different # of data points
					ClearTimetagArray(PHASE_DATA);
					ClearTimetagArray(FREQ_DATA);

					// Update data #, start and end
                    fPhaseData[0]=fNum;
                    fPhaseData[1]=(F_TYPE)1.0;
                    fPhaseData[2]=fNum;

                    // Update filenames
                    strlcpy(szFile, "NEW.DAT", FILE_NAME_SIZE);
					strlcpy(szFileTitle, "NEW.DAT", FILE_TITLE_SIZE);
                    strlcpy(szPhaseFile, "NEW.DAT", FILE_NAME_SIZE);
                    strlcpy(szPhaseFileTitle, "NEW.DAT", FILE_TITLE_SIZE);

                    // Update status display
					SetWindowText(hwndPhaseFilename, "NEW.DAT");
                    _snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fTau);
					ShortenExp(szBuffer);
                   SetWindowText(hwndPhaseTau, szBuffer);
                    _snprintf(szBuffer, sizeof(szBuffer), "%d", (int)fNum);
                    SetWindowText(hwndPhaseNum, szBuffer);
                    SetWindowText(hwndPhaseEnd, szBuffer);
                    SetWindowText(hwndPhaseStart, "1");
                    bPhaseGapFill=FALSE;
                    bPhaseNorm=FALSE;
                    bQuadDriftRem=FALSE;
                    nPhaseGapsFilled=0;

					// Set new data flags
					bPhaseDataChanged=TRUE;
					bPhaseDataUnsaved=TRUE;
					bPhaseScaleChanged=TRUE;
					bNoiseGenerated=TRUE;

					// Activate Phase Functions
                    ActivateFunctions(MF_ENABLED);

					// Put info into log file
					_snprintf(szBuffer, sizeof(szBuffer), "# Pts=%d",
						(int)fNum);
					WriteLog(46, szBuffer);
								
                    // Switch status indicators to phase data
					Button_SetCheck(hwndFreqSelectButton, bDataType);
					Button_SetCheck(hwndPhaseSelectButton, (1-bDataType));

					// Display normal cursor
                    SetCursor(hArrow);

					// Refresh Tabs menu
					SetTabMenu();
                }

				// Fill gaps (if any) in phase data
				FillGaps(fPhaseData, PHASE_DATA);
				
				// Go right into EndDialog()
                // Respond to esc key or cancel button
                case IDCANCEL:
                case IDC_NOISE_CANCEL:
                {
                    EndDialog (hDlg, 0);
                }
                return TRUE;
            }
        }
        break;
     }
     return FALSE;
}
#endif

#ifndef LITE_VER
/*****************************************************************************/
/*                                                                           */
/*                   Calendar Dialog Procedure                               */
/*                                                                           */
/*	02/23/02	Added autorepeat for year & month up & down buttons          */
/*	08/13/02	Added color to GPS week, month & year labels                 */
/*	08/18/02	Added copy command to copy calendar to clipboard             */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK CalendarDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam)
{
	#include <time.h>           // Header for Std C time functions & tm struct

	// Autorepeat macro
	#define SLOW 10				// Autorepeat accelerator slow threshold
	#define FAST 30				// Autorepeat accelerator fast threshold

    // Local variables
    RECT rect;                  // Calendar screen rectangle
	static HBRUSH hWBrush;		// White brush for coloring dlg box controls
	static HBRUSH hBBrush;		// Button brush for coloring dlg box controls
	static LOGFONT logfont;		// Font structure - static fills it with zeros
    static struct tm *datetime; // Standard C time structure
                                // Day of Month=tm_mday (1-31)
                                // Month of Year=tm_mon (0-11)
                                // Year since 1900=tm_year
    static int nMonth;          // Month of year(1-12)
    static int nThisMonth;      // Current month
    static int nYear;           // Year
    static int nThisYear;       // Current year
    static int nToday;          // Today's day # (1-31)
    static long lTime;          // Time value
	static BOOL bClip=0;		// Flag to copy calendar to clipboard
	static BOOL bButton=FALSE;	// Flag that autorepeating button active

	// Autorepeat variables
	static int bAuto;			// Flag for autorepeat
	static int nAccel;			// Autorepeat accelerator count				

	// char szBuffer[BUFFER_SIZE+1];   // Text buffer
	// Peek message
	MSG msg;					// Message structure for local peek

	// Set global dialog box handle
	hDialog=hDlg;

    switch(message)
    {
        case WM_INITDIALOG:
        {
			// Create brushes to set background color of non-text area
			hWBrush=CreateSolidBrush(0x00FFFFFF);
			hBBrush=CreateSolidBrush(GetSysColor(COLOR_BTNFACE));

			// Write prompt message
			WritePromptMessage(TB_CAL);

            // Get current date and time using Std C lib finctions
            time(&lTime);
            datetime=localtime(&lTime);
			nToday=datetime->tm_mday;
            nMonth=datetime->tm_mon+1;
            nThisMonth=nMonth;
            nYear=datetime->tm_year+1900;
            nThisYear=nYear;

			// Write calendar
            WriteCalendar(hDlg, nMonth, nThisMonth, nYear, nThisYear, nToday,
				bClip);
        }
        return TRUE;

		// Set control colors				
		case WM_CTLCOLORSTATIC: // Msg sent by read-only edit & static controls
		{
			// Force gps week control colors - blue text on grey background
			if(GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_GPS))
			{
				// Set text colors - background and text itself
				SetBkColor(GET_WM_CTLCOLOR_HDC(wParam, lParam, message),
					GetSysColor(COLOR_BTNFACE));
				SetTextColor(GET_WM_CTLCOLOR_HDC(wParam, lParam, message),
					0x00800000); // Dark Blue

				return((DWORD)hBBrush);
			}

			// Force month color - red text on grey background
			if(GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_MONTH))
			{
				// Set colors - background and text itself
				SetBkColor(GET_WM_CTLCOLOR_HDC(wParam, lParam, message),
					GetSysColor(COLOR_BTNFACE));
				SetTextColor(GET_WM_CTLCOLOR_HDC(wParam, lParam, message),
					0x000000FF); // Red

				return((DWORD)hBBrush);
			}

			// Force year color - red text on grey background
			if(GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_YEAR))
			{
				// Set colors - background and text itself
				SetBkColor(GET_WM_CTLCOLOR_HDC(wParam, lParam, message),
					GetSysColor(COLOR_BTNFACE));
				SetTextColor(GET_WM_CTLCOLOR_HDC(wParam, lParam, message),
					0x000000FF); // Red

				return((DWORD)hBBrush);
			}

			// Force day control colors - black text on white background
			if((GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+0)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+1)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+2)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+3)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+4)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+5)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+6)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+7)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+8)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+9)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+10)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+11)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+12)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+13)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+14)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+15)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+16)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+17)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+18)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+19)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+20)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+21)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+22)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+23)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+24)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+25)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+26)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+27)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+28)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+29)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+30)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+31)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+32)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+33)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+34)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+35)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+36)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+37)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+38)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+39)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+40)) ||
			   (GET_WM_CTLCOLOR_HWND(wParam, lParam, message)==
				GETHCTL(IDC_CAL_DAY1+41)) )
			{
				// Set colors - background and text itself
				SetBkColor(GET_WM_CTLCOLOR_HDC(wParam, lParam, message),
					0x00FFFFFF); // White
				SetTextColor(GET_WM_CTLCOLOR_HDC(wParam, lParam, message),
					0x00000000); // Black

				// Return white brush to color non-text background
				// of each control
				return((DWORD)hWBrush);
			}
		}

		case WM_COMMAND:
        {
            switch(GET_WM_COMMAND_ID(wParam, lParam))
            {
                // Respond to help button
				case IDHELP:
                {
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::CALENDAR_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
 					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::CALENDAR_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "CALENDAR_FUNCTION");
					#endif
               }
                break;


                case IDC_CAL_YRUP:
                {
					// Start when button depressed
					if((GET_WM_COMMAND_CMD(wParam, lParam))==BN_SETFOCUS)
					{	
						// Set button to pressed stste
						Button_SetState(GETHCTL(IDC_CAL_YRUP), 1);
						
						// Activate autorepeating
						bAuto=TRUE;

						// Set autorepeating button flag
						bButton=TRUE;

						// Set acceperator count to zero
						nAccel=0;

						// Autorepeat loop
						while(bAuto)
						{
							// Increment year
							nYear++;

							// Limit max year to 2099
							if(nYear>2099)
							{
								nYear=1900;
							}

							// Rewrite calendar
							WriteCalendar(hDlg, nMonth, nThisMonth, nYear,
								nThisYear, nToday, bClip);

							// Redisplay dialog box
							GetClientRect(hDlg, &rect);
							InvalidateRect(hDlg, &rect, FALSE);

							// Let system update display & get messages
							while(PeekMessage(&msg, NULL, 0, 0, PM_REMOVE))
							{
								if(!IsDialogMessage(hDlg, &msg))
								{
									TranslateMessage(&msg);
									DispatchMessage(&msg);
								}
							}

							// Increment accelerator count
							nAccel++;
							
							// Set autorepeat rate
							if(nAccel<SLOW) // Slow
							{
								Sleep(200);
							}
							else if(nAccel<FAST) // Medium
							{
								Sleep(100);
							}
							else // Fast
							{
								Sleep(50);
							}
						}
					}

					// Stop when button released
					// or respond to keyboard shortcut
					if((GET_WM_COMMAND_CMD(wParam, lParam))==BN_CLICKED)
					{	
						if(bButton) // Button released
						{
							// Stop autorepeating
							bAuto=FALSE;

							// Reset autorepeating button flag
							bButton=FALSE;

							// Remove the last increment to allow single steps
							// Decrement year
							nYear--;

							// Limit min year to 1900
							if(nYear<1900)
							{
								nYear=2099;
							}

							// Rewrite calendar
							WriteCalendar(hDlg, nMonth, nThisMonth, nYear,
								nThisYear, nToday, bClip);

							// Redisplay dialog box
							GetClientRect(hDlg, &rect);
							InvalidateRect(hDlg, &rect, FALSE);

							// Remove focus from button
							SetFocus(GETHCTL(IDC_CAL_TODAY));
						}
						else // Respond to year up ALT-Y keyboard shortcut
						{
							// Increment year
							nYear++;

							// Limit max year to 2099
							if(nYear>2099)
							{
								nYear=1900;
							}

							// Rewrite calendar
							WriteCalendar(hDlg, nMonth, nThisMonth, nYear,
								nThisYear, nToday, bClip);

							// Redisplay dialog box
							GetClientRect(hDlg, &rect);
							InvalidateRect(hDlg, &rect, FALSE);
						}
					}
				}
                break;

                case IDC_CAL_YRDN:
                {
					// Start when button depressed
					if((GET_WM_COMMAND_CMD(wParam, lParam))==BN_SETFOCUS)
					{	
						// Set button to pressed stste
						Button_SetState(GETHCTL(IDC_CAL_YRDN), 1);
						
						// Activate autorepeating
						bAuto=TRUE;

						// Set autorepeating button flag
						bButton=TRUE;

						// Set acceperator count to zero
						nAccel=0;

						// Autorepeat loop
						while(bAuto)
						{
							// Decrement year
							nYear--;

							// Limit min year to 1900
							if(nYear<1900)
							{
								nYear=2099;
							}

							// Rewrite calendar
							WriteCalendar(hDlg, nMonth, nThisMonth, nYear,
								nThisYear, nToday, bClip);

							// Redisplay dialog box
							GetClientRect(hDlg, &rect);
							InvalidateRect(hDlg, &rect, FALSE);

							// Let system update display & get messages
							while(PeekMessage(&msg, NULL, 0, 0, PM_REMOVE))
							{
								if(!IsDialogMessage(hDlg, &msg))
								{
									TranslateMessage(&msg);
									DispatchMessage(&msg);
								}
							}

							// Increment accelerator count
							nAccel++;
							
							// Set autorepeat rate
							if(nAccel<SLOW) // Slow
							{
								Sleep(200);
							}
							else if(nAccel<FAST) // Medium
							{
								Sleep(100);
							}
							else // Fast
							{
								Sleep(50);
							}
						}
					}

					// Stop when button released
					// or respond to keyboard shortcut
					if((GET_WM_COMMAND_CMD(wParam, lParam))==BN_CLICKED)
					{	
						if(bButton) // Button released
						{
							// Stop autorepeating
							bAuto=FALSE;

							// Reset autorepeating button flag
							bButton=FALSE;

							// Remove the last decrement to allow single steps
							// Increment year
							nYear++;

							// Limit max year to 2099
							if(nYear>2099)
							{
								nYear=1900;
							}

							// Rewrite calendar
							WriteCalendar(hDlg, nMonth, nThisMonth, nYear,
								nThisYear, nToday, bClip);

							// Redisplay dialog box
							GetClientRect(hDlg, &rect);
							InvalidateRect(hDlg, &rect, FALSE);

							// Remove focus from button
							SetFocus(GETHCTL(IDC_CAL_TODAY));
						}
						else // Respond to year down ALT-R keyboard shortcut
						{
							// Decrement year
							nYear--;

							// Limit min year to 1900
							if(nYear<1900)
							{
								nYear=2099;
							}

							// Rewrite calendar
							WriteCalendar(hDlg, nMonth, nThisMonth, nYear,
								nThisYear, nToday, bClip);

							// Redisplay dialog box
							GetClientRect(hDlg, &rect);
							InvalidateRect(hDlg, &rect, FALSE);
						}
					}
                }
                break;

                case IDC_CAL_MOUP:
				{
					// Start when button depressed
					if((GET_WM_COMMAND_CMD(wParam, lParam))==BN_SETFOCUS)
					{	
						// Set button to pressed stste
						Button_SetState(GETHCTL(IDC_CAL_MOUP), 1);
						
						// Activate autorepeating
						bAuto=TRUE;

						// Set autorepeating button flag
						bButton=TRUE;

						// Set acceperator count to zero
						nAccel=0;

						// Autorepeat loop
						while(bAuto)
						{
							// Increment month
							nMonth++;
							if(nMonth==13)
							{
								nMonth=1;
								nYear++;
							}

							// Limit max year to 2099
							if(nYear>2099)
							{
								nYear=1900;
							}

							// Rewrite calendar
							WriteCalendar(hDlg, nMonth, nThisMonth, nYear,
								nThisYear, nToday, bClip);

							// Redisplay dialog box
							GetClientRect(hDlg, &rect);
							InvalidateRect(hDlg, &rect, FALSE);

							// Let system update display & get messages
							while(PeekMessage(&msg, NULL, 0, 0, PM_REMOVE))
							{
								if(!IsDialogMessage(hDlg, &msg))
								{
									TranslateMessage(&msg);
									DispatchMessage(&msg);
								}
							}

							// Increment accelerator count
							nAccel++;
							
							// Set autorepeat rate
							if(nAccel<SLOW) // Slow
							{
								Sleep(200);
							}
							else if(nAccel<FAST) // Medium
							{
								Sleep(100);
							}
							else // Fast
							{
								Sleep(50);
							}
						}
					}

					// Stop when button released
					// or respond to keyboard shortcut
					if((GET_WM_COMMAND_CMD(wParam, lParam))==BN_CLICKED)
					{	
						if(bButton) // Button released
						{
							// Stop autorepeating
							bAuto=FALSE;

							// Reset autorepeating button flag
							bButton=FALSE;

							// Remove the last increment to allow single steps
							// Decrement month
							nMonth--;
							if(nMonth==0)
							{
								nMonth=12;
								nYear--;
							}

							// Limit min year to 1900
							if(nYear<1900)
							{
								nYear=2099;
							}

							// Rewrite calendar
							WriteCalendar(hDlg, nMonth, nThisMonth, nYear,
								nThisYear, nToday, bClip);

							// Redisplay dialog box
							GetClientRect(hDlg, &rect);
							InvalidateRect(hDlg, &rect, FALSE);

							// Remove focus from button
							SetFocus(GETHCTL(IDC_CAL_TODAY));
						}
						else // Respond to month up ALT-U keyboard shortcut
						{
							// Increment month
							nMonth++;
							if(nMonth==13)
							{
								nMonth=1;
								nYear++;
							}

							// Limit max year to 2099
							if(nYear>2099)
							{
								nYear=1900;
							}

							// Rewrite calendar
							WriteCalendar(hDlg, nMonth, nThisMonth, nYear,
								nThisYear, nToday, bClip);

							// Redisplay dialog box
							GetClientRect(hDlg, &rect);
							InvalidateRect(hDlg, &rect, FALSE);
						}
					}
                }
				break;

                case IDC_CAL_MODN:
                {
					// Start when button depressed
					if((GET_WM_COMMAND_CMD(wParam, lParam))==BN_SETFOCUS)
					{	
						// Set button to pressed stste
						Button_SetState(GETHCTL(IDC_CAL_MODN), 1);
						
						// Activate autorepeating
						bAuto=TRUE;

						// Set autorepeating button flag
						bButton=TRUE;

						// Set acceperator count to zero
						nAccel=0;

						// Autorepeat loop
						while(bAuto)
						{
							// Decrement month
							nMonth--;
							if(nMonth==0)
							{
								nMonth=12;
								nYear--;
							}

							// Limit min year to 1900
							if(nYear<1900)
							{
								nYear=2099;
							}

							// Rewrite calendar
							WriteCalendar(hDlg, nMonth, nThisMonth, nYear,
								nThisYear, nToday, bClip);

							// Redisplay dialog box
							GetClientRect(hDlg, &rect);
							InvalidateRect(hDlg, &rect, FALSE);

							// Let system update display & get messages
							while(PeekMessage(&msg, NULL, 0, 0, PM_REMOVE))
							{
								if(!IsDialogMessage(hDlg, &msg))
								{
									TranslateMessage(&msg);
									DispatchMessage(&msg);
								}
							}

							// Increment accelerator count
							nAccel++;
							
							// Set autorepeat rate
							if(nAccel<SLOW) // Slow
							{
								Sleep(200);
							}
							else if(nAccel<FAST) // Medium
							{
								Sleep(100);
							}
							else // Fast
							{
								Sleep(50);
							}
						}
					}

					// Stop when button released
					// or respond to keyboard shortcut
					if((GET_WM_COMMAND_CMD(wParam, lParam))==BN_CLICKED)
					{	
						if(bButton) // Button released
						{
							// Stop autorepeating
							bAuto=FALSE;

							// Reset autorepeating button flag
							bButton=FALSE;

							// Remove the last decrement to allow single steps
							// Increment month
							nMonth++;
							if(nMonth==13)
							{
								nMonth=1;
								nYear++;
							}

							// Limit max year to 2099
							if(nYear>2099)
							{
								nYear=1900;
							}

							// Rewrite calendar
							WriteCalendar(hDlg, nMonth, nThisMonth, nYear,
								nThisYear, nToday, bClip);

							// Redisplay dialog box
							GetClientRect(hDlg, &rect);
							InvalidateRect(hDlg, &rect, FALSE);

							// Remove focus from button
							SetFocus(GETHCTL(IDC_CAL_TODAY));
						}
						else // Respond to month down ALT-D keyboard shortcut
						{
							// Decrement month
							nMonth--;
							if(nMonth==0)
							{
								nMonth=12;
								nYear--;
							}

							// Limit min year to 1900
							if(nYear<1900)
							{
								nYear=2099;
							}


							// Rewrite calendar
							WriteCalendar(hDlg, nMonth, nThisMonth, nYear,
								nThisYear, nToday, bClip);

							// Redisplay dialog box
							GetClientRect(hDlg, &rect);
							InvalidateRect(hDlg, &rect, FALSE);
						}
					}
                }
                break;

                case IDC_CAL_TODAY:
                {
                    // Redisplay dialog box
                    GetClientRect(hDlg, &rect);
                    InvalidateRect(hDlg, &rect, FALSE);

					// Reinitialize
					SendMessage(hDlg, WM_INITDIALOG, (WPARAM)0, (LPARAM)0);
				}
				break;

                case IDC_CAL_COPY:
                {
					// Set clipboard flag
					bClip=TRUE;

					// Rewrite calendar
					WriteCalendar(hDlg, nMonth, nThisMonth, nYear, nThisYear,
						nToday, bClip);

                    // Redisplay dialog box
                    GetClientRect(hDlg, &rect);
                    InvalidateRect(hDlg, &rect, FALSE);

					// Let system update display & get messages
					while(PeekMessage(&msg, NULL, 0, 0, PM_REMOVE))
					{
						if(!IsDialogMessage(hDlg, &msg))
						{
							TranslateMessage(&msg);
							DispatchMessage(&msg);
						}
					}

					// Copy calendar bitmap to clipboard
					CopyDialog(hDlg, 822, 1000);

					// Clear clipboard flag
					bClip=FALSE;

					// Rewrite calendar - may need current day highlighted
					WriteCalendar(hDlg, nMonth, nThisMonth, nYear, nThisYear,
						nToday, bClip);

                    // Redisplay dialog box
                    GetClientRect(hDlg, &rect);
                    InvalidateRect(hDlg, &rect, FALSE);
				}
				break;

                case IDCANCEL:
				{
					// Delete brushes
					DeleteObject(hWBrush);
					DeleteObject(hBBrush);

					// Close dialog box
                    EndDialog (hDlg, 0);
                }
                return TRUE;
            }
		}
        break;
     }
     return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*                   Calendar Subroutine                                     */
/*                                                                           */
/*  Function to write calendar info on screen for given month and year       */
/*                                                                           */
/*  Revision record:                                                         */
/*		08/18/02	Added BOOL bClip and clipboard writing code              */
/*                                                                           */
/*****************************************************************************/

void WINAPI WriteCalendar(HWND hDlg, int nMonth, int nThisMonth,
	int nYear, int nThisYear, int nToday, BOOL bClip)
{
    // Local variables
    char szBuffer[BUFFER_SIZE+1];   // Text buffer
    static char *szMonth[]={"January", "February", "March", "April", "May",
        "June", "July", "August", "September", "October", "November",
        "December"};            // Month names
    int i;                      // Index
	static int nDOW;            // Day of week (0-6, Sun=0)
    static int nDOY;            // Day of year
    static int nDaysInMonth;    // # days in month
    static long lnMJD;          // MJD

	// Get DOW, DOY and MJD
    DateConv(&nMonth, &nDaysInMonth, &nYear, &nDOW, &nDOY,
        &lnMJD);

	// Display GPS week #s
	i=MJDtoGPS(lnMJD);
	_snprintf(szBuffer, sizeof(szBuffer), "GPS Weeks %d-%d", i, ((i+5)%1024));

	// Limit display to + #s
	if(i>=0)
	{
		SetWindowText(GETHCTL(IDC_CAL_GPS), szBuffer);
	}
	else
	{
		SetWindowText(GETHCTL(IDC_CAL_GPS), "");
	}

    // Write month
    strlcpy(szBuffer, szMonth[nMonth-1], sizeof(szBuffer));
    SetWindowText(GETHCTL(IDC_CAL_MONTH), szBuffer);

    // Write year
    _snprintf(szBuffer, sizeof(szBuffer), "%d", nYear);
	SetWindowText(GETHCTL(IDC_CAL_YEAR), szBuffer);

    // Clear cells
    for(i=0; i<42; i++)
    {
		_snprintf(szBuffer, sizeof(szBuffer), "");
        SetWindowText(GETHCTL(IDC_CAL_DAY1+i), szBuffer);
    }

    // Write to cells
    // Note that a CR LF is needed at the end of each line
    for(i=0; i<nDaysInMonth; i++)
    {
		_snprintf(szBuffer, sizeof(szBuffer), "%2.0d   %d\r\n%ld", 1+i, nDOY+i,
            lnMJD+i);
        SetWindowText(GETHCTL(
            IDC_CAL_DAY0+nDOW+1+i), szBuffer);
    }

    if(nYear==nThisYear && nMonth==nThisMonth && !bClip)
    {
        // Highlight current day
		SendMessage(GETHCTL(IDC_CAL_DAY0+nToday+nDOW), EM_SETSEL,
			GET_EM_SETSEL_MPS(0, 2));
	}

	return;
}

/*****************************************************************************/
/*                                                                           */
/*                           DateConv()                                      */
/*                                                                           */
/*      Function to convert month & year to day of week, DOY and MJD,        */
/*      plus # days in month.                                                */
/*                                                                           */
/*      Calling program sets month and year.  1st day of month is assumed.   */
/*      Function sets corresponding day of week, day of year, MJD and        */
/*      # days in month.                                                     */
/*                                                                           */
/*      Uses date functions from Hammer library.                             */
/*                                                                           */
/*      Parameters:                                                          */
/*          int  lpnMonth          pointer to month (January=1)              */
/*          int  lpnDaysInMonth    pointer to # days in month                */
/*          int  lpnYear           pointer to year (e.g. 1995)               */
/*          int  lpnDOW            pointer to day of week (Sunday=0)         */
/*          int  lpnDOY            pointer to day of year                    */
/*          long lplnMJD           pointer to Modified Julian Date           */
/*                                                                           */
/*      Returns nothing (void)                                               */
/*                                                                           */
/*      Revision record:                                                     */
/*          03/30/96    Adapted from date_conv() of SCRN_CAL.C               */
/*          04/08/97    Fixed bug in century leap year logic                 */
/*			07/18/97	Changed to new date function to avoid Hammer Library */
/*                                                                           */
/*****************************************************************************/

void WINAPI DateConv(int *lpnMonth, int *lpnDaysInMonth,
	int *lpnYear, int *lpnDOW, int *lpnDOY, long *lplnMJD)
{
	static int sum[] = { 0, 31, 59, 90, 120, 151, 181, 212,
						  243, 273, 304, 334, 365 };
	static int num_days[] = {31, 28, 31, 30, 31, 30, 31, 31,
						  30, 31, 30, 31};
	// LOCAL VARIABLES
	int month;
	int year;
	int dow;                         /* day of week: 0=Sunday ... 6=Saturday */
	int day=1;                                      /* day of month always 1 */
	int doy;                                                  /* day of year */
	int leap=0;                                            /* leap year flag */
	long int gdate;                                        /* Gregorian date */
	long int jdate;                                          /* Julian day # */
	long int mjd;                                     /* Modified Julian Day */

	// INITIALIZATIONS
	month=*lpnMonth;
	year=*lpnYear;

	// DATE CONVERSIONS
	gdate=MakeDate(month, day, year);
	BreakDate(gdate, &month, &day, &year);
	dow=DayOfWeek(gdate);

	doy=sum[month-1]+day;

	if( year % 4 == 0 && year % 100 != 0 || year % 400 == 0 )
	{
		leap=1;
		if(month>2)
		{
			doy++;
		}                                                          /* end if */
	}                                                              /* end if */

	jdate=DateToJulian(gdate);
	mjd=jdate-2400001L;

	// PASS RESULTS
	*lplnMJD=mjd;
	*lpnDOW=dow;
	*lpnDOY=doy;

	if(month!=2)
	{
		leap=0;
	}                                                              /* end if */

	*lpnDaysInMonth=num_days[month-1]+leap;
}                                                      /* end date_convert() */

/*****************************************************************************/
#endif

#ifndef LITE_VER
/*****************************************************************************/
/*                                                                           */
/*                   File Dialog Procedure                                   */
/*                                                                           */
/*	Function to support editing of plot and data filenames                   */
/*                                                                           */
/*  Revision record:                                                         */
/*      04/06/98    Created                                                  */
/*		07/11/02	Added PSD filename                                       */
/*		08/16/03	Added autocorrelation plot and data filenames            */
/*		12/19/05	Added dynamic stability plot filename                    */
/*		11/29/11	Added help file name and path                            */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK FileDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	// Chars
	char szBuffer[BUFFER_SIZE+1];	// General text buffer
	char szName[FILENAMESIZE+1];    // File name buffer
	char szExt[BUFFER_SIZE+1];		// File extension buffer
	char szNewPath[FILENAMESIZE+1]; // New path buffer
	// Temporary filename buffers
	char szTempFile[FILENAMESIZE+1];	// Temp full filename buffer
	char szTempTitle[FILENAMESIZE+1];	// Temp file title buffer
	char szTempPath[FILENAMESIZE+1];	// Temp file path buffer
	char szTempName[FILENAMESIZE+1];    // Temp file name buffer
	char szTempExt[BUFFER_SIZE+1];		// Temp file extension buffer

	// BOOLs
	static BOOL bMessage=FALSE;		// Flag for message box opened
	// Buffers to save original filenames in case of an abort
	static char szPPlotSave[FILENAMESIZE+1];
	static char szFPlotSave[FILENAMESIZE+1];
	static char szSPlotSave[FILENAMESIZE+1];
	static char szHPlotSave[FILENAMESIZE+1];
	static char szPSPlotSave[FILENAMESIZE+1];
	static char szAPlotSave[FILENAMESIZE+1];
	static char szDPlotSave[FILENAMESIZE+1];
	static char szPhaseSave[FILENAMESIZE+1];
	static char szFreqSave[FILENAMESIZE+1];
	static char szStabSave[FILENAMESIZE+1];
	static char szPSDSave[FILENAMESIZE+1];
	static char szAutoSave[FILENAMESIZE+1];
	static char szHelpSave[FILENAMESIZE+1];
	static char szPathSave[FILENAMESIZE+1];

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Write prompt message
			LoadString(hInst, IDS_MESSAGE_FILENAMES, szBuffer,
				BUFFER_SIZE);
			WriteMessage(szBuffer);

			// Save original filenames in case of abort
			strlcpy(szPPlotSave, sPPlot.plot_filename, sizeof(szPPlotSave));
			strlcpy(szFPlotSave, sFPlot.plot_filename, sizeof(szFPlotSave));
			strlcpy(szSPlotSave, sSPlot.plot_filename, sizeof(szSPlotSave));
			strlcpy(szHPlotSave, sHPlot.plot_filename, sizeof(szHPlotSave));
			strlcpy(szPSPlotSave, sPSPlot.plot_filename, sizeof(szPSPlotSave));
			strlcpy(szAPlotSave, sAPlot.plot_filename, sizeof(szAPlotSave));
			strlcpy(szDPlotSave, sDPlot.plot_filename, sizeof(szDPlotSave));
			strlcpy(szPhaseSave, szPhaseFile, sizeof(szPhaseSave));
			strlcpy(szFreqSave, szFreqFile, sizeof(szFreqSave));
			strlcpy(szPSDSave, szPSDFile, sizeof(szPSDSave));
			strlcpy(szAutoSave, szAutoFile, sizeof(szAutoSave));
			strlcpy(szStabSave, szStabFile, sizeof(szStabSave));
			strlcpy(szHelpSave, szHelpFile, sizeof(szHelpSave));
			strlcpy(szPathSave, szPath, sizeof(szPathSave));

			// Initialize plot filename edit boxes
			SetWindowText(GETHCTL(IDC_FILE_PHASEPLOT), sPPlot.plot_filename);
			SetWindowText(GETHCTL(IDC_FILE_FREQPLOT), sFPlot.plot_filename);
			SetWindowText(GETHCTL(IDC_FILE_SIGMAPLOT), sSPlot.plot_filename);
			SetWindowText(GETHCTL(IDC_FILE_HISTOPLOT), sHPlot.plot_filename);
			SetWindowText(GETHCTL(IDC_FILE_SPECTPLOT), sPSPlot.plot_filename);
			SetWindowText(GETHCTL(IDC_FILE_AUTOPLOT), sAPlot.plot_filename);
			SetWindowText(GETHCTL(IDC_FILE_DAVARPLOT), sDPlot.plot_filename);

			// Initialize stability data filename edit box
			SetWindowText(GETHCTL(IDC_FILE_STABDATA), szStabFile);

			// Initialize PSD data filename edit box
			SetWindowText(GETHCTL(IDC_FILE_PSDDATA), szPSDFile);
			
			// Initialize autocorrelation data filename edit box
			SetWindowText(GETHCTL(IDC_FILE_AUTODATA), szAutoFile);

			// Initialize help edit box
			SetWindowText(GETHCTL(IDC_FILE_HELP), szHelpFile);

			// Initialize path edit box
			SetWindowText(GETHCTL(IDC_FILE_PATH), szPath);

			// Initialize phase data filename edit box
			if(bPhaseData)
			{
				EnableWindow(GETHCTL(IDC_FILE_PHASEDATA), TRUE);
				SetWindowText(GETHCTL(IDC_FILE_PHASEDATA), szPhaseFile);
			}
			else
			{
				EnableWindow(GETHCTL(IDC_FILE_PHASEDATA), FALSE);
				LoadString(hInst, IDS_MESSAGE_NOPHASEDATA, szBuffer,
					BUFFER_SIZE);
				SetWindowText(GETHCTL(IDC_FILE_PHASEDATA), szBuffer);
			}

			// Initialize freq data filename edit box
			if(bFreqData)
			{
				EnableWindow(GETHCTL(IDC_FILE_FREQDATA), TRUE);
				SetWindowText(GETHCTL(IDC_FILE_FREQDATA), szFreqFile);
			}
			else
			{
				EnableWindow(GETHCTL(IDC_FILE_FREQDATA), FALSE);
				LoadString(hInst, IDS_MESSAGE_NOFREQDATA, szBuffer,
					BUFFER_SIZE);
				SetWindowText(GETHCTL(IDC_FILE_FREQDATA), szBuffer);
			}
		}
		return TRUE;

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				// Respond to help button message
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::FILENAMES_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::FILENAMES_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "FILENAMES_FUNCTION");
					#endif
				}
				break;

				// Respond to set button
				case IDC_FILE_SET:
				{
					// Get new path from edit box
					GetWindowText(GETHCTL(IDC_FILE_PATH),
						szNewPath, FILENAMESIZE);

					if(CheckPath(szNewPath, hDlg, "Set"))
					{			
						// New path OK
						strlcpy(szPath, szNewPath, FILE_NAME_SIZE);

						// Redisplay the new path
						SetWindowText(GETHCTL(IDC_FILE_PATH), szNewPath);
					}
					else // New path NG
					{
						// Restore original path
						SetWindowText(GETHCTL(IDC_FILE_PATH), szPath);
					}

					// Set phase plot filename
					_splitpath(sPPlot.plot_filename, NULL, NULL, szName,
						szExt);
					strlcpy(sPPlot.plot_filename, szPath, FILENAMESIZE);
					strlcat(sPPlot.plot_filename, szName, FILENAMESIZE);
					strlcat(sPPlot.plot_filename, szExt, FILENAMESIZE);
					SetWindowText(GETHCTL(IDC_FILE_PHASEPLOT),
						sPPlot.plot_filename);

					// Set freq plot filename
					_splitpath(sFPlot.plot_filename, NULL, NULL, szName,
						szExt);
					strlcpy(sFPlot.plot_filename, szPath, FILENAMESIZE);
					strlcat(sFPlot.plot_filename, szName, FILENAMESIZE);
					strlcat(sFPlot.plot_filename, szExt, FILENAMESIZE);
					SetWindowText(GETHCTL(IDC_FILE_FREQPLOT),
						sFPlot.plot_filename);

					// Set sigma plot filename
					_splitpath(sSPlot.plot_filename, NULL, NULL, szName,
						szExt);
					strlcpy(sSPlot.plot_filename, szPath, FILENAMESIZE);
					strlcat(sSPlot.plot_filename, szName, FILENAMESIZE);
					strlcat(sSPlot.plot_filename, szExt, FILENAMESIZE);
					SetWindowText(GETHCTL(IDC_FILE_SIGMAPLOT),
						sSPlot.plot_filename);

					// Set histogram plot filename
					_splitpath(sHPlot.plot_filename, NULL, NULL, szName,
						szExt);
					strlcpy(sHPlot.plot_filename, szPath, FILENAMESIZE);
					strlcat(sHPlot.plot_filename, szName, FILENAMESIZE);
					strlcat(sHPlot.plot_filename, szExt, FILENAMESIZE);
					SetWindowText(GETHCTL(IDC_FILE_HISTOPLOT),
						sHPlot.plot_filename);

					// Set spectrum plot filename
					_splitpath(sPSPlot.plot_filename, NULL, NULL, szName,
						szExt);
					strlcpy(sPSPlot.plot_filename, szPath, FILENAMESIZE);
					strlcat(sPSPlot.plot_filename, szName, FILENAMESIZE);
					strlcat(sPSPlot.plot_filename, szExt, FILENAMESIZE);
					SetWindowText(GETHCTL(IDC_FILE_SPECTPLOT),
						sPSPlot.plot_filename);

					// Set autocorrelation plot filename
					_splitpath(sAPlot.plot_filename, NULL, NULL, szName,
						szExt);
					strlcpy(sAPlot.plot_filename, szPath, FILENAMESIZE);
					strlcat(sAPlot.plot_filename, szName, FILENAMESIZE);
					strlcat(sAPlot.plot_filename, szExt, FILENAMESIZE);
					SetWindowText(GETHCTL(IDC_FILE_AUTOPLOT),
						sAPlot.plot_filename);

					// Set dynamic stability plot filename
					_splitpath(sDPlot.plot_filename, NULL, NULL, szName,
						szExt);
					strlcpy(sDPlot.plot_filename, szPath, FILENAMESIZE);
					strlcat(sDPlot.plot_filename, szName, FILENAMESIZE);
					strlcat(sDPlot.plot_filename, szExt, FILENAMESIZE);
					SetWindowText(GETHCTL(IDC_FILE_DAVARPLOT),
						sDPlot.plot_filename);

					// Set stability data filename
					_splitpath(szStabFile, NULL, NULL, szName, szExt);
					strlcpy(szStabFile, szPath, FILE_NAME_SIZE);
					strlcat(szStabFile, szName, FILE_NAME_SIZE);
					strlcat(szStabFile, szExt, FILE_NAME_SIZE);
					SetWindowText(GETHCTL(IDC_FILE_STABDATA), szStabFile);

					// Set PSD data filename
					_splitpath(szPSDFile, NULL, NULL, szName, szExt);
					strlcpy(szPSDFile, szPath, FILE_NAME_SIZE);
					strlcat(szPSDFile, szName, FILE_NAME_SIZE);
					strlcat(szPSDFile, szExt, FILE_NAME_SIZE);
					SetWindowText(GETHCTL(IDC_FILE_PSDDATA), szPSDFile);

					// Set autocorrelation data filename
					_splitpath(szAutoFile, NULL, NULL, szName, szExt);
					strlcpy(szAutoFile, szPath, FILE_NAME_SIZE);
					strlcat(szAutoFile, szName, FILE_NAME_SIZE);
					strlcat(szAutoFile, szExt, FILE_NAME_SIZE);
					SetWindowText(GETHCTL(IDC_FILE_AUTODATA), szAutoFile);

					#if(0) // May not want to do this
					// Set help filename
					_splitpath(szHelpFile, NULL, NULL, szName, szExt);
					strlcpy(szHelpFile, szPath, FILE_NAME_SIZE);
					strlcat(szHelpFile, szName, FILE_NAME_SIZE);
					strlcat(szHelpFile, szExt, FILE_NAME_SIZE);
					SetWindowText(GETHCTL(IDC_FILE_HELP), szHelpFile);
					#endif
				}
				break;
				
				// Respond to reset button
				case IDC_FILE_RESET:
				{
					// Reset phase plot filename
					strlcpy(sPPlot.plot_filename, szDrive, FILENAMESIZE);
					strlcat(sPPlot.plot_filename, szDirectory, FILENAMESIZE);
					strlcat(sPPlot.plot_filename, "PHASE.TKF", FILENAMESIZE);
					SetWindowText(GETHCTL(IDC_FILE_PHASEPLOT),
						sPPlot.plot_filename);

					// Reset freq plot filename
					strlcpy(sFPlot.plot_filename, szDrive, FILENAMESIZE);
					strlcat(sFPlot.plot_filename, szDirectory, FILENAMESIZE);
					strlcat(sFPlot.plot_filename, "FREQ.TKF", FILENAMESIZE);
					SetWindowText(GETHCTL(IDC_FILE_FREQPLOT),
						sFPlot.plot_filename);

					// Reset sigma plot filename
					strlcpy(sSPlot.plot_filename, szDrive, FILENAMESIZE);
					strlcat(sSPlot.plot_filename, szDirectory, FILENAMESIZE);
					strlcat(sSPlot.plot_filename, "SIGMA.TKF", FILENAMESIZE);
					SetWindowText(GETHCTL(IDC_FILE_SIGMAPLOT),
						sSPlot.plot_filename);

					// Reset histogram plot filename
					strlcpy(sHPlot.plot_filename, szDrive, FILENAMESIZE);
					strlcat(sHPlot.plot_filename, szDirectory, FILENAMESIZE);
					strlcat(sHPlot.plot_filename, "HISTO.TKF", FILENAMESIZE);
					SetWindowText(GETHCTL(IDC_FILE_HISTOPLOT),
						sHPlot.plot_filename);

					// Reset spectrum plot filename
					strlcpy(sPSPlot.plot_filename, szDrive, FILENAMESIZE);
					strlcat(sPSPlot.plot_filename, szDirectory, FILENAMESIZE);
					strlcat(sPSPlot.plot_filename, "SPECTRUM.TKF",
						FILENAMESIZE);
					SetWindowText(GETHCTL(IDC_FILE_SPECTPLOT),
						sPSPlot.plot_filename);

					// Reset autocorrelation plot filename
					strlcpy(sAPlot.plot_filename, szDrive, FILENAMESIZE);
					strlcat(sAPlot.plot_filename, szDirectory, FILENAMESIZE);
					strlcat(sAPlot.plot_filename, "AUTO.TKF", FILENAMESIZE);
					SetWindowText(GETHCTL(IDC_FILE_AUTOPLOT),
						sAPlot.plot_filename);

					// Reset dynamic stability plot filename
					strlcpy(sDPlot.plot_filename, szDrive, FILENAMESIZE);
					strlcat(sDPlot.plot_filename, szDirectory, FILENAMESIZE);
					strlcat(sDPlot.plot_filename, "AUTO.TKF", FILENAMESIZE);
					SetWindowText(GETHCTL(IDC_FILE_DAVARPLOT),
						sDPlot.plot_filename);

					// Reset stability data filename
					strlcpy(szStabFile, szDrive, FILE_NAME_SIZE);
					strlcat(szStabFile, szDirectory, FILE_NAME_SIZE);
					strlcat(szStabFile, "SIGMA.TAU", FILE_NAME_SIZE);
					SetWindowText(GETHCTL(IDC_FILE_STABDATA), szStabFile);

					// Reset PSD data filename
					strlcpy(szPSDFile, szDrive, FILE_NAME_SIZE);
					strlcat(szPSDFile, szDirectory, FILE_NAME_SIZE);
					strlcat(szPSDFile, "PSD.DAT", FILE_NAME_SIZE);
					SetWindowText(GETHCTL(IDC_FILE_PSDDATA), szPSDFile);
					
					// Reset autocorrelation data filename
					strlcpy(szAutoFile, szDrive, FILE_NAME_SIZE);
					strlcat(szAutoFile, szDirectory, FILE_NAME_SIZE);
					strlcat(szAutoFile, "AUTO.DAT", FILE_NAME_SIZE);
					SetWindowText(GETHCTL(IDC_FILE_AUTODATA), szAutoFile);
					
					// Reset help filename
					strlcpy(szHelpFile, szDrive, FILE_NAME_SIZE);
					strlcat(szHelpFile, szDirectory, FILE_NAME_SIZE);
					strlcat(szHelpFile, HELPFILESTRING, FILE_NAME_SIZE);
					SetWindowText(GETHCTL(IDC_FILE_HELP), szHelpFile);
					
					// Reset path
					strlcpy(szPath, szDrive, FILE_NAME_SIZE);
					strlcat(szPath, szDirectory, FILE_NAME_SIZE);
					SetWindowText(GETHCTL(IDC_FILE_PATH), szPath);
				}
				break;
				
				// Respond to phase plot filename edit control message
				case IDC_FILE_PHASEPLOT:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(GetFocus()!=GETHCTL(IDC_FILE_CANCEL)) && (!bMessage))
					{
						// Set Message flag
						bMessage=TRUE;

						GetWindowText(GETHCTL(IDC_FILE_PHASEPLOT),
							szTempFile, FILENAMESIZE);

						// Validate new filename
						if(CheckFilename(szTempFile, szTempTitle, szTempPath,
							szTempName, szTempExt, hDlg,
							"Phase Plot Filename"))
						{
							// Filename OK
							strlcpy(sPPlot.plot_filename, szTempFile,
								FILENAMESIZE);

							// Redisplay the new filename
							SetWindowText(GETHCTL(IDC_FILE_PHASEPLOT),
								szTempFile);
						}
						else // Filename NG
						{
							// Restore original filename
							SetWindowText(GETHCTL(IDC_FILE_PHASEPLOT),
								sPPlot.plot_filename);
							SetFocus(GETHCTL(IDC_FILE_PHASEPLOT));
							break;
						}
					}
 					else
					{
						// Reset message flag
						bMessage=FALSE;
					}
                }
                break;

				// Respond to freq plot filename edit control message
				case IDC_FILE_FREQPLOT:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(GetFocus()!=GETHCTL(IDC_FILE_CANCEL)) && (!bMessage))
					{
						// Set Message flag
						bMessage=TRUE;

						GetWindowText(GETHCTL(IDC_FILE_FREQPLOT),
							szTempFile, FILENAMESIZE);

						// Validate new filename
						if(CheckFilename(szTempFile, szTempTitle, szTempPath,
							szTempName, szTempExt, hDlg,
							"Freq Plot Filename"))
						{
							// Filename OK
							strlcpy(sFPlot.plot_filename, szTempFile,
								FILENAMESIZE);

							// Redisplay the new filename
							SetWindowText(GETHCTL(IDC_FILE_FREQPLOT),
								szTempFile);
						}
						else // Filename NG
						{
							// Restore original filename
							SetWindowText(GETHCTL(IDC_FILE_FREQPLOT),
								sFPlot.plot_filename);
							SetFocus(GETHCTL(IDC_FILE_FREQPLOT));
							break;
						}
					}
  					else
					{
						// Reset message flag
						bMessage=FALSE;
					}
                }
                break;

				// Respond to sigma plot filename edit control message
				case IDC_FILE_SIGMAPLOT:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(GetFocus()!=GETHCTL(IDC_FILE_CANCEL)) && (!bMessage))
					{
						// Set Message flag
						bMessage=TRUE;

						GetWindowText(GETHCTL(IDC_FILE_SIGMAPLOT),
							szTempFile, FILENAMESIZE);

						// Validate new filename
						if(CheckFilename(szTempFile, szTempTitle, szTempPath,
							szTempName, szTempExt, hDlg,
							"Sigma Plot Filename"))
						{
							// Filename OK
							strlcpy(sSPlot.plot_filename, szTempFile,
								FILENAMESIZE);

							// Redisplay the new filename
							SetWindowText(GETHCTL(IDC_FILE_SIGMAPLOT),
								szTempFile);
						}
						else // Filename NG
						{
							// Restore original filename
							SetWindowText(GETHCTL(IDC_FILE_SIGMAPLOT),
								sSPlot.plot_filename);
							SetFocus(GETHCTL(IDC_FILE_SIGMAPLOT));
							break;
						}
					}
  					else
					{
						// Reset message flag
						bMessage=FALSE;
					}
                }
                break;

				// Respond to histogram plot filename edit control message
				case IDC_FILE_HISTOPLOT:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(GetFocus()!=GETHCTL(IDC_FILE_CANCEL)) && (!bMessage))
					{
						// Set Message flag
						bMessage=TRUE;

						GetWindowText(GETHCTL(IDC_FILE_HISTOPLOT),
							szTempFile, FILENAMESIZE);

						// Validate new filename
						if(CheckFilename(szTempFile, szTempTitle, szTempPath,
							szTempName, szTempExt, hDlg,
							"Histo Plot Filename"))
						{
							// Filename OK
							strlcpy(sHPlot.plot_filename, szTempFile,
								FILENAMESIZE);

							// Redisplay the new filename
							SetWindowText(GETHCTL(IDC_FILE_HISTOPLOT),
								szTempFile);
						}
						else // Filename NG
						{
							// Restore original filename
							SetWindowText(GETHCTL(IDC_FILE_HISTOPLOT),
								sHPlot.plot_filename);
							SetFocus(GETHCTL(IDC_FILE_HISTOPLOT));
							break;
						}
					}
  					else
					{
						// Reset message flag
						bMessage=FALSE;
					}
				}
                break;

				// Respond to spectrum plot filename edit control message
				case IDC_FILE_SPECTPLOT:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(GetFocus()!=GETHCTL(IDC_FILE_CANCEL)) && (!bMessage))
					{
						// Set Message flag
						bMessage=TRUE;

						GetWindowText(GETHCTL(IDC_FILE_SPECTPLOT),
							szTempFile, FILENAMESIZE);

						// Validate new filename
						if(CheckFilename(szTempFile, szTempTitle, szTempPath,
							szTempName, szTempExt, hDlg,
							"Spectrum Plot Filename"))
						{
							// Filename OK
							strlcpy(sPSPlot.plot_filename, szTempFile,
								FILENAMESIZE);

							// Redisplay the new filename
							SetWindowText(GETHCTL(IDC_FILE_SPECTPLOT),
								szTempFile);
						}
						else // Filename NG
						{
							// Restore original filename
							SetWindowText(GETHCTL(IDC_FILE_SPECTPLOT),
								sPSPlot.plot_filename);
							SetFocus(GETHCTL(IDC_FILE_SPECTPLOT));
							break;
						}
					}
  					else
					{
						// Reset message flag
						bMessage=FALSE;
					}
                }
                break;

				// Respond to autocorrelation plot filename edit control msg
				case IDC_FILE_AUTOPLOT:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(GetFocus()!=GETHCTL(IDC_FILE_CANCEL)) && (!bMessage))
					{
						// Set Message flag
						bMessage=TRUE;

						GetWindowText(GETHCTL(IDC_FILE_AUTOPLOT),
							szTempFile, FILENAMESIZE);

						// Validate new filename
						if(CheckFilename(szTempFile, szTempTitle, szTempPath,
							szTempName, szTempExt, hDlg,
							"Autocorrelation Plot Filename"))
						{
							// Filename OK
							strlcpy(sAPlot.plot_filename, szTempFile,
								FILENAMESIZE);

							// Redisplay the new filename
							SetWindowText(GETHCTL(IDC_FILE_AUTOPLOT),
								szTempFile);
						}
						else // Filename NG
						{
							// Restore original filename
							SetWindowText(GETHCTL(IDC_FILE_AUTOPLOT),
								sAPlot.plot_filename);
							SetFocus(GETHCTL(IDC_FILE_AUTOPLOT));
							break;
						}
					}
  					else
					{
						// Reset message flag
						bMessage=FALSE;
					}
                }
                break;

				// Respond to dynamic stability plot filename edit control msg
				case IDC_FILE_DAVARPLOT:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(GetFocus()!=GETHCTL(IDC_FILE_CANCEL)) && (!bMessage))
					{
						// Set Message flag
						bMessage=TRUE;

						GetWindowText(GETHCTL(IDC_FILE_DAVARPLOT),
							szTempFile, FILENAMESIZE);

						// Validate new filename
						if(CheckFilename(szTempFile, szTempTitle, szTempPath,
							szTempName, szTempExt, hDlg,
							"Dynamic Stability Plot Filename"))
						{
							// Filename OK
							strlcpy(sDPlot.plot_filename, szTempFile,
								FILENAMESIZE);

							// Redisplay the new filename
							SetWindowText(GETHCTL(IDC_FILE_DAVARPLOT),
								szTempFile);
						}
						else // Filename NG
						{
							// Restore original filename
							SetWindowText(GETHCTL(IDC_FILE_DAVARPLOT),
								sDPlot.plot_filename);
							SetFocus(GETHCTL(IDC_FILE_DAVARPLOT));
							break;
						}
					}
  					else
					{
						// Reset message flag
						bMessage=FALSE;
					}
                }
                break;

				// Respond to phase data filename edit control message
				case IDC_FILE_PHASEDATA:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(GetFocus()!=GETHCTL(IDC_FILE_CANCEL)) && (!bMessage))
					{
						// Set Message flag
						bMessage=TRUE;

						// Get new phase filename
						GetWindowText(GETHCTL(IDC_FILE_PHASEDATA),
							szTempFile, FILENAMESIZE);

						// Validate new filename
						if(CheckFilename(szTempFile, szTempTitle, szTempPath,
							szTempName, szTempExt, hDlg,
							"Phase Data Filename"))
						{
							// Filename OK
							strlcpy(szPhaseFile, szTempFile, FILE_NAME_SIZE);

							// Redisplay the new filename
							SetWindowText(GETHCTL(IDC_FILE_PHASEDATA),
								szTempFile);
						}
						else // Filename NG
						{
							// Restore original filename
							SetWindowText(GETHCTL(IDC_FILE_PHASEDATA),
								szPhaseFile);
							SetFocus(GETHCTL(IDC_FILE_PHASEDATA));
							break;
						}

						// Assign new phase data file title
						_splitpath(szPhaseFile, NULL, NULL, szPhaseFileTitle,
							szBuffer);
						strlcat(szPhaseFileTitle, szBuffer, FILE_TITLE_SIZE);

						// Put new phase data title into status bar
						SetWindowText(hwndPhaseFilename, szPhaseFileTitle);

						// Reassign current filenames & titles if phase data
						if(bDataType==PHASE_DATA)
						{
							strlcpy(szFile, szPhaseFile, FILE_NAME_SIZE);
							strlcpy(szFileTitle, szPhaseFileTitle,
								FILE_TITLE_SIZE);
						}
					}
 					else
					{
						// Reset message flag
						bMessage=FALSE;
					}
                }
                break;

				// Respond to freq data filename edit control message
				case IDC_FILE_FREQDATA:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(GetFocus()!=GETHCTL(IDC_FILE_CANCEL)) && (!bMessage))
					{
						// Set Message flag
						bMessage=TRUE;

						// Get new freq filename
						GetWindowText(GETHCTL(IDC_FILE_FREQDATA),
							szTempFile, FILENAMESIZE);

						// Validate new filename
						if(CheckFilename(szTempFile, szTempTitle, szTempPath,
							szTempName, szTempExt, hDlg,
							"Freq Data Filename"))
						{
							// Filename OK
							strlcpy(szFreqFile, szTempFile, FILE_NAME_SIZE);

							// Redisplay the new filename
							SetWindowText(GETHCTL(IDC_FILE_FREQDATA),
								szTempFile);
						}
						else // Filename NG
						{
							// Restore original filename
							SetWindowText(GETHCTL(IDC_FILE_FREQDATA),
								szFreqFile);
							SetFocus(GETHCTL(IDC_FILE_FREQDATA));
							break;
						}

						// Assign new freq data file title
						_splitpath(szFreqFile, NULL, NULL, szFreqFileTitle,
							szBuffer);
						strlcat(szFreqFileTitle, szBuffer, FILE_TITLE_SIZE);

						// Put new freq data title into status bar
						SetWindowText(hwndFreqFilename, szFreqFileTitle);

						// Reassign current filenames & titles if freq data
						if(bDataType==FREQ_DATA)
						{
							strlcpy(szFile, szFreqFile, FILE_NAME_SIZE);
							strlcpy(szFileTitle, szFreqFileTitle,
								FILE_TITLE_SIZE);
						}
					}
					else
					{
						// Reset message flag
						bMessage=FALSE;
					}
                }
                break;

				// Respond to stability data filename edit control message
				case IDC_FILE_STABDATA:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(GetFocus()!=GETHCTL(IDC_FILE_CANCEL)) && (!bMessage))
					{
						// Set Message flag
						bMessage=TRUE;

						GetWindowText(GETHCTL(IDC_FILE_STABDATA),
							szTempFile, FILENAMESIZE);

						// Validate new filename
						if(CheckFilename(szTempFile, szTempTitle, szTempPath,
							szTempName, szTempExt, hDlg,
							"Stability Data Filename"))
						{
							// Filename OK
							strlcpy(szStabFile, szTempFile, FILE_NAME_SIZE);

							// Redisplay the new filename
							SetWindowText(GETHCTL(IDC_FILE_STABDATA),
								szTempFile);
						}
						else // Filename NG
						{
							// Restore original filename
							SetWindowText(GETHCTL(IDC_FILE_STABDATA),
								szStabFile);
							SetFocus(GETHCTL(IDC_FILE_STABDATA));
							break;
						}
					}
 					else
					{
						// Reset message flag
						bMessage=FALSE;
					}
                }
                break;

				// Respond to PSD data filename edit control message
				case IDC_FILE_PSDDATA:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(GetFocus()!=GETHCTL(IDC_FILE_CANCEL)) && (!bMessage))
					{
						// Set Message flag
						bMessage=TRUE;

						GetWindowText(GETHCTL(IDC_FILE_PSDDATA),
							szTempFile, FILENAMESIZE);

						// Validate new filename
						if(CheckFilename(szTempFile, szTempTitle, szTempPath,
							szTempName, szTempExt, hDlg,
							"PSD Data Filename"))
						{
							// Filename OK
							strlcpy(szPSDFile, szTempFile, FILE_NAME_SIZE);

							// Redisplay the new filename
							SetWindowText(GETHCTL(IDC_FILE_PSDDATA),
								szPSDFile);
						}
						else // Filename NG
						{
							// Restore original filename
							SetWindowText(GETHCTL(IDC_FILE_PSDDATA),
								szPSDFile);
							SetFocus(GETHCTL(IDC_FILE_PSDDATA));
							break;
						}
					}
 					else
					{
						// Reset message flag
						bMessage=FALSE;
					}
                }
                break;

				// Respond to autocorrelation data filename edit control msg
				case IDC_FILE_AUTODATA:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(GetFocus()!=GETHCTL(IDC_FILE_CANCEL)) && (!bMessage))
					{
						// Set Message flag
						bMessage=TRUE;

						GetWindowText(GETHCTL(IDC_FILE_AUTODATA),
							szTempFile, FILENAMESIZE);

						// Validate new filename
						if(CheckFilename(szTempFile, szTempTitle, szTempPath,
							szTempName, szTempExt, hDlg,
							"Autocorrelation Data Filename"))
						{
							// Filename OK
							strlcpy(szAutoFile, szTempFile, FILE_NAME_SIZE);

							// Redisplay the new filename
							SetWindowText(GETHCTL(IDC_FILE_AUTODATA),
								szAutoFile);
						}
						else // Filename NG
						{
							// Restore original filename
							SetWindowText(GETHCTL(IDC_FILE_AUTODATA),
								szAutoFile);
							SetFocus(GETHCTL(IDC_FILE_AUTODATA));
							break;
						}
					}
 					else
					{
						// Reset message flag
						bMessage=FALSE;
					}
                }
                break;

				// Respond to help filename edit control msg
				case IDC_FILE_HELP:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(GetFocus()!=GETHCTL(IDC_FILE_CANCEL)) && (!bMessage))
					{
						// Set Message flag
						bMessage=TRUE;

						GetWindowText(GETHCTL(IDC_FILE_HELP),
							szTempFile, FILENAMESIZE);

						// Validate new filename
						if(CheckFilename(szTempFile, szTempTitle, szTempPath,
							szTempName, szTempExt, hDlg,
							"Help Filename"))
						{
							// Filename OK
							strlcpy(szHelpFile, szTempFile, FILE_NAME_SIZE);

							// Redisplay the new filename
							SetWindowText(GETHCTL(IDC_FILE_HELP),
								szHelpFile);
						}
						else // Filename NG
						{
							// Restore original filename
							SetWindowText(GETHCTL(IDC_FILE_HELP),
								szHelpFile);
							SetFocus(GETHCTL(IDC_FILE_HELP));
							break;
						}
					}
 					else
					{
						// Reset message flag
						bMessage=FALSE;
					}
                }
                break;

				// Respond to path edit control message
				case IDC_FILE_PATH:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel or set button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(GetFocus()!=GETHCTL(IDC_FILE_CANCEL)) &&
						(GetFocus()!=GETHCTL(IDC_FILE_SET)) && (!bMessage))
					{
						// Set Message flag
						bMessage=TRUE;

						// Get new path from edit box
						GetWindowText(GETHCTL(IDC_FILE_PATH),
							szNewPath, FILENAMESIZE);

						if(CheckPath(szNewPath, hDlg, "Path"))
						{
							// New path OK
							strlcpy(szPath, szNewPath, FILE_NAME_SIZE);

							// Redisplay the new path
							SetWindowText(GETHCTL(IDC_FILE_PATH), szNewPath);
						}
						else // New path NG
						{
							// Restore original path
							SetWindowText(GETHCTL(IDC_FILE_PATH), szPath);
						}
					}
					else
					{
						// Reset message flag
						bMessage=FALSE;
					}
                }
                break;

                // Respond to CR in an edit control
                // Note: No button is a DEFPUSHBUTTON
                case IDOK:
                {
                    // Does phase plot filename edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FILE_PHASEPLOT))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FILE_PHASEPLOT, 0,
							EN_KILLFOCUS));
					}

                    // Does freq plot filename edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FILE_FREQPLOT))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FILE_FREQPLOT, 0,
							EN_KILLFOCUS));
					}

                    // Does sigma plot filename edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FILE_SIGMAPLOT))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FILE_SIGMAPLOT, 0,
							EN_KILLFOCUS));
					}

                    // Does histogram plot filename edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FILE_HISTOPLOT))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FILE_HISTOPLOT, 0,
							EN_KILLFOCUS));
					}

                    // Does spectrum plot filename edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FILE_SPECTPLOT))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FILE_SPECTPLOT, 0,
							EN_KILLFOCUS));
					}

                    // Does autocorr plot filename edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FILE_AUTOPLOT))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FILE_AUTOPLOT, 0,
							EN_KILLFOCUS));
					}

                    // Does phase data filename edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FILE_PHASEDATA))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FILE_PHASEDATA, 0,
							EN_KILLFOCUS));
					}

                    // Does freq data filename edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FILE_FREQDATA))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FILE_FREQDATA, 0,
							EN_KILLFOCUS));
					}

	                // Does stab data filename edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FILE_STABDATA))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FILE_STABDATA, 0,
							EN_KILLFOCUS));
					}

					// Does PSD data filename edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FILE_PSDDATA))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FILE_PSDDATA, 0,
							EN_KILLFOCUS));
					}
                    
					// Does autocorr data filename edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FILE_AUTODATA))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FILE_AUTODATA, 0,
							EN_KILLFOCUS));
					}
  					
					// Does help filename edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FILE_HELP))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FILE_HELP, 0,
							EN_KILLFOCUS));
					}
  					
					// Does path edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FILE_PATH))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FILE_PATH, 0,
							EN_KILLFOCUS));
					}
				}
                break;

				// Respond to OK buttom message
                case IDC_FILE_ACCEPT:
                {
					// Put info into log file
					WriteLog(53, szFile);

                    EndDialog (hDlg, 0);
				}
                return TRUE;
				
               // Respond to esc key or cancel button
                case IDCANCEL:
                case IDC_FILE_CANCEL:
                {
					// Restore original filenames
					strlcpy(sPPlot.plot_filename, szPPlotSave, FILENAMESIZE);
					strlcpy(sFPlot.plot_filename, szFPlotSave, FILENAMESIZE);
					strlcpy(sSPlot.plot_filename, szSPlotSave, FILENAMESIZE);
					strlcpy(sHPlot.plot_filename, szHPlotSave, FILENAMESIZE);
					strlcpy(sPSPlot.plot_filename, szPSPlotSave, FILENAMESIZE);
					strlcpy(sAPlot.plot_filename, szAPlotSave, FILENAMESIZE);
					strlcpy(sDPlot.plot_filename, szDPlotSave, FILENAMESIZE);
					strlcpy(szPhaseFile, szPhaseSave, FILE_NAME_SIZE);
					strlcpy(szFreqFile, szFreqSave, FILE_NAME_SIZE);
					strlcpy(szStabFile, szStabSave, FILE_NAME_SIZE);
					strlcpy(szPSDFile, szPSDSave, FILE_NAME_SIZE);
					strlcpy(szAutoFile, szAutoSave, FILE_NAME_SIZE);
					strlcpy(szHelpFile, szHelpSave, FILE_NAME_SIZE);
					strlcpy(szPath, szPathSave, FILE_NAME_SIZE);
					
					EndDialog (hDlg, 0);
                }
                return TRUE;
            }
        }
        break;
	 }
     return FALSE;
}

/*****************************************************************************/
#endif

/*****************************************************************************/
/*                                                                           */
/*                          Inputs Dialog Procedure                          */
/*                                                                           */
/*  Note: Timetag scale scale does not affect timetag value - it is used to  */
/*        determine tau.  Timetag offset does affect timetag values - it is  */
/*        applied as timetags are read.                                      */
/*                                                                           */
/*  Revision record:                                                         */
/*      09/12/00    Created                                                  */
/*		08/12/01	Added timetag scale                                      */
/*		12/07/02	Added timetag offset                                     */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK InputsDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam)
{
    // Local variables
    // Chars
	char szBuffer[BUFFER_SIZE+1];   // Text buffer
	char szSection[BUFFER_SIZE+1];  // Section name
	char szKey[BUFFER_SIZE+1];		// Key name
    // F_TYPEs
    static F_TYPE fTau;         // Tau value
	static F_TYPE fAdd;         // Addend value
    static F_TYPE fMult;        // Multiplier value
	static F_TYPE fTag;			// Timetag scale factor
	static F_TYPE fOffset;		// Timetag offset value

    switch(message)
    {
        case WM_INITDIALOG:
        {
			// Set prompt text to show data type
			// Read default text 
			GetWindowText(GETHCTL(IDC_INPUTS_TEXT), szBuffer, BUFFER_SIZE);
			
			// Concatenate appropriate text
			if(bDataType==FREQ_DATA)
			{
				strlcat(szBuffer, " freq data.", sizeof(szBuffer));
			}
			else // Phase data
			{
				strlcat(szBuffer, " phase data.", sizeof(szBuffer));
			}
			
			// Save revised text
            SetWindowText(GETHCTL(IDC_INPUTS_TEXT), szBuffer);
			
			// Put default value from INI file into addend
			if(bDataType==FREQ_DATA)
			{
				_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
					fFreqAddendInput);
			}
			else // Phase data
			{
				_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
					fPhaseAddendInput);
			}

			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_INPUTS_ADD), szBuffer);

			// Put default value from INI file into multiplier
			if(bDataType==FREQ_DATA)
			{
				_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
					fFreqMultiplierInput);
			}
			else // Phase data
			{
				_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
					fPhaseMultiplierInput);
			}

			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_INPUTS_MULT), szBuffer);

			// Put default value from INI file into tau
			if(bDataType==FREQ_DATA)
			{
				_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
					fFreqTauInput);
			}
			else // Phase data
			{
				_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
					fPhaseTauInput);
			}

			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_INPUTS_TAU), szBuffer);

			// Put default value from INI file into tag scale factor
			if(bDataType==FREQ_DATA)
			{
				_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
					fFreqTagScale);
			}
			else // Phase data
			{
				_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
					fPhaseTagScale);
			}

			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_INPUTS_TAGSCALE), szBuffer);

			// Put default value from INI file into tag offset value
			if(bDataType==FREQ_DATA)
			{
				_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
					fFreqTagOffset);
			}
			else // Phase data
			{
				_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
					fPhaseTagOffset);
			}

			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_INPUTS_TAGOFFSET), szBuffer);
        }
        return TRUE;

        case WM_COMMAND:
        {
            switch(GET_WM_COMMAND_ID(wParam, lParam))
            {
                case IDHELP:
                {
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::INPUTS_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::INPUTS_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "NPUTS_FUNCTION");
					#endif
                }
                break;

                case IDC_INPUTS_ADD:
                {
                    // Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_INPUTS_CANCEL)))
                    {
                        // Get addend
						GetWindowText(GETHCTL(IDC_INPUTS_ADD), szBuffer,
							BUFFER_SIZE);
                        fAdd=(F_TYPE)atof(szBuffer);

                        // Redisplay addend
                        _snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
							fAdd);
						ShortenExp(szBuffer);
                       SetWindowText(GETHCTL(IDC_INPUTS_ADD), szBuffer);
					}
                }
                break;

                case IDC_INPUTS_MULT:
                {
                    // Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_INPUTS_CANCEL)))
                    {
                        // Get multiplier
						GetWindowText(GETHCTL(IDC_INPUTS_MULT), szBuffer,
							BUFFER_SIZE);
                        fMult=(F_TYPE)atof(szBuffer);

                        // Redisplay multiplier
                        _snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
							fMult);
						ShortenExp(szBuffer);
                        SetWindowText(GETHCTL(IDC_INPUTS_MULT), szBuffer);
					}
                }
                break;

                case IDC_INPUTS_TAU:
                {
                    // Respond to edit control when it loses the input focus
                    // unless it loses it to the cancel button
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_INPUTS_CANCEL)))
                    {
                        // Get tau
						GetWindowText(GETHCTL(IDC_INPUTS_TAU),	szBuffer,
							BUFFER_SIZE);
                        fTau=(F_TYPE)atof(szBuffer);

                        // Redisplay tau
                        _snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
							fTau);
						ShortenExp(szBuffer);
                        SetWindowText(GETHCTL(IDC_INPUTS_TAU), szBuffer);
					 }
                }
                break;

                case IDC_INPUTS_TAGSCALE:
                {
                    // Respond to edit control when it loses the input focus
                    // unless it loses it to the cancel button
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_INPUTS_CANCEL)))
                    {
                        // Get tag scale
						GetWindowText(GETHCTL(IDC_INPUTS_TAGSCALE),	szBuffer,
							BUFFER_SIZE);
						fTag=(F_TYPE)atof(szBuffer);

						// Redisplay tag sacle
						_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
							fTag);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_INPUTS_TAGSCALE), szBuffer);
					}
                }
                break;

                case IDC_INPUTS_TAGOFFSET:
                {
                    // Respond to edit control when it loses the input focus
                    // unless it loses it to the cancel button
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_INPUTS_CANCEL)))
                    {
                        // Get tag offset
						GetWindowText(GETHCTL(IDC_INPUTS_TAGOFFSET), szBuffer,
							BUFFER_SIZE);
						fOffset=(F_TYPE)atof(szBuffer);

						// Redisplay tag offset
						_snprintf(szBuffer, sizeof(szBuffer), "%+20.13e",
							fOffset);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_INPUTS_TAGOFFSET), szBuffer);
					}
                }
                break;

                // Respond to CR in an edit control
				// Note: No button is a DEFPUSHBUTTON
                case IDOK:
                {
                    // Does add edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_INPUTS_ADD))
                    {
						// Send EN_KILLFOCUS message to add edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_INPUTS_ADD, 0,
							EN_KILLFOCUS));
					}

					// Does multiplier edit control have focus?
					if(GetFocus()==GETHCTL(IDC_INPUTS_MULT))
					{
						// Send EN_KILLFOCUS message to multiplier edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_INPUTS_MULT, 0,
							EN_KILLFOCUS));
					}

					// Does tau edit control have focus?
					if(GetFocus()==GETHCTL(IDC_INPUTS_TAU))
					{
						// Send EN_KILLFOCUS message to tau edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_INPUTS_TAU, 0,
							EN_KILLFOCUS));
					}

					// Does tag scale edit control have focus?
					if(GetFocus()==GETHCTL(IDC_INPUTS_TAGSCALE))
					{
						// Send EN_KILLFOCUS message to slope tag scale ctrl
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_INPUTS_TAGSCALE, 0,
							EN_KILLFOCUS));
					}

					// Does tag offset edit control have focus?
					if(GetFocus()==GETHCTL(IDC_INPUTS_TAGOFFSET))
					{
						// Send EN_KILLFOCUS message to slope tag offset ctrl
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_INPUTS_TAGOFFSET, 0,
							EN_KILLFOCUS));
					}
				}
				break;

				// Respond to OK button - accept changes
				// Store values and close dialog box
				case IDC_INPUTS_ACCEPT:
				{
					// Get addend
					GetWindowText(GETHCTL(IDC_INPUTS_ADD), szBuffer,
						BUFFER_SIZE);
                    fAdd=(F_TYPE)atof(szBuffer);
					
                    // Get multiplier
					GetWindowText(GETHCTL(IDC_INPUTS_MULT), szBuffer,
						BUFFER_SIZE);
                    fMult=(F_TYPE)atof(szBuffer);

					// Get tau
					GetWindowText(GETHCTL(IDC_INPUTS_TAU), szBuffer,
						BUFFER_SIZE);
                    fTau=(F_TYPE)atof(szBuffer);

					// Get tag scale
					GetWindowText(GETHCTL(IDC_INPUTS_TAGSCALE), szBuffer,
						BUFFER_SIZE);
                    fTag=(F_TYPE)atof(szBuffer);

					// Get tag offset
					GetWindowText(GETHCTL(IDC_INPUTS_TAGOFFSET), szBuffer,
						BUFFER_SIZE);
                    fOffset=(F_TYPE)atof(szBuffer);

					// Use new values
					if(bDataType==FREQ_DATA)
					{
						fFreqTauInput=fTau;
						fFreqAddendInput=fAdd;
						fFreqMultiplierInput=fMult;
						fFreqTagScale=fTag;
						fFreqTagOffset=fOffset;
					}
					else // Phase data
					{
						fPhaseTauInput=fTau;
						fPhaseAddendInput=fAdd;
						fPhaseMultiplierInput=fMult;
						fPhaseTagScale=fTag;
						fPhaseTagOffset=fOffset;
					}
					
					// Store values in [Inputs] section of ini file
					LoadString(hInst, IDS_INI_SECTION_15, szSection,
						BUFFER_SIZE);

					// Phase tau value
					_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
						fPhaseTauInput);
					ShortenExp(szBuffer);
					LoadString(hInst, IDS_INI_KEY_49, szKey, BUFFER_SIZE);
					WritePrivateProfileString(szSection, szKey, szBuffer,
						szIniFile);

					// Freq tau value
					_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
						fFreqTauInput);
					ShortenExp(szBuffer);
					LoadString(hInst, IDS_INI_KEY_50, szKey, BUFFER_SIZE);
					WritePrivateProfileString(szSection, szKey, szBuffer,
						szIniFile);

					// Phase scale addend value
					_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
						fPhaseAddendInput);
					ShortenExp(szBuffer);
					LoadString(hInst, IDS_INI_KEY_51, szKey, BUFFER_SIZE);
					WritePrivateProfileString(szSection, szKey, szBuffer,
						szIniFile);

					// Freq scale addend value
					_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
						fFreqAddendInput);
					ShortenExp(szBuffer);
					LoadString(hInst, IDS_INI_KEY_52, szKey, BUFFER_SIZE);
					WritePrivateProfileString(szSection, szKey, szBuffer,
						szIniFile);

					// Phase scale multiplier value
					_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
						fPhaseMultiplierInput);
					ShortenExp(szBuffer);
					LoadString(hInst, IDS_INI_KEY_53, szKey, BUFFER_SIZE);
					WritePrivateProfileString(szSection, szKey, szBuffer,
						szIniFile);

					// Freq scale multiplier value
					_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
						fFreqMultiplierInput);
					ShortenExp(szBuffer);
					LoadString(hInst, IDS_INI_KEY_54, szKey, BUFFER_SIZE);
					WritePrivateProfileString(szSection, szKey, szBuffer,
						szIniFile);

					// Phase tag scale multiplier value
					_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
						fPhaseTagScale);
					ShortenExp(szBuffer);
					LoadString(hInst, IDS_INI_KEY_83, szKey, BUFFER_SIZE);
					WritePrivateProfileString(szSection, szKey, szBuffer,
						szIniFile);

					// Freq tag scale multiplier value
					_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
						fFreqTagScale);
					ShortenExp(szBuffer);
					LoadString(hInst, IDS_INI_KEY_98, szKey, BUFFER_SIZE);
					WritePrivateProfileString(szSection, szKey, szBuffer,
						szIniFile);

					// Phase tag scale offset value
					_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
						fPhaseTagOffset);
					ShortenExp(szBuffer);
					LoadString(hInst, IDS_INI_KEY_101, szKey, BUFFER_SIZE);
					WritePrivateProfileString(szSection, szKey, szBuffer,
						szIniFile);

					// Freq tag scale offset value
					_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
						fFreqTagOffset);
					ShortenExp(szBuffer);
					LoadString(hInst, IDS_INI_KEY_102, szKey, BUFFER_SIZE);
					WritePrivateProfileString(szSection, szKey, szBuffer,
						szIniFile);

					// Close dialog box
                    bNewInputs=TRUE;
					EndDialog(hDlg, 0);
                }
                return TRUE;

                // Reject changes - don't store values - just close dialog box
                // Respond to esc key or cancel button
                case IDCANCEL:
                case IDC_INPUTS_CANCEL:
				{
                    bNewInputs=FALSE;
					EndDialog(hDlg, 0);
                }
                return TRUE;
            }
        }
        break;
     }
     return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*							   CopyDialog()                                  */
/*                                                                           */
/*		Function to copy dialog box as bitmap to Windows clipboard           */
/*                                                                           */
/*      Parameters:                                                          */
/*      	HWND hDlg	Handle to stats dialog box                           */
/*			int nXCrop	%% horizontal size                                   */
/*          int nYCrop	%% vertical size                                     */
/*                                                                           */
/*      Note: Crop values are divided by 1000 to set fraction of dialog      */
/*            box to copy, starting from top left                            */                                                             
/*                                                                           */
/*      Return:                                                              */
/*			None	(void)                                                   */
/*                                                                           */
/*		Revision record:                                                     */
/*			10/16/02	Created from (now-obsolete) CopyCalendar()           */
/*                                                                           */
/*****************************************************************************/
void WINAPI CopyDialog(HWND hDlg, int nXCrop, int nYCrop)
{
	// Local variables
	// Bitmap variables
	static HBITMAP hStatsBitmap=0;	// Handle to stats bitmap
    HDC hdcStats;				    // Handle to statsr device context
	HDC hdcStatsMem;				// Handle to stats memory device context
    RECT rect;						// Dialog box rectangle
	int nXSize;						// Dialog box width in pixels
	int nYSize;						// Dialog box height in pixels

	// Save ststs as color bitmap in memory
	// Get size of stats dialog box
	GetClientRect(hDlg, &rect);
	nXSize=rect.right-rect.left;
	nYSize=rect.bottom-rect.top;

	// Set horizintal size
	nXSize*=nXCrop;
	nXSize/=1000;

	// Set vertical size
	nYSize*=nYCrop;
	nYSize/=1000;

	// Get handle to stats dialog device context
	hdcStats=GetDC(hDlg);

	// Create memory device context
	hdcStatsMem=CreateCompatibleDC(hdcStats);

	// Detete existing stats bitmap (if any)
	if(hStatsBitmap)
	{
		DeleteObject(hStatsBitmap);
	}

	// Create an empty device dependent color bitmap for stats
	hStatsBitmap=CreateCompatibleBitmap(hdcStats, nXSize, nYSize);

	// Select color bitmap into memory device context
	SelectObject(hdcStatsMem, hStatsBitmap);

	// Copy pixels from screen to memory
	BitBlt(hdcStatsMem, 0, 0, nXSize, nYSize, hdcStats, 0, 0, SRCCOPY);

	// Copy the bitmap to the clipboard
	OpenClipboard(hDlg);
	EmptyClipboard();
	SetClipboardData(CF_BITMAP, hStatsBitmap);
	CloseClipboard();

	// Clean up - added 05/23/04
	DeleteDC(hdcStats);
	DeleteDC(hdcStatsMem);
}

#if(0) // Not working - may never - use Graphic CopyMetaq() instead 
/*****************************************************************************/
/*                                                                           */
/*							   CopyMeta()                                    */
/*                                                                           */
/*		Function to copy window as metafile to Windows clipboard             */
/*                                                                           */
/*      Parameters:                                                          */
/*      	HWND hWin	Handle to window to be copied                        */
/*			int nXCrop	%% horizontal size                                   */
/*          int nYCrop	%% vertical size                                     */
/*                                                                           */
/*      Note: Crop values are divided by 1000 to set fraction of dialog      */
/*            box to copy, starting from top left                            */                                                             
/*                                                                           */
/*      Return:                                                              */
/*			None	(void)                                                   */
/*                                                                           */
/*		Revision record:                                                     */
/*			05/23/04	Created from CopyDialog()                            */
/*						NOT WORKING YET                                      */
/*                                                                           */
/*****************************************************************************/
void WINAPI CopyMeta(HWND hWin, int nXCrop, int nYCrop)
{
	// Local variables
	static HMETAFILE hmf;			// Handle to metafile
	HDC hdcMeta;					// Handle to metafile device context
	HGLOBAL hGMem;					// Handle to block of global memory
	LPMETAFILEPICT pMFP;			// Pointer to metafile structure
    RECT rect;						// Dialog box rectangle
	int nXSize;						// Window width in pixels
	int nYSize;						// Window height in pixels

	// Create metafile in memory
	hdcMeta=CreateMetaFile(NULL);

	// Draw plot on metafile device context
	// (Don't know how to do that)

	// Close metafile and get handle to it
	hmf=CloseMetaFile(hdcMeta);

	// Allocate memory for metafile structure
	hGMem=GlobalAlloc(GHND, sizeof(METAFILEPICT));

	// Lock memory and get pointer to metafile structure
	pMFP=(LPMETAFILEPICT)GlobalLock(hGMem);
	
	// Get size of window to be copied
	GetClientRect(hWin, &rect);
	nXSize=rect.right-rect.left;
	nYSize=rect.bottom-rect.top;

	// Set horizintal size
	nXSize*=nXCrop;
	nXSize/=1000;

	// Set vertical size
	nYSize*=nYCrop;
	nYSize/=1000;

	// Set metafile struct fields
	// pMFP->mm=MM_?;
	pMFP->xExt=nXSize;
	pMFP->yExt=nYSize;
	pMFP->hMF=hmf;

	// Unlock memory
	GlobalUnlock(hGMem);

	// Copy the metafile to the clipboard
	OpenClipboard(hWin);
	EmptyClipboard();
	SetClipboardData(CF_METAFILEPICT, hGMem);
	CloseClipboard();

	// Clean up
	DeleteDC(hdcMeta);
}
#endif

/*****************************************************************************/
/*                                                                           */
/*                   Plot Insert Dialog Procedure                            */
/*                                                                           */
/*  Dialog box function to select and delete plot insert files               */
/*                                                                           */
/*  Revision record:                                                         */
/*		10/01/03	Created                                                  */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK PlotInsertDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	// Chars
	// Temporary filename buffers
	static char szTempFile[FILENAMESIZE+1];		// Temp full filename buffer
	static char szTempTitle[FILENAMESIZE+1];	// Temp file title buffer
	static char szTempPath[FILENAMESIZE+1];		// Temp file path buffer
	static char szTempName[FILENAMESIZE+1];		// Temp file name buffer
	static char szTempExt[BUFFER_SIZE+1];		// Temp file extension buffer
	// char szBuffer[BUFFER_SIZE+1];				// Text buffer
	// BOOLs
	static BOOL bMessage=FALSE;					// Flag for message box opened
	static BOOL bTKF=FALSE;						// Flag for tkf file test
	// Misc
	FILE *fhFile;           					// DOS file handle

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Write prompt message
			WriteMessage("Select or clear plot insert files.");

			// Initialize filenames
			SetWindowText(GETHCTL(IDC_INSERT_PHASEFILE),
				szPhasePlotInsertFile);
			SetWindowText(GETHCTL(IDC_INSERT_FREQFILE), szFreqPlotInsertFile);
			SetWindowText(GETHCTL(IDC_INSERT_STABFILE), szStabPlotInsertFile);
			SetWindowText(GETHCTL(IDC_INSERT_ACFFILE), szACFPlotInsertFile);

			// Initialize on button states
			Button_SetCheck(GETHCTL(IDC_INSERT_PHASEON), bDoPhasePlotInsert);
			Button_SetCheck(GETHCTL(IDC_INSERT_FREQON), bDoFreqPlotInsert);
			Button_SetCheck(GETHCTL(IDC_INSERT_STABON), bDoStabPlotInsert);
			Button_SetCheck(GETHCTL(IDC_INSERT_ACFON), bDoACFPlotInsert);
		}
		return TRUE;

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				// Respond to help button message
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::PLOT_INSERTS.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::PLOT_INSERTS.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "PLOT_INSERTS");
					#endif
				}
				break;

				// Respond to phase insert on button message 
				case IDC_INSERT_PHASEON:
				{
					// Get button state
					bDoPhasePlotInsert=
						Button_GetCheck(GETHCTL(IDC_INSERT_PHASEON));
                }
                break;
				
				// Respond to frequency insert on button message 
				case IDC_INSERT_FREQON:
				{
					// Get button state
					bDoFreqPlotInsert=
						Button_GetCheck(GETHCTL(IDC_INSERT_FREQON));
                 }
                break;
				
				// Respond to stability insert on button message 
				case IDC_INSERT_STABON:
				{
					// Get button state
					bDoStabPlotInsert=
						Button_GetCheck(GETHCTL(IDC_INSERT_STABON));
                 }
                break;
				
				// Respond to autocorrelation insert on button message 
				case IDC_INSERT_ACFON:
				{
					// Get button state
					bDoACFPlotInsert=
						Button_GetCheck(GETHCTL(IDC_INSERT_ACFON));
                 }
                break;
				
				// Respond to phase plot insert filename edit control
				case IDC_INSERT_PHASEFILE:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(GetFocus()!=GETHCTL(IDC_FILE_CANCEL)) && (!bMessage))
					{
						// Set Message flag
						bMessage=TRUE;

						// Get filename
						GetWindowText(GETHCTL(IDC_INSERT_PHASEFILE),
							szTempFile, FILENAMESIZE);

						// Check for null filename
						if((strcmp(szTempFile, "None")==0))
						{
							// Redisplay null filename
							SetWindowText(GETHCTL(IDC_INSERT_PHASEFILE),
								szTempFile);

							// Ignore it
							break;
						}

						// Check for default filename
						// Compose default phase plot insert filename
						strlcpy(szTempName, szPath, sizeof(szTempName));
						strlcat(szTempName, "p_insert.tkf",
							sizeof(szTempName));

						if((strcmp(szTempFile, szTempName)==0))
						{
							// Redisplay default filename
							SetWindowText(GETHCTL(IDC_INSERT_PHASEFILE),
								szTempFile);

							// Ignore it
							break;
						}

						// Check if valid tkf file
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_INSERT_TKF, NULL, 0));

						// Validate new filename
						if((CheckFilename(szTempFile, szTempTitle, szTempPath,
							szTempName, szTempExt, hDlg,
							"Phase Plot Insert Filename")) && bTKF)
						{
							// Filename OK
							strlcpy(szPhasePlotInsertFile, szTempFile,
								FILE_NAME_SIZE);

							// Redisplay the new filename
							SetWindowText(GETHCTL(IDC_INSERT_PHASEFILE),
								szTempFile);

							// Turn on
							bDoPhasePlotInsert=TRUE;
							Button_SetCheck(GETHCTL(IDC_INSERT_PHASEON),
								bDoPhasePlotInsert);
						}
						else // Filename NG
						{
							// Restore original filename
							SetWindowText(GETHCTL(IDC_INSERT_PHASEFILE),
								szPhasePlotInsertFile);
							SetFocus(GETHCTL(IDC_INSERT_PHASEFILE));
							break;
						}
					}
 					else
					{
						// Reset message flag
						bMessage=FALSE;
					}
                }
                break;

				// Respond to frequency plot insert filename edit control
				case IDC_INSERT_FREQFILE:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(GetFocus()!=GETHCTL(IDC_FILE_CANCEL)) && (!bMessage))
					{
						// Set Message flag
						bMessage=TRUE;

						// Get filename
						GetWindowText(GETHCTL(IDC_INSERT_FREQFILE),
							szTempFile, FILENAMESIZE);

						// Check for null filename
						if((strcmp(szTempFile, "None")==0))
						{
							// Redisplay null filename
							SetWindowText(GETHCTL(IDC_INSERT_FREQFILE),
								szTempFile);

							// Ignore it
							break;
						}

						// Check for default filename
						// Compose default frequency plot insert filename
						strlcpy(szTempName, szPath, sizeof(szTempName));
						strlcat(szTempName, "f_insert.tkf",
							sizeof(szTempName));

						if((strcmp(szTempFile, szTempName)==0))
						{
							// Redisplay default filename
							SetWindowText(GETHCTL(IDC_INSERT_FREQFILE),
								szTempFile);

							// Ignore it
							break;
						}

						// Check if valid tkf file
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_INSERT_TKF, NULL, 0));

						// Validate new filename
						if((CheckFilename(szTempFile, szTempTitle, szTempPath,
							szTempName, szTempExt, hDlg,
							"Frequency Plot Insert Filename")) && bTKF)
						{
							// Filename OK
							strlcpy(szFreqPlotInsertFile, szTempFile,
								FILE_NAME_SIZE);

							// Redisplay the new filename
							SetWindowText(GETHCTL(IDC_INSERT_FREQFILE),
								szTempFile);

							// Turn on
							bDoFreqPlotInsert=TRUE;
							Button_SetCheck(GETHCTL(IDC_INSERT_FREQON),
								bDoFreqPlotInsert);
						}
						else // Filename NG
						{
							// Restore original filename
							SetWindowText(GETHCTL(IDC_INSERT_FREQFILE),
								szFreqPlotInsertFile);
							SetFocus(GETHCTL(IDC_INSERT_FREQFILE));
							break;
						}
					}
 					else
					{
						// Reset message flag
						bMessage=FALSE;
					}
                }
                break;

				// Respond to stability plot insert filename edit control
				case IDC_INSERT_STABFILE:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(GetFocus()!=GETHCTL(IDC_FILE_CANCEL)) && (!bMessage))
					{
						// Set Message flag
						bMessage=TRUE;

						// Get filename
						GetWindowText(GETHCTL(IDC_INSERT_STABFILE),
							szTempFile, FILENAMESIZE);

						// Check for null filename
						if((strcmp(szTempFile, "None")==0))
						{
							// Redisplay null filename
							SetWindowText(GETHCTL(IDC_INSERT_STABFILE),
								szTempFile);

							// Ignore it
							break;
						}

						// Check for default filename
						// Compose default stability plot insert filename
						strlcpy(szTempName, szPath, sizeof(szTempName));
						strlcat(szTempName, "s_insert.tkf",
							sizeof(szTempName));

						if((strcmp(szTempFile, szTempName)==0))
						{
							// Redisplay default filename
							SetWindowText(GETHCTL(IDC_INSERT_STABFILE),
								szTempFile);

							// Ignore it
							break;
						}

						// Check if valid tkf file
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_INSERT_TKF, NULL, 0));

						// Validate new filename
						if((CheckFilename(szTempFile, szTempTitle, szTempPath,
							szTempName, szTempExt, hDlg,
							"Stability Plot Insert Filename")) && bTKF)
						{
							// Filename OK
							strlcpy(szStabPlotInsertFile, szTempFile,
								FILE_NAME_SIZE);

							// Redisplay the new filename
							SetWindowText(GETHCTL(IDC_INSERT_STABFILE),
								szTempFile);

							// Turn on
							bDoStabPlotInsert=TRUE;
							Button_SetCheck(GETHCTL(IDC_INSERT_STABON),
								bDoStabPlotInsert);
						}
						else // Filename NG
						{
							// Restore original filename
							SetWindowText(GETHCTL(IDC_INSERT_STABFILE),
								szStabPlotInsertFile);
							SetFocus(GETHCTL(IDC_INSERT_STABFILE));
							break;
						}
					}
 					else
					{
						// Reset message flag
						bMessage=FALSE;
					}
                }
                break;

				// Respond to autocorrelation plot insert filename edit control
				case IDC_INSERT_ACFFILE:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(GetFocus()!=GETHCTL(IDC_FILE_CANCEL)) && (!bMessage))
					{
						// Set Message flag
						bMessage=TRUE;

						// Get filename
						GetWindowText(GETHCTL(IDC_INSERT_ACFFILE),
							szTempFile, FILENAMESIZE);

						// Check for null filename
						if((strcmp(szTempFile, "None")==0))
						{
							// Redisplay null filename
							SetWindowText(GETHCTL(IDC_INSERT_ACFFILE),
								szTempFile);

							// Ignore it
							break;
						}

						// Check for default filename
						// Compose default autocorrelation plot insert filename
						strlcpy(szTempName, szPath, sizeof(szTempName));
						strlcat(szTempName, "a_insert.tkf",
							sizeof(szTempName));

						if((strcmp(szTempFile, szTempName)==0))
						{
							// Redisplay default filename
							SetWindowText(GETHCTL(IDC_INSERT_ACFFILE),
								szTempFile);

							// Ignore it
							break;
						}

						// Check if valid tkf file
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_INSERT_TKF, NULL, 0));

						// Validate new filename
						if((CheckFilename(szTempFile, szTempTitle, szTempPath,
							szTempName, szTempExt, hDlg,
							"Autocorrelation Plot Insert Filename")) && bTKF)
						{
							// Filename OK
							strlcpy(szACFPlotInsertFile, szTempFile,
								FILE_NAME_SIZE);

							// Redisplay the new filename
							SetWindowText(GETHCTL(IDC_INSERT_ACFFILE),
								szTempFile);

							// Turn on
							bDoACFPlotInsert=TRUE;
							Button_SetCheck(GETHCTL(IDC_INSERT_ACFON),
								bDoACFPlotInsert);
						}
						else // Filename NG
						{
							// Restore original filename
							SetWindowText(GETHCTL(IDC_INSERT_ACFFILE),
								szACFPlotInsertFile);
							SetFocus(GETHCTL(IDC_INSERT_ACFFILE));
							break;
						}
					}
 					else
					{
						// Reset message flag
						bMessage=FALSE;
					}
                }
                break;

				// Respond to phase insert filename browse button
				case IDC_INSERT_PHASEBROWSE:
				{
					// Initialize OPENFILENAME structure
					InsertFileInitialize(hDlg, hInst,
						"Phase Plot Insert File");

					// Clear filename
					strlcpy(szTempFile, "", sizeof(szTempFile));

					// Invoke standard File Open Dialog
					if(FileOpenDlg(FALSE, hDlg, szTempFile, szTempTitle))
					{
						;
					}
					else // Error
					{
						// Enter null filename
						strlcpy(szPhasePlotInsertFile, "None", FILE_NAME_SIZE);

						// Turn off
						bDoPhasePlotInsert=FALSE;
					}

					// Check if valid tkf file
					SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_INSERT_TKF, NULL, 0));

					// Use file if valid
					if(bTKF)
					{
						// Copy entered filename
						strlcpy(szPhasePlotInsertFile, szTempFile,
							FILE_NAME_SIZE);

						// Turn on
						bDoPhasePlotInsert=TRUE;
						Button_SetCheck(GETHCTL(IDC_INSERT_PHASEON),
							bDoPhasePlotInsert);
					}
					else // Not valid tkf file
					{
						// Stay with original filename and state
						;
					}

					// Display the filename
					SetWindowText(GETHCTL(IDC_INSERT_PHASEFILE),
						szPhasePlotInsertFile);
				}
				break;
				
				// Respond to frequency insert filename browse button
				case IDC_INSERT_FREQBROWSE:
				{
					// Initialize OPENFILENAME structure
					InsertFileInitialize(hDlg, hInst,
						"Frequency Plot Insert File");

					// Clear filename
					strlcpy(szTempFile, "", sizeof(szTempFile));

					// Invoke standard File Open Dialog
					if(FileOpenDlg(FALSE, hDlg, szTempFile, szTempFile))
					{
						;
					}
					else // Error
					{
						// Enter null filename
						strlcpy(szFreqPlotInsertFile, "None", FILE_NAME_SIZE);

						// Turn off
						bDoFreqPlotInsert=FALSE;
					}

					// Check if valid tkf file
					SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_INSERT_TKF, NULL, 0));

					// Use file if valid
					if(bTKF)
					{
						// Copy entered filename
						strlcpy(szFreqPlotInsertFile, szTempFile,
							FILE_NAME_SIZE);

						// Turn on
						bDoFreqPlotInsert=TRUE;
						Button_SetCheck(GETHCTL(IDC_INSERT_FREQON),
							bDoFreqPlotInsert);
					}
					else // Not valid tkf file
					{
						// Stay with original filename and state
						;
					}

					// Display the filename
					SetWindowText(GETHCTL(IDC_INSERT_FREQFILE),
						szFreqPlotInsertFile);
				}
				break;

				// Respond to stability insert filename browse button
				case IDC_INSERT_STABBROWSE:
				{
					// Initialize OPENFILENAME structure
					InsertFileInitialize(hDlg, hInst,
						"Stability Plot Insert File");

					// Clear filename
					strlcpy(szTempFile, "", sizeof(szTempFile));

					// Invoke standard File Open Dialog
					if(FileOpenDlg(FALSE, hDlg, szTempFile, szTempFile))
					{
						;
					}
					else // Error
					{
						// Enter null filename
						strlcpy(szStabPlotInsertFile, "None", FILE_NAME_SIZE);

						// Turn off
						bDoStabPlotInsert=FALSE;
					}

					// Check if valid tkf file
					SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_INSERT_TKF, NULL, 0));

					// Use file if valid
					if(bTKF)
					{
						// Copy entered filename
						strlcpy(szStabPlotInsertFile, szTempFile,
							FILE_NAME_SIZE);

						// Turn on
						bDoStabPlotInsert=TRUE;
						Button_SetCheck(GETHCTL(IDC_INSERT_STABON),
							bDoStabPlotInsert);
					}
					else // Not valid tkf file
					{
						// Stay with original filename and state
						;
					}

						// Display the filename
					SetWindowText(GETHCTL(IDC_INSERT_STABFILE),
						szStabPlotInsertFile);
				}
				break;

				// Respond to autocorrelation insert filename browse button
				case IDC_INSERT_ACFBROWSE:
				{
					// Initialize OPENFILENAME structure
					InsertFileInitialize(hDlg, hInst,
						"Autocorrelation Plot Insert File");

					// Clear filename
					strlcpy(szTempFile, "", sizeof(szTempFile));

					// Invoke standard File Open Dialog
					if(FileOpenDlg(FALSE, hDlg, szTempFile, szTempFile))
					{
						;
					}
					else // Error
					{
						// Enter null filename
						strlcpy(szACFPlotInsertFile, "None", FILE_NAME_SIZE);

						// Turn off
						bDoACFPlotInsert=FALSE;
					}

					// Check if valid tkf file
					SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_INSERT_TKF, NULL, 0));

					// Use file if valid
					if(bTKF)
					{
						// Copy entered filename
						strlcpy(szACFPlotInsertFile, szTempFile,
							FILE_NAME_SIZE);

						// Turn on
						bDoACFPlotInsert=TRUE;
						Button_SetCheck(GETHCTL(IDC_INSERT_ACFON),
							bDoACFPlotInsert);
					}
					else // Not valid tkf file
					{
						// Stay with original filename and state
						;
					}

					// Display the filename
					SetWindowText(GETHCTL(IDC_INSERT_ACFFILE),
						szACFPlotInsertFile);
				}
				break;

				// Respond to phase insert default filename button
				case IDC_INSERT_PHASEDEF:
				{
					// Compose default phase plot insert filename
					strlcpy(szPhasePlotInsertFile, szPath, FILE_NAME_SIZE);
					strlcat(szPhasePlotInsertFile, "p_insert.tkf",
						FILE_NAME_SIZE);

					// Set filename
					SetWindowText(GETHCTL(IDC_INSERT_PHASEFILE),
						szPhasePlotInsertFile);
                }
                break;
				
				// Respond to freq insert default filename button
				case IDC_INSERT_FREQDEF:
				{
					// Compose default freq plot insert filename
					strlcpy(szFreqPlotInsertFile, szPath, FILE_NAME_SIZE);
					strlcat(szFreqPlotInsertFile, "f_insert.tkf",
						FILE_NAME_SIZE);

					// Set filename
					SetWindowText(GETHCTL(IDC_INSERT_FREQFILE),
						szFreqPlotInsertFile);
                }
                break;
				
				// Respond to stability insert default filename button
				case IDC_INSERT_STABDEF:
				{
					// Compose default stability plot insert filename
					strlcpy(szStabPlotInsertFile, szPath, FILE_NAME_SIZE);
					strlcat(szStabPlotInsertFile, "s_insert.tkf",
						FILE_NAME_SIZE);

					// Set filename
					SetWindowText(GETHCTL(IDC_INSERT_STABFILE),
						szStabPlotInsertFile);
                }
                break;
				
				// Respond to autocorrelation insert default filename button
				case IDC_INSERT_ACFDEF:
				{
					// Compose default autocorrelation plot insert filename
					strlcpy(szACFPlotInsertFile, szPath, FILE_NAME_SIZE);
					strlcat(szACFPlotInsertFile, "a_insert.tkf",
						FILE_NAME_SIZE);

					// Set filename
					SetWindowText(GETHCTL(IDC_INSERT_ACFFILE),
						szACFPlotInsertFile);
                }
                break;

				// Respond to phase insert clear button
				case IDC_INSERT_PHASECLR:
				{
					// Clear filename
					SetWindowText(GETHCTL(IDC_INSERT_PHASEFILE), "None");

					// Reset on state
					Button_SetCheck(GETHCTL(IDC_INSERT_PHASEON), FALSE);
                }
                break;

				// Respond to freq insert clear button
				case IDC_INSERT_FREQCLR:
				{
					// Clear filename
					SetWindowText(GETHCTL(IDC_INSERT_FREQFILE), "None");

					// Reset on state
					Button_SetCheck(GETHCTL(IDC_INSERT_FREQON), FALSE);
                }
                break;

				// Respond to stability insert clear button
				case IDC_INSERT_STABCLR:
				{
					// Clear filename
					SetWindowText(GETHCTL(IDC_INSERT_STABFILE), "None");

					// Reset on state
					Button_SetCheck(GETHCTL(IDC_INSERT_STABON), FALSE);
                }
                break;

				// Respond to autocorrelation insert clear button
				case IDC_INSERT_ACFCLR:
				{
					// Clear filename
					SetWindowText(GETHCTL(IDC_INSERT_ACFFILE), "None");

					// Reset on state
					Button_SetCheck(GETHCTL(IDC_INSERT_ACFON), FALSE);
                 }
                break;
                
                // Internal subroutine to check if file is tkf file
				// Filename being checked is szTempFile
				// First four hex bytes of tkf file are 1B, 25, 21, 30
				// Test results in bTKF
				case IDC_INSERT_TKF:
				{
					// Initialize flag to false
					bTKF=FALSE;

					// Open file for reading
					if((fhFile=fopen(szTempFile, "r"))==NULL)
					{
						// Error - could not open input file
	                    MessageBox(hDlg,"Could Not Open File",
							"Plot Insert Filename",	MB_ICONEXCLAMATION);
						break;
					}

					// Read file into szTempExt buffer
					// Read stops at \n, EOF or BUFFER_SIZE-1
					// The latter will generally be the case
					fgets(szTempExt, BUFFER_SIZE, fhFile);

					// Test first four bytes
					if(szTempExt[0]==0x1B && szTempExt[1]==0x25 &&
						szTempExt[2]==0x21 && szTempExt[3]==0x30)
					{
						bTKF=TRUE;
					}
					else
					{
	                    // Not a tkf file
						MessageBox(hDlg,"Not a Valid TKF File",
							"Plot Insert Filename",	MB_ICONEXCLAMATION);
					}

					// Close file
					fclose(fhFile);
				}
				break;

				// Respond to CR in an edit control
                // Note: No button is a DEFPUSHBUTTON
                case IDOK:
                {
                    // Does phase plot insert filename edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_INSERT_PHASEFILE))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_INSERT_PHASEFILE, 0,
							EN_KILLFOCUS));
					}

                    // Does freq plot insert filename edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_INSERT_FREQFILE))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_INSERT_FREQFILE, 0,
							EN_KILLFOCUS));
					}

                    // Does stability plot insert filename edit control
					// have focus?
                    if(GetFocus()==GETHCTL(IDC_INSERT_STABFILE))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_INSERT_STABFILE, 0,
							EN_KILLFOCUS));
					}

                    // Does autocorrelation plot insert filename edit control
					// have focus?
                    if(GetFocus()==GETHCTL(IDC_INSERT_ACFFILE))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_INSERT_ACFFILE, 0,
							EN_KILLFOCUS));
					}
				}
				break;

					// Respond to esc key or close button
                case IDCANCEL:
                case IDC_INSERT_CLOSE:
                {
                    EndDialog (hDlg, 0);
                }
                return TRUE;
            }
        }
        break;
	 }
     return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*                   Rename Tab Dialog Procedure                             */
/*                                                                           */
/*	Function to rename a data tab filename                                   */
/*  Invoked by Rename Selected Tab item in Tabs menu                         */
/*  Activated only if there is at least one tab                              */
/*  Tab # to be renamed is global nTab                                       */
/*                                                                           */
/*  Revision record:                                                         */
/*      11/20/06    Created                                                  */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK RenameTabDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	// Chars
	static char szFilename[FILENAMESIZE+1];		// Filename buffer
	// Note:  These buffers aren't actually used
	// but are needed for CheckFilename() function
	char szTitle[FILENAMESIZE+1];				// Title buffer
	char szPath[FILENAMESIZE+1];				// Path buffer
	char szName[FILENAMESIZE+1];				// Name buffer
	char szExt[FILENAMESIZE+1];					// Ext buffer
	// char szBuffer[BUFFER_SIZE+1];				// Text buffer
	// Ints
	// BOOLs
	static BOOL bErrorTrap=FALSE;   // Flag for entry error
	// F_TYPEs


	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Initialize empty path, name & extension
			strlcpy(szTitle, "", sizeof(szTitle));
			strlcpy(szPath, "", sizeof(szPath));
			strlcpy(szName, "", sizeof(szName));
			strlcpy(szExt, "", sizeof(szExt));

			// Put current tab filename into edit control
			if(bDataType==PHASE_DATA)
			{
				strlcpy(szFilename, sPTab[nTab].szTitle, sizeof(szFilename));
			}
			else // Freq data
			{
				strlcpy(szFilename, sFTab[nTab].szTitle, sizeof(szFilename));
			}
			SetWindowText(GETHCTL(IDC_RENAMETAB_FILENAME), szFilename);
		}
		return TRUE;

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				// Respond to help button message
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::TABS.HTM", HH_DISPLAY_TOPIC,
                        0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::TABS.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "TABS");
					#endif
				}
				break;

				// Respond to filename edit control message
				case IDC_RENAMETAB_FILENAME:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_RENAMETAB_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get new filename
						GetWindowText(GETHCTL(IDC_RENAMETAB_FILENAME),
							szFilename, BUFFER_SIZE);

						// Validate new filename
						if(CheckFilename(szFilename, szTitle, szPath,
							szName, szExt, hDlg,
							"Tab Filename"))
						{
							// Filename OK
							// Redisplay the new filename
							SetWindowText(GETHCTL(IDC_RENAMETAB_FILENAME),
								szFilename);
						}
						else // Filename NG
						{
							// Restore original filename
							if(bDataType==PHASE_DATA)
							{
								strlcpy(szFilename, sPTab[nTab].szTitle,
									sizeof(szFilename));
							}
							else // Freq data
							{
								strlcpy(szFilename, sFTab[nTab].szTitle,
									sizeof(szFilename));
							}
							SetWindowText(GETHCTL(IDC_RENAMETAB_FILENAME),
								szFilename);
							SetFocus(GETHCTL(IDC_FILE_PHASEPLOT));
							break;
						}
                    }
                    else
                    {
                        // Reset error flag
                        bErrorTrap=FALSE;
                    }
                }
                break;

                // Respond to CR in an edit control
                // Note: No button is a DEFPUSHBUTTON
                case IDOK:
                {
                    // Does filename edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_RENAMETAB_FILENAME))
                    {
						// Send EN_KILLFOCUS message to filename edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RENAMETAB_FILENAME, 0,
							EN_KILLFOCUS));
					}
				}
                break;

				// Respond to OK buttom message
                case IDC_RENAMETAB_ACCEPT:
                {
					if(bDataType==PHASE_DATA)
					{
						strlcpy(sPTab[nTab].szTitle, szFilename,
							FILE_TITLE_SIZE);
					}
					else // Freq data
					{
						strlcpy(sFTab[nTab].szTitle, szFilename,
							FILE_TITLE_SIZE);
					}
				}
                // Go right into EndDialog()
                // Respond to esc key or cancel button
                case IDCANCEL:
                case IDC_RENAMETAB_CANCEL:
                {
                    EndDialog (hDlg, 0);
                }
	            return TRUE;
            }
		}
        break;
	}
     return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*                   Phase Data Function Fit Dialog Procedure                */
/*                                                                           */
/*	Function to support initializing function fit expression parameters      */
/*                                                                           */
/*  Revision record:                                                         */
/*      12/21/07    Created                                                  */
/*      07/11/08	Added support for removing function fit from freq data   */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK PhaseFuncDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	char szBuffer[BUFFER_SIZE+1];   // Text buffer
	int i;							// General index
	static BOOL bErrorTrap=FALSE;   // Flag for entry error

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Show function expression
			strlcpy(szBuffer, "x(t)=", sizeof(szBuffer));
			strlcat(szBuffer, sPPlot.function, sizeof(szBuffer));
			SetWindowText(GETHCTL(IDC_FUNC_FUNC), szBuffer);
			
			// Loop through active parameters
			for(i=0; i<sPPlot.num; i++)
			{
				// Show active edit control label
				ShowWindow(GETHCTL(IDC_FUNC_ALABEL+i), SW_SHOWNORMAL);

				// Show active edit control
				ShowWindow(GETHCTL(IDC_FUNC_A+i), SW_SHOWNORMAL);
				
				// Display original parameter value
				_snprintf(szBuffer, sizeof(szBuffer), "%e", sPPlot.param[i]);
				ShortenExp(szBuffer);
				SetWindowText(GETHCTL(IDC_FUNC_A+i), szBuffer);
			
				// Save original parameter value
				sPPrev.param[i]=sPPlot.param[i];
			}

			// Loop through inactive parameters
			for(i=sPPlot.num; i<NUMPARAMS; i++)
			{
				// Show active edit control label
				ShowWindow(GETHCTL(IDC_FUNC_ALABEL+i), SW_HIDE);

				// Hide active edit control
				ShowWindow(GETHCTL(IDC_FUNC_A+i), SW_HIDE);
			}
			// Clear remove fit checkbox state
			sPPlot.remove=FALSE;
			Button_SetCheck(GETHCTL(IDC_FUNC_REMOVE), sPPlot.remove);
		}
		return TRUE;

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				// Respond to help button message
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::PLOT_OPTIONS_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::PLOT_OPTIONS_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "PLOT_OPTIONS_FUNCTION");
					#endif
				}
				break;

                // Respond to a parameter edit control
				case IDC_FUNC_A:
                {
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDCANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get (new) a parameter value
						GetWindowText(GETHCTL(IDC_FUNC_A), szBuffer,
							BUFFER_SIZE);
						sPPlot.param[0]=atof(szBuffer);

						// No validation is done
						// Just redisplay new value
						_snprintf(szBuffer, sizeof(szBuffer), "%e",
								sPPlot.param[0]);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_FUNC_A), szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

                // Respond to b parameter edit control
				case IDC_FUNC_B:
                {
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDCANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get (new) a parameter value
						GetWindowText(GETHCTL(IDC_FUNC_B), szBuffer,
							BUFFER_SIZE);
						sPPlot.param[1]=atof(szBuffer);

						// No validation is done
						// Just redisplay new value
						_snprintf(szBuffer, sizeof(szBuffer), "%e",
								sPPlot.param[1]);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_FUNC_B), szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

                // Respond to c parameter edit control
				case IDC_FUNC_C:
                {
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDCANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get (new) a parameter value
						GetWindowText(GETHCTL(IDC_FUNC_C), szBuffer,
							BUFFER_SIZE);
						sPPlot.param[2]=atof(szBuffer);

						// No validation is done
						// Just redisplay new value
						_snprintf(szBuffer, sizeof(szBuffer), "%e",
								sPPlot.param[2]);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_FUNC_C), szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

                // Respond to d parameter edit control
				case IDC_FUNC_D:
                {
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDCANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get (new) a parameter value
						GetWindowText(GETHCTL(IDC_FUNC_D), szBuffer,
							BUFFER_SIZE);
						sPPlot.param[3]=atof(szBuffer);

						// No validation is done
						// Just redisplay new value
						_snprintf(szBuffer, sizeof(szBuffer), "%e",
								sPPlot.param[3]);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_FUNC_D), szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

                // Respond to e parameter edit control
				case IDC_FUNC_E:
                {
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDCANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get (new) a parameter value
						GetWindowText(GETHCTL(IDC_FUNC_E), szBuffer,
							BUFFER_SIZE);
						sPPlot.param[4]=atof(szBuffer);

						// No validation is done
						// Just redisplay new value
						_snprintf(szBuffer, sizeof(szBuffer), "%e",
								sPPlot.param[4]);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_FUNC_E), szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

                // Respond to f parameter edit control
				case IDC_FUNC_F:
                {
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDCANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get (new) a parameter value
						GetWindowText(GETHCTL(IDC_FUNC_F), szBuffer,
							BUFFER_SIZE);
						sPPlot.param[5]=atof(szBuffer);

						// No validation is done
						// Just redisplay new value
						_snprintf(szBuffer, sizeof(szBuffer), "%e",
								sPPlot.param[5]);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_FUNC_F), szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

                // Respond to g parameter edit control
				case IDC_FUNC_G:
                {
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDCANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get (new) a parameter value
						GetWindowText(GETHCTL(IDC_FUNC_G), szBuffer,
							BUFFER_SIZE);
						sPPlot.param[6]=atof(szBuffer);

						// No validation is done
						// Just redisplay new value
						_snprintf(szBuffer, sizeof(szBuffer), "%e",
								sPPlot.param[6]);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_FUNC_G), szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

                // Respond to h parameter edit control
				case IDC_FUNC_H:
                {
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDCANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get (new) a parameter value
						GetWindowText(GETHCTL(IDC_FUNC_H), szBuffer,
							BUFFER_SIZE);
						sPPlot.param[7]=atof(szBuffer);

						// No validation is done
						// Just redisplay new value
						_snprintf(szBuffer, sizeof(szBuffer), "%e",
								sPPlot.param[7]);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_FUNC_H), szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

                // Respond to i parameter edit control
				case IDC_FUNC_I:
                {
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDCANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get (new) a parameter value
						GetWindowText(GETHCTL(IDC_FUNC_I), szBuffer,
							BUFFER_SIZE);
						sPPlot.param[8]=atof(szBuffer);

						// No validation is done
						// Just redisplay new value
						_snprintf(szBuffer, sizeof(szBuffer), "%e",
								sPPlot.param[8]);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_FUNC_I), szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

                // Respond to j parameter edit control
				case IDC_FUNC_J:
                {
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDCANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get (new) a parameter value
						GetWindowText(GETHCTL(IDC_FUNC_J), szBuffer,
							BUFFER_SIZE);
						sPPlot.param[9]=atof(szBuffer);

						// No validation is done
						// Just redisplay new value
						_snprintf(szBuffer, sizeof(szBuffer), "%e",
								sPPlot.param[9]);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_FUNC_J), szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

                // Respond to CR in an edit control
                // Note: No button is a DEFPUSHBUTTON
                case IDOK:
                {
                    // Does a parameter edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FUNC_A))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FUNC_A, 0,
							EN_KILLFOCUS));
					}

                    // Does b parameter edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FUNC_B))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FUNC_B, 0,
							EN_KILLFOCUS));
					}

                    // Does c parameter edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FUNC_C))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FUNC_C, 0,
							EN_KILLFOCUS));
					}

                    // Does d parameter edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FUNC_D))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FUNC_D, 0,
							EN_KILLFOCUS));
					}

                    // Does e parameter edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FUNC_E))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FUNC_E, 0,
							EN_KILLFOCUS));
					}

                    // Does f parameter edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FUNC_F))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FUNC_F, 0,
							EN_KILLFOCUS));
					}

                    // Does g parameter edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FUNC_G))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FUNC_G, 0,
							EN_KILLFOCUS));
					}

                    // Does h parameter edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FUNC_H))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FUNC_H, 0,
							EN_KILLFOCUS));
					}

	                // Does i parameter edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FUNC_I))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FUNC_I, 0,
							EN_KILLFOCUS));
					}

					// Does j parameter edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FUNC_J))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FUNC_J, 0,
							EN_KILLFOCUS));
					}
                    
				}
                break;

				// Respond to remove fit checkbox
				case IDC_FUNC_REMOVE:
				{
					sPPlot.remove=Button_GetCheck(GETHCTL(IDC_FUNC_REMOVE));
				}
				break;

				// Reset all active fit parameters to defaults
				case IDC_FUNC_RESET:
				{
					// Loop through active parameters
					for(i=0; i<sPPlot.num; i++)
					{
						// Restore default parameter value (1.0)
						sPPlot.param[i]=1.0;

						// Redisplay default value
						_snprintf(szBuffer, sizeof(szBuffer), "%e", 1.0);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_FUNC_A+i), szBuffer);
					}
				}
				break;

				// Respond to OK buttom message
                case IDC_FUNC_ACCEPT:
                {
					// Close dialog box
                    EndDialog (hDlg, 0);
				}
                return TRUE;
				
               // Respond to esc key or cancel button
                case IDCANCEL:
                case IDC_FUNC_CANCEL:
                {
					// Restore original parameter values
					// Loop through active parameters
					for(i=0; i<sPPlot.num; i++)
					{
						// Restore original parameter value
						sPPlot.param[i]=sPPrev.param[i];
					}
					
					// Close dialog box
					EndDialog (hDlg, 0);
                }
                return TRUE;
            }
        }
        break;
	 }
     return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*                   Freq Data Function Fit Dialog Procedure                 */
/*                                                                           */
/*	Function to support initializing function fit expression parameters      */
/*                                                                           */
/*  Revision record:                                                         */
/*      12/21/07    Created                                                  */
/*      07/11/08	Added support for removing function fit from freq data   */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK FreqFuncDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	char szBuffer[BUFFER_SIZE+1];   // Text buffer
	int i;							// General index
	static BOOL bErrorTrap=FALSE;   // Flag for entry error

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Show function expression
			strlcpy(szBuffer, "y(t)=", sizeof(szBuffer));
			strlcat(szBuffer, sFPlot.function, sizeof(szBuffer));
			SetWindowText(GETHCTL(IDC_FUNC_FUNC), szBuffer);
			
			// Loop through active parameters
			for(i=0; i<sFPlot.num; i++)
			{
				// Show active edit control label
				ShowWindow(GETHCTL(IDC_FUNC_ALABEL+i), SW_SHOWNORMAL);

				// Show active edit control
				ShowWindow(GETHCTL(IDC_FUNC_A+i), SW_SHOWNORMAL);
				
				// Display original parameter value
				_snprintf(szBuffer, sizeof(szBuffer), "%e", sFPlot.param[i]);
				ShortenExp(szBuffer);
				SetWindowText(GETHCTL(IDC_FUNC_A+i), szBuffer);
			
				// Save original parameter value
				sPPrev.param[i]=sFPlot.param[i];
			}

			// Loop through inactive parameters
			for(i=sFPlot.num; i<NUMPARAMS; i++)
			{
				// Show active edit control label
				ShowWindow(GETHCTL(IDC_FUNC_ALABEL+i), SW_HIDE);

				// Hide active edit control
				ShowWindow(GETHCTL(IDC_FUNC_A+i), SW_HIDE);
			}

			// Clear remove fit checkbox state
			sFPlot.remove=FALSE;
			Button_SetCheck(GETHCTL(IDC_FUNC_REMOVE), sFPlot.remove);
		}
		return TRUE;

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				// Respond to help button message
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::FUNCTION_FIT_PARAMETERS.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::FUNCTION_FIT_PARAMETERS.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "FUNCTION_FIT_PARAMETERS");
					#endif
				}
				break;

                // Respond to a parameter edit control
				case IDC_FUNC_A:
                {
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDCANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get (new) a parameter value
						GetWindowText(GETHCTL(IDC_FUNC_A), szBuffer,
							BUFFER_SIZE);
						sFPlot.param[0]=atof(szBuffer);

						// No validation is done
						// Just redisplay new value
						_snprintf(szBuffer, sizeof(szBuffer), "%e",
								sFPlot.param[0]);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_FUNC_A), szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

                // Respond to b parameter edit control
				case IDC_FUNC_B:
                {
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDCANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get (new) a parameter value
						GetWindowText(GETHCTL(IDC_FUNC_B), szBuffer,
							BUFFER_SIZE);
						sFPlot.param[1]=atof(szBuffer);

						// No validation is done
						// Just redisplay new value
						_snprintf(szBuffer, sizeof(szBuffer), "%e",
								sFPlot.param[1]);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_FUNC_B), szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

                // Respond to c parameter edit control
				case IDC_FUNC_C:
                {
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDCANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get (new) a parameter value
						GetWindowText(GETHCTL(IDC_FUNC_C), szBuffer,
							BUFFER_SIZE);
						sFPlot.param[2]=atof(szBuffer);

						// No validation is done
						// Just redisplay new value
						_snprintf(szBuffer, sizeof(szBuffer), "%e",
								sFPlot.param[2]);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_FUNC_C), szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

                // Respond to d parameter edit control
				case IDC_FUNC_D:
                {
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDCANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get (new) a parameter value
						GetWindowText(GETHCTL(IDC_FUNC_D), szBuffer,
							BUFFER_SIZE);
						sFPlot.param[3]=atof(szBuffer);

						// No validation is done
						// Just redisplay new value
						_snprintf(szBuffer, sizeof(szBuffer), "%e",
								sFPlot.param[3]);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_FUNC_D), szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

                // Respond to e parameter edit control
				case IDC_FUNC_E:
                {
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDCANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get (new) a parameter value
						GetWindowText(GETHCTL(IDC_FUNC_E), szBuffer,
							BUFFER_SIZE);
						sFPlot.param[4]=atof(szBuffer);

						// No validation is done
						// Just redisplay new value
						_snprintf(szBuffer, sizeof(szBuffer), "%e",
								sFPlot.param[4]);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_FUNC_E), szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

                // Respond to f parameter edit control
				case IDC_FUNC_F:
                {
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDCANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get (new) a parameter value
						GetWindowText(GETHCTL(IDC_FUNC_F), szBuffer,
							BUFFER_SIZE);
						sFPlot.param[5]=atof(szBuffer);

						// No validation is done
						// Just redisplay new value
						_snprintf(szBuffer, sizeof(szBuffer), "%e",
								sFPlot.param[5]);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_FUNC_F), szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

                // Respond to g parameter edit control
				case IDC_FUNC_G:
                {
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDCANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get (new) a parameter value
						GetWindowText(GETHCTL(IDC_FUNC_G), szBuffer,
							BUFFER_SIZE);
						sFPlot.param[6]=atof(szBuffer);

						// No validation is done
						// Just redisplay new value
						_snprintf(szBuffer, sizeof(szBuffer), "%e",
								sFPlot.param[6]);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_FUNC_G), szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

                // Respond to h parameter edit control
				case IDC_FUNC_H:
                {
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDCANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get (new) a parameter value
						GetWindowText(GETHCTL(IDC_FUNC_H), szBuffer,
							BUFFER_SIZE);
						sFPlot.param[7]=atof(szBuffer);

						// No validation is done
						// Just redisplay new value
						_snprintf(szBuffer, sizeof(szBuffer), "%e",
								sFPlot.param[7]);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_FUNC_H), szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

                // Respond to i parameter edit control
				case IDC_FUNC_I:
                {
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDCANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get (new) a parameter value
						GetWindowText(GETHCTL(IDC_FUNC_I), szBuffer,
							BUFFER_SIZE);
						sFPlot.param[8]=atof(szBuffer);

						// No validation is done
						// Just redisplay new value
						_snprintf(szBuffer, sizeof(szBuffer), "%e",
								sFPlot.param[8]);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_FUNC_I), szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

                // Respond to j parameter edit control
				case IDC_FUNC_J:
                {
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDCANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get (new) a parameter value
						GetWindowText(GETHCTL(IDC_FUNC_J), szBuffer,
							BUFFER_SIZE);
						sFPlot.param[9]=atof(szBuffer);

						// No validation is done
						// Just redisplay new value
						_snprintf(szBuffer, sizeof(szBuffer), "%e",
								sFPlot.param[9]);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_FUNC_J), szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

                // Respond to CR in an edit control
                // Note: No button is a DEFPUSHBUTTON
                case IDOK:
                {
                    // Does a parameter edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FUNC_A))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FUNC_A, 0,
							EN_KILLFOCUS));
					}

                    // Does b parameter edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FUNC_B))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FUNC_B, 0,
							EN_KILLFOCUS));
					}

                    // Does c parameter edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FUNC_C))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FUNC_C, 0,
							EN_KILLFOCUS));
					}

                    // Does d parameter edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FUNC_D))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FUNC_D, 0,
							EN_KILLFOCUS));
					}

                    // Does e parameter edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FUNC_E))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FUNC_E, 0,
							EN_KILLFOCUS));
					}

                    // Does f parameter edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FUNC_F))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FUNC_F, 0,
							EN_KILLFOCUS));
					}

                    // Does g parameter edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FUNC_G))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FUNC_G, 0,
							EN_KILLFOCUS));
					}

                    // Does h parameter edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FUNC_H))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FUNC_H, 0,
							EN_KILLFOCUS));
					}

	                // Does i parameter edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FUNC_I))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FUNC_I, 0,
							EN_KILLFOCUS));
					}

					// Does j parameter edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FUNC_J))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FUNC_J, 0,
							EN_KILLFOCUS));
					}
                    
				}
                break;

				// Respond to remove fit checkbox
				case IDC_FUNC_REMOVE:
				{
					sFPlot.remove=Button_GetCheck(GETHCTL(IDC_FUNC_REMOVE));
				}
				break;

				// Reset all active fit parameters to defaults
				case IDC_FUNC_RESET:
				{
					// Loop through active parameters
					for(i=0; i<sFPlot.num; i++)
					{
						// Restore default parameter value (1.0)
						sFPlot.param[i]=1.0;

						// Redisplay default value
						_snprintf(szBuffer, sizeof(szBuffer), "%e", 1.0);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_FUNC_A+i), szBuffer);
					}
				}
				break;

				// Respond to OK buttom message
                case IDC_FUNC_ACCEPT:
                {
					// Close dialog box
                    EndDialog (hDlg, 0);
				}
                return TRUE;
				
               // Respond to esc key or cancel button
                case IDCANCEL:
                case IDC_FUNC_CANCEL:
                {
					// Restore original parameter values
					// Loop through active parameters
					for(i=0; i<sFPlot.num; i++)
					{
						// Restore original parameter value
						sFPlot.param[i]=sPPrev.param[i];
					}
					
					// Close dialog box
					EndDialog (hDlg, 0);
                }
                return TRUE;
            }
        }
        break;
	 }
     return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*                   Freq Jump Detection Dialog Procedure                    */
/*                                                                           */
/*	Function to support initializing jump detection parameters               */
/*                                                                           */
/*  Parameters are stored as follows:                                        */
/*      Window length				int		sFPlot.length                    */
/*      Window offset				int		sFPlot.offset                    */
/*      Fractional Freq Limit		float	sFPlot.limit                     */
/*		Sigma Factor converted to   float	sFPlot.limit                     */
/*                                                                           */
/*  Revision record:                                                         */
/*      02/02/08    Created                                                  */
/*		02/07/08	Added show cusum plot checkbox                           */
/*		02/10/08	Added confidence factor checkbox						 */
/*		02/24/08	Added BLKAVG and SEQAVG radio buttons                    */
/*		02/25/08	Added disabling of window offset for SEQAVG method       */
/*		03/01/08	Added window length validation                           */
/*		03/06/08	Added alt color checkbox                                 */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK FreqJumpDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	char szBuffer[BUFFER_SIZE+1];   // Text buffer
	int i;							// General index & int value
	static int npts;                // # freq data points
	static BOOL bErrorTrap=FALSE;   // Flag for entry error
	static float sigma;				// Sigma value for freq data
									// Overlapping ADEV for AF=window length
									// over entire data set
	static F_TYPE *fWorkData;       // Working data array
	static F_TYPE fTau;				// Tau value
	float val;						// General float value
	static double sig;				// Sigma value as double

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Assign # freq data points
			npts=(int)(fFreqData[2]-fFreqData[1]+1);
			
			// Get tau value
			GetWindowText(GetDlgItem(hwndMain, IDC_FREQTAU),
				szBuffer, BUFFER_SIZE);

			// Use its absolute value
			fTau=fabs(atof(szBuffer));

			// Get sigma value
			// Note:  Will get sigma calc error if window length NG
			#if(1) // Added 03/01/08 - Probably not necessary
			// Check for invalid window length
			if( (sFPlot.length<5) || (sFPlot.length>npts/2) )
			{
				// Set window length to default
				sFPlot.length=max(5, npts/10);
			}
			#endif
			
			SendMessage(hDlg, WM_COMMAND,
				GET_WM_COMMAND_MPS(IDC_JUMP_CALCSIGMA, NULL,0));

			// Show current values
			// Initialization is done in InitFreqPlotParams()
			// Show current length
			_snprintf(szBuffer, sizeof(szBuffer), "%d", sFPlot.length);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_JUMP_SIZE), szBuffer);

			// Enable offset for BLKAVG only
			if(sFPlot.method==BLKAVG)
			{
				// Enable offset
				_snprintf(szBuffer, sizeof(szBuffer), "%d", sFPlot.offset);
				ShortenExp(szBuffer);
				SetWindowText(GETHCTL(IDC_JUMP_OFFSET), szBuffer);
				EnableWindow(GETHCTL(IDC_JUMP_OFFSET), TRUE);
			}
			else 
			{
				// Make visible offset blank (sFPlot.offset stays same)
				SetWindowText(GETHCTL(IDC_JUMP_OFFSET), "");

				// Disable offset
				EnableWindow(GETHCTL(IDC_JUMP_OFFSET), FALSE);
			}

			// Show current fractional freq limit
			_snprintf(szBuffer, sizeof(szBuffer), "%e", sFPlot.limit);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_JUMP_FREQ), szBuffer);

			// Show current sigma factor limit
			_snprintf(szBuffer, sizeof(szBuffer), "%5.3f", sFPlot.limit/sigma);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_JUMP_SIGMA), szBuffer);

			// Save current freq jump detection parameters
			sFPrev.length=sFPlot.length;
			sFPrev.offset=sFPlot.offset;
			sFPrev.limit=sFPlot.limit;
			sFPrev.method=sFPlot.method;
			sFPrev.data_color=sFPlot.data_color;

			// Show BLKAVG radiobutton state
			if(sFPlot.method==BLKAVG)
			{
				Button_SetCheck(GETHCTL(IDC_JUMP_BLKAVG), TRUE);
			}
			else
			{
				Button_SetCheck(GETHCTL(IDC_JUMP_BLKAVG), FALSE);
			}

			// Show SEQAVG radiobutton state
			if(sFPlot.method==SEQAVG)
			{
				Button_SetCheck(GETHCTL(IDC_JUMP_SEQAVG), TRUE);
			}
			else
			{
				Button_SetCheck(GETHCTL(IDC_JUMP_SEQAVG), FALSE);
			}

			// Show cusum checkbox state
			Button_SetCheck(GETHCTL(IDC_JUMP_CUSUM), sFPlot.do_cusum);

			// Show confidence factor checkbox state
			Button_SetCheck(GETHCTL(IDC_JUMP_CONF), sFPlot.do_conf);

			// Show alt color checkbox state
			Button_SetCheck(GETHCTL(IDC_JUMP_ALTCOLOR), sFPlot.data_color);
		}
		return TRUE;

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				// Respond to help button message
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::JUMP_DETECTION_PARAMETERS.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::JUMP_DETECTION_PARAMETERS.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "JUMP_DETECTION_PARAMETERS");
					#endif
				}
				break;
				
				// Respond to detection method radiobuttons
				case IDC_JUMP_SEQAVG:
 				case IDC_JUMP_BLKAVG:
                {
					if(Button_GetCheck(GETHCTL(IDC_JUMP_BLKAVG)))
					{
						sFPlot.method=BLKAVG;
					}
					if(Button_GetCheck(GETHCTL(IDC_JUMP_SEQAVG)))
					{
						sFPlot.method=SEQAVG;
					}

					// Enable offset for BLKAVG only
					if(sFPlot.method==BLKAVG)
					{
						// Enable offset
						_snprintf(szBuffer, sizeof(szBuffer), "%d", sFPlot.offset);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_JUMP_OFFSET), szBuffer);
						EnableWindow(GETHCTL(IDC_JUMP_OFFSET), TRUE);
					}
					else 
					{
						// Make visible offset blank (sFPlot.offset stays same)
						SetWindowText(GETHCTL(IDC_JUMP_OFFSET), "");

						// Disable offset
						EnableWindow(GETHCTL(IDC_JUMP_OFFSET), FALSE);
					}
				}
				break;

				// Respond to window length edit control
                // Length must be between 5 and # data points/2
				// Default length is # data points/10 or 5
				// whichever is larger
				// Quietly reject negative values
				case IDC_JUMP_SIZE:
                {
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDCANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get (new) window length
						GetWindowText(GETHCTL(IDC_JUMP_SIZE), szBuffer,
							BUFFER_SIZE);
						i=abs(atoi(szBuffer));

						// Validate new length
						// Min allowable window length is 5
						// Max allowable window length is # data points/2
						if(ValidateInteger(hDlg, i, 5, npts/2)==TRUE)
						{							
							// Entry OK
							sFPlot.length=i;
						}
						else // Invalid entry
						{
							// Set window length to default
							sFPlot.length=max(5, npts/10);
						}

						// Redisplay new length
						_snprintf(szBuffer, sizeof(szBuffer), "%d", sFPlot.length);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_JUMP_SIZE), szBuffer);

						// Reset offset to zero
						sFPlot.offset=0;

						// Redisplay new offset
						_snprintf(szBuffer, sizeof(szBuffer), "%d", sFPlot.offset);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_JUMP_OFFSET), szBuffer);

						// Recalc sigma for new window length
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_JUMP_CALCSIGMA, NULL,0));

						// Use default sigma factor to assign new values
						// Set new fractional freq limit
						sFPlot.limit=(float)(sigma*3.0);
						_snprintf(szBuffer, sizeof(szBuffer), "%e", sFPlot.limit);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_JUMP_FREQ), szBuffer);

						// Set new sigma factor limit
						_snprintf(szBuffer, sizeof(szBuffer), "%5.3f", 3.0);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_JUMP_SIGMA), szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

                // Offset must be between 0 and npts%length
				// Default offset is zero
				// Quietly reject negative values
				
				// Respond to window offset edit control
				case IDC_JUMP_OFFSET:
                {
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDCANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get (new) window offset
						GetWindowText(GETHCTL(IDC_JUMP_OFFSET), szBuffer,
							BUFFER_SIZE);
						i=abs(atoi(szBuffer));

						// Check entry - must be between 0 and npts%length
						if(ValidateInteger(hDlg, i, 0, npts%sFPlot.length)==TRUE)
						{
							// New value OK
							sFPlot.offset=i;

							// Redisplay new offset
							_snprintf(szBuffer, sizeof(szBuffer), "%d", sFPlot.offset);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_JUMP_OFFSET), szBuffer);
						}
						else // Bad entry
						{
							// Invalid entry - restore current value
							_snprintf(szBuffer, sizeof(szBuffer), "%d", sFPlot.offset);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_JUMP_OFFSET), szBuffer);
						}
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}

					// Don't recalc sigma for new window offset
				}
				break;

                // Fractional freq and sigma factor edit controls
				// use "interchangable solutions"
				// Setting one updates the other
				// so they stay in sync
				// Default is 3 sigma - freq set accordingly
				// Quietly reject negative values
				
				// Respond to fractional freq edit control
				case IDC_JUMP_FREQ:
                {
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDCANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get (new) fractional freq
						GetWindowText(GETHCTL(IDC_JUMP_FREQ), szBuffer,
							BUFFER_SIZE);
						val=(float)fabs(atof(szBuffer));

						// Validate new fractional freq
						sFPlot.limit=val;

						// Redisplay new fractional freq limit
						_snprintf(szBuffer, sizeof(szBuffer), "%e", sFPlot.limit);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_JUMP_FREQ), szBuffer);

						// Redisplay new sigma factor limit
						_snprintf(szBuffer, sizeof(szBuffer), "%5.3f", sFPlot.limit/sigma);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_JUMP_SIGMA), szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

                // Sigma factor
				// Sigma factor must be >0 (no upper bound)
				// Default value is 3.0
				// Quietly reject negative values
				
				// Respond to sigma factor edit control
				case IDC_JUMP_SIGMA:
                {
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDCANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Get (new) sigma factor
						GetWindowText(GETHCTL(IDC_JUMP_SIGMA), szBuffer,
							BUFFER_SIZE);
						val=(float)fabs(atof(szBuffer));

						// Validation new value
						sFPlot.limit=sigma*val;

						// Redisplay new fractional freq limit
						_snprintf(szBuffer, sizeof(szBuffer), "%e", sFPlot.limit);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_JUMP_FREQ), szBuffer);

						// Redisplay new sigma factor limit
						_snprintf(szBuffer, sizeof(szBuffer), "%5.3f", sFPlot.limit/sigma);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_JUMP_SIGMA), szBuffer);
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Respond to show cusum plot checkbox
				case IDC_JUMP_CUSUM:
                {
					sFPlot.do_cusum=Button_GetCheck(GETHCTL(IDC_JUMP_CUSUM));
				}
				break;

				// Respond to confidence factor checkbox
				case IDC_JUMP_CONF:
                {
					sFPlot.do_conf=Button_GetCheck(GETHCTL(IDC_JUMP_CONF));
				}
				break;

				// Respond to alt color checkbox
				case IDC_JUMP_ALTCOLOR:
                {
					sFPlot.data_color=Button_GetCheck(GETHCTL(IDC_JUMP_ALTCOLOR));
				}
				break;

				// Internal subroutine to calc sigma
				case IDC_JUMP_CALCSIGMA:
                {
					#if(0) // Original code
					// Overlapping ADEV for AF=window length over all freq data
					CalcFreqOverlapSigma(fFreqData, &sig, sFPlot.length);
					sigma=(float)sig;
					#endif

					#if(1) // Faster code 02/10/08
					// This code converts freq data to phase data
					// for faster calculation with large data sets
					// Note: If already have equivalent phase data, don't
					// need to alloc mem and do conversion.  Can just
					// use the existing phase data if bSynch flag is TRUE. 
					// In that case, need to assign fWorkData ptr to it

					if(!bSynch) // Don't have phase data
					{
						// Need to convert freq data to phase data
						// Allocate memory for working phase data
						// converted from freq data for ADEV calc
						if((fWorkData=(F_TYPE*)malloc((npts+ARRAY_OFFSET+1+EXTRA_MEM)*
							sizeof(F_TYPE)))==NULL)
						{
							// Display error message
							#ifdef MEM_DEBUG
							AllocErrorMessageEx(__FILE__, __LINE__,
								(nNum+ARRAY_OFFSET+1+EXTRA_MEM)*
								sizeof(F_TYPE));
							#else
							AllocErrorMessage();
							#endif

							return TRUE;
						}

						// Convert freq data to phase data for sigma calc
						ConvFreqToPhase(fFreqData, fWorkData, fTau, FALSE);
					}
					else // Assign fWorkData pointer to phase data
					{
						fWorkData=fPhaseData;
					}

					#if(1) // Added 03/01/08 - Probably not necessary
					// Check for invalid window length
					if( (sFPlot.length<5) || (sFPlot.length>npts/2) )
					{
						// Set window length to default
						sFPlot.length=max(5, npts/10);
					}
					#endif
			
					// Calc overlapping sigma from fWorkData phase data
					// Note: The 3rd arg is the basic tau_0
					nDummy=CalcPhaseOverlapSigma(fWorkData, &sig, fTau, sFPlot.length);

					// Error trap for bad calc
					if(nDummy<1)
					{
						// Display error message?
						MessageBox(hDlg, "Error in Sigma Calculation", "Stable32 Error",
							MB_OK | MB_ICONHAND);

						// Free working array if didn't have phase data
						if(!bSynch)
						{
							// Free working data array
							free(fWorkData);
						}
						return TRUE;
					}

					// Free working array if didn't have phase data
					if(!bSynch)
					{
						// Free working data array
						free(fWorkData);
					}
					#endif

					// Assign sigma values
					sigma=(float)sig;
					sFPlot.sigma=(float)sig;
				}
				break;

                // Respond to CR in an edit control
                // Note: No button is a DEFPUSHBUTTON
                case IDOK:
                {
                    // Does window length edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_JUMP_SIZE))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_JUMP_SIZE, 0,
							EN_KILLFOCUS));
					}

                    // Does window offset edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_JUMP_OFFSET))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_JUMP_OFFSET, 0,
							EN_KILLFOCUS));
					}

                    // Does fractional freq edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_JUMP_FREQ))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_JUMP_FREQ, 0,
							EN_KILLFOCUS));
					}

                    // Does sigma factor edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_JUMP_SIGMA))
                    {
						// Send EN_KILLFOCUS message to edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_JUMP_SIGMA, 0,
							EN_KILLFOCUS));
					}
				}
                break;

				// Reset all jump parameters to defaults
				case IDC_JUMP_RESET:
				{
					// Set jump detection parameters to defaults
					sFPlot.length=max(5, (int)((fFreqData[2]-fFreqData[1]+1.0)/10.0));
					sFPlot.offset=0;
					sFPlot.method=SEQAVG;

					// Recalc sigma for new window length
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_JUMP_CALCSIGMA, NULL,0));

					// Set new limit
					sFPlot.limit=(float)(3.0*sigma);

					// Redisplay new length
					_snprintf(szBuffer, sizeof(szBuffer), "%d", sFPlot.length);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_JUMP_SIZE), szBuffer);

					// Redisplay new offset
					_snprintf(szBuffer, sizeof(szBuffer), "%d", sFPlot.offset);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_JUMP_OFFSET), szBuffer);

					// Redisplay new fractional freq limit
					_snprintf(szBuffer, sizeof(szBuffer), "%e", sFPlot.limit);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_JUMP_FREQ), szBuffer);

					// Redisplay new sigma factor limit
					_snprintf(szBuffer, sizeof(szBuffer), "%5.3f", sFPlot.limit/sigma);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_JUMP_SIGMA), szBuffer);

					// Show BLKAVG radiobutton state
					if(sFPlot.method==BLKAVG)
					{
						Button_SetCheck(GETHCTL(IDC_JUMP_BLKAVG), TRUE);
					}
					else
					{
						Button_SetCheck(GETHCTL(IDC_JUMP_BLKAVG), FALSE);
					}

					// Show SEQAVG radiobutton state
					if(sFPlot.method==SEQAVG)
					{
						Button_SetCheck(GETHCTL(IDC_JUMP_SEQAVG), TRUE);
					}
					else
					{
						Button_SetCheck(GETHCTL(IDC_JUMP_SEQAVG), FALSE);
					}

					// Enable offset for BLKAVG only
					if(sFPlot.method==BLKAVG)
					{
						// Enable offset
						_snprintf(szBuffer, sizeof(szBuffer), "%d", sFPlot.offset);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_JUMP_OFFSET), szBuffer);
						EnableWindow(GETHCTL(IDC_JUMP_OFFSET), TRUE);
					}
					else 
					{
						// Make visible offset blank (sFPlot.offset stays same)
						SetWindowText(GETHCTL(IDC_JUMP_OFFSET), "");

						// Disable offset
						EnableWindow(GETHCTL(IDC_JUMP_OFFSET), FALSE);
					}

					// Reset cusum checkbox state
					sFPlot.do_cusum=FALSE;
					Button_SetCheck(GETHCTL(IDC_JUMP_CUSUM), FALSE);

					// Reset confidence factor checkbox state
					sFPlot.do_conf=FALSE;
					Button_SetCheck(GETHCTL(IDC_JUMP_CONF), FALSE);

					// Reset alt color checkbox state
					sFPlot.data_color=FALSE;
					Button_SetCheck(GETHCTL(IDC_JUMP_ALTCOLOR), FALSE);
				}
				break;

				// Respond to OK buttom message
                case IDC_JUMP_ACCEPT:
                {
					// Close dialog box
                    EndDialog (hDlg, 0);
				}
                return TRUE;
				
               // Respond to esc key or cancel button
                case IDCANCEL:
                case IDC_JUMP_CANCEL:
                {
					// Restore original parameter values
					sFPlot.length=sFPrev.length;
					sFPlot.offset=sFPrev.offset;
					sFPlot.limit=sFPrev.limit;
					sFPlot.method=sFPrev.method;
					sFPlot.data_color=sFPrev.data_color;
					
					// Close dialog box
					EndDialog (hDlg, 0);
                }
                return TRUE;
            }
        }
        break;
	 }
     return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*                   Vibra Dialog Procedure                                  */
/*                                                                           */
/*      Revision record:                                                     */
/*          06/07/99    Created from Simple2.c                               */
/*			05/20/08	Added Sine FM type                                   */
/*			05/21/08	Copied from separate Vibra project into Stable32     */
/*						Added copy command                                   */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK VibraDlgProc(HWND hDlg, UINT msg, WPARAM wParam, LPARAM lParam)
{
	// Local macros for calc type
	#define SINE	0
	#define RANDOM	1
	#define FM		2

    // Local variables
	char szBuffer[BUFFER_SIZE];
	static int nClip;				// Size of szClipboard (chars)
	static BOOL bType=SINE;			// Analysis type
	static double fMHz=10;			// Frequency, MHz
	static double fGamma=1e-9;		// Gamma
	static double fG=1.0;			// G
	static double fFreq=100.0;		// Vib or mod freq
	static double fL=0.0;			// L(f)

	// Clipboard variables
	HGLOBAL hClipboard;				// Handle to clipboard text buffer
	LPSTR	szClipboard;			// Ptr to clipboard text string

    // Dialog box message switch statement
    switch(msg)
    {
        case WM_INITDIALOG:
        {
			// Set the vib type button states
			Button_SetCheck(GETHCTL(IDC_VIBRA_SINE), TRUE);
			Button_SetCheck(GETHCTL(IDC_VIBRA_RAND), FALSE);
			Button_SetCheck(GETHCTL(IDC_VIBRA_FM), FALSE);

			// Call the setup routine
			PostMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDC_VIBRA_SETUP,
				NULL, 0));

			// Calc
			PostMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDC_VIBRA_CALC,
				NULL, 0));

            return TRUE;
        }

 		case WM_COMMAND:
        {
            switch(GET_WM_COMMAND_ID(wParam, lParam))
            {
		       case IDC_VIBRA_HELP:
				{
					#if(0) // Obsolete - fixed help filename
					// Invoke help file
					strlcpy(szBuffer, "Stable32.chm::VIBRA.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/19/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::VIBRA.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					// This method is simpler and easier to change
					// for a different help type and eliminates need
					// for local text buffer
					CallHelp(hDlg, "VIBRA");
					#endif

					return 0;
				}

		       case IDC_VIBRA_SETUP:
				{
					// Set up the dialog box labels for the current vib type
					if(bType==SINE)
					{
						ShowWindow(GETHCTL(IDC_VIBRA_GAMMA), SW_SHOWNORMAL);
						SetWindowText(GETHCTL(IDC_VIBRA_GAMMALABEL),
							"Ga&mma, 1/g:");
						SetWindowText(GETHCTL(IDC_VIBRA_VIB),
							"Vibration");
						SetWindowText(GETHCTL(IDC_VIBRA_GLABEL),
							"&g peak:");
						SetWindowText(GETHCTL(IDC_VIBRA_FVIBLABEL),
							"Vib Freq, &Hz:");
						SetWindowText(GETHCTL(IDC_VIBRA_DBCLABEL),
							"L(f), dBc:");
						SetWindowText(GETHCTL(IDC_VIBRA_RESULTS),
							"Spurious Level");
					}
					else if(bType==RANDOM)// Random
					{
						ShowWindow(GETHCTL(IDC_VIBRA_GAMMA), SW_SHOWNORMAL);
						SetWindowText(GETHCTL(IDC_VIBRA_GAMMALABEL),
							"Ga&mma, 1/g:");
						SetWindowText(GETHCTL(IDC_VIBRA_VIB),
							"Vibration");
						SetWindowText(GETHCTL(IDC_VIBRA_GLABEL),
							"&g/Hz:");
						SetWindowText(GETHCTL(IDC_VIBRA_FVIBLABEL),
							"Vib Freq, &Hz:");
						SetWindowText(GETHCTL(IDC_VIBRA_DBCLABEL),
							"L(f), dBc/Hz:");
						SetWindowText(GETHCTL(IDC_VIBRA_RESULTS),
							"Phase Noise");
					}
					else // FM
					{
						ShowWindow(GETHCTL(IDC_VIBRA_GAMMA), SW_HIDE);
						SetWindowText(GETHCTL(IDC_VIBRA_GAMMALABEL),
							"");
						SetWindowText(GETHCTL(IDC_VIBRA_VIB),
							"FM Modulation");
						SetWindowText(GETHCTL(IDC_VIBRA_GLABEL),
							"&Dev, Hz peak:");
						SetWindowText(GETHCTL(IDC_VIBRA_FVIBLABEL),
							"Rate, &Hz:");
						SetWindowText(GETHCTL(IDC_VIBRA_DBCLABEL),
							"L(f), dBc:");
						SetWindowText(GETHCTL(IDC_VIBRA_RESULTS),
							"FM SB Level");
					}
					return 0;
				}

		       case IDC_VIBRA_RESULT:
				{
					// Calc result for the current vib type
					if(bType==SINE)
					{
						fL=20*log10((fMHz*1e6*fG*fGamma)/(2*fFreq));
					}
					else if(bType==RANDOM)
					{
						fL=20*log10((fMHz*1e6*sqrt(2*fG)*fGamma)/(2*fFreq));
					}
					else // FM
					{
						fL=20*log10((fG)/(2*fFreq));
					}
					return 0;
				}

			   case IDC_VIBRA_SHOW:
				{
					// Show the carrier freq value
					sprintf(szBuffer, "%5.3f", fMHz);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_VIBRA_MHZ), szBuffer);

					// Show the gamma value
					sprintf(szBuffer, "%5.4e", fGamma);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_VIBRA_GAMMA), szBuffer);

					// Show the g value
					sprintf(szBuffer, "%5.4e", fG);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_VIBRA_G), szBuffer);

					// Show the vib freq value
					sprintf(szBuffer, "%5.3f", fFreq);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_VIBRA_FVIB), szBuffer);

					// Show the result value
					if(fL<0.0)
					{
						sprintf(szBuffer, "%5.2f", fL);
						ShortenExp(szBuffer);
					}
					else // Invalid result
					{
						strcpy(szBuffer, "Invalid");
					}
					
					SetWindowText(GETHCTL(IDC_VIBRA_DBC), szBuffer);

					return 0;
				}

				case IDC_VIBRA_MHZ:
				{
					// Clear result
					SetWindowText(GETHCTL(IDC_VIBRA_DBC), "");

                    // Respond to edit control when it loses the input focus
                    // unless it loses it to the cancel button
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_VIBRA_CANCEL)))
                    {
                        // Get carrier freq
						GetWindowText(GETHCTL(IDC_VIBRA_MHZ), szBuffer,
							BUFFER_SIZE);
						if(atof(szBuffer)) // Ignore zero freq
						{
							fMHz=fabs(atof(szBuffer));
						}

						// Calc
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_VIBRA_CALC, NULL, 0));
					}

					return 0;
				}

				case IDC_VIBRA_GAMMA:
				{
					// Clear result
					SetWindowText(GETHCTL(IDC_VIBRA_DBC), "");

					// Respond to edit control when it loses the input focus
                    // unless it loses it to the cancel button
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_VIBRA_CANCEL)))
                    {
                        // Get gamma
						GetWindowText(GETHCTL(IDC_VIBRA_GAMMA), szBuffer,
							BUFFER_SIZE);
						if(atof(szBuffer)) // Ignore zero gamma
						{
							fGamma=fabs(atof(szBuffer));
						}

						// Calc
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_VIBRA_CALC, NULL, 0));
					}

					return 0;
				}

				case IDC_VIBRA_G:
				{
					// Clear result
					SetWindowText(GETHCTL(IDC_VIBRA_DBC), "");

                    // Respond to edit control when it loses the input focus
                    // unless it loses it to the cancel button
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_VIBRA_CANCEL)))
                    {
                        // Get g
						GetWindowText(GETHCTL(IDC_VIBRA_G), szBuffer,
							BUFFER_SIZE);
						if(atof(szBuffer)) // Ignore zero g
						{
							fG=fabs(atof(szBuffer));
						}

						// Calc
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_VIBRA_CALC, NULL, 0));
					}

					return 0;
				}

				case IDC_VIBRA_FVIB:
				{
					// Clear result
					SetWindowText(GETHCTL(IDC_VIBRA_DBC), "");

                    // Respond to edit control when it loses the input focus
                    // unless it loses it to the cancel button
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_VIBRA_CANCEL)))
                    {
                        // Get vib freq
						GetWindowText(GETHCTL(IDC_VIBRA_FVIB), szBuffer,
							BUFFER_SIZE);
						if(atof(szBuffer)) // Ignore zero vib freq
						{
							fFreq=fabs(atof(szBuffer));
						}

						// Calc
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_VIBRA_CALC, NULL, 0));
					}

					return 0;
				}

				case IDC_VIBRA_COPY:
				{
					// Allocate clipboard memory
					nClip=(10*80);
					hClipboard=GlobalAlloc(GMEM_DDESHARE,
						(DWORD)nClip);
					szClipboard=GlobalLock(hClipboard);

					if(bType==SINE)
					{
						// Heading
						strlcpy(szClipboard, "Sine Vibration:", nClip);
						strlcat(szClipboard, "\r\n", nClip);

						// Carrier Freq
						_snprintf(szBuffer, sizeof(szBuffer), "  Carrier Freq = %f MHz", fMHz);
						strlcat(szClipboard, szBuffer, nClip);
						strlcat(szClipboard, "\r\n", nClip);

						// Gamma
						_snprintf(szBuffer, sizeof(szBuffer), "  Gamma = %5.4e 1/g", fGamma);
						strlcat(szClipboard, szBuffer, nClip);
						strlcat(szClipboard, "\r\n", nClip);

						// G
						_snprintf(szBuffer, sizeof(szBuffer), "  g = %5.4e peak", fG);
						strlcat(szClipboard, szBuffer, nClip);
						strlcat(szClipboard, "\r\n", nClip);

						// Vib freq
						_snprintf(szBuffer, sizeof(szBuffer), "  Vib Freq = %5.4e Hz", fFreq);
						strlcat(szClipboard, szBuffer, nClip);
						strlcat(szClipboard, "\r\n", nClip);

						// L(f)
						_snprintf(szBuffer, sizeof(szBuffer), "  L(f) = %4.2f dBc", fL);
						strlcat(szClipboard, szBuffer, nClip);
						strlcat(szClipboard, "\r\n", nClip);

						// Shorten exponents
						ShortenExp(szBuffer);

						// Write info to clipboard
						GlobalUnlock(hClipboard);
						OpenClipboard(NULL);
						EmptyClipboard();
						SetClipboardData(CF_TEXT, hClipboard);
						CloseClipboard();
					}
					else if(bType==RANDOM)// Random
					{
						// Heading
						strlcpy(szClipboard, "Random Vibration:", nClip);
						strlcat(szClipboard, "\r\n", nClip);

						// Carrier Freq
						_snprintf(szBuffer, sizeof(szBuffer), "  Carrier Freq = %f MHz", fMHz);
						strlcat(szClipboard, szBuffer, nClip);
						strlcat(szClipboard, "\r\n", nClip);

						// Gamma
						_snprintf(szBuffer, sizeof(szBuffer), "  Gamma = %5.4e 1/g", fGamma);
						strlcat(szClipboard, szBuffer, nClip);
						strlcat(szClipboard, "\r\n", nClip);

						// G
						_snprintf(szBuffer, sizeof(szBuffer), "  Vib PSD = %5.4e g/Hz", fG);
						strlcat(szClipboard, szBuffer, nClip);
						strlcat(szClipboard, "\r\n", nClip);

						// Vib freq
						_snprintf(szBuffer, sizeof(szBuffer), "  Vib Freq = %5.4e Hz", fFreq);
						strlcat(szClipboard, szBuffer, nClip);
						strlcat(szClipboard, "\r\n", nClip);

						// L(f)
						_snprintf(szBuffer, sizeof(szBuffer), "  L(f) = %4.2f dBc/Hz", fL);
						strlcat(szClipboard, szBuffer, nClip);
						strlcat(szClipboard, "\r\n", nClip);

						// Shorten exponents
						ShortenExp(szBuffer);

						// Write info to clipboard
						GlobalUnlock(hClipboard);
						OpenClipboard(NULL);
						EmptyClipboard();
						SetClipboardData(CF_TEXT, hClipboard);
						CloseClipboard();
					}
					else // FM
					{
						// Heading
						strlcpy(szClipboard, "Sine FM:", nClip);
						strlcat(szClipboard, "\r\n", nClip);

						// Mod dev
						_snprintf(szBuffer, sizeof(szBuffer), "  Mod Dev = %5.4e Hz, peak", fG);
						strlcat(szClipboard, szBuffer, nClip);
						strlcat(szClipboard, "\r\n", nClip);

						// Mod rate
						_snprintf(szBuffer, sizeof(szBuffer), "  Mod Rate = %5.4e Hz", fFreq);
						strlcat(szClipboard, szBuffer, nClip);
						strlcat(szClipboard, "\r\n", nClip);

						// L(f)
						_snprintf(szBuffer, sizeof(szBuffer), "  L(f) = %4.2f dBc/Hz", fL);
						strlcat(szClipboard, szBuffer, nClip);
						strlcat(szClipboard, "\r\n", nClip);

						// Shorten exponents
						ShortenExp(szBuffer);

						// Write info to clipboard
						GlobalUnlock(hClipboard);
						OpenClipboard(NULL);
						EmptyClipboard();
						SetClipboardData(CF_TEXT, hClipboard);
						CloseClipboard();
					}

					return 0;
				}

                // Respond to CR in an edit control
				// Note: No button is a DEFPUSHBUTTON
                case IDOK:
                {
                    // Does carrier freq edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_VIBRA_MHZ))
                    {
						// Send EN_KILLFOCUS message to carrier freq edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_VIBRA_MHZ, 0,
							EN_KILLFOCUS));
					}

					// Does gamma edit control have focus?
					if(GetFocus()==GETHCTL(IDC_VIBRA_GAMMA))
					{
						// Send EN_KILLFOCUS message to gamma edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_VIBRA_GAMMA, 0,
							EN_KILLFOCUS));
					}

					// Does g edit control have focus?
					if(GetFocus()==GETHCTL(IDC_VIBRA_G))
					{
						// Send EN_KILLFOCUS message to g edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_VIBRA_G, 0,
							EN_KILLFOCUS));
					}

					// Does vib freq edit control have focus?
					if(GetFocus()==GETHCTL(IDC_VIBRA_FVIB))
					{
						// Send EN_KILLFOCUS message to vib freq edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_VIBRA_FVIB, 0,
							EN_KILLFOCUS));
					}
					
					return 0;
				}

				case IDC_VIBRA_CALC:
				{
					// Calc the results
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_VIBRA_RESULT, NULL, 0));

					// Show the results
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_VIBRA_SHOW, NULL, 0));

					return 0;
				}
				
				case IDCANCEL:
                case IDC_VIBRA_CANCEL:
                {
					// Close dialog box
					EndDialog (hDlg, 0);

					return 0;
                }

                case IDC_VIBRA_SINE:
                {
					// Set type
					bType=SINE;

					// Call the setup routine
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_VIBRA_SETUP, NULL, 0));

					// Calc
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_VIBRA_CALC, NULL, 0));

					return 0;
                }

                case IDC_VIBRA_RAND:
                {
					// Set type
					bType=RANDOM;

					// Call the setup routine
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_VIBRA_SETUP, NULL, 0));

					// Calc
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_VIBRA_CALC, NULL, 0));

					return 0;
                }

                case IDC_VIBRA_FM:
                {
					// Set type
					bType=FM;

					// Call the setup routine
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_VIBRA_SETUP, NULL, 0));

					// Calc
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_VIBRA_CALC, NULL, 0));

					return 0;
                }
                return TRUE;
            }
        }
        break;
    }

    return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*                   Details Dialog Procedure                                */
/*                                                                           */
/*      Function to display details about data file being opened             */
/*      Shows table of data columns and their numeric values as parsed       */
/*		for either first or last active (numeric) line of file               */
/*      Allows selection of columns and formats for date and time values     */
/*      to be converted into MJD timetags                                    */
/*                                                                           */
/*      Note: At present, supports 3 date and 2 time formats:                */
/*			US date w/ 2-difit year:	MM/DD/YY                             */
/*			US date w/ 4-digit year:	MM/DD/YYYY                           */
/*			ISO date:				    YYYY/MM/DD                           */
/*			Time w/o sec:				HH:MM                                */
/*          Time w/ sec:				HH:MM:SS                             */
/*                                                                           */
/*      Other possibilities include UNIX and Excel date numbers              */
/*      Month names, etc (e.g. Jan 1, 2008) would parse into multiple cols   */
/*      columns and are not suportable as-is                                 */
/*                                                                           */
/*      Revision record:                                                     */
/*          08/11/08    Created                                              */
/*			08/12/08	Working                                              */
/*			08/13/08	Working better - added more features                 */
/*			08/16/08	Added display button                                 */
/*			08/19/08	Added max col # bound                                */
/*			08/20/09	Added Comments button to display UNIX # comments     */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK DetailsDlgProc(HWND hDlg, UINT msg, WPARAM wParam, LPARAM lParam)
{
    // Local macros
	#define DSIZE 12	// Size of date format + EOS, largest is actually 8+1
	#define TSIZE 12	// Size of time format + EOS, largest is actually 8+1
	#define	CSIZE 32	// Size of MJD string in clipboard

	// Macro for the date and time formats
	// There are the indices into their dformat[] ans tformat[] string arrays
	// They are the same as the format except all upper case w/o symbols
	#define	MMDDYY		0	// US date
	#define	MMDDYYYY	1	// US date w/ 4-digit year
	#define YYYYMMDD	2	// ISO date
	#define	UNIX		3	// UNIX date based on Jan 1, 1970
							// Also applies to DOS and C/C++ Run Time Libraries
	#define	EXCEL		4	// Excel date format based on Jan 0, 1900
							// after non-existant Feb 29, 1900 leap year day
	#define	HHMM		0	// Hour & minutes
	#define	HHMMSS		1	// Hours, minutes & seconds

	// Local variables
	// Chars
	static char szBuffer1[BUFFER_SIZE+1];	// Col 1 text buffer
	static char szBuffer2[BUFFER_SIZE+1];	// Col 2 text buffer
	static char szBuffer3[BUFFER_SIZE+1];	// Col 3 text buffer
	static char szBuffer4[BUFFER_SIZE+1];	// Col 4 text buffer
	static char szHeader1[BUFFER_SIZE+1];	// Col 1 header text buffer
	static char szHeader2[BUFFER_SIZE+1];	// Col 2 header text buffer
	static char szHeader3[BUFFER_SIZE+1];	// Col 3 header text buffer
	static char szHeader4[BUFFER_SIZE+1];	// Col 4 header text buffer
	// char szBuffer[BUFFER_SIZE+1];			// Text buffer
	// Bools
	static BOOL bFirst=TRUE;				// Show first line flag
	// Ints
	int i;									// General index
	int j;									// Secondary index
	static int r;							// Row index
	static int d=0;							// Date column #
	static int t=0;							// Time column #
	static int dtype;						// Date format
	static int ttype;						// Time format
	static int cols=0;						// # columns
	// Doubles
	double val;								// Double value
	// For strptime
	struct tm sTM;							// Time structure
	int nMJD;								// Integer MJD
	static double fMJD;							// Complete MJD

	// Clipboard variables
	static HGLOBAL hClipboard;				// Handle to clipboard text buffer
	static LPSTR	szClipboard;			// Ptr to clipboard text string

	// List view column struts
	static LV_COLUMN col1;					// 1st list view column
	static LV_COLUMN col2;					// 2nd list view column
	static LV_COLUMN col3;					// 3rd list view column
	static LV_COLUMN col4;					// 4th list view column
	static LV_ITEM item;					// Column view item struct

	// String table for date formats
	// Order is per date format combo list box
	char dformat[][DSIZE] = { "%m/%d/%y", "%m/%d/%Y", "%Y/%m/%d", "UNIX", "Excel" };

	// String table for time formats
	// Order is per time format combo list box
	char tformat[][TSIZE] = { "%H:%M", "%H:%M:%S" };

	// Dialog box message switch statement
    switch(msg)
    {
		case WM_INITDIALOG:
		{
			// Show filename
			SetWindowText(GETHCTL(IDC_DETAILS_FILE), szFile);

			// Define 3 columns in the list box
			// Note that the columns are arranged 1,2,3,4
			// All are left justified
			// and headings are adjusted to center

			// Define left column 1
			strlcpy(szHeader1, "Column", sizeof(szHeader1));
			col1.mask=LVCF_FMT | LVCF_TEXT | LVCF_WIDTH;
			col1.fmt=LVCFMT_LEFT;
			col1.cx=50;
			col1.pszText=szHeader1;
			col1.cchTextMax=BUFFER_SIZE;
			col1.iSubItem=0;

			// Define 2nd column 2
			strlcpy(szHeader2, "              Raw Value", sizeof(szHeader2));
			col2.mask=LVCF_FMT | LVCF_TEXT | LVCF_WIDTH;
			col2.fmt=LVCFMT_LEFT;
			col2.cx=160;
			col2.pszText=szHeader2;
			col2.cchTextMax=BUFFER_SIZE;
			col2.iSubItem=0;

			// Define 3rd column 3
			strlcpy(szHeader3, "              Parsed Value", sizeof(szHeader3));
			col3.mask=LVCF_FMT | LVCF_TEXT | LVCF_WIDTH;
			col3.fmt=LVCFMT_LEFT;
			col3.cx=160;
			col3.pszText=szHeader3;
			col3.cchTextMax=BUFFER_SIZE;
			col3.iSubItem=0;

			// Define 4th column 4
			strlcpy(szHeader4, "              Numeric Value", sizeof(szHeader3));
			col4.mask=LVCF_FMT | LVCF_TEXT | LVCF_WIDTH;
			col4.fmt=LVCFMT_LEFT;
			col4.cx=160;
			col4.pszText=szHeader4;
			col4.cchTextMax=BUFFER_SIZE;
			col4.iSubItem=0;

			// Insert the columns
			// Insert 1st column (left)
			ListView_InsertColumn(GETHCTL(IDC_DETAILS_TABLE), 1, &col1);
			// Insert 2nd column
			ListView_InsertColumn(GETHCTL(IDC_DETAILS_TABLE), 2, &col2);
			// Insert 3rd column
			ListView_InsertColumn(GETHCTL(IDC_DETAILS_TABLE), 3, &col3);
			// Insert 4th column
			ListView_InsertColumn(GETHCTL(IDC_DETAILS_TABLE), 4, &col4);

			// There are 4 strings with the raw and parsed contents
			// of the first and last active (numeric) file rows
			// The parsed version has space delimiting only
			// TRACE_STR(szFirstRaw);
			// TRACE_STR(szFirstParse);
			// TRACE_STR(szRaw);
			// TRACE_STR(szParse);
			
			// Setup controls
			SendMessage(hDlg, WM_COMMAND,
					GET_WM_COMMAND_MPS(IDC_DETAILS_SETUP, NULL, 0));

			return TRUE;
        }

 		case WM_COMMAND:
        {
            switch(GET_WM_COMMAND_ID(wParam, lParam))
            {
				case IDC_DETAILS_HELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::MULTICOLUMN_DETAILS.HTM",
						HH_DISPLAY_TOPIC, 0L);

					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::MULTICOLUMN_DETAILS.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "MULTICOLUMN_DETAILS");
					#endif

					return 0;
				}

				// Respond to first radiobutton
				case IDC_DETAILS_FIRST:
				{
					// Set first flag
					bFirst=TRUE;

					// Show file info
					SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DETAILS_SHOW, NULL, 0));

					// Setup controls
					SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DETAILS_SETUP, NULL, 0));

					return 0;
				}

				// Respond to last radiobutton
				case IDC_DETAILS_LAST:
				{
					// Clear first flag
					bFirst=FALSE;

					// Show file info
					SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DETAILS_SHOW, NULL, 0));

					// Setup controls
					SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DETAILS_SETUP, NULL, 0));

					return 0;
				}

				// Respond to display button
				case IDC_DETAILS_DISPLAY:
				{
					strlcpy(szBuffer1, szNotepad, sizeof(szBuffer1));
					strlcat(szBuffer1, " ", sizeof(szBuffer1));
					strlcat(szBuffer1, szFile, sizeof(szBuffer1));
					WinExec(szBuffer1, SW_SHOWNORMAL);

					return 0;
				}

				// Respond to comments button
				case IDC_DETAILS_COMMENTS:
				{
					strlcpy(szBuffer1, szNotepad, sizeof(szBuffer1));
					strlcat(szBuffer1, " ", sizeof(szBuffer1));
					strlcat(szBuffer1, "Comments.txt", sizeof(szBuffer1));
					WinExec(szBuffer1, SW_SHOWNORMAL);

					return 0;
				}

				// Respond to date column selection
				case IDC_DETAILS_DATE:
				{
					// Get the new date column
					d=ComboBox_GetCurSel(GETHCTL(IDC_DETAILS_DATE));

					// Is a date column selected?
					if(d)
					{
						// Activate date format combo box if date column
						EnableWindow(GETHCTL(IDC_DETAILS_DATETYPE), TRUE);
						
						// Calculate MJD
						SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_DETAILS_CALCMJD, NULL, 0));
					}
					else
					{
						// Show no date/time or MJD
						SetWindowText(GETHCTL(IDC_DETAILS_MJD), "No date col selected");
						SetWindowText(GETHCTL(IDC_DETAILS_DATETIME), "");

						// Deactivate date format combo box if no date column
						EnableWindow(GETHCTL(IDC_DETAILS_DATETYPE), FALSE);
					}

					return 0;
				}

				// Respond to time column selection
				case IDC_DETAILS_TIME:
				{
					// Get the new time column
					t=ComboBox_GetCurSel(GETHCTL(IDC_DETAILS_TIME));

					// Is a time column selected?
					if(t)
					{
						// Activate date format combo box if date column
						EnableWindow(GETHCTL(IDC_DETAILS_TIMETYPE), TRUE);

					}
					else
					{
						EnableWindow(GETHCTL(IDC_DETAILS_TIMETYPE), FALSE);
					}

					// Calculate MJD
					SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DETAILS_CALCMJD, NULL, 0));

					return 0;
				}

				// Respond to date format selection
				case IDC_DETAILS_DATETYPE:
				{
					// Get the new date format
					dtype=ComboBox_GetCurSel(GETHCTL(IDC_DETAILS_DATETYPE));

					// Disable time boxes if not applicable
					if(dtype==UNIX || dtype==EXCEL)
					{
						EnableWindow(GETHCTL(IDC_DETAILS_TIME), FALSE);
					}
					else
					{
						EnableWindow(GETHCTL(IDC_DETAILS_TIME), TRUE);
					}
					
					// Calculate MJD
					SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DETAILS_CALCMJD, NULL, 0));

					return 0;
				}

				// Respond to time format selection
				case IDC_DETAILS_TIMETYPE:
				{
					// Calculate MJD
					SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DETAILS_CALCMJD, NULL, 0));

					return 0;
				}

				// Respond to copy button
				case IDC_DETAILS_COPY:
				{
					// Allocate clipboard memory
					hClipboard=GlobalAlloc(GMEM_DDESHARE,(DWORD) CSIZE);
					szClipboard=GlobalLock(hClipboard);

					_snprintf(szClipboard, CSIZE, "%12.7f", fMJD);

					GlobalUnlock(hClipboard);
						OpenClipboard(NULL);
						EmptyClipboard();
						SetClipboardData(CF_TEXT, hClipboard);
						CloseClipboard();

					return 0;
				}

				// Subroutine to show file info
				case IDC_DETAILS_SHOW:
				{
					// Note: The ListView_InsertItem macro is used to insert a new row
					// which is inserted prior to the iItem index
					// So the iItem member is the zero-based row # to insert at (above) 
					// An iItem index = 0 inserts a new row above the others
					// ListView_InsertItem can't insert a subitem, so its iSubItem must be 0
					// Use ListView_SetItem to insert subitem text
					// The iSubItem member is the zero-based column #
					// counting from original leftmost column

					// For testing
					// TRACE_INT(nDataFileSize);
					
					// Clear table
					ListView_DeleteAllItems(GETHCTL(IDC_DETAILS_TABLE));

					cols=0;

					if(bFirst) // First line
					{
						// Ignore leading whitespace
						i=0;
						while(i<(int)strlen(szFirstParse))
						{
							if(isspace(szFirstParse[i]))
							{
								i++;
							}
							else
							{
								break;
							}
						}

						// Put column #s, raw and parsed input items into table
						// i=0; // Start after leading whitespace
						r=0;
						while(1)
						{
							// At start of field
							// Scan for next space delimiter or EOS, etc.
							j=0;
							while((szFirstParse[i]!=' ')&&(!iscntrl(szFirstParse[i])))
							{
								// Copy characters of current item
								szBuffer3[j]=szFirstParse[i];
								szBuffer2[j]=szFirstRaw[i];

								// Exclude characters like CR and LF
								if(szBuffer3[j]=='\r' || szBuffer3[j]=='\n' || szBuffer3[j]=='\f')
								{
									szBuffer3[j]=' ';
								}
								if(szBuffer2[j]=='\r' || szBuffer2[j]=='\n' || szBuffer2[j]=='\f')
								{
									szBuffer2[j]=' ';
								}

								// Increment indices
								i++;
								j++;
							}

							cols++;

							// Ignore cols > MAX_NUM_COLS
							if(cols>MAX_NUM_COLS)
							{
								cols--;
								break;
							}
							
							// Insert EOS for this item
							szBuffer3[j]='\0';
							szBuffer2[j]='\0';

							// Don't display a blank line
							// Not sure why that can happen, but this prevents it
							if(strlen(szBuffer2)==0)
							{
								break;
							}

							// Put column # into 1st column of table row
							item.mask=LVIF_TEXT;
							item.iItem=r;
							item.iSubItem=0;
							item.state=0;
							item.stateMask=0;
							_snprintf(szBuffer1, sizeof(szBuffer1), "%d",r+1);
							item.pszText=szBuffer1;
							item.cchTextMax=BUFFER_SIZE;
							item.iImage=0;
							item.lParam=0;

							// Insert item
							ListView_InsertItem(GETHCTL(IDC_DETAILS_TABLE), &item);

							// Put parsed item into 2nd column of table row
							item.mask=LVIF_TEXT;
							item.iItem=r;
							item.iSubItem=1;
							item.state=0;
							item.stateMask=0;
							item.pszText=szBuffer2;
							item.cchTextMax=BUFFER_SIZE;
							item.iImage=0;
							item.lParam=0;

							// Insert item
							ListView_SetItem(GETHCTL(IDC_DETAILS_TABLE), &item);

							// Put parsed item into 3rd column of table row
							item.mask=LVIF_TEXT;
							item.iItem=r;
							item.iSubItem=2;
							item.state=0;
							item.stateMask=0;
							item.pszText=szBuffer3;
							item.cchTextMax=BUFFER_SIZE;
							item.iImage=0;
							item.lParam=0;

							// Insert item
							ListView_SetItem(GETHCTL(IDC_DETAILS_TABLE), &item);

							// Put numeric item into 4th column of table row
							item.mask=LVIF_TEXT;
							item.iItem=r;
							item.iSubItem=3;
							item.state=0;
							item.stateMask=0;
							item.pszText=szBuffer3;
							val=atof(szBuffer3);
							_snprintf(szBuffer3, sizeof(szBuffer3),"%20.15e", val);
							ShortenExp(szBuffer3);
							item.cchTextMax=BUFFER_SIZE;
							item.iImage=0;
							item.lParam=0;

							// Insert item
							ListView_SetItem(GETHCTL(IDC_DETAILS_TABLE), &item);

							// Now at space or EOS, etc.
							// Quit if we're at EOS, etc.
							if(iscntrl(szFirstParse[i]))
							{
								break;
							}

							// Now at space
							// Move through any more spaces in this place
							while((szFirstParse[i+1]==' ')||(iscntrl(szFirstParse[i+1])))
							{
								i++;
							}

							// Now at last space or EOS, etc.
							// Quit if we're at EOS, etc.
							if(iscntrl(szFirstParse[i]))
							{
								break;
							}

							// Now at last space between fields
							// Increment row # and szFirstParse index
							r++;
							i++;
							
							// Now at start of next field
						}
					}
					else // Last line
					{
						// Ignore leading whitespace
						i=0;
						while(i<(int)strlen(szParse))
						{
							if(isspace(szParse[i]))
							{
								i++;
							}
							else
							{
								break;
							}
						}

						// Put column #s, raw and parsed input items into table
						// i=0; // Start after leading whitespace
						r=0;
						while(1)
						{
							// At start of field
							// Scan for next space delimiter or EOS, etc.
							j=0;
							while((szParse[i]!=' ')&&(!iscntrl(szParse[i])))
							{
								// Copy characters of current item
								szBuffer3[j]=szParse[i];
								szBuffer2[j]=szRaw[i];

								// Exclude characters like CR and LF
								if(szBuffer3[j]=='\r' || szBuffer3[j]=='\n' || szBuffer3[j]=='\f')
								{
									szBuffer3[j]=' ';
								}
								if(szBuffer2[j]=='\r' || szBuffer2[j]=='\n' || szBuffer2[j]=='\f')
								{
									szBuffer2[j]=' ';
								}

								// Increment indices
								i++;
								j++;
							}

							cols++;
							
							// Insert EOS for this item
							szBuffer3[j]='\0';
							szBuffer2[j]='\0';

							// Don't display a blank line
							// Not sure why that can happen, but this prevents it
							if(strlen(szBuffer2)==0)
							{
								break;
							}

							// Put column # into 1st column of table row
							item.mask=LVIF_TEXT;
							item.iItem=r;
							item.iSubItem=0;
							item.state=0;
							item.stateMask=0;
							_snprintf(szBuffer1, sizeof(szBuffer1), "%d",r+1);
							item.pszText=szBuffer1;
							item.cchTextMax=BUFFER_SIZE;
							item.iImage=0;
							item.lParam=0;

							// Insert item
							ListView_InsertItem(GETHCTL(IDC_DETAILS_TABLE), &item);

							// Put parsed item into 2nd column of table row
							item.mask=LVIF_TEXT;
							item.iItem=r;
							item.iSubItem=1;
							item.state=0;
							item.stateMask=0;
							item.pszText=szBuffer2;
							item.cchTextMax=BUFFER_SIZE;
							item.iImage=0;
							item.lParam=0;

							// Insert item
							ListView_SetItem(GETHCTL(IDC_DETAILS_TABLE), &item);

							// Put parsed item into 3rd column of table row
							item.mask=LVIF_TEXT;
							item.iItem=r;
							item.iSubItem=2;
							item.state=0;
							item.stateMask=0;
							item.pszText=szBuffer3;
							item.cchTextMax=BUFFER_SIZE;
							item.iImage=0;
							item.lParam=0;

							// Insert item
							ListView_SetItem(GETHCTL(IDC_DETAILS_TABLE), &item);

							// Put numeric item into 4th column of table row
							item.mask=LVIF_TEXT;
							item.iItem=r;
							item.iSubItem=3;
							item.state=0;
							item.stateMask=0;
							item.pszText=szBuffer3;
							val=atof(szBuffer3);
							_snprintf(szBuffer3, sizeof(szBuffer3),"%20.15e", val);
							ShortenExp(szBuffer3);
							item.cchTextMax=BUFFER_SIZE;
							item.iImage=0;
							item.lParam=0;

							// Insert item
							ListView_SetItem(GETHCTL(IDC_DETAILS_TABLE), &item);

							// Now at space or EOS, etc.
							// Quit if we're at EOS, etc.
							if(iscntrl(szParse[i]))
							{
								break;
							}

							// Now at space
							// Move through any more spaces in this place
							while((szParse[i+1]==' ')||(iscntrl(szParse[i+1])))
							{
								i++;
							}

							// Now at space or EOS, etc.
							// Quit if we're at EOS, etc.
							if(iscntrl(szParse[i]))
							{
								break;
							}

							// Now at last space between fields
							// Increment row # and szParse index
							r++;
							i++;

							// Now at start of next field
						}
					}

					return 0;
				}

				// Subroutine to setup controls
				case IDC_DETAILS_SETUP:
				{
					// Show file info
					SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DETAILS_SHOW, NULL, 0));

					// Set state of line radiobuttons
					Button_SetCheck(GETHCTL(IDC_DETAILS_FIRST), bFirst);
					Button_SetCheck(GETHCTL(IDC_DETAILS_LAST), !bFirst);

					// Show # columns of data = # rows of table
					sprintf(szBuffer1, "# Cols = %d", cols);
					SetWindowText(GETHCTL(IDC_DETAILS_COLS), szBuffer1);

					// Show # rows of data in file
					sprintf(szBuffer1, "# Rows = %d", nDataFileSize);
					SetWindowText(GETHCTL(IDC_DETAILS_ROWS), szBuffer1);

					// Show # rejected rows of data in file
					sprintf(szBuffer1, "(%d Rejected)", nDataFileRejects);
					SetWindowText(GETHCTL(IDC_DETAILS_REJECTS), szBuffer1);

					// Show delimiters
					if(bComma)
					{
						SetWindowText(GETHCTL(IDC_DETAILS_DELIM), "Spaces\nTabs\nBars");
					}
					else // US
					{
						SetWindowText(GETHCTL(IDC_DETAILS_DELIM), "Spaces\nCommas\nTabs\nBars");
					}

					// Show decimal point type
					if(bComma)
					{
						SetWindowText(GETHCTL(IDC_DETAILS_DP), "European (,)");
					}
					else // US
					{
						SetWindowText(GETHCTL(IDC_DETAILS_DP), "US (.)");
					}

					// Put column #s into date column combo drop list box
					j=ComboBox_ResetContent(GETHCTL(IDC_DETAILS_DATE));
					j=ComboBox_InsertString(GETHCTL(IDC_DETAILS_DATE), 0, "None");
					for(i=1; i<=cols; i++)
					{
						_snprintf(szBuffer1, sizeof(szBuffer1), "%d", i);
						j=ComboBox_InsertString(GETHCTL(IDC_DETAILS_DATE), i,
									szBuffer1);
					}

					// Put column #s into time column combo drop list boxe
					j=ComboBox_ResetContent(GETHCTL(IDC_DETAILS_TIME));
					j=ComboBox_InsertString(GETHCTL(IDC_DETAILS_TIME), 0, "None");
					for(i=1; i<=cols; i++)
					{
						_snprintf(szBuffer1, sizeof(szBuffer1), "%d", i);
						j=ComboBox_InsertString(GETHCTL(IDC_DETAILS_TIME), i,
									szBuffer1);
					}

					// Select None columns
					j=ComboBox_SetCurSel(GETHCTL(IDC_DETAILS_DATE), 0);
					j=ComboBox_SetCurSel(GETHCTL(IDC_DETAILS_TIME), 0);

					// Put date formats into date format combo drop list box
					// Note: Add new date formats here and in dformat[]
					j=ComboBox_ResetContent(GETHCTL(IDC_DETAILS_DATETYPE));
					j=ComboBox_InsertString(GETHCTL(IDC_DETAILS_DATETYPE), 0, "Excel");
					j=ComboBox_InsertString(GETHCTL(IDC_DETAILS_DATETYPE), 0, "UNIX");
					j=ComboBox_InsertString(GETHCTL(IDC_DETAILS_DATETYPE), 0, "YYYY/MM/DD");
					j=ComboBox_InsertString(GETHCTL(IDC_DETAILS_DATETYPE), 0, "MM/DD/YYYY");
					j=ComboBox_InsertString(GETHCTL(IDC_DETAILS_DATETYPE), 0, "MM/DD/YY");

					// Put time formats into time format combo drop list box
					// Note: Add new time formats here and in tformat[]
					j=ComboBox_ResetContent(GETHCTL(IDC_DETAILS_TIMETYPE));
					j=ComboBox_InsertString(GETHCTL(IDC_DETAILS_TIMETYPE), 0, "HH:MM:SS");
					j=ComboBox_InsertString(GETHCTL(IDC_DETAILS_TIMETYPE), 0, "HH:MM");

					// Select first formats
					j=ComboBox_SetCurSel(GETHCTL(IDC_DETAILS_DATETYPE), 0);
					j=ComboBox_SetCurSel(GETHCTL(IDC_DETAILS_TIMETYPE), 0);

					// Disable format combo boxs (no columns selected)
					EnableWindow(GETHCTL(IDC_DETAILS_DATETYPE), FALSE);
					EnableWindow(GETHCTL(IDC_DETAILS_TIMETYPE), FALSE);

					// Disable copy button
					EnableWindow(GETHCTL(IDC_DETAILS_COPY), FALSE);

					// Show no date and MJD
					SetWindowText(GETHCTL(IDC_DETAILS_DATETIME), "No date col selected");
					SetWindowText(GETHCTL(IDC_DETAILS_MJD), "");

					// Disable comments button if no comments in file
					if(nComments)
					{
						EnableWindow(GETHCTL(IDC_DETAILS_COMMENTS), TRUE);
					}
					else
					{
						EnableWindow(GETHCTL(IDC_DETAILS_COMMENTS), FALSE);
					}

					return 0;
				}

				// Subroutine to calc and display MJD
				case IDC_DETAILS_CALCMJD:
				{
					if(dtype==UNIX) // UNIX/DOS/C time() format
									// sec after Jan 1, 1970
					{
						// MJD is UNIX time() in seconds (as double)
						// divided by 86400. seconds per day
						// plus 40587. days
						// This conversion involves only one field
	
						// Get the selected date column
						// which includes fractional day, if any
						d=ComboBox_GetCurSel(GETHCTL(IDC_DETAILS_DATE));

						// Get date column value using ListView_GetItemText()
						// 1st arg is handle of the list control
						// 2nd arg is zero-based row #
						// 3rd arg is zero-based column #
						// 4th arg is pointer to string to receive text
						// 5th arg is max allowable size of received string
						// We want the 2nd column (1) with the raw value
						ListView_GetItemText(GETHCTL(IDC_DETAILS_TABLE),
							d-1, 1, szBuffer1, sizeof(szBuffer1));

						// Calc MJD
						fMJD=atof(szBuffer1);
						fMJD/=86400.;
						fMJD+=40587.;
					}
					else if(dtype==EXCEL) // Excel date/time format
										  // days after Jan 1 1900
					{
						// MJD is Excel day/fractional day plus 15018
						// after non-existant Feb 29, 1900 leap year day
						// so add 15018. to Excel day/fractional day (as float)
						// to get MJD/fractional MJD
						// This conversion involves only one field

						// Get the selected date column
						// which includes fractional day, if any
						d=ComboBox_GetCurSel(GETHCTL(IDC_DETAILS_DATE));

						// Get date column value using ListView_GetItemText()
						// 1st arg is handle of the list control
						// 2nd arg is zero-based row #
						// 3rd arg is zero-based column #
						// 4th arg is pointer to string to receive text
						// 5th arg is max allowable size of received string
						// We want the 2nd column (1) with the raw value
						ListView_GetItemText(GETHCTL(IDC_DETAILS_TABLE),
							d-1, 1, szBuffer1, sizeof(szBuffer1));

						// Calc MJD
						fMJD=atof(szBuffer1);
						fMJD+=15018.;
					}
					else // Calendar date format
					{
						// Get the selected date column
						d=ComboBox_GetCurSel(GETHCTL(IDC_DETAILS_DATE));

						// Get date column value using ListView_GetItemText()
						// 1st arg is handle of the list control
						// 2nd arg is zero-based row #
						// 3rd arg is zero-based column #
						// 4th arg is pointer to string to receive text
						// 5th arg is max allowable size of received string
						// We want the 2nd column (1) with the raw value
						ListView_GetItemText(GETHCTL(IDC_DETAILS_TABLE),
							d-1, 1, szBuffer1, sizeof(szBuffer1));

						// Get the selected time column
						d=ComboBox_GetCurSel(GETHCTL(IDC_DETAILS_TIME));

						// Get time column value using ListView_GetItemText()
						// We want the 2nd column (1) with the raw value
						ListView_GetItemText(GETHCTL(IDC_DETAILS_TABLE),
							d-1, 1, szBuffer2, sizeof(szBuffer2));

						// Add time to date and time string if time column selected
						if(ComboBox_GetCurSel(GETHCTL(IDC_DETAILS_TIME)))
						{
							// Compose date and time string
							strncat(szBuffer1, " ", sizeof(szBuffer1));
							strncat(szBuffer1, szBuffer2, sizeof(szBuffer1));
						}

						// Show date & time
						SetWindowText(GETHCTL(IDC_DETAILS_DATETIME), szBuffer1);

						// Get the selected time format
						ttype=ComboBox_GetCurSel(GETHCTL(IDC_DETAILS_TIMETYPE));
						strncpy(szBuffer3, tformat[ttype], sizeof(szBuffer3));

						// Get the selected date format
						dtype=ComboBox_GetCurSel(GETHCTL(IDC_DETAILS_DATETYPE));
						strncpy(szBuffer2, dformat[dtype], sizeof(szBuffer2));

						// Compose conversion format
						// Add time format to conversion string if time column selected
						if(ComboBox_GetCurSel(GETHCTL(IDC_DETAILS_TIME)))
						{
							strncat(szBuffer2, " ", sizeof(szBuffer2));
							strncat(szBuffer2, szBuffer3, sizeof(szBuffer2));
						}

						#if(0) // For testing
						strcpy(szBuffer3, szBuffer1);
						// Add time format if time column selected
						if(ComboBox_GetCurSel(GETHCTL(IDC_DETAILS_TIME)))
						{
							strcat(szBuffer3, " ");
							strcat(szBuffer3, szBuffer2);
						}
						SetWindowText(GETHCTL(IDC_DETAILS_FILE), szBuffer3);
						#endif

						// Zero time elements in case they are not parsed
						sTM.tm_sec=0;
						sTM.tm_min=0;
						sTM.tm_hour=0;

						// Perform conversion
						strptime(szBuffer1, szBuffer2, &sTM);

						#if(0) // For testing
						// Show day, month and year
						// tm.mday is 1-31
						// tm_mon is 0-11
						// tm_year is 1900=0
						strcat(szBuffer3, " ");
						strcat(szBuffer3, itoa(sTM.tm_mday, szBuffer1, 10));
						strcat(szBuffer3, " ");
						strcat(szBuffer3, itoa(sTM.tm_mon, szBuffer1, 10));
						strcat(szBuffer3, " ");
						strcat(szBuffer3, itoa(sTM.tm_year, szBuffer1, 10));
						// Show hour, minute and second
						// tm.hour is 0-23
						// tm_min is 0-59
						// tm_sec is 0-59
						strcat(szBuffer3, " ");
						strcat(szBuffer3, itoa(sTM.tm_hour, szBuffer1, 10));
						strcat(szBuffer3, " ");
						strcat(szBuffer3, itoa(sTM.tm_min, szBuffer1, 10));
						strcat(szBuffer3, " ");
						strcat(szBuffer3, itoa(sTM.tm_sec, szBuffer1, 10));
						SetWindowText(GETHCTL(IDC_DETAILS_FILE), szBuffer3);
						#endif

						// If time format doesn't includes seconds (e.g., HH:MM)
						// the zero the seconds
						// even though data itself may have included them
						if(ttype==HHMM)
						{
							sTM.tm_sec=0;
						}
						
						// Convert calendar date and time to integer plus fractional MJD
						// Date to integer MJD - not that month # is incremented
						nMJD=DateToMJD(sTM.tm_mday, sTM.tm_mon+1, sTM.tm_year+1900);
						// TRACE_INT(nMJD);

						// Calc the fractional MJD
						fMJD=(sTM.tm_hour/24.)+(sTM.tm_min/1440.)+(sTM.tm_sec/86400.);

						// Combine them
						fMJD+=(double)nMJD;
					}

					// Show complete MJD
					sprintf(szBuffer1, "%12.7f", fMJD);
					SetWindowText(GETHCTL(IDC_DETAILS_MJD), szBuffer1);
					
					// Enable copy button
					EnableWindow(GETHCTL(IDC_DETAILS_COPY), TRUE);

					return 0;
				}

				case IDCANCEL:
                case IDC_DETAILS_CANCEL:
                {
					// Close dialog box
					EndDialog (hDlg, 0);

					return 0;
                }

                return TRUE;
            }
        }
        break;
    }

    return FALSE;
}

