/*****************************************************************************/
/*                                                                           */
/*                            STABLE_M.C                                     */
/*                                                                           */
/*      Stable Windows 95/NT Dialog Box Functions (3rd Group)                */
/*                                                                           */
/*      TimetagDlgProc()                                                     */
/*      RegularizeDlgProc()                                                  */
/*      ClearDlgProc()                                                       */
/*      MulticolumnDlgProc()                                                 */
/*		MultiDlgProc()                                                       */
/*      DomainDlgProc()                                                      */
/*      RunDlgProc()                                                         */
/*      GetRunData()                                                         */
/*      ReadDlgProc()                                                        */
/*      CornDlgProc()                                                        */
/*      GetSigmaData()                                                       */
/*      GetCornData()                                                        */
/*      GetCornResults()                                                     */
/*      PrintDataDlgProc()                                                   */
/*      AbortProc()                                                          */
/*      PrintDlgProc()                                                       */
/*      PartDlgProc()                                                        */
/*		FilterDlgProc()                                                      */
/*                                                                           */
/*      Revision record:                                                     */
/*          10/12/96    Created from STABLE_E.C w/o editing functions        */
/*          04/11/97    Changed to NewAverageFreqData() and                  */
/*                      NewAveragePhaseData() usage                          */
/*          05/04/97    Changed to more FrequenC DLL usage                   */
/*          06/29/97    Use GET_WM_COMMAND_ID, etc. WIN32 compatibility      */
/*                      macros to process WM_COMMAND messages:               */
/*                      wParam <- GET_WM_COMMAND_ID(wParam, lParam)          */
/*                      HIWORD(lParam) <- GET_WM_COMMAND_CMD(wParam, lParam) */
/*                      Replaced WORD with UINT                              */
/*          06/30/97    Replaced FAR PASCAL _export with WINAPI              */
/*                      Replaced MoveTo() with MoveToEx()                    */
/*			07/11/97	Made numerous Win32 compatibility changes            */
/*			07/25/97	Made changes for Visual C++ compilation w/o warnings */
/*			12/23/97	Made changes for BC Win32 compliation w/o warnings   */
/*			01/16/98	Added ShortenExp() usage for MSC VC++                */
/*			12/11/99	Added MultiDlgProc() for # columns > 8               */
/*			08/17/01	Added CornDlgProc()                                  */
/*			08/18/01	Added GetCornData()                                  */
/*			07/23/07    Changed to safe string functions                     */
/*          07/17/08	Added FilterDlgProc()                                */
/*                                                                           */
/* (c) 1996-2008  W. Riley  Hamilton Technical Services  All Rights Reserved */
/*                                                                           */
/*****************************************************************************/

#define STRICT                  // For Win32 compatibility

#include "stable_w.h"           // Stable/Win include file

// #define LOGGING					// For test logging

// File macros
#define SEC_PER_DAY   86400.

#ifndef LITE_VER
/*****************************************************************************/
/*                                                                           */
/*                   Timetag Dialog Procedure                                */
/*                                                                           */
/*  Procedure to generate timetag data                                       */
/*                                                                           */
/*                                                                           */
/*      Revision record:                                                     */
/*          09/27/96    Changed default to 1                                 */
/*          09/27/96    Added code to activate/deactivate increment edit box */
/*          10/29/96    Added edit box CR logic                              */
/*          02/24/97    Increased precision of start value                   */
/*			05/15/02	Added setting of plot scale flag                     */
/*			05/16/01	Added setting of fTagScale                           */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK TimetagDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local macros
	#define SECONDS_UNITS 0
	#define DAYS_UNITS    1
	#define OTHER_UNITS   3

	// Local variables
	// Chars
	char szBuffer[BUFFER_SIZE+1];       // Text buffer
	// Ints
	int nSize;                          // Size of active timetag array
	int i;                              // Index
	static int nUnits=SECONDS_UNITS;    // Units code
	// F_TYPEs
	F_TYPE fTau;                        // Tau value
	F_TYPE *fNew;                       // Temporary timetag array pointer
	static F_TYPE fStart=1.0;           // Timetag start value
	F_TYPE fIncrement;                  // Timetag increment

    switch(message)
    {
        case WM_INITDIALOG:
        {
            // Write prompt message
            WritePromptMessage(TB_TIMETAG);

            // Initialize the controls
            switch(nUnits)
            {
                case SECONDS_UNITS:
                {
                    // Initialize the units radio buttons to Seconds
                    Button_SetCheck(GETHCTL(IDC_TIMETAG_SECS), TRUE);
					Button_SetCheck(GETHCTL(IDC_TIMETAG_DAYS), FALSE);
                    Button_SetCheck(GETHCTL(IDC_TIMETAG_OTHER), FALSE);

                    // Mark the Increment control as N/A
                    LoadString(hInst, IDS_MESSAGE_NA, szBuffer, BUFFER_SIZE);
                    SetWindowText(GETHCTL(IDC_TIMETAG_INC), szBuffer);

                    // Deactivate increment edit box & label
                    EnableWindow(GETHCTL(IDC_TIMETAG_INC), FALSE);
                    EnableWindow(GETHCTL(IDC_TIMETAG_INCLABEL), FALSE);
                }
                break;

                case DAYS_UNITS:
                {
                    // Initialize the units radio buttons to Days
                    Button_SetCheck(GETHCTL(IDC_TIMETAG_SECS), FALSE);
                    Button_SetCheck(GETHCTL(IDC_TIMETAG_DAYS), TRUE);
                    Button_SetCheck(GETHCTL(IDC_TIMETAG_OTHER), FALSE);

                    // Mark the Increment control as N/A
                    LoadString(hInst, IDS_MESSAGE_NA, szBuffer, BUFFER_SIZE);
                    SetWindowText(GETHCTL(IDC_TIMETAG_INC), szBuffer);

                    // Deactivate increment edit box
                    EnableWindow(GETHCTL(IDC_TIMETAG_INC), FALSE);
                    EnableWindow(GETHCTL(IDC_TIMETAG_INCLABEL), FALSE);
                }
				break;

                case OTHER_UNITS:
                {
                    // Initialize the units radio buttons to Other
                    Button_SetCheck(GETHCTL(IDC_TIMETAG_SECS), FALSE);
                    Button_SetCheck(GETHCTL(IDC_TIMETAG_DAYS), FALSE);
					Button_SetCheck(GETHCTL(IDC_TIMETAG_OTHER), TRUE);

                    if(bDataType==FREQ_DATA)
                    {
                        GetWindowText(hwndFreqTau, szBuffer, BUFFER_SIZE);
                    }
                    else
                    {
                        GetWindowText(hwndPhaseTau, szBuffer, BUFFER_SIZE);
                    }

                    // Set increment to tau
                    SetWindowText(GETHCTL(IDC_TIMETAG_INC), szBuffer);

                    // Activate increment edit box
                    EnableWindow(GETHCTL(IDC_TIMETAG_INC), TRUE);
                    EnableWindow(GETHCTL(IDC_TIMETAG_INCLABEL), TRUE);
                }
                break;
			}

            // Initialize the data type radio buttons
            Button_SetCheck(GETHCTL(IDC_TIMETAG_PHASE), !bDataType);
            Button_SetCheck(GETHCTL(IDC_TIMETAG_FREQ), bDataType);

            // Disable data type button for which there is no data
            if(!bFreqData)
            {
                EnableWindow(GETHCTL(IDC_TIMETAG_FREQ), FALSE);
            }

            if(!bPhaseData)
            {
				EnableWindow(GETHCTL(IDC_TIMETAG_PHASE), FALSE);
            }

			// Initialize the start value to 1
			_snprintf(szBuffer, sizeof(szBuffer), "%17.8e", fStart);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_TIMETAG_START), szBuffer);

			return TRUE;
		}

        case WM_COMMAND:
        {
            switch(GET_WM_COMMAND_ID(wParam, lParam))
            {
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::TIMETAGS_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::TIMETAGS_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "TIMETAGS_FUNCTION");
					#endif
                }
                break;

                // Detect Seconds button change
                case IDC_TIMETAG_SECS:
                {
                    if(GET_WM_COMMAND_CMD(wParam, lParam)==BN_CLICKED)
                    {
                        // Mark the Increment control as N/A
						LoadString(hInst, IDS_MESSAGE_NA, szBuffer,
							BUFFER_SIZE);
						SetWindowText(GETHCTL(IDC_TIMETAG_INC),	szBuffer);

                        // Deactivate increment edit box
                        EnableWindow(GETHCTL(IDC_TIMETAG_INC), FALSE);
						EnableWindow(GETHCTL(IDC_TIMETAG_INCLABEL),
                            FALSE);

                        // Save the units type
                        nUnits=SECONDS_UNITS;
                    }
                }
                break;

                // Detect Days button change
				case IDC_TIMETAG_DAYS:
                {
                    if(GET_WM_COMMAND_CMD(wParam, lParam)==BN_CLICKED)
                    {
                        LoadString(hInst, IDS_MESSAGE_NA, szBuffer,
                            BUFFER_SIZE);
                        // Mark the Increment control as N/A
						SetWindowText(GETHCTL(IDC_TIMETAG_INC),	szBuffer);

                        // Deactivate increment edit box
                        EnableWindow(GETHCTL(IDC_TIMETAG_INC), FALSE);
                        EnableWindow(GETHCTL(IDC_TIMETAG_INCLABEL),
                            FALSE);

                        // Save the units type
                        nUnits=DAYS_UNITS;
                    }
                }
                break;

                // Detect Other button change
                case IDC_TIMETAG_OTHER:
                {
					if(GET_WM_COMMAND_CMD(wParam, lParam)==BN_CLICKED)
                    {
                        // Get the tau value
                        if(bDataType)
						{
                            GetWindowText(hwndFreqTau, szBuffer, BUFFER_SIZE);
                        }
                        else
                        {
                            GetWindowText(hwndPhaseTau, szBuffer, BUFFER_SIZE);
                        }

                        // Save the units type
                        nUnits=OTHER_UNITS;

                        // Initialize the increment value to tau
						SetWindowText(GETHCTL(IDC_TIMETAG_INC), szBuffer);

                        // Activate increment edit box
                        EnableWindow(GETHCTL(IDC_TIMETAG_INC), TRUE);
                        EnableWindow(GETHCTL(IDC_TIMETAG_INCLABEL),
                            TRUE);
                    }
                }
                break;

                // Respond to start edit control message
                case IDC_TIMETAG_START:
                {
					// Respond to edit control when it loses the input focus
                    // unless it loses it to the cancel button
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_TIMETAG_CANCEL)))
					{
                        // Get start
						GetWindowText(GETHCTL(IDC_TIMETAG_START), szBuffer,
							BUFFER_SIZE);
                        fStart=(F_TYPE)atof(szBuffer);

                        // Redisplay start
						_snprintf(szBuffer, sizeof(szBuffer), "%17.8e",
							fStart);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_TIMETAG_START), szBuffer);
                    }
                }
                break;

                // respond to increment edit control message
                case IDC_TIMETAG_INC:
                {
                    // Respond to edit control when it loses the input focus
                    // unless it loses it to the cancel button
                    if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
                        (GetFocus()!=GETHCTL(IDC_TIMETAG_CANCEL)))
                    {
                        // Get increment
						GetWindowText(GETHCTL(IDC_TIMETAG_INC),	szBuffer,
							BUFFER_SIZE);
                        fIncrement=(F_TYPE)atof(szBuffer);

                        // Redisplay increment
                        _snprintf(szBuffer, sizeof(szBuffer), "%11.5e",
							fIncrement);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_TIMETAG_INC),	szBuffer);
                    }
                }
                break;

				// Respond to CR in an edit control
                // Note: No button is a DEFPUSHBUTTON
                case IDOK:
                {
                    // Does start edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_TIMETAG_START))
                    {
                        // Send EN_KILLFOCUS message to start edit control
                        SendMessage(hDlg, WM_COMMAND,
                            GET_WM_COMMAND_MPS(IDC_TIMETAG_START, NULL,
                                EN_KILLFOCUS));
                    }

                    // Does increment edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_TIMETAG_INC))
                    {
                        // Send EN_KILLFOCUS message to increment edit control
						SendMessage(hDlg, WM_COMMAND,
                            GET_WM_COMMAND_MPS(IDC_TIMETAG_INC, NULL,
                            EN_KILLFOCUS));
                    }
                }
                break;

                case IDC_TIMETAG_ACCEPT:
                {
                    // Generate timetag data
                    if(bDataType==FREQ_DATA)
                    {
                        // Assign size, start and end values to timetag array
                        fFreqTimetags[0]=fFreqData[0];
                        fFreqTimetags[1]=fFreqData[1];
                        fFreqTimetags[2]=fFreqData[2];
						nSize=(int)fFreqTimetags[0];
           
						// Realloc freq timetag array
                        if((fNew=(F_TYPE*)realloc((char *)
                            fFreqTimetags, (nSize+ARRAY_OFFSET)*
							sizeof(F_TYPE)))==NULL)
                        {
                            AllocErrorMessage();
							EndDialog (hDlg, 0);
							return TRUE;
                        }
                        else
                        {
                            fFreqTimetags=fNew;
						}

                        // Assign array pointer
						fTags=fFreqTimetags;

                        // Get the tau value
                        GetWindowText(hwndFreqTau, szBuffer, BUFFER_SIZE);
                        fTau=atof(szBuffer);

                        // Set the freq timetag exists flag
                        bFreqTimetags=TRUE;

						// Set the plot scale changed flag
						bFreqScaleChanged=TRUE;
                    }
                    else
                    {
                        // Assign size, start and end values to timetag array
                        fPhaseTimetags[0]=fPhaseData[0];
                        fPhaseTimetags[1]=fPhaseData[1];
                        fPhaseTimetags[2]=fPhaseData[2];
                        nSize=(int)fPhaseTimetags[0];

                        // Realloc phase timetag array
                        if((fNew=(F_TYPE*)realloc((char *)
                            fPhaseTimetags, (nSize+ARRAY_OFFSET)*
							sizeof(F_TYPE)))==NULL)
                        {
                            AllocErrorMessage();
							EndDialog (hDlg, 0);
							return TRUE;
                        }
                        else
                        {
							fPhaseTimetags=fNew;
                        }

						// Assign array pointer
                        fTags=fPhaseTimetags;

                        // Get the tau value
                        GetWindowText(hwndPhaseTau, szBuffer, BUFFER_SIZE);
                        fTau=atof(szBuffer);

                        // Set the phase timetag exists flag
                        bPhaseTimetags=TRUE;

						// Set the plot scale changed flag
						bPhaseScaleChanged=TRUE;
                    }

                    // Set increment
                    switch(nUnits)
                    {
                        case SECONDS_UNITS:
                        {
                            // Set increment
							fIncrement=fTau;

							// Set tag scale
							if(bDataType==FREQ_DATA)
							{
								fFreqTagScale=1.0;
							}
							else // Phase data
							{
								fPhaseTagScale=1.0;
							}
                        }
                        break;

                        case DAYS_UNITS:
                        {
                            // Set increment
                            fIncrement=fTau/SEC_PER_DAY;

							// Set tag scale
							if(bDataType==FREQ_DATA)
							{
								fFreqTagScale=SEC_PER_DAY;
							}
							else // Phase data
							{
								fPhaseTagScale=SEC_PER_DAY;
							}
                        }
                        break;

						case OTHER_UNITS:
                        {
                            // Get increment
							GetWindowText(GETHCTL(IDC_TIMETAG_INC),	szBuffer,
								BUFFER_SIZE);

                            // Set increment
                            fIncrement=atof(szBuffer);

							// Set tag scale
							if(bDataType==FREQ_DATA)
							{
								fFreqTagScale=fTau/fIncrement;
							}
							else // Phase data
							{
								fPhaseTagScale=fTau/fIncrement;
							}
                        }
                        break;
                    }

                    // Get increment
					GetWindowText(GETHCTL(IDC_TIMETAG_START), szBuffer,
						BUFFER_SIZE);
                    fStart=atof(szBuffer);

                    // Store timetag data
                    for(i=0; i<nSize; i++)
                    {
                        fTags[i+ARRAY_OFFSET]=fStart+(i*fIncrement);
                    }

					// Put info into log file
					_snprintf(szBuffer, sizeof(szBuffer), "Increment=%e",
						fIncrement);
					ShortenExp(szBuffer);
					if(bDataType==FREQ_DATA)
					{
						WriteLog(43, szBuffer);
					}
					else // Phase data
					{
						WriteLog(42, szBuffer);
					}
								
                    // Activate regularize functions
                    ActivateFunctions(MF_ENABLED);
                }

                // Fall right into cancel
                // Respond to esc key or cancel button
                case IDCANCEL:
				case IDC_TIMETAG_CANCEL:
                {
                    EndDialog (hDlg, 0);
                }
                return TRUE;
			}
        }
        break;
     }
     return FALSE;
}
#endif

#ifndef LITE_VER
/*****************************************************************************/
/*                                                                           */
/*                   Regularize Dialog Procedure                             */
/*                                                                           */
/*      Use the timetag data to find missing data points and insert gaps as  */
/*      necessary to make the data regular (points at every tau interval).   */
/*      Corresponding points are also added to the timetag array.            */
/*                                                                           */
/*      The measurement interval is determined either by a user entry        */
/*      (in timetag units) or by the interval between the first 2 data       */
/*      points.  Data is considered missing if the spacing between any       */
/*      data points exceeds 1.5 times this value.  A sufficient # of gaps    */
/*      is added to eliminate the interruption in the regular flow of data.  */
/*      Timetags are added at intervals equal to the above-determined tau.   */
/*                                                                           */
/*      Revision record:                                                     */
/*          08/23/96    Partially implemented                                */
/*          08/24/96    Implementation complete - seems OK                   */
/*          09/27/96    Revised to handle blank timetags                     */
/*          11/03/96    Added increment filename extension logic             */
/*          02/18/97    Added blank timetag logic                            */
/*			12/10/97	Added calc & display of # missing points             */
/*			12/12/97	Made fixes to regularize logic                       */
/*						Set analysis limits to full range                    */
/*						Made tau interval read only                          */
/*			12/14/97	Made more fixes to regularize logic                  */
/*			05/02/02	Changed to faster blockwise regularize logic         */
/*			05/05/02	New faster regularization seems to be OK             */
/*			09/24/02	Changed to call new RegularizeCount() and            */
/*						RegularizeInsert() functions                         */
/*			11/18/06	Added CreateTab() call                               */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK RegularizeDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	// Chars
	char szBuffer[BUFFER_SIZE+1];   // Text buffer
	// Ints
	static int nSize;               // Array size
	static int nStart;              // Start index #
	static int nEnd;                // End index #
	static int nNum;                // # points to process
	static int nGaps;               // # interruptions (gaps) in data
	static int nMissingPts;			// Total # missing points in data
	// BOOLs
	static BOOL bGapAdded=FALSE;    // Flag for gap(s) added to data
	static BOOL bBlankTag=FALSE;    // Flag for blank timetag
	// F_TYPEs
	static F_TYPE fInterval;        // Tau interval of timetags

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Get dialog box title
			GetWindowText(hDlg, szBoxTitle, TITLESIZE);

			// Reset blank timetag flag
			bBlankTag=FALSE;

			// Find tau interval between 1st 2 timetags
			if(bDataType==FREQ) // Frequency data
			{
				fInterval=fFreqTimetags[ARRAY_OFFSET+1]-
					fFreqTimetags[ARRAY_OFFSET];

				// Reset freq analysis limits to full range
				fFreqData[1]=1.0;
				fFreqData[2]=fFreqData[0];
				_snprintf(szBuffer, sizeof(szBuffer), "%5.0d", 1);
				SetWindowText(hwndFreqStart, szBuffer);
				_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
					(int)fFreqData[0]);
				SetWindowText(hwndFreqEnd, szBuffer);

				// Update status bar
				UpdateStatusBar(hwndMain, NEW_DATA);
			}
			else // Phase data
			{
				fInterval=fPhaseTimetags[ARRAY_OFFSET+1]-
					fPhaseTimetags[ARRAY_OFFSET];

				// Reset phase analysis limits to full range
				fPhaseData[1]=1.0;
				fPhaseData[2]=fPhaseData[0];
				_snprintf(szBuffer, sizeof(szBuffer), "%5.0d", 1);
				SetWindowText(hwndPhaseStart, szBuffer);
				_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
					(int)fPhaseData[0]);
				SetWindowText(hwndPhaseEnd, szBuffer);

				// Update status bar
				UpdateStatusBar(hwndMain, NEW_DATA);
			}

			// Display the tau interval value
			_snprintf(szBuffer, sizeof(szBuffer), "%17.10e", fInterval);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_REGULARIZE_TAU), szBuffer);

			// Set analysis limits
			nStart=(int)fData[1];
			nEnd=(int)fData[2];
			nNum=nEnd-nStart+1;

			// Count # interruptions and missing points
			bBlankTag=RegularizeCount(fData, fTags, &nGaps, &nMissingPts);

			// Check if too many missing points to fit
			if(nNum+nMissingPts>nMaxSize)
			{
				// Display error message
				LoadString(hInst, IDS_MESSAGE_MANYMISSING,
					szBuffer, BUFFER_SIZE);
				MessageBox(hDlg, szBuffer, "Regularize",
					MB_ICONEXCLAMATION);

				// Abort
				EndDialog (hDlg, 0);
				return TRUE;
			}

			// Display the # interruptions
			_snprintf(szBuffer, sizeof(szBuffer), "%d", nGaps);
			SetWindowText(GETHCTL(IDC_REGULARIZE_GAPS), szBuffer);

			// Display the estimated # of missing points
			_snprintf(szBuffer, sizeof(szBuffer), "%d", nMissingPts);
			SetWindowText(GETHCTL(IDC_REGULARIZE_MISSING), szBuffer);
		}
		return TRUE;

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::REGULARIZE_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::REGULARIZE_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "REGULARIZE_FUNCTION");
					#endif
				}
				break;

				// Respond to CR in an edit control
				// Note: No button is a DEFPUSHBUTTON
				case IDOK:
				{
					// Does tau interval edit control have focus?
					if(GetFocus()==GETHCTL(IDC_REGULARIZE_TAU))
					{
						// Send EN_KILLFOCUS message to start edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_REGULARIZE_TAU, NULL,
							EN_KILLFOCUS));
					}
				}
				break;

				// Respond to OK button
				case IDC_REGULARIZE_ACCEPT:
				{
					if(bBlankTag)
					{
						LoadString(hInst, IDS_MESSAGE_BLANKTAG, szBuffer,
							BUFFER_SIZE);
						MessageBox(hDlg, szBuffer, szBoxTitle,
							MB_ICONEXCLAMATION);
						break;
					}

					if(nGaps)
					{
						// Create tab to save previous data if requested
						if(bTabs && bTabChange)
						{
							CreateTab();
						}

						// Insert missing points
						// Make space for the missing data
						// Realloc timetags

						// Set busy flag
						bBusy=TRUE;
						
						// Realloc tags to new # required
						nSize=(int)fData[0];
						if((fNew=(F_TYPE*)realloc(fTags,
							(nSize+nMissingPts+ARRAY_OFFSET+EXTRA_MEM)
							*sizeof(F_TYPE)))==NULL)
						{
							AllocErrorMessage();
							EndDialog (hDlg, 0);
							return TRUE;
 						}
						else
						{
							fTags=fNew;
						}

						// Realloc data to new # required
						if((fNew=(F_TYPE*)realloc(fData,
							(nSize+nMissingPts+ARRAY_OFFSET+EXTRA_MEM)
							*sizeof(F_TYPE)))==NULL)
						{
							AllocErrorMessage();
							EndDialog (hDlg, 0);
							return TRUE;
 						}
						else
						{
							fData=fNew;
						}

						// Insert missing points in data and timetags
						bGapAdded=RegularizeInsert(fData, fTags);
					}

					if(bGapAdded)
					{
						// Update array bounds
						nSize=(int)fData[0];
						nEnd=(int)fData[2];

						if(bDataType==FREQ_DATA) // Frequency data
						{
							// Update array pointers
							fFreqTimetags=fTags;
							fFreqData=fData;

							// Update status display
							_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
								nSize);
							SetWindowText(hwndFreqNum, szBuffer);
							_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
								nEnd);
							SetWindowText(hwndFreqEnd, szBuffer);

							// Set changed flags
							bFreqDataChanged=TRUE;
							bFreqDataUnsaved=TRUE;
							sFPlot.new_file=TRUE;
							bFreqScaleChanged=TRUE;

							// Force new PSD plot scale
							sPSPlot.y_tic=0;

							// Set redraw flag
							bFreqRedraw=TRUE;

							// Put info into log file
							_snprintf(szBuffer, sizeof(szBuffer), "# Pts=%d",
								nMissingPts);
							WriteLog(45, szBuffer);
								
							// Increment filename
							if(bIncExtension)
							{
								IncExtension(szFile, FREQ_DATA);
								IncExtension(szFileTitle, FREQ_DATA);
								IncExtension(szFreqFile, FREQ_DATA);
								IncExtension(szFreqFileTitle, FREQ_DATA);
								SetWindowText(hwndFreqFilename,
									szFileTitle);
							}
						}
						else // Phase data
						{
							// Update array pointers
							fPhaseTimetags=fTags;
							fPhaseData=fData;

							// Update status display
							_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
								nSize);
							SetWindowText(hwndPhaseNum, szBuffer);
							_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
								nEnd);
							SetWindowText(hwndPhaseEnd, szBuffer);

							// Set changed flags
							bPhaseDataChanged=TRUE;
							bPhaseDataUnsaved=TRUE;
							bPhaseScaleChanged=TRUE;

							// Force new PSD plot scale
							sPSPlot.y_tic=0;

							// Set redraw flag
							bPhaseRedraw=TRUE;

							// Put info into log file
							_snprintf(szBuffer, sizeof(szBuffer), "# Pts=%d",
								nMissingPts);
							WriteLog(44, szBuffer);
								
							// Increment filename
							if(bIncExtension)
							{
								IncExtension(szFile, PHASE_DATA);
								IncExtension(szFileTitle, PHASE_DATA);
								IncExtension(szPhaseFile, PHASE_DATA);
								IncExtension(szPhaseFileTitle, PHASE_DATA);
								SetWindowText(hwndPhaseFilename,
									szFileTitle);
							}
						}

						// Redraw status plots from new data
						UpdateStatusBar(hwndMain, NEW_DATA);

						// Clear plot lines
						ClearLines();

						// Reset busy flag
						bBusy=FALSE;
					}
				}
				// Fall into EndDialog()
				// Respond to esc and cancel button
				case IDCANCEL:
				case IDC_REGULARIZE_CANCEL:
				{
					EndDialog (hDlg, 0);
				}
				return TRUE;
			}
		}
		break;
	 }
	 return FALSE;
}
#endif
/*****************************************************************************/
/*                                                                           */
/*                   Clear Dialog Procedure                                  */
/*                                                                           */
/*      Function to clear selected data or timetag arrays                    */
/*                                                                           */
/*                                                                           */
/*      Upon each entry, the What to Clear selections are set to the         */
/*      current data and (if it exists) timetag data type.  Items that       */
/*      don't exist are grayed.  Any combination of items can be selected    */
/*      to be cleared.  While not clearing the timetags for data that is     */
/*      is cleared would be strange, it is not forbidden.                    */
/*                                                                           */
/*      Revision record:                                                     */
/*          12/20/96    Added bSaveType & associated logic so both plot      */
/*                      menus will be grayed if both arrays are cleared      */
/*          03/26/97    Fixed graying logic                                  */
/*			05/15/02	Added setting of plot scale changed flag when        */
/*                      timetags cleared                                     */
/*			11/18/06	Added CreateTab() call                               */
/*			01/03/12	Added clear all button                               */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK ClearDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	// BOOLs
	static BOOL bClearFreqData;
	static BOOL bClearFreqTags;
	static BOOL bClearPhaseData;
	static BOOL bClearPhaseTags;
	static BOOL bSaveType;          // BOOL to save original data type
	// Chars
	// char szBuffer[BUFFER_SIZE+1];   // Text buffer

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Initialize the flags
			if(bDataType==FREQ_DATA)
			{
				bClearFreqData=TRUE;
				bClearFreqTags=FALSE;
				if(bFreqTimetags)
				{
					bClearFreqTags=TRUE;
				}
				bClearPhaseData=FALSE;
				bClearPhaseTags=FALSE;
			}
			else
			{
				bClearFreqData=FALSE;
				bClearFreqTags=FALSE;
				bClearPhaseData=TRUE;
				bClearPhaseTags=FALSE;
				if(bPhaseTimetags)
				{
					bClearPhaseTags=TRUE;
				}
			}
			// Initialize the checkboxes
			Button_SetCheck(GETHCTL(IDC_CLEAR_FREQDATA), bClearFreqData);
			Button_SetCheck(GETHCTL(IDC_CLEAR_FREQTAGS), bClearFreqTags);
			Button_SetCheck(GETHCTL(IDC_CLEAR_PHASEDATA), bClearPhaseData);
			Button_SetCheck(GETHCTL(IDC_CLEAR_PHASETAGS), bClearPhaseTags);

			// Gray checkboxes for which there is no data
			EnableWindow(GETHCTL(IDC_CLEAR_FREQDATA), bFreqData);
			EnableWindow(GETHCTL(IDC_CLEAR_FREQTAGS), bFreqTimetags);
			EnableWindow(GETHCTL(IDC_CLEAR_PHASEDATA), bPhaseData);
			EnableWindow(GETHCTL(IDC_CLEAR_PHASETAGS), bPhaseTimetags);

			return TRUE;
		}

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::CLEAR_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::CLEAR_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "CLEAR_FUNCTION");
					#endif
				}
				break;

				case IDC_CLEAR_FREQDATA:
				{
					bClearFreqData=
						(BOOL)Button_GetCheck(GETHCTL(IDC_CLEAR_FREQDATA));
				}
				break;

				case IDC_CLEAR_FREQTAGS:
				{
					bClearFreqTags=
						(BOOL)Button_GetCheck(GETHCTL(IDC_CLEAR_FREQTAGS));
				}
				break;

				case IDC_CLEAR_PHASEDATA:
				{
					bClearPhaseData=
						(BOOL)Button_GetCheck(GETHCTL(IDC_CLEAR_PHASEDATA));
				}
				break;

				case IDC_CLEAR_PHASETAGS:
				{
					bClearPhaseTags=
						(BOOL)Button_GetCheck(GETHCTL(IDC_CLEAR_PHASETAGS));
				}
				break;

				case IDC_CLEAR_ALL:
				{
					bClearPhaseData=TRUE;
					bClearPhaseTags=TRUE;
					bClearFreqData=TRUE;
					bClearFreqTags=TRUE;
				}

				// Fall into IDOK

				case IDOK:
				{
                    // Create tab to save previous data if requested
					if(bTabs && bTabChange)
					{
						CreateTab();
					}
						
					// Save original data type
					bSaveType=bDataType;

					// Clear selected arrays
					// Note: Timetag processing must preceed data processing
					if(bClearFreqTags)
					{
						bDataType=FREQ_DATA;
						ClearTimetagArray(FREQ_DATA);
						bFreqScaleChanged=TRUE;
					}

					if(bClearPhaseTags)
					{
						bDataType=PHASE_DATA;
						ClearTimetagArray(PHASE_DATA);
						bPhaseScaleChanged=TRUE;
					}

					if(bClearFreqData)
					{
						bDataType=FREQ_DATA;
						ClearDataArray(FREQ_DATA);
						bSynch=FALSE;

						WriteLog(2, "");
						
						bDataType=bSaveType;
						if(bDataType==FREQ_DATA)
						{
							// Deactivate data-dependent functions
							ActivateFunctions(MF_GRAYED);
						}
						else
						{
							// Activate data-dependent functions
							ActivateFunctions(MF_ENABLED);
						}
					}

					if(bClearPhaseData)
					{
						bDataType=PHASE_DATA;
						ClearDataArray(PHASE_DATA);
						bSynch=FALSE;

						WriteLog(1, "");
						
						bDataType=bSaveType;
						if(bDataType==PHASE_DATA)
						{
							// Deactivate data-dependent functions
							ActivateFunctions(MF_GRAYED);
						}
						else
						{
							// Activate data-dependent functions
							ActivateFunctions(MF_ENABLED);
						}
					}

					// Refresh Tabs menu
					SetTabMenu();

					// Restore original data type
					bDataType=bSaveType;
				}

				// Fall into IDCANCEL

				case IDCANCEL:
				{
					EndDialog (hDlg, 0);
				}
				return TRUE;
			}
		}
		break;
	 }
	 return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*                   Multicolumn Dialog Procedure                            */
/*                                                                           */
/*      Function to select data column #s for data or timetag arrays         */
/*                                                                           */
/*      Up to 8 columns of data is supported.  Separate rows are shown for   */
/*      timetags and data.  If a duplicate column selection is made, the     */
/*      previous one is erased.  This is how one can revert to reading only  */
/*      one column of data.                                                  */
/*                                                                           */
/*      Active col #s go from 1 to 8; a col # = 0 is inactive                */
/*                                                                           */
/*      Globals:    szFileText      last line of file (reformatted)          */
/*                  bCancelDataRead Flag to indicate data read was aborted   */
/*                                                                           */
/*      Messages:                                                            */
/*      Note: Need to review for WIN32 compatibility                         */
/*          (1) To get # data columns, MulticolumnDlgProc() sends a          */
/*              IDM_MCOL_NCOL message to the main message switching loop.    */
/*              It responds with a IDC_MCOL_SETNCOL message containing nCols */
/*              as its wParam.                                               */
/*          (2) To receive column # for the phase or freq tags or data, the  */
/*              main program sends a IDC_MCOL_GETPT, _GETPD, _GETFT or GETFD */
/*              message to MulticolumnDlgProc().  It responds with the same  */
/*              message to the main processing loop with the col # as the    */
/*              LOWORD of its lParam.                                        */
/*                                                                           */
/*      Revision record:                                                     */
/*          09/22/96    Added display of 1st line of file                    */
/*                      Added use of bCancelDataRead flag                    */
/*          06/20/97    Added display of "... (more)" annunciator            */
/*			01/11/01	Changed "1st" annotation to "last"                   */
/*			04/18/01	Added bSkip support to immediately close dialog      */
/*			08/11/08	Added details button                                 */
/*			08/12/08	Allow 0 as tag column to avoid reading timetags      */
/*			01/07/12	Added support for # TagCol= and # DatCol=            */
/*						data file header items                               */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK MulticolumnDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	// Ints
	int i;							// index
	// Note: These column variables start at 1 = 1st column
	static int nPhaseTagCol=1;		// Col # of phase timetags
	static int nPhaseDatCol=2;		// Col # of phase data
	static int nFreqTagCol=1;		// Col # of freq timetags
	static int nFreqDatCol=2;		// Col # of freq data
	static int nTempTagCol;			// Temporary col # of timetags
	static int nTempDatCol;			// Temporary col # of data
	static int nCols=8;				// # columns in data file (2-8, set later)
	// Chars
	// char szBuffer[BUFFER_SIZE+1];   // Text buffer

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Send message to get # data cols
			// OK for Win32 compatibility
			// Win 3.1 Args are:    HWND    hWnd    Window to get message
			//                      WORD    wMsg    Message
			//                      WORD    wParam  Command ID
			//                      DWORD   lParam  LOWORD=window handle
			//                                      HIWORD=notification
			//                                      code (not used)
			SendMessage(hwndMain, WM_COMMAND,
				GET_WM_COMMAND_MPS(IDM_MCOL_NCOL, hDlg, 0));

			#if(1) // New code 01/07/12
			// If data and timetag columns are defined by header items
			// in the data file using # TagCol= and #DatCol=
			// which are parsed into globals nTCol and nDCol respectively,
			// then use those column assignments
			// and immediately close this dialog box
			// The column #s are zero-based
			// and a column # of 0 means there is no such column
			// Both header items should be included if they are used
			if(nTCol || nDCol)
			{
				// Send tag and data column #s to main message loop
				// Updated for Win32 compatibility
				// Win 3.1 Args: HWND    hWnd    Window to get message =
				//                               hwndMain
				//               WORD    wMsg    Message = WM_COMMAND
				//               WORD    wParam  Command ID
				//               DWORD   lParam  LOWORD=col #
				//                               HIWORD=not used
				SendMessage(hwndMain, WM_COMMAND,
					GET_WM_COMMAND_MPS(IDM_MCOL_TAG, nTCol, 0));

				// Send data column #
				SendMessage(hwndMain, WM_COMMAND,
					GET_WM_COMMAND_MPS(IDM_MCOL_DAT, nDCol, 0));

				// Close dialog box
				EndDialog (hDlg, 0);
			}
			#endif
			
			// Make sure col #s are <= # cols
			if(nTempDatCol>nCols || nTempTagCol>nCols)
			{
				// reinitialize col #s
				if(bDataType==PHASE_DATA)
				{
					nPhaseTagCol=1;
					nPhaseDatCol=2;
				}
				else
				{
					nFreqTagCol=1;
					nFreqDatCol=2;
				}
			}

			// Set temporary column #s
			if(bDataType==PHASE_DATA)
			{
				nTempTagCol=nPhaseTagCol;
				nTempDatCol=nPhaseDatCol;
			}
			else
			{
				nTempTagCol=nFreqTagCol;
				nTempDatCol=nFreqDatCol;
			}

			// Clear all radio buttons
			for(i=0; i<16; i++)
			{
				Button_SetCheck(GETHCTL(IDC_MCOL_T1+i), FALSE);
			}

			// Set active timetag col radio button
			Button_SetCheck(GETHCTL(IDC_MCOL_T1+nTempTagCol-1), TRUE);

			// Set active data col radio buttons
			Button_SetCheck(GETHCTL(IDC_MCOL_D1+nTempDatCol-1), TRUE);

			// Hide inactive columns
			for(i=7; i>=nCols; i--)
			{
				EnableWindow(GETHCTL(IDC_MCOL_T1+i), 0);
				ShowWindow(GETHCTL(IDC_MCOL_T1+i), SW_HIDE);
				EnableWindow(GETHCTL(IDC_MCOL_D1+i), 0);
				ShowWindow(GETHCTL(IDC_MCOL_D1+i), SW_HIDE);
			}

			// Display the last line of the file
			SetWindowText(GETHCTL(IDC_MCOL_TEXT), szFileText);

			if(bLongLine)
			{
				ShowWindow(GETHCTL(IDC_MCOL_MORE), SW_SHOWNORMAL);

			}
			else
			{
				ShowWindow(GETHCTL(IDC_MCOL_MORE), SW_HIDE);
			}

			// Accept and close dialog box if skip flag is set
			if(bSkip)
			{
				// Send an IDOK message to close dialog box
				SendMessage(hDlg, WM_COMMAND,
					GET_WM_COMMAND_MPS(IDOK, NULL, 0));
			}

			return TRUE;
		}

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::MULTICOLUMN_DATA.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::MULTICOLUMN_DATA.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "MULTICOLUMN_DATA");
					#endif
				}
				break;

				// Custom messages
				// Set # data columns=LOWORD of incoming message's lParam
				case IDC_MCOL_SETNCOL:
				{
					nCols=(int)LOWORD(lParam);
				}

				// Respond to radio button changes
				case IDC_MCOL_T1:
				{
					nTempTagCol=1;
					if(nTempDatCol==1)
					{
						Button_SetCheck(GETHCTL(IDC_MCOL_D1+0), FALSE);
						nTempDatCol=0;
					}
				}
				break;

				case IDC_MCOL_T2:
				{
					nTempTagCol=2;
					if(nTempDatCol==2)
					{
						Button_SetCheck(GETHCTL(IDC_MCOL_D1+1), FALSE);
						nTempDatCol=0;
					}
				}
				break;

				case IDC_MCOL_T3:
				{
					nTempTagCol=3;
					if(nTempDatCol==3)
					{
						Button_SetCheck(GETHCTL(IDC_MCOL_D1+2), FALSE);
						nTempDatCol=0;
					}
				}
				break;

				case IDC_MCOL_T4:
				{
					nTempTagCol=4;
					if(nTempDatCol==4)
					{
						Button_SetCheck(GETHCTL(IDC_MCOL_D1+3), FALSE);
						nTempDatCol=0;
					}
				}
				break;

				case IDC_MCOL_T5:
				{
					nTempTagCol=5;
					if(nTempDatCol==5)
					{
						Button_SetCheck(GETHCTL(IDC_MCOL_D1+4), FALSE);
						nTempDatCol=0;
					}
				}
				break;

				case IDC_MCOL_T6:
				{
					nTempTagCol=6;
					if(nTempDatCol==6)
					{
						Button_SetCheck(GETHCTL(IDC_MCOL_D1+5), FALSE);
						nTempDatCol=0;
					}
				}
				break;

				case IDC_MCOL_T7:
				{
					nTempTagCol=7;
					if(nTempDatCol==7)
					{
						Button_SetCheck(GETHCTL(IDC_MCOL_D1+6), FALSE);
						nTempDatCol=0;
					}
				}
				break;

				case IDC_MCOL_T8:
				{
					nTempTagCol=8;
					if(nTempDatCol==8)
					{
						Button_SetCheck(GETHCTL(IDC_MCOL_D1+7), FALSE);
						nTempDatCol=0;
					}
				}
				break;

				case IDC_MCOL_D1:
				{
						nTempDatCol=1;
						if(nTempTagCol==1)
						{
							Button_SetCheck(GETHCTL(IDC_MCOL_T1+0), FALSE);
							nTempTagCol=0;
						}
				}
				break;

				case IDC_MCOL_D2:
				{
						nTempDatCol=2;
						if(nTempTagCol==2)
						{
							Button_SetCheck(GETHCTL(IDC_MCOL_T1+1), FALSE);
							nTempTagCol=0;
						}
				}
				break;

				case IDC_MCOL_D3:
				{
						nTempDatCol=3;
						if(nTempTagCol==3)
						{
							Button_SetCheck(GETHCTL(IDC_MCOL_T1+2), FALSE);
							nTempTagCol=0;
						}
				}
				break;

				case IDC_MCOL_D4:
				{
						nTempDatCol=4;
						if(nTempTagCol==4)
						{
							Button_SetCheck(GETHCTL(IDC_MCOL_T1+3), FALSE);
							nTempTagCol=0;
						}
				}
				break;

				case IDC_MCOL_D5:
				{
						nTempDatCol=5;
						if(nTempTagCol==5)
						{
							Button_SetCheck(GETHCTL(IDC_MCOL_T1+4), FALSE);
							nTempTagCol=0;
						}
				}
				break;

				case IDC_MCOL_D6:
				{
						nTempDatCol=6;
						if(nTempTagCol==6)
						{
							Button_SetCheck(GETHCTL(IDC_MCOL_T1+5), FALSE);
							nTempTagCol=0;
						}
				}
				break;

				case IDC_MCOL_D7:
				{
						nTempDatCol=7;
						if(nTempTagCol==7)
						{
							Button_SetCheck(GETHCTL(IDC_MCOL_T1+6), FALSE);
							nTempTagCol=0;
						}
				}
				break;

				case IDC_MCOL_D8:
				{
						nTempDatCol=8;
						if(nTempTagCol==8)
						{
							Button_SetCheck(GETHCTL(IDC_MCOL_T1+7), FALSE);
							nTempTagCol=0;
						}
				}
				break;

				case IDC_MCOL_DETAILS:
				{
					// Open dialog box
					InvokeDialogBox(hInst, "DetailsBox", hDlg,
						(DLGPROC)DetailsDlgProc);
				}
				break;

				case IDOK:
				{
					// Update column #s
					if(bDataType==PHASE_DATA)
					{
						nPhaseDatCol=nTempDatCol;
						nPhaseTagCol=nTempTagCol;
					}
					else
					{
						nFreqDatCol=nTempDatCol;
						nFreqTagCol=nTempTagCol;
					}

					// Send new tag and data column #s to main message loop
					// Updated for Win32 compatibility
					// Win 3.1 Args: HWND    hWnd    Window to get message =
					//                               hwndMain
					//               WORD    wMsg    Message = WM_COMMAND
					//               WORD    wParam  Command ID
					//               DWORD   lParam  LOWORD=col #
					//                               HIWORD=not used
					SendMessage(hwndMain, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDM_MCOL_TAG, nTempTagCol, 0));

					// Send data column #
					SendMessage(hwndMain, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDM_MCOL_DAT, nTempDatCol, 0));

					EndDialog (hDlg, 0);
				}
				return TRUE;

				case IDCANCEL:
				{
					bCancelDataRead=TRUE;
					EndDialog (hDlg, 0);
				}
				return TRUE;
			}
		}
		break;
	 }
	 return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*                    Multi Dialog Procedure                                 */
/*                                                                           */
/*      Function to select timetag and data columns for # columns > 8        */
/*                                                                           */
/*      Messages:                                                            */
/*          (1) To get # data columns, MulticolumnDlgProc() sends a          */
/*              IDM_MCOL_NCOL message to the main message switching loop.    */
/*              It responds with a IDC_MCOL_SETNCOL message containing nCols */
/*              as its wParam.                                               */
/*          (2) To receive column # for the phase or freq tags or data, the  */
/*              main program sends a IDC_MCOL_GETPT, _GETPD, _GETFT or GETFD */
/*              message to MulticolumnDlgProc().  It responds with the same  */
/*              message to the main processing loop with the col # as the    */
/*              LOWORD of its lParam.                                        */
/*                                                                           */
/*      Revision record:                                                     */
/*          12/11/99    Created                                              */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK MultiDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	// Chars
	char szBuffer[BUFFER_SIZE+1];       // Text buffer
	// Ints
	// int i;                          // Index - Not used
	int nEntry;                        // # entered by user
	int nPrev;                         // Previous value
	static int nTags;                  // Timetag column # (1=1st col)
	static int nData;                  // Data column # (1=1st col)
	static int nCols;                  // # Columns
	// BOOLs
	static BOOL bErrorTrap=FALSE;      // Flag for entry error

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Send message to get # data cols
			// OK for Win32 compatibility
			// Win 3.1 Args are:    HWND    hWnd    Window to get message
			//                      WORD    wMsg    Message
			//                      WORD    wParam  Command ID
			//                      DWORD   lParam  LOWORD=window handle
			//                                      HIWORD=notification
			//                                      code (not used)
			SendMessage(hwndMain, WM_COMMAND,
				GET_WM_COMMAND_MPS(IDM_MCOL_NCOL, hDlg, 0));
			
			// Initialize selections
			nTags=1;
			nData=2;

			// Set the timetag column display
			_snprintf(szBuffer, sizeof(szBuffer), "%d", nTags);
			SetWindowText(GETHCTL(IDC_MULTI_TAGS), szBuffer);

			// Set the data column display
			_snprintf(szBuffer, sizeof(szBuffer), "%d", nData);
			SetWindowText(GETHCTL(IDC_MULTI_DATA), szBuffer);

			return TRUE;
		}

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				// Respond to Help pushbutton
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::MULTICOLUMN_DATA.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::MULTICOLUMN_DATA.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "MULTICOLUMN_DATA");
					#endif
				}
				break;

				// Custom messages
				case IDC_MCOL_SETNCOL:
				{
					// Set # data columns=LOWORD of incoming message's lParam
					nCols=(int)LOWORD(lParam);

					// Set the # data columns display
					_snprintf(szBuffer, sizeof(szBuffer), "# Columns = %d",
						nCols);
					SetWindowText(GETHCTL(IDC_MULTI_NUM), szBuffer);
				}

				// Respond to Tags edit control message
				case IDC_MULTI_TAGS:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_MULTI_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Save previous value
						nPrev=nTags;

						// Get (new) timetag column #
						GetWindowText(GETHCTL(IDC_MULTI_TAGS), szBuffer,
							BUFFER_SIZE);
						nEntry=abs(atoi(szBuffer));

						// Note: Lower limit changed from 1 to 0 08/12/08
						// si that no timetags can be read
						// Check entry - must be between 0 and nCols
						// where 0 indicates no timetag column
						// Numeric params are value, min & max
						if(ValidateInteger(hDlg, nEntry, 0, nCols)==TRUE)
						{
							// New value OK
							nTags=nEntry;

							// Redisplay value
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nTags);
							SetWindowText(GETHCTL(IDC_MULTI_TAGS), szBuffer);
						}
						else
						{
							// Invalid entry - restore previous value
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nPrev);
							SetWindowText(GETHCTL(IDC_MULTI_TAGS), szBuffer);
							SetFocus(GETHCTL(IDC_MULTI_TAGS));
						}
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Respond to Data edit control message
				case IDC_MULTI_DATA:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_MULTI_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Save previous value
						nPrev=nData;

						// Get (new) data column #
						GetWindowText(GETHCTL(IDC_MULTI_DATA), szBuffer,
							BUFFER_SIZE);
						nEntry=abs(atoi(szBuffer));

						// Check entry - must be between 1 and nCols
						// Numeric params are value, min & max
						if(ValidateInteger(hDlg, nEntry, 1, nCols)==TRUE)
						{
							// New value OK
							nData=nEntry;

							// Redisplay value
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nData);
							SetWindowText(GETHCTL(IDC_MULTI_DATA), szBuffer);
						}
						else
						{
							// Invalid entry - restore previous value
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nPrev);

							SetWindowText(GETHCTL(IDC_MULTI_DATA), szBuffer);
							SetFocus(GETHCTL(IDC_MULTI_DATA));
						}
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Respond to details button
				case IDC_MULTI_DETAILS:
				{
					// Open dialog box
					InvokeDialogBox(hInst, "DetailsBox", hDlg,
						(DLGPROC)DetailsDlgProc);
				}
				break;

				// Respond to CR in an edit control
				// Note: No button is a DEFPUSHBUTTON
				case IDOK:
				{
					// Does timetags edit control have focus?
					if(GetFocus()==GETHCTL(IDC_MULTI_TAGS))
					{
						// Send EN_KILLFOCUS message to start edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_MULTI_TAGS, NULL,
							EN_KILLFOCUS));
					}

					// Does data edit control have focus?
					if(GetFocus()==GETHCTL(IDC_MULTI_DATA))
					{
						// Send EN_KILLFOCUS message to end edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_MULTI_DATA, NULL,
							EN_KILLFOCUS));
					}
				}
				break;

				case IDC_MULTI_ACCEPT:
				{
					// Send new tag and data column #s to main message loop
					// Updated for Win32 compatibility
					// Win 3.1 Args: HWND    hWnd    Window to get message =
					//                               hwndMain
					//               WORD    wMsg    Message = WM_COMMAND
					//               WORD    wParam  Command ID
					//               DWORD   lParam  LOWORD=col #
					//                               HIWORD=not used
					SendMessage(hwndMain, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDM_MCOL_TAG, nTags, 0));

					// Send data column #
					SendMessage(hwndMain, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDM_MCOL_DAT, nData, 0));
					
					// Closed dialog box
					EndDialog (hDlg, 0);
				}
				return TRUE;

				// Respond to esc key or cancel button
				case IDCANCEL:
				case IDC_MULTI_CANCEL:
				{
					// Abort data read & close dialog box
					bCancelDataRead=TRUE;
					EndDialog (hDlg, 0);
				}
				return TRUE;
			}
		}
		break;
	 }
	 return FALSE;
}

#ifndef LITE_VER
/*****************************************************************************/
/*                                                                           */
/*                   Domain Dialog Procedure                                 */
/*                                                                           */
/*      Domain dialog box controls:                                          */
/*              ID                  Description             Variable         */
/*         IDC_DOMAIN_PSD   Power spectral density type     nPSDType         */
/*              PSD_Y    = 1    Sy(f)                                        */
/*              PSD_X    = 2    Sx(f)                                        */
/*              PSD_P    = 3    So(f)                                        */
/*              PSD_L    = 4    L(f)                                         */
/*         IDC_DOMAIN_SIG   Sigma type                      nSigmaType       */
/*              SIG_Y    = 5    Normal Sigma                                 */
/*              MODSIG_Y = 6    Modified Sigma                               */
/*              SIG_X    = 7    Time Sigma                                   */
/*         IDC_DOMAIN_FREQ  Sideband frequency (Hz)         fFreq            */
/*         IDC_DOMAIN_TAU   Tau (Seconds)                   fTau             */
/*         IDC_DOMAIN_MHZ   Carrier frequency (MHz)         fMHz             */
/*         IDC_DOMAIN_AF    Averaging factor                fAF              */
/*         IDC_DOMAIN_BW    Bandwidth factor                fBW              */
/*         IDC_DOMAIN_FRWF  Freq domain RW FM noise coeff                    */
/*         IDC_DOMAIN_FFF   Freq domain F FM noise coeff                     */
/*         IDC_DOMAIN_FWF   Freq domain W FM noise coeff                     */
/*         IDC_DOMAIN_FFP   Freq domain F PM noise coeff                     */
/*         IDC_DOMAIN_FWP   Freq domain W PM noise coeff                     */
/*         IDC_DOMAIN_TRWF  Time domain RW FM noise coeff                    */
/*         IDC_DOMAIN_TFF   Time domain F FM noise coeff                     */
/*         IDC_DOMAIN_TWF   Time domain W FM noise coeff                     */
/*         IDC_DOMAIN_TFP   Time domain F PM noise coeff                     */
/*         IDC_DOMAIN_TWP   Time domain W PM noise coeff                     */
/*         IDC_DOMAIN_FALL  Freq domain total PSD value (read only)          */
/*         IDC_DOMAIN_TALL  Time domain total sigma coeff (read only)        */
/*                                                                           */
/*      Calculations are done with CalcDomain() and ConvDomain() from        */
/*      FrequenC Library.   CalcDomain() calculates the h(alpha) parameter   */
/*      from the noise coeff, tau, SB freq, carrier freq, BW factor,         */
/*      noise param type, alpha and avg factor.  ConvDomain() converts an    */
/*      h(alpha) value to a noise parameter, given the tau, SB freq, carrier */
/*      freq, BW factor, noise type, alpha and avg factor.                   */
/*                                                                           */
/*      The following messages initiate internal processes within the        */
/*      DomainDlgProc() function:                                            */
/*                                                                           */
/*          IDC_DOMAIN_TTOF     Do time to freq domain conversion            */
/*          IDC_DOMAIN_FTOT     Do freq to time conversion                   */
/*          IDC_DOMAIN_TOTAL    Recalc total noise parameters                */
/*                                                                           */
/*      The bFlag controls message reprocessing to avoid circular loops and  */
/*      stack overflow during recalculations.                                */
/*                                                                           */
/*      An L(f) value of 0 is a special case denoting a noise coefficient=0  */
/*                                                                           */
/*      Recalc logic:                                                        */
/*                                                                           */
/*      Domain  Item Changed    Recalc      Remarks                          */
/*                                                                           */
/*      Time    Sigma Type      Freq        Existing sigma values remain     */
/*      "       Tau             Freq        "                                */
/*      "       Avg Factor      Time        New sigma values calculated      */
/*      "       BW Factor       Freq        Existing sigma values remain     */
/*      "       Sigma Param     Freq        New PSD values calculated        */
/*      Freq    PSD Type        Freq        "                                */
/*      "       SB Freq         Freq        "                                */
/*      "       Carrier Freq    Time        Existing PSD values remain       */
/*      "       PSD Param       Time        New sigma values calculated      */
/*                                                                           */
/*      The basic idea is this:  Sigma type, tau, bw factor & carrier freq   */
/*      are static inputs.  The opposite domain is recalclated to keep       */
/*      results consistent.  New avg factor finds corresponding sigma.  New  */
/*      PSD type does units conversion.  New SB freq finds corresponding     */
/*      PSD.  New sigma or PSD param value performs domain conversion.       */
/*                                                                           */
/*                                                                           */
/*      Revision record:                                                     */
/*          10/30/96    Added edit control CR logic                          */
/*          11/01/96    Changed layout; added PSD & sigma info               */
/*          11/02/96    Added BW factor disabling; Added clear all button    */
/*                      Changed PSD & sigma type lists to stringtables       */
/*          11/25/96    Added freq domain BW edit control                    */
/*			12/18/98	Added copy button to copy results to clipboard       */
/*			01/15/99	Added copy to clipboard functionality                */
/*			01/28/07	Added PSD and sigma plots                            */
/*			08/24/07	Added nClip usage                                    */
/*          07/23/16	Added code for integrated phase jitter and           */
/*                      residual FM                                          */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK DomainDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local macros
	#define PI 3.141592654

	// Local variables
	// Chars
	char szBuffer[BUFFER_SIZE+1];   // Text buffer
	// Ints
	int nDummy;					// Dummy function return value
	static int i;               // Index
	static int j;               // Secondary index
	static int nPSDType=4;      // PSD type: Sy(f)=1, Sx(f)=2, So(f)=3, L(f)=4
	static int nSigmaType=5;    // Sigma type: Normal=5, Modified=6, Time=7
	static int nAvgFactor=1;    // Sigma averaging factor
	static int nSaveAvgFactor;	// Saved averaging factor
	static int nSigmaSize;		// # sigma data plot points
	static int nPSDSize;		// # PSD data plot points
	static int nClip;			// Size of szClipboard (chars)
	// Floats
	static float fMHz=10.0;     // Carrier frequency, MHz
	static float fBW=10.0;      // Bandwidth factor
	static float fHigh;			// High frequency cutoff, Hz
	static float fSBFreq=1.0;	// Fourier (sideband) frequency, Hz
	static float fSaveSBFreq;	// Saved sideband freq
	static float fTau=1.0;      // Tau, seconds
	static float fFALL=0.0;     // Total freq domain PSD value
	static float fTALL=0.0;     // Total time domain sigma value
	static float fNoise;        // Noise parameter h(alpha)
	static float fPS[5];        // Power spectrum array - index=alpha+2
	static float fSigma[5];     // Sigma array - index=alpha+2
	static float fH[5];			// h(alpha) parameter
	static float fSaveTau;		// Saved tau
	static float fStartTau;		// Starting tau for plot
	static float fEndTau;		// Ending tau for plot
	static float fStartFreq;	// Starting freq for plot
	static float fEndFreq;		// Ending freq for plot
	static float fJitter;		// Integrated phase jitter
	static float fResidual;		// Residual FM
	static float fKdB;			// PSD value
	static float fK;			// PSD coefficient
// BOOLs
	static BOOL bFlag=FALSE;    // Message processing flag
	static BOOL bComma=FALSE;	// Insert comma flag
	static BOOL bBreak=FALSE;	// Flag to break out of loop
	// Clipboard variables
	HGLOBAL hClipboard;			// Handle to clipboard text buffer
	LPSTR	szClipboard;		// Ptr to clipboard text string

	// GraphiC plotting
	// char TitleString[40];                   // Dialog box title string
	HWND hChildWnd=NULL;
	HANDLE hChildAccel=NULL;

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Write prompt message
			WritePromptMessage(TB_DOMAIN);

			// Disable the copy button until there are results
			EnableWindow(GETHCTL(IDC_DOMAIN_COPY), FALSE);

			// Set default start and end freq and tau
			fStartFreq=(float)1.0e+00;
			fEndFreq=(float)1.0e+03;
			fStartTau=(float)1.0e-03;
			fEndTau=(float)1.0e-00;

			// Fill up the PSD list box
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_DOMAIN_PSD));
			for(i=0; i<NUM_DOMAIN_PSDTYPES; i++)
			{
				LoadString(hInst, IDS_DOMAIN_PSDTYPE_0+i, szBuffer,
					BUFFER_SIZE+1);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_DOMAIN_PSD), i,
					szBuffer);
			}

			// Fill up the sigma list box
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_DOMAIN_SIG));
			for(i=0; i<NUM_DOMAIN_SIGTYPES; i++)
			{
				LoadString(hInst, IDS_DOMAIN_SIGTYPE_0+i, szBuffer,
					BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_DOMAIN_SIG), i,
					szBuffer);
			}

			// Initialize display
			SendMessage(hDlg, WM_COMMAND,
				GET_WM_COMMAND_MPS(IDC_DOMAIN_CLEAR, NULL, 0));

			return TRUE;
		}

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::DOMAIN_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::DOMAIN_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "DOMAIN_FUNCTION");
					#endif
				}
				break;

				// Display PSD info
				case IDC_DOMAIN_DSPPSD:
				{
					switch(nPSDType)
					{
						case PSD_L:
						{
							for(i=0; i<NUM_DOMAIN_TYPES; i++)
							{
								LoadString(hInst, IDS_DOMAIN_PSD_L0+i,
									szBuffer, BUFFER_SIZE);
								SetWindowText(GETHCTL(IDC_DOMAIN_PSD0+i),
									szBuffer);
							}
						}
						break;

						case PSD_P:
						{
							for(i=0; i<NUM_DOMAIN_TYPES; i++)
							{
								LoadString(hInst, IDS_DOMAIN_PSD_P0+i,
									szBuffer, BUFFER_SIZE);
								SetWindowText(GETHCTL(IDC_DOMAIN_PSD0+i),
									szBuffer);
							}
						}
						break;

						case PSD_X:
						{
							for(i=0; i<NUM_DOMAIN_TYPES; i++)
							{
								LoadString(hInst, IDS_DOMAIN_PSD_X0+i,
									szBuffer, BUFFER_SIZE);
								SetWindowText(GETHCTL(IDC_DOMAIN_PSD0+i),
									szBuffer);
							}
						}
						break;

						case PSD_Y:
						{
							for(i=0; i<NUM_DOMAIN_TYPES; i++)
							{
								LoadString(hInst, IDS_DOMAIN_PSD_Y0+i,
									szBuffer, BUFFER_SIZE);
								SetWindowText(GETHCTL(IDC_DOMAIN_PSD0+i),
									szBuffer);
							}
						}
						break;
					}
				}
				break;

				// Display Sigma info
				case IDC_DOMAIN_DSPSIG:
				{
					switch(nSigmaType)
					{
						case SIG_Y:
						{
							for(i=0; i<NUM_DOMAIN_TYPES; i++)
							{
								LoadString(hInst, IDS_DOMAIN_SIG_Y0+i,
									szBuffer, BUFFER_SIZE);
								SetWindowText(GETHCTL(IDC_DOMAIN_SIG0+i),
									szBuffer);
							}
						}
						break;

						case MODSIG_Y:
						{
							for(i=0; i<NUM_DOMAIN_TYPES; i++)
							{
								LoadString(hInst, IDS_DOMAIN_SIG_M0+i,
									szBuffer, BUFFER_SIZE);
								SetWindowText(GETHCTL(IDC_DOMAIN_SIG0+i),
									szBuffer);
							}
						}
						break;

						case SIG_X:
						{
							for(i=0; i<NUM_DOMAIN_TYPES; i++)
							{
								LoadString(hInst, IDS_DOMAIN_SIG_X0+i,
									szBuffer, BUFFER_SIZE);
								SetWindowText(GETHCTL(IDC_DOMAIN_SIG0+i),
									szBuffer);
							}
						}
						break;
					}
				}
				break;

				// Respond to clear all button
				case IDC_DOMAIN_CLEAR:
				{
					// Disable processing
					bFlag=FALSE;

					// Disable the copy button until there are results
					EnableWindow(GETHCTL(IDC_DOMAIN_COPY), FALSE);

					// Clear noise parameters
					for(i=0; i<5; i++)
					{
						fPS[i]=0.0;
						fSigma[i]=0.0;
					}

					// Disable the plot buttons
					EnableWindow(GETHCTL(IDC_DOMAIN_PLOTPSD), FALSE);
					EnableWindow(GETHCTL(IDC_DOMAIN_PLOTSIGMA), FALSE);
					
					// Clear other parameters
					fTau=1.0;
					nAvgFactor=1;
					fBW=10.0;
					fSBFreq=1.0;
					fMHz=10.0;

					// Set parameter types
					nSigmaType=SIG_Y;
					nPSDType=PSD_L;

					// Show PSD type
					nDummy=ComboBox_SetCurSel(GETHCTL(IDC_DOMAIN_PSD),
						4-nPSDType);

					// Display PSD info
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_DOMAIN_DSPPSD, NULL, 0));

					// Show sigma type
					nDummy=ComboBox_SetCurSel(GETHCTL(IDC_DOMAIN_SIG),
						nSigmaType-5);

					// Display sigma info
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_DOMAIN_DSPSIG, NULL, 0));

					// Load the sideband freq
					_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fSBFreq);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_DOMAIN_FREQ), szBuffer);

					// Load the tau value
					_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fTau);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_DOMAIN_TAU), szBuffer);

					// Load the start tau value
					_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fStartTau);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_DOMAIN_STARTTAU), szBuffer);

					// Load the end tau value
					_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fEndTau);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_DOMAIN_ENDTAU), szBuffer);

					// Load the start freq value
					_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
						fStartFreq);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_DOMAIN_STARTFREQ), szBuffer);

					// Load the end freq value
					_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fEndFreq);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_DOMAIN_ENDFREQ), szBuffer);

					// Load the carrier freq
					_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fMHz);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_DOMAIN_MHZ), szBuffer);

					// Load the averaging factor
					_snprintf(szBuffer, sizeof(szBuffer), "%d", nAvgFactor);
					SetWindowText(GETHCTL(IDC_DOMAIN_AF), szBuffer);

					// Load the bw factor
					_snprintf(szBuffer, sizeof(szBuffer), "%5.3f", fBW);
					SetWindowText(GETHCTL(IDC_DOMAIN_BW), szBuffer);

					// Load the bw value
					_snprintf(szBuffer, sizeof(szBuffer), "%5.3f",
						fBW/(2.0*PI*fTau));
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_DOMAIN_FHIGH), szBuffer);

					// Disable the bw factor edit control
					EnableWindow(GETHCTL(IDC_DOMAIN_BWLABEL), FALSE);
					EnableWindow(GETHCTL(IDC_DOMAIN_BW), FALSE);

					// Disable the bw value edit control
					EnableWindow(GETHCTL(IDC_DOMAIN_FLABEL), FALSE);
					EnableWindow(GETHCTL(IDC_DOMAIN_FHIGH), FALSE);

					// Load all the noise parameters
					for(i=0; i<5; i++) // i=alpha+2
					{
						// Load the freq domain noise parameters
						if(nPSDType==PSD_L)
						{
							if(fPS[i])
							{
								_snprintf(szBuffer, sizeof(szBuffer), "%5.1f",
									fPS[i]);
							}
							else
							{
								LoadString(hInst, IDS_MESSAGE_NONE, szBuffer,
									BUFFER_SIZE);
							}
						}
						else
						{
							_snprintf(szBuffer, sizeof(szBuffer), "%11.5e",
								fPS[i]);
							ShortenExp(szBuffer);
						}

						SetWindowText(GETHCTL(IDC_DOMAIN_FRWF+i), szBuffer);

						// Load the time domain noise parameters
						_snprintf(szBuffer, sizeof(szBuffer), "%11.5e",
							fSigma[i]);
						ShortenExp(szBuffer);
						SetWindowText(GETHCTL(IDC_DOMAIN_TRWF+i), szBuffer);
					}

					// Recalc the total parameter values
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_DOMAIN_TOTAL, NULL, 0));

					// Enable processing
					bFlag=TRUE;
				}
				break;

				// Updating scheme:
				// -----------------
				// | Freq  | Time  |
				// -----------------
				// | PSD   | Sigma |
				// -----------------
				// Changing any Freq item updates all PSD items
				// with Time and Sigma items unchanged
				// Changing any Time item updates all Sigma items
				// with Freq and PSD items unchanged
				// Changing a PSD item updates that Sigma item
				// Changing a Sigma item updates that PSD item

				// Detect PSD type change (nPSDType)
				// PSD type control is in Freq group
				// Changed PSD type requires recalc
				// of all PSD freq domain values
				// Note: This is a PSD units conversion
				case IDC_DOMAIN_PSD:
				{
					// Redisplay PSD info
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_DOMAIN_DSPPSD, NULL, 0));

					// Process PSD change
					if(bFlag)
					{
						// Get (new) PSD type
						nPSDType=
							4-ComboBox_GetCurSel(GETHCTL(IDC_DOMAIN_PSD));

						// Recalc the new freq domain parameter values
						for(i=0; i<5; i++) // alpha=i-2
						{
							// Recalc the freq domain parameter value
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_DOMAIN_TTOF,
								NULL, 0));
						}

						// Recalc the total parameter values
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_TOTAL,
							NULL, 0));
					}
				}
				break;

				// Detect SB freq change (fSBFreq)
				// FREQ control is in Freq group
				// Changed SB freq requires recalc
				// of all PSD freq domain values
				// Note:  This wil show PSD as a function
				// of SB freq for same sigma
				case IDC_DOMAIN_FREQ:
				{
					// Process SB freq change
					if(bFlag)
					{
						// Get (new) SB freq
						GetWindowText(GETHCTL(IDC_DOMAIN_FREQ), szBuffer,
							BUFFER_SIZE);
						fSBFreq=(float)fabs(atof(szBuffer));

						// Trap zero SB freq value
						if(!fSBFreq)
						{
							fSBFreq=1.0;
						}

						// Redisplay the SB freq value
						if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS))
						{
							_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
								fSBFreq);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_DOMAIN_FREQ),	szBuffer);
						}

						// Recalc the new freq domain parameter values
						for(i=0; i<5; i++) // alpha=i-2
						{
							// Recalc the freq domain parameter value
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_DOMAIN_TTOF, NULL, 0));
						}

						// Recalc the total parameter values
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_TOTAL, NULL, 0));
					}
				}
				break;

				// Detect carrier freq change (fMHz)
				// MHZ control is in Freq group
				// Changed carrier freq requires recalc
				// of all PSD freq domain values
				case IDC_DOMAIN_MHZ:
				{
					// Process SB freq change
					if(bFlag)
					{
						// Get (new) carrier freq
						GetWindowText(GETHCTL(IDC_DOMAIN_MHZ), szBuffer,
							BUFFER_SIZE);
						fMHz=(float)fabs(atof(szBuffer));

						// Trap zero carrier freq value
						if(!fMHz)
						{
							fMHz=10.0;
						}

						if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS))
						{
							// Redisplay the MHz factor value
							_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
								fMHz);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_DOMAIN_MHZ), szBuffer);
						}

						// Recalc the new freq domain parameter values
						for(i=0; i<5; i++) // alpha=i-2
						{
							// Recalc the freq domain parameter value
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_DOMAIN_TTOF,
								NULL, 0));
						}

						// Recalc the total parameter values
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_TOTAL,
							NULL, 0));
					}
				}
				break;

				// Detect sigma type change (nSigmaType)
				// SIG control is in Time group
				// Changed sigma type requires recalc
				// of all Sigma time domain items
				case IDC_DOMAIN_SIG:
				{
					// Redisplay Sigma info
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_DOMAIN_DSPSIG, NULL, 0));

					if(bFlag)
					{
						// Get (new) sigma type
						nSigmaType=5+
							ComboBox_GetCurSel(GETHCTL(IDC_DOMAIN_SIG));

						// Recalc the new time domain parameter values
						for(i=0; i<5; i++) // alpha=i-2
						{
							// Recalc the time domain parameter values
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_DOMAIN_FTOT,
								NULL, 0));
						}

						// Recalc the total parameter values
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_TOTAL,
							NULL, 0));
					}
				}
				break;

				// Detect tau change (fTau)
				// TAU control is in Time group
				// Changed tau value requires recalc
				// of all Sigma time domain items
				// Note: This will show sigma as a function of tau
				case IDC_DOMAIN_TAU:
				{
					if(bFlag)
					{
						// Get (new) tau value
						GetWindowText(GETHCTL(IDC_DOMAIN_TAU), szBuffer,
							BUFFER_SIZE);
						fTau=(float)fabs(atof(szBuffer));

						// Trap zero tau value
						if(!fTau)
						{
							fTau=1.0;
						}

						if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS))
						{
							// Redisplay the tau value
							_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
								fTau);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_DOMAIN_TAU), szBuffer);
						}

						// The new tau value also affects the BW factor
						// fBW=fhigh*2*pi*tau
						// Get fhigh and find new fBW
						GetWindowText(GETHCTL(IDC_DOMAIN_FHIGH), szBuffer,
							BUFFER_SIZE);
						fBW=(float)(2.0*PI*fTau*fabs(atof(szBuffer)));

						// And save it in BW control
						_snprintf(szBuffer, sizeof(szBuffer), "%5.3f", fBW);
						SetWindowText(GETHCTL(IDC_DOMAIN_BW), szBuffer);
						
						// Recalc the new time domain parameter values
						for(i=0; i<5; i++) // alpha=i-2
						{
							// Recalc the time domain parameter value
							SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_FTOT,
							NULL, 0));
						}

						// Recalc the total parameter values
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_TOTAL,
							NULL, 0));
					}
				}
				break;

				// Detect avg factor change (nAvgFactor)
				// AF control is in Time group
				// Changed avg factor requires recalc
				// of all Sigma time domain values
				// Note:  This wil show sigma as a function of avg factor
				case IDC_DOMAIN_AF:
				{
					if(bFlag)
					{
						// Get (new) avg factor
						GetWindowText(GETHCTL(IDC_DOMAIN_AF),szBuffer,
							BUFFER_SIZE);
						nAvgFactor=abs(atoi(szBuffer));

						// Trap zero avg factor value
						if(!nAvgFactor)
						{
							nAvgFactor=1;
						}

						if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS))
						{
							// Redisplay the avg factor value
							_snprintf(szBuffer, sizeof(szBuffer), "%d",
								nAvgFactor);
							SetWindowText(GETHCTL(IDC_DOMAIN_AF), szBuffer);
						}

						// Recalc the new time domain parameter values
						for(i=0; i<5; i++) // alpha=i-2
						{
							// Recalc the time domain parameter value
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_DOMAIN_FTOT,
								NULL, 0));
						}

						// Recalc the total parameter values
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_TOTAL,
							NULL, 0));
					}
				}
				break;

				// Detect BW factor change (fBW)
				// BW control is in Time group
				// BW factor change requires recalc
				// of all Sigma time domain values
				// It also changes fHigh
				case IDC_DOMAIN_BW:
				{
					if(bFlag)
					{
						// Get (new) BW factor
						GetWindowText(GETHCTL(IDC_DOMAIN_BW), szBuffer,
							BUFFER_SIZE);
						fBW=(float)fabs(atof(szBuffer));

						// Trap zero bw factor
						if(!fBW)
						{
							fBW=10.0;
						}

						if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS))
						{
							// Redisplay the bw factor
							_snprintf(szBuffer, sizeof(szBuffer), "%5.3f",
								fBW);
							SetWindowText(GETHCTL(IDC_DOMAIN_BW), szBuffer);

							// Redisplay the fhigh value
							_snprintf(szBuffer, sizeof(szBuffer), "%5.3f",
								fBW/(2.0*PI*fTau));
							SetWindowText(GETHCTL(IDC_DOMAIN_FHIGH), szBuffer);
						}

						// Recalc the new time domain parameter values
						for(i=0; i<5; i++) // alpha=i-2
						{
							// Recalc the freq domain parameter value
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_DOMAIN_FTOT,
								NULL, 0));
						}

						// Recalc the total parameter values
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_TOTAL, NULL, 0));
					}
				}
				break;

				// Detect fHigh value change (fBW/2*pi*tau)
				// FHIGH control is in Freq group
				// fHigh change requires recalc of all PSD freq domain items
				// It also changes BW Factor
				case IDC_DOMAIN_FHIGH:
				{
					if(bFlag)
					{
						// Get (new) fHigh value
						// Note:  This actually changes fBW
						GetWindowText(GETHCTL(IDC_DOMAIN_FHIGH), szBuffer,
							BUFFER_SIZE);
						fBW=(float)(2.0*PI*fTau*fabs(atof(szBuffer)));

						// Trap zero bw value
						if(!fBW)
						{
							fBW=10.0;
						}

						if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS))
						{
							// Redisplay the bw factor
							_snprintf(szBuffer, sizeof(szBuffer), "%5.3f",
								fBW);
							SetWindowText(GETHCTL(IDC_DOMAIN_BW), szBuffer);

							// Redisplay the fhigh value
							_snprintf(szBuffer, sizeof(szBuffer), "%5.3f",
								fBW/(2.0*PI*fTau));
							SetWindowText(GETHCTL(IDC_DOMAIN_FHIGH), szBuffer);
						}

						// Recalc the new freq domain parameter values
						for(i=0; i<5; i++) // alpha=i-2
						{
							// Recalc the freq domain parameter value
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_DOMAIN_TTOF,
								NULL, 0));
						}

						// Recalc the total parameter values
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_TOTAL,
							NULL, 0));
					}
				}
				break;

				// Detect freq domain parameter change
				// All of these controls are in PSD group
				// Changing any of them requires recalc
				// of corresponding Sigma time domain value
				// (actually all Sigma values are recalculated)
				case IDC_DOMAIN_FRWF: // i=0
				case IDC_DOMAIN_FFF:  // i=1
				case IDC_DOMAIN_FWF:  // i=2
				case IDC_DOMAIN_FFP:  // i=3
				case IDC_DOMAIN_FWP:  // i=4
				{
					i=GET_WM_COMMAND_ID(wParam, lParam)-IDC_DOMAIN_FRWF;

					// Process freq domain parameter value
					if(bFlag)
					{
						// Get new freq domain parameter value
						GetWindowText(GETHCTL(IDC_DOMAIN_FRWF+i), szBuffer,
							BUFFER_SIZE);
						fPS[i]=(float)atof(szBuffer);

						if( (strcmp(szBuffer, "None")==0) || (!fPS[i]) )
						{
							fPS[i]=0.0;

							if( (i==3) || (i==4) ) // FPM or WPM
							{
								// Disable bw factor edit control
								EnableWindow(GETHCTL(IDC_DOMAIN_BWLABEL),
									FALSE);
								EnableWindow(GETHCTL(IDC_DOMAIN_BW),
									FALSE);

								// Disable bw value edit control
								EnableWindow(GETHCTL(IDC_DOMAIN_FLABEL),
									FALSE);
								EnableWindow(GETHCTL(IDC_DOMAIN_FHIGH),
									FALSE);
							}
						}
						else
						{
							if( (i==3) || (i==4) ) // FPM or WPM
							{
								// Enable bw factor edit control
								EnableWindow(GETHCTL(IDC_DOMAIN_BWLABEL),
									TRUE);
								EnableWindow(GETHCTL(IDC_DOMAIN_BW),
									TRUE);

								// Enable bw value edit control
								EnableWindow(GETHCTL(IDC_DOMAIN_FLABEL),
									TRUE);
								EnableWindow(GETHCTL(IDC_DOMAIN_FHIGH),
									TRUE);
							}
						}

						if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS))
						{
							// Redisplay the freq domain noise parameter
							if(nPSDType==PSD_L)
							{
								if(fPS[i])
								{
									_snprintf(szBuffer, sizeof(szBuffer),
										"%5.1f", fPS[i]);
								}
								else
								{
									LoadString(hInst, IDS_MESSAGE_NONE,
										szBuffer, BUFFER_SIZE);
								}
							}
							else
							{
								_snprintf(szBuffer, sizeof(szBuffer), "%11.5e",
									fPS[i]);
								ShortenExp(szBuffer);
							}

							SetWindowText(GETHCTL(IDC_DOMAIN_FRWF+i),
								szBuffer);
						}

						// Recalc the time domain parameter value
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_FTOT,
							NULL, 0));

						// Recalc the total parameter values
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_TOTAL,
							NULL, 0));
					}
				}
				break;

				// Detect time domain parameter change
				// All of these controls are in Sigma group
				// Changing any of them requires recalc
				// of corresponding PSD freq domain value
				// (actually all PSD values are recalculated)
				case IDC_DOMAIN_TRWF: // i=0
				case IDC_DOMAIN_TFF:  // i=1
				case IDC_DOMAIN_TWF:  // i=2
				case IDC_DOMAIN_TFP:  // i=3
				case IDC_DOMAIN_TWP:  // i=4
				{
					i=GET_WM_COMMAND_ID(wParam, lParam)-IDC_DOMAIN_TRWF;

					// Process time domain parameter value
					if(bFlag)
					{
						// Get new time domain parameter value
						GetWindowText(GETHCTL(IDC_DOMAIN_TRWF+i), szBuffer,
							BUFFER_SIZE);
						fSigma[i]=(float)atof(szBuffer);

						if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS))
						{
							// Redisplay the time domain noise parameter
							_snprintf(szBuffer, sizeof(szBuffer), "%11.5e",
								fSigma[i]);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_DOMAIN_TRWF+i),
								szBuffer);
						}

						if( ((i==3)||(i==4)) && (fSigma[i]) )
						// Non-zero FPM or WPM
						{
							// Enable bw factor edit control
							EnableWindow(GETHCTL(IDC_DOMAIN_BWLABEL),
								TRUE);
							EnableWindow(GETHCTL(IDC_DOMAIN_BW),
								TRUE);

							// Enable bw value edit control
							EnableWindow(GETHCTL(IDC_DOMAIN_FLABEL),
								TRUE);
							EnableWindow(GETHCTL(IDC_DOMAIN_FHIGH),
								TRUE);
						}

						if( ((i==3)||(i==4)) && (!fSigma[i]) )
						// zero FPM or WPM
						{
							// Disable bw factor edit control
							EnableWindow(GETHCTL(IDC_DOMAIN_BWLABEL),
								FALSE);
							EnableWindow(GETHCTL(IDC_DOMAIN_BW),
								FALSE);

							// Disable bw value edit control
							EnableWindow(GETHCTL(IDC_DOMAIN_FLABEL),
								FALSE);
							EnableWindow(GETHCTL(IDC_DOMAIN_FHIGH),
								FALSE);
						}

						// Recalc the freq domain parameter value
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_TTOF,
							NULL, 0));

						// Recalc the total parameter values
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_TOTAL,
							NULL, 0));
					}
				}
				break;

				// Detect start freq change
				// Note:  Start freq cannot be zero
				// or equal to or larger than end freq
				case IDC_DOMAIN_STARTFREQ:
				{
					if(bFlag)
					{
						// Get (new) start freq value
						GetWindowText(GETHCTL(IDC_DOMAIN_STARTFREQ), szBuffer,
							BUFFER_SIZE);
						fStartFreq=(float)fabs(atof(szBuffer));

						// Trap zero start freq value
						if(!fStartFreq)
						{
							// Set start freq to default
							fStartFreq=(float)1.0;
						}

						if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS))
						{
							// Redisplay the start freq value
							_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
								fStartFreq);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_DOMAIN_STARTFREQ),
								szBuffer);
						}

						// Calculate integrated phase jitter
						PostMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDC_DOMAIN_JITTER, NULL, 0));

						// Calculate residual FM
						PostMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDC_DOMAIN_RESIDUAL, NULL, 0));
					}
				}
				break;

				// Detect end freq change
				// End freq cannot be zero
				// or equal to or smaller than start freq
				case IDC_DOMAIN_ENDFREQ:
				{
					if(bFlag)
					{
						// Get (new) end freq value
						GetWindowText(GETHCTL(IDC_DOMAIN_ENDFREQ), szBuffer,
							BUFFER_SIZE);
						fEndFreq=(float)fabs(atof(szBuffer));

						// Trap zero end freq value
						if(!fEndFreq)
						{
							// Set end freq to default
							fEndFreq=(float)1000.0;
						}

						if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS))
						{
							// Redisplay the end freq value
							_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
								fEndFreq);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_DOMAIN_ENDFREQ), szBuffer);
						}

						// Calculate integrated phase jitter
						PostMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDC_DOMAIN_JITTER, NULL, 0));

						// Calculate residual FM
						PostMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDC_DOMAIN_RESIDUAL, NULL, 0));
					}
				}
				break;

				// Detect start tau change
				// Note:  Start tau cannot be zero
				// or equal to or larger than end tau
				case IDC_DOMAIN_STARTTAU:
				{
					if(bFlag)
					{
						// Get (new) start tau value
						GetWindowText(GETHCTL(IDC_DOMAIN_STARTTAU), szBuffer,
							BUFFER_SIZE);
						fStartTau=(float)fabs(atof(szBuffer));

						// Trap zero start tau value
						if(!fStartTau)
						{
							// Set start tau to default
							fStartTau=(float)1.0e-03;
						}

						if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS))
						{
							// Redisplay the start tau value
							_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
								fStartTau);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_DOMAIN_STARTTAU),
								szBuffer);
						}
					}
				}
				break;

				// Detect end tau change
				// End tau cannot be zero
				// or equal to or smaller than start tau
				case IDC_DOMAIN_ENDTAU:
				{
					if(bFlag)
					{
						// Get (new) end tau value
						GetWindowText(GETHCTL(IDC_DOMAIN_ENDTAU), szBuffer,
							BUFFER_SIZE);
						fEndTau=(float)fabs(atof(szBuffer));

						// Trap zero end tau value
						if(!fEndTau)
						{
							// Set end tau to default
							fEndTau=(float)1.0;
						}

						if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS))
						{
							// Redisplay the end tau value
							_snprintf(szBuffer, sizeof(szBuffer), "%10.5e",
								fEndTau);
							ShortenExp(szBuffer);
							SetWindowText(GETHCTL(IDC_DOMAIN_ENDTAU), szBuffer);
						}
					}
				}
				break;

				// Respond to CR in an edit control
				// Note: No button is a DEFPUSHBUTTON
				case IDOK:
				{
					// Does freq edit control have focus?
					if(GetFocus()==GETHCTL(IDC_DOMAIN_FREQ))
					{
						// Send EN_KILLFOCUS message to freq edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_FREQ, NULL,
							EN_KILLFOCUS));
					}

					// Does MHz edit control have focus?
					if(GetFocus()==GETHCTL(IDC_DOMAIN_MHZ))
					{
						// Send EN_KILLFOCUS message to MHz edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_MHZ, NULL,
							EN_KILLFOCUS));
					}

					// Does tau edit control have focus?
					if(GetFocus()==GETHCTL(IDC_DOMAIN_TAU))
					{
						// Send EN_KILLFOCUS message to tau edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_TAU, NULL,
							EN_KILLFOCUS));
					}

					// Does avg factor edit control have focus?
					if(GetFocus()==GETHCTL(IDC_DOMAIN_AF))
					{
						// Send EN_KILLFOCUS message to af edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_AF, NULL,
							EN_KILLFOCUS));
					}

					// Does bw factor edit control have focus?
					if(GetFocus()==GETHCTL(IDC_DOMAIN_BW))
					{
						// Send EN_KILLFOCUS message to bw factor edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_BW, NULL,
							EN_KILLFOCUS));
					}

					// Does bw value edit control have focus?
					if(GetFocus()==GETHCTL(IDC_DOMAIN_FHIGH))
					{
						// Send EN_KILLFOCUS message to bw value edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_FHIGH, NULL,
							EN_KILLFOCUS));
					}

					// Does time domain rwfm edit control have focus?
					if(GetFocus()==GETHCTL(IDC_DOMAIN_TRWF))
					{
						// Send EN_KILLFOCUS message to rwfm edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_TRWF, NULL,
							EN_KILLFOCUS));
					}

					// Does time domain ffm edit control have focus?
					if(GetFocus()==GETHCTL(IDC_DOMAIN_TFF))
					{
						// Send EN_KILLFOCUS message to ffm edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_TFF, NULL,
							EN_KILLFOCUS));
					}

					// Does time domain wfm edit control have focus?
					if(GetFocus()==GETHCTL(IDC_DOMAIN_TWF))
					{
						// Send EN_KILLFOCUS message to wfm edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_TWF, NULL,
							EN_KILLFOCUS));
					}

					// Does time domain fpm edit control have focus?
					if(GetFocus()==GETHCTL(IDC_DOMAIN_TFP))
					{
						// Send EN_KILLFOCUS message to fpm edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_TFP, NULL,
							EN_KILLFOCUS));
					}

					// Does time domain wpm edit control have focus?
					if(GetFocus()==GETHCTL(IDC_DOMAIN_TWP))
					{
						// Send EN_KILLFOCUS message to wpm edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_TWP, NULL,
							EN_KILLFOCUS));
					}

					// Does freq domain rwfm edit control have focus?
					if(GetFocus()==GETHCTL(IDC_DOMAIN_FRWF))
					{
						// Send EN_KILLFOCUS message to rwfm edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_FRWF, NULL,
							EN_KILLFOCUS));
					}

					// Does freq domain ffm edit control have focus?
					if(GetFocus()==GETHCTL(IDC_DOMAIN_FFF))
					{
						// Send EN_KILLFOCUS message to ffm edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_FFF, NULL,
							EN_KILLFOCUS));
					}

					// Does freq domain wfm edit control have focus?
					if(GetFocus()==GETHCTL(IDC_DOMAIN_FWF))
					{
						// Send EN_KILLFOCUS message to wfm edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_FWF, NULL,
							EN_KILLFOCUS));
					}

					// Does freq domain fpm edit control have focus?
					if(GetFocus()==GETHCTL(IDC_DOMAIN_FFP))
					{
						// Send EN_KILLFOCUS message to fpm edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_FFP, NULL,
							EN_KILLFOCUS));
					}

					// Does freq domain wpm edit control have focus?
					if(GetFocus()==GETHCTL(IDC_DOMAIN_FWP))
					{
						// Send EN_KILLFOCUS message to wpm edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_FWP, NULL,
							EN_KILLFOCUS));
					}

					// Does start freq edit control have focus?
					if(GetFocus()==GETHCTL(IDC_DOMAIN_STARTFREQ))
					{
						// Send EN_KILLFOCUS message to start freq edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_STARTFREQ, NULL,
							EN_KILLFOCUS));
					}

					// Does end freq edit control have focus?
					if(GetFocus()==GETHCTL(IDC_DOMAIN_ENDFREQ))
					{
						// Send EN_KILLFOCUS message to end freq edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_ENDFREQ, NULL,
							EN_KILLFOCUS));
					}

					// Does start tau edit control have focus?
					if(GetFocus()==GETHCTL(IDC_DOMAIN_STARTTAU))
					{
						// Send EN_KILLFOCUS message to start tau edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_STARTTAU, NULL,
							EN_KILLFOCUS));
					}

					// Does end tau edit control have focus?
					if(GetFocus()==GETHCTL(IDC_DOMAIN_ENDTAU))
					{
						// Send EN_KILLFOCUS message to end tau edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_ENDTAU, NULL,
							EN_KILLFOCUS));
					}
				}
				break;

				case IDC_DOMAIN_TTOF:
				{
					// Inhibit message processing
					bFlag=FALSE;

					// Get fhigh
					GetWindowText(GETHCTL(IDC_DOMAIN_FHIGH), szBuffer,
						BUFFER_SIZE);
					fHigh=(float)fabs(atof(szBuffer));

					// Recalc the freq domain parameter value
					if(fSigma[i])
					{
						CalcDomain(&fNoise, fSigma[i], fTau*nAvgFactor,
							fSBFreq, (float)(fMHz*1e6), fHigh,
							nSigmaType, i-2, nAvgFactor);
						ConvDomain(fNoise, &fPS[i], fTau*nAvgFactor,
							fSBFreq, (float)(fMHz*1e6), fHigh,
							nPSDType, i-2, nAvgFactor);
					}
					else
					{
						fPS[i]=0.0;
						fNoise=0.0;
						fPS[i]=0.0;
					}

					// Display the freq domain noise parameter
					if(nPSDType==PSD_L)
					{
						if(fPS[i])
						{
							_snprintf(szBuffer, sizeof(szBuffer), "%5.1f",
								fPS[i]);
						}
						else
						{
							LoadString(hInst, IDS_MESSAGE_NONE, szBuffer,
								BUFFER_SIZE);
						}
					}
					else
					{
						_snprintf(szBuffer, sizeof(szBuffer), "%11.5e",
							fPS[i]);
						ShortenExp(szBuffer);
					}
					SetWindowText(GETHCTL(IDC_DOMAIN_FRWF+i), szBuffer);

					// Allow message processing
					bFlag=TRUE;
				}
				break;

				case IDC_DOMAIN_FTOT:
				{
					// Inhibit message processing
					bFlag=FALSE;

					// Get fhigh
					GetWindowText(GETHCTL(IDC_DOMAIN_FHIGH), szBuffer,
						BUFFER_SIZE);
					fHigh=(float)fabs(atof(szBuffer));

					// Recalc the time domain parameter value
					if(fPS[i])
					{
						CalcDomain(&fNoise, fPS[i], fTau*nAvgFactor,
							fSBFreq, (float)(fMHz*1e6), fHigh,
							nPSDType, i-2, nAvgFactor);
						ConvDomain(fNoise, &fSigma[i], fTau*nAvgFactor,
							fSBFreq, (float)(fMHz*1e6), fHigh,
							nSigmaType, i-2, nAvgFactor);
					}
					else
					{
						fSigma[i]=0.0;
						fNoise=0.0;
						fPS[i]=0.0;
					}

					// Display the time domain noise parameter
					_snprintf(szBuffer, sizeof(szBuffer), "%11.5e", fSigma[i]);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_DOMAIN_TRWF+i), szBuffer);

					// Allow message processing
					bFlag=TRUE;
				}
				break;

				case IDC_DOMAIN_TOTAL:
				{
					// Inhibit message processing
					bFlag=FALSE;

					// Calc total PSD
					fFALL=AddPSD(fPS, nPSDType);

					// Display total PSD
					if(nPSDType==PSD_L)
					{
						if(fFALL)
						{
							_snprintf(szBuffer, sizeof(szBuffer), "%5.1f",
								fFALL);
						}
						else
						{
							LoadString(hInst, IDS_MESSAGE_NONE, szBuffer,
								BUFFER_SIZE);
						}
					}
					else
					{
						_snprintf(szBuffer, sizeof(szBuffer), "%11.5e", fFALL);
						ShortenExp(szBuffer);
					}
					SetWindowText(GETHCTL(IDC_DOMAIN_FALL), szBuffer);

					// Calc total Sigma
					fTALL=AddSigma(fSigma);

					// Display the total sigma
					_snprintf(szBuffer, sizeof(szBuffer), "%11.5e", fTALL);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_DOMAIN_TALL), szBuffer);

					// Enable buttons until there are non-zero results
					if(fTALL)
					{
						// Enable the copy button
						EnableWindow(GETHCTL(IDC_DOMAIN_COPY), TRUE);

						// Disable the plot buttons
						EnableWindow(GETHCTL(IDC_DOMAIN_PLOTPSD), TRUE);
						EnableWindow(GETHCTL(IDC_DOMAIN_PLOTSIGMA), TRUE);
					
					}
					else // No results
					{
						// Disable the copy button
						EnableWindow(GETHCTL(IDC_DOMAIN_COPY), FALSE);

						// Disable the plot buttons
						EnableWindow(GETHCTL(IDC_DOMAIN_PLOTPSD), FALSE);
						EnableWindow(GETHCTL(IDC_DOMAIN_PLOTSIGMA), FALSE);
					
					}

					#if(1) // New code 07/23/17
					// Do we have PSD values?
					if (fFALL)
					{
						// Calculate integrated phase jitter
						PostMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDC_DOMAIN_JITTER, NULL, 0));

						// Calculate residual FM
						PostMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDC_DOMAIN_RESIDUAL, NULL, 0));
					}
					else // No noise
					{
						// Clear results
						SetWindowText(GETHCTL(IDC_DOMAIN_JIT), "");
						SetWindowText(GETHCTL(IDC_DOMAIN_PS), "");
						SetWindowText(GETHCTL(IDC_DOMAIN_FM), "");
					}
					#endif

					// Allow message processing
					bFlag=TRUE;
				}
				break;

				// Procedure to plot sigma from psd values
				case IDC_DOMAIN_PLOTSIGMA:
				{
					// We are going to calc sigma for a set of tau values
					// to generate data for a sigma-tau plot
					// After doing that, we want to restore
					// everything as it was
					// I'm assuming everything is set OK going into this
					// Save	current avg factor and tau
					nSaveAvgFactor=nAvgFactor;
					fSaveTau=fTau;
					fSaveSBFreq=fSBFreq;

					// Set starting tau to smallest cardinal value
					// consistent with highest PSD frequency
					// and proceed in octave steps toward
					// highest cardinal tau value
					// consistent with lowest PSD frequency
					// No automatic way to do that
					// Must manually enter tau range 

					// Get start tau value
					GetWindowText(GETHCTL(IDC_DOMAIN_STARTTAU), szBuffer,
						BUFFER_SIZE);
					fStartTau=(float)fabs(atof(szBuffer));

					// Get end tau value
					GetWindowText(GETHCTL(IDC_DOMAIN_ENDTAU), szBuffer,
						BUFFER_SIZE);
					fEndTau=(float)fabs(atof(szBuffer));

					// Calc # sigma data points = # octaves between
					// tau start and end
					nSigmaSize=(int)ceil((log(fEndTau/fStartTau)/log(2.0)));
					
					// It is possible for the # sigma points
					// to exceed this by 1
					// if fEndTau is exactly divisible by fStartTau
					// Increment nSigmaSize to be safe
					nSigmaSize++;
					nSigmaSize++;

					// Increment nSigmaSize once again for final point
					// at end tau
					nSigmaSize++;

					// Double nSigmaSize for 2 points/octave
					nSigmaSize*=2;

					// Reallocate size of sigma data arrays
					nDummy=ReallocSigmaArrays(nSigmaSize);

					// Note: If nDummy is -1 then there was a memory
					// reallocation error and we should bail out
					if(nDummy==-1)
					{
						PostMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDCANCEL, NULL, 0));
						break;
					}

					// Initializations
					fTau=fStartTau;
					nAvgFactor=1;
					j=0;

					// Loop through AF increments
					while(fTau*nAvgFactor<fEndTau)
					{
						// Calc the time domain parameter values
						for(i=0; i<5; i++) // alpha=i-2
						{
							// Calc the time domain parameter value
							// Inputs is PSD value for particular noise type
							// along with other params
							// Output is sigma value for that noise type
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_DOMAIN_FTOT,
								NULL, 0));

							fH[i]=fNoise;
						}

						// Calc the total parameter values
						// Takes individual sigma values and finds their total
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_TOTAL,
							NULL, 0));

						// Store sigma-tau data in plot array
						if(nSigmaType==SIG_Y)
						{
							sNormSigData.sigma[j]=fTALL;
							sNormSigData.tau[j]=fTau*nAvgFactor;
							sNormSigData.num[j]=0; // No symbols
							sNormSigData.points=j+1;
							sNormSigData.rows=j+1;
						}
						else // mod or time sigma
						{
							sModSigData.sigma[j]=fTALL;
							sModSigData.tau[j]=fTau*nAvgFactor;
							sNormSigData.num[j]=0; // No symbols
							sModSigData.points=j+1;
							sModSigData.rows=j+1;
						}
						
						// Increment AF and index
						// nAvgFactor*=2; // 1 point/octave
						// 2 points/octave is smoother
						if(nAvgFactor<3)
						{
							// Increment AF until it's big enough to multiply
							nAvgFactor++; 
						}
						else
						{
							// 2 points/octave
							nAvgFactor=(int)((double)nAvgFactor*sqrt(2.0)); 
						}
						j++;
					}

					// Calc final point at end tau
					nAvgFactor=(int)floor(fEndTau/fTau);
					{
						// Calc the time domain parameter values
						for(i=0; i<5; i++) // alpha=i-2
						{
							// Calc the time domain parameter value
							// Inputs is PSD value for particular noise type
							// along with other params
							// Output is sigma value for that noise type
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_DOMAIN_FTOT,
								NULL, 0));

							fH[i]=fNoise;
						}

						// Calc the total parameter values
						// Takes individual sigma values and finds their total
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_TOTAL,
							NULL, 0));

						// Store sigma-tau data in plot array
						// Note: The data is plotted w/o symbols
						// because the num struct item is zero
						if(nSigmaType==SIG_Y)
						{
							sNormSigData.sigma[j]=fTALL;
							sNormSigData.tau[j]=fTau*nAvgFactor;
							sNormSigData.points=j+1;
							sNormSigData.rows=j+1;
						}
						else // mod or time sigma
						{
							sModSigData.sigma[j]=fTALL;
							sModSigData.tau[j]=fTau*nAvgFactor;
							sModSigData.points=j+1;
							sModSigData.rows=j+1;
						}
					}

					// Set plot type (global)
					// Rather than SIGMA_PLOT to omit # data points,
					// tau & filename
					nPlotType=DOMAIN_SIGMA_PLOT; 

					// Set sigma type (global)
					if(nSigmaType==SIG_Y)
					{
						nSigmaPlotType=NORMAL_SIGMA;
					}

					if(nSigmaType==MODSIG_Y)
					{
						nSigmaPlotType=MODIFIED_SIGMA;
					}

					if(nSigmaType==SIG_X)
					{
						nSigmaPlotType=TIME_SIGMA;
					}

					// Eliminate all sigma plot lines
					for(i=0; i<SLINE_NUMLINES; i++)
					{
						sSLine[i].nLineType=SLINE_NONE;
					}

					// Initialize sigma plot params
					InitSigmaPlotParams();
					CalcSigmaPlotScale();

					// Set sigma plot flags
					sSPlot.do_date=TRUE;
					sSPlot.do_box=TRUE;
					sSPlot.do_errbar=FALSE;
					sSPlot.do_line=FALSE;
					sSPlot.do_mouse=FALSE;
					sSPlot.do_fit=FALSE;
					sSPlot.do_table=FALSE;
					sSPlot.do_wide=TRUE;
					sSPlot.new_file=TRUE;
					sSPlot.new_name=TRUE;

					// Make line wider
					// The do_wide flag dowsn't accomplish this
					// Actually, the thick value causes a wider tline setting
					// in the no symbol sigma plot
					sSPlot.thick=WIDELINESIZE;

					// Set plot title
					_snprintf(sSPlot.title, TITLESIZE,
						"TIME DOMAIN STABILITY");

					// Set plot subtitle (show non-zero noise params)
					strlcpy(sSPlot.subtitle, "", SUBTITLESIZE);
					bComma=FALSE;
					for(i=0; i<5; i++) // alpha=i-2
					{
						if(fH[i] && bComma)
						{
							_snprintf(szBuffer, sizeof(szBuffer),
								", h]%d[=%1.2e", i-2, fH[i]);
							strlcat(sSPlot.subtitle, szBuffer, SUBTITLESIZE);
						}

						if(fH[i] && !bComma)
						{
							_snprintf(szBuffer, sizeof(szBuffer),
								"h]%d[=%1.2e", i-2, fH[i]);
							strlcat(sSPlot.subtitle, szBuffer, SUBTITLESIZE);
							bComma=TRUE;
						}
					}

					// 2-digit exponent
					ShortenExp(sSPlot.subtitle);

					// Set the carrier freq
					sSPlot.carrier=fMHz;

					// Set the BW
					sSPlot.bw=fHigh;
					
					// Create child window for plot
					GPCWINCreate(hChildWnd, hInst, hDlg, SW_SHOWNORMAL,
						&hChildAccel, NULL);

					// Restore domain settings
					nAvgFactor=nSaveAvgFactor;
					fTau=fSaveTau;
					fSBFreq=fSaveSBFreq;

					// Recalc the time domain parameter values
					for(i=0; i<5; i++) // alpha=i-2
					{
						// Recalc the time domain parameter value
						// Inputs is PSD value for particular noise type
						// along with other params
						// Output is sigma value for that noise type
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_FTOT,
							NULL, 0));
					}

					// Recalc the total parameter values
					// Takes individual sigma values and finds their total
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_DOMAIN_TOTAL,
						NULL, 0));
				}
				break;

				// Procedure to plot psd from sigma values
				case IDC_DOMAIN_PLOTPSD:
				{
					// We are going to calc psd for a set of freq values
					// to generate data for a psd vs freq plot
					// After doing that,
					// we want to restore everything as it was
					// I'm assuming everything is set OK going into this
					// Save	current avg factor and tau
					nSaveAvgFactor=nAvgFactor;
					fSaveTau=fTau;
					fSaveSBFreq=fSBFreq;

					// Set avg factor to 1
					//nAvgFactor=1; // Don't want this!

					// Set starting freq to lowest cardinal value
					// consistent with largest tau
					// and proceed in octave steps
					// toward highest cardinal freq value
					// consistent with smallest tau
					// No automatic way to do that
					// Must manually enter freq range 

					// Get start freq value
					GetWindowText(GETHCTL(IDC_DOMAIN_STARTFREQ), szBuffer,
						BUFFER_SIZE);
					fStartFreq=(float)fabs(atof(szBuffer));

					// Get end freq value
					GetWindowText(GETHCTL(IDC_DOMAIN_ENDFREQ), szBuffer,
						BUFFER_SIZE);
					fEndFreq=(float)fabs(atof(szBuffer));

					// Calc # psd data points
					// # octaves between freq start and end
					nPSDSize=(int)ceil((log(fEndFreq/fStartFreq)/log(2.0)));
					
					// It is possible for the # psd points to exceed this by 1
					// if fEndFreq is exactly divisible by fStartFreq
					// Increment nPSDSize to be safe
					nPSDSize++;
					nPSDSize++;

					// Increment nPSDSize once more for last point at end freq
					nPSDSize++;

					// Double nPSDSize for 2 points/octave
					nPSDSize*=2;

					#if(0) // Original code
					// Reallocate size of PSD data arrays
					if((fFreq=(float*)
						realloc(fFreq, (nPSDSize)*sizeof(float)))==NULL)
					{
						// Nothing useful can be done, so announce error
						// and post a messgage to close dialog box
						AllocErrorMessage();
						PostMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDCANCEL,
							NULL, 0));
						return TRUE;
					}

					// The fPSD array has additional space
					// for the std data header
					if((fPSD=(float*)
						realloc(fPSD,
						(nPSDSize+ARRAY_OFFSET)*sizeof(float)))==NULL)
					{
						// Nothing useful can be done, so announce error,
						// clean up and post a message to close dialog box
						AllocErrorMessage();
						free(fFreq);
						PostMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDCANCEL, NULL, 0));
						return TRUE;
					}
					#endif

					#if(1) // New code 08/24/07
					// Reallocate size of PSD data arrays
					if((fFreq=(realtype*)
						realloc(fFreq, (nPSDSize)*sizeof(realtype)))==NULL)
					{
						// Nothing useful can be done, so announce error
						// and post a messgage to close dialog box
						AllocErrorMessage();
						PostMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDCANCEL,
							NULL, 0));
						return TRUE;
					}

					// The fPSD array has additional space
					// for the std data header
					if((fPSD=(realtype*)
						realloc(fPSD,
						(nPSDSize+ARRAY_OFFSET)*sizeof(realtype)))==NULL)
					{
						// Nothing useful can be done, so announce error,
						// clean up and post a message to close dialog box
						AllocErrorMessage();
						free(fFreq);
						PostMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDCANCEL, NULL, 0));
						return TRUE;
					}
					#endif

					// Initializations
					fSBFreq=fStartFreq;
					j=0;

					// Loop through tau increments
					while(fSBFreq<fEndFreq)
					{
						// Calc the frequency domain parameter values
						for(i=0; i<5; i++) // alpha=i-2
						{
							// Calc the freq domain parameter value
							// Inputs is sigma value for particular noise type
							// along with other params
							// Output is psd value for that noise type
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_DOMAIN_TTOF,
								NULL, 0));

							fH[i]=fNoise;
						}

						// Calc the total parameter values
						// Takes individual psd values and finds their total
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_TOTAL,
							NULL, 0));

						// Store psd-freq data in plot array
						if(nPSDType==PSD_L)
						{
							fPSD[j]=fFALL;
							fFreq[j]=fSBFreq;
						}
						else // These are logged
						{
							fPSD[j]=(float)log10(fFALL);
							fFreq[j]=fSBFreq;
						}

						// Increment freq and index
						// Increment AF and index
						// fSBFreq*=2; // 1 point/octave
						// 2 points/octave is smoother
						fSBFreq*=(float)sqrt(2.0); // 2 points/octave
						j++;
					}

					// Set # FFT points to twice actual # of PSD data points
					// j is zero based, and 1 more point added below
					// so use j+2 and then double that
					sPSPlot.nfft=2*(j+2);

					// Calc final point at end freq
					fSBFreq=fEndFreq;
					{
						// Calc the frequency domain parameter values
						for(i=0; i<5; i++) // alpha=i-2
						{
							// Calc the freq domain parameter value
							// Inputs is sigma value for particular noise type
							// along with other params
							// Output is psd value for that noise type
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_DOMAIN_TTOF,
								NULL, 0));

							fH[i]=fNoise;
						}

						// Calc the total parameter values
						// Takes individual psd values and finds their total
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_TOTAL,
							NULL, 0));

						// Store psd-freq data in plot array
						if(nPSDType==PSD_L)
						{
							fPSD[j]=fFALL;
							fFreq[j]=fSBFreq;
						}
						else // These are logged
						{
							fPSD[j]=(float)log10(fFALL);
							fFreq[j]=fSBFreq;
						}
					}

					// Set plot type (global)
					// Rather than SPECT_PLOT to omit # data points,
					// tau & filename
					nPlotType=DOMAIN_PSD_PLOT; 

					// The call to PowerSpectrumPlot() in GPCWndProc()
					// uses sPSPlot.plotype with the following codes:
					// 0=Sx(f), 1=So(f), 2=L(f), 3=Sy(f)
					// which are not the same as the
					// PSD_X, PSD_P, PSD_L & PSD_Y macros
					// which have the nPSDType values
					// 1=Sy(f), 2=Sx(f), 3=So(f), 4=L(f)
					// Must make that conversion here
					if(nPSDType==PSD_X)
					{
						// Set Sx(f) PSD plotype
						sPSPlot.plotype=0;
						bDataType=PHASE_DATA;
					}
					if(nPSDType==PSD_P)
					{
						// Set So(f) PSD plotype
						sPSPlot.plotype=1;
						bDataType=PHASE_DATA;
					}
					if(nPSDType==PSD_L)
					{
						// Set L(f) PSD plotype
						sPSPlot.plotype=2;
						bDataType=PHASE_DATA;
					}
					if(nPSDType==PSD_Y)
					{
						// Set Sy(f) PSD plotype
						sPSPlot.plotype=3;
						bDataType=FREQ_DATA;
					}

					// Set PSD plot flags
					sPSPlot.do_date=TRUE;
					sPSPlot.do_box=TRUE;
					sPSPlot.do_errbar=TRUE; // Must be true to get plot
					sPSPlot.do_line=FALSE;
					sPSPlot.do_mouse=FALSE;
					sPSPlot.do_fit=FALSE;
					sPSPlot.do_table=FALSE;
					sPSPlot.do_wide=TRUE;
					sPSPlot.new_file=TRUE;
					sPSPlot.new_name=TRUE;
					sPSPlot.smooth=FALSE;

					// Make line wider
					// The do_wide flag dowsn't accomplish this
					sPSPlot.thick=WIDELINESIZE;

					// Force automatic plot scale calc
					sPSPlot.y_tic=0;

					// Set plot title
					_snprintf(sPSPlot.title, TITLESIZE,
						"FREQUENCY DOMAIN STABILITY");

					// Set plot subtitle (show non-zero noise params)
					strlcpy(sPSPlot.subtitle, "", SUBTITLESIZE);
					bComma=FALSE;
					for(i=0; i<5; i++) // alpha=i-2
					{
						if(fH[i] && bComma)
						{
							_snprintf(szBuffer, sizeof(szBuffer),
								", h]%d[=%1.2e", i-2, fH[i]);
							strlcat(sPSPlot.subtitle, szBuffer, SUBTITLESIZE);
						}

						if(fH[i] && !bComma)
						{
							_snprintf(szBuffer, sizeof(szBuffer),
								"h]%d[=%1.2e", i-2, fH[i]);
							strlcat(sPSPlot.subtitle, szBuffer, SUBTITLESIZE);
							bComma=TRUE;
						}
					}

					ShortenExp(sPSPlot.subtitle);

					// Set the carrier freq
					sPSPlot.carrier=fMHz;

					// Set the BW
					sPSPlot.bw=fHigh;
					
					// Create child window for plot
					GPCWINCreate(hChildWnd, hInst, hDlg, SW_SHOWNORMAL,
						&hChildAccel, NULL);

					// Free arrays
					free(fFreq);
					free(fPSD);
					
					// Restore domain settings
					nAvgFactor=nSaveAvgFactor;
					fTau=fSaveTau;
					fSBFreq=fSaveSBFreq;

					// Calc the frequency domain parameter values
					for(i=0; i<5; i++) // alpha=i-2
					{
						// Calc the freq domain parameter value
						// Inputs is sigma value for particular noise type
						// along with other params
						// Output is PSD value for that noise type
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_DOMAIN_TTOF, NULL, 0));
					}

					// Calc the total parameter values
					// Takes individual PSD values and finds their total
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_DOMAIN_TOTAL, NULL, 0));
				}
				break;

				#if(1) // New code 07/23/16
				// Procedure to calculate integrated phase jitter
				case IDC_DOMAIN_JITTER:
				{
					// This procedure finds the rms phase jitter from the power law phase noise model
					// over the bandwidth of the PSD plot from f1 = fStartFreq to f2 = fEndFreq
					// The 5 PSD values are those entered as L(f) for W PM, F PM, W FM, F FM and RW FM noise
					// with corresponding power law noise exponents of 0 thru -4
					// and dBc/Hz values of fPS[i] where i = 4 + x
					// The calculation uses the numeric rad^2/Hz values corresponding to So(1 Hz) = L(f) + 3 dB
					// Ref: U.L. Rohde, "Digital PLL Frequency Synthesizers", Section A-2-2
					//
					// We have L(f) in dBc/Hz = fPS[i] at f = fSBFreq in Hz
					// where i = array index = 4 + x and x = PSD exponent of So(f) = Kf^x in rad^2/Hz
					// e.g., x = -2 for W FM noise (slope = -20 dB/decade)
					//
					// We want So(f) at f = 1 Hz which is K in expression above
					// K in dB rad^2/Hz = fPS[i] +3 + 10*x*log(1/fSBFreq)
					// and its numeric value is 10^(dB/10)
					// Example: W FM noise x=-2, i=2, L(10 Hz) = -100 dBc/Hz
					// K = -100 +3 +10*-2*log(1/10) = -100 +3 +20 = -77 dB rad^2/Hz = 2e-8 rad^2/Hz
					//
					// We then find the integrated phase jitter for each power law noise term as:
					// delta phi squared = K/(x+1) * (f2^x+1 - f1^x+1) for x!=-1
					// delta phi squared = K * log(f2-f1) for x=-1
					// One sums those noise power values and takes the sqrt to get the rms phase jitter

					// Initialize the phase jitter
					fJitter = 0.0;

					// Loop through the five power law noise terms
					for (i = 0; i < 5; i++) // i is fPS[] index, x (Beta) is i-4
					{
						// Do we have this noise term?  And is it a reasonable value?
						if (fPS[i] < -3.0)
						{
							// Find noise coefficient K = numeric rad^2/Hz at 1 Hz
							fKdB = (float)(fPS[i] + 3.0 + 10.0*(i - 4)*log10(1.0 / fSBFreq));
							fK = (float)(pow(10.0, fKdB/10.0));

							// Find and sum the phase jitter power in rad^2 rms for this noise term
							if (i == 3) // F PM
							{
								fJitter += (float)(fK * (log(fEndFreq) - log(fStartFreq)));
							}
							else
							{
								fJitter += (float)((fK / (i -3)) * (pow(fEndFreq, i - 3) - pow(fStartFreq, i - 3)));
							}
						}
					}

					// Clear break flag
					bBreak = FALSE;

					// If all noise terms are greater than or equal -3 dB the results are invalid
					if (fPS[0] >= -3.0 && fPS[1] >= -3.0 && fPS[2] >= -3.0 && fPS[3] >= -3.0 && fPS[4] >= -3.0)
					{
						if (fFALL = 0.0)
						{
							// Clear results
							SetWindowText(GETHCTL(IDC_DOMAIN_JIT), "");
							SetWindowText(GETHCTL(IDC_DOMAIN_PS), "");
							SetWindowText(GETHCTL(IDC_DOMAIN_FM), "");
						}
						else
						{
							// Invalidate results
							SetWindowText(GETHCTL(IDC_DOMAIN_JIT), "Invalid");
							SetWindowText(GETHCTL(IDC_DOMAIN_PS), "Invalid");
							SetWindowText(GETHCTL(IDC_DOMAIN_FM), "Invalid");
						}

						// Stop
						bBreak = TRUE;
					}

					// Bail out
					if (bBreak)
					{
						break;
					}

					// Calc integrated phase jitter in rad^2 rms
					fJitter = (float) (sqrt(fJitter));

					// Show jitter
					_snprintf(szBuffer, sizeof(szBuffer), "%9.3e", fJitter);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_DOMAIN_JIT), szBuffer);
					_snprintf(szBuffer, sizeof(szBuffer), "%9.3e", fJitter*1e6/(2*PI*fMHz));
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_DOMAIN_PS), szBuffer);

					// Another way to display the rms jitter is as an optional PSD plot message
				}
				break;
				#endif

				#if(1) // New code 07/23/16
				// Procedure to calculate residual FM
				case IDC_DOMAIN_RESIDUAL:
				{
					// This procedure finds the residual FM from the power law phase noise model
					// over the bandwidth of the PSD plot from f1 = fStartFreq to f2 = fEndFreq
					// The 5 PSD values are those entered as L(f) for W PM, F PM, W FM, F FM and RW FM noise
					// with corresponding power law noise exponents of 0 thru -4
					// and dBc/Hz values of fPS[i] where i = 4 + x
					// The calculation uses the numeric rad^2/Hz values corresponding to So(1 Hz) = L(f) + 3 dB
					// Ref: U.L. Rohde, "Digital PLL Frequency Synthesizers", Section A-2-2
					//
					// We have L(f) in dBc/Hz = fPS[i] at f = fSBFreq in Hz
					// where i = array index = 4 + x and x = PSD exponent of So(f) = Kf^x in rad^2/Hz
					// e.g., x = -2 for W FM noise (slope = -20 dB/decade)
					//
					// We want So(f) at f = 1 Hz which is K in expression above
					// K in dB rad^2/Hz = fPS[i] +3 + 10*x*log(1/fSBFreq)
					// and its numeric value is 10^(dB/10)
					// Example: W FM noise x=-2, i=2, L(10 Hz) = -100 dBc/Hz
					// K = -100 +3 +10*-2*log(1/10) = -100 +3 +20 = -77 dB rad^2/Hz = 2e-8 rad^2/Hz
					//
					// We then find the residual FM for each power law noise term as:
					// delta f squared = K/(x+1) * (f2^x+1 - f1^x+1) for x!=-3
					// delta f squared = K * log(f2-f1) for x=-3
					// One sums those noise power values and takes the sqrt to get the rms residual FM

					// Initialize the residual FM
					fResidual = 0.0;

					// Loop through the five power law noise terms
					for (i = 0; i < 5; i++) // i is fPS[] index, x (Beta) is i-4
					{
						// Do we have this noise term?  And is it a reasonable value?
						if (fPS[i] < -3.0)
						{
							// Find noise coefficient K = numeric rad^2/Hz at 1 Hz
							fKdB = (float)(fPS[i] + 3.0 + 10.0*(i - 4)*log10(1.0 / fSBFreq));
							fK = (float)(pow(10.0, fKdB / 10.0));

							// Find and sum the resudual FM power in Hz^2 rms for this noise term
							if (i == 1) // F FM
							{
								fResidual += (float)(fK * (log(fEndFreq) - log(fStartFreq)));
							}
							else
							{
								fResidual += (float)((fK / (i - 1)) * (pow(fEndFreq, i - 1) - pow(fStartFreq, i - 1)));
							}
						}
					}

					// Clear break flag
					bBreak = FALSE;

					// If all noise terms are greater than or equal -3 dB the results are invalid
					if (fPS[0] >= -3.0 && fPS[1] >= -3.0 && fPS[2] >= -3.0 && fPS[3] >= -3.0 && fPS[4] >= -3.0)
					{
						if (fFALL = 0.0)
						{
							// Clear results
							SetWindowText(GETHCTL(IDC_DOMAIN_JIT), "");
							SetWindowText(GETHCTL(IDC_DOMAIN_PS), "");
							SetWindowText(GETHCTL(IDC_DOMAIN_FM), "");
						}
						else
						{
							// Invalidate results
							SetWindowText(GETHCTL(IDC_DOMAIN_JIT), "Invalid");
							SetWindowText(GETHCTL(IDC_DOMAIN_PS), "Invalid");
							SetWindowText(GETHCTL(IDC_DOMAIN_FM), "Invalid");
						}

						// Stop
						bBreak = TRUE;
					}

					// Bail out
					if (bBreak)
					{
						break;
					}

					// Calc residual FM in Hz rms
					fResidual = (float)(sqrt(fResidual));

					// Show residual FM
					_snprintf(szBuffer, sizeof(szBuffer), "%9.3e", fResidual);
					ShortenExp(szBuffer);
					SetWindowText(GETHCTL(IDC_DOMAIN_FM), szBuffer);

					// Another way to display the residual FM is as an optional PSD plot message
				}
				break;
				#endif

				case IDC_DOMAIN_COPY:
				{
					// Allocate global memory for 16 lines of info
					nClip=16*80;
					hClipboard=GlobalAlloc(GMEM_DDESHARE, (DWORD)nClip);
					szClipboard=GlobalLock(hClipboard);

					// Main heading
					strlcpy(szClipboard, "Domain Calculation Results:",
						nClip);
					strlcat(szClipboard, "\r\n", nClip);

					// Domain headings
					strlcat(szClipboard, "Frequency Domain\t\tTime Domain",
						nClip);
					strlcat(szClipboard, "\r\n", nClip);

					// PSD & sigma types
					strlcat(szClipboard, "PSD Type    :\t",
						nClip);
					GetWindowText(GETHCTL(IDC_DOMAIN_PSD), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\tSigma Type:\t",
						nClip);
					GetWindowText(GETHCTL(IDC_DOMAIN_SIG), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);

					// SB freq & tau
					strlcat(szClipboard, "SB Freq (Hz):\t",
						nClip);
					GetWindowText(GETHCTL(IDC_DOMAIN_FREQ), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\tTau (Sec) :\t",
						nClip);
					GetWindowText(GETHCTL(IDC_DOMAIN_TAU), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);

					// Carrier freq & AF
					strlcat(szClipboard, "Carrier(MHz):\t",
						nClip);
					GetWindowText(GETHCTL(IDC_DOMAIN_MHZ), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\tAvg Factor:\t",
						nClip);
					GetWindowText(GETHCTL(IDC_DOMAIN_AF), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);

					// BW & BW factor (W & F PM only)
					if(IsWindowEnabled(GETHCTL(IDC_DOMAIN_FHIGH)))
					{
						strlcat(szClipboard, "BW (Hz)     : ",
							nClip);
						GetWindowText(GETHCTL(IDC_DOMAIN_FHIGH), szBuffer,
								BUFFER_SIZE);
						strlcat(szClipboard, szBuffer, nClip);
						strlcat(szClipboard, "\tBW Factor : ",
							nClip);
						GetWindowText(GETHCTL(IDC_DOMAIN_BW), szBuffer,
								BUFFER_SIZE);
						strlcat(szClipboard, szBuffer, nClip);
						strlcat(szClipboard, "\r\n", nClip);
					}
					else
					{
						strlcat(szClipboard, "\r\n", nClip);
					}

					// Space
					strlcat(szClipboard, "\r\n", nClip);

					// Power Law Noise heading
					strlcat(szClipboard, "Power Law Noise",
						nClip);
					strlcat(szClipboard, "\r\n", nClip);

					// PSD & sigma types
					strlcat(szClipboard, "Type ", nClip);
					GetWindowText(GETHCTL(IDC_DOMAIN_PSD0), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\tPSD\t\tType ",
						nClip);
					GetWindowText(GETHCTL(IDC_DOMAIN_SIG0), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\t\tSigma\r\n",
						nClip);

					// RWFM PSD & sigma
					strlcat(szClipboard, "RWFM ", nClip);
					GetWindowText(GETHCTL(IDC_DOMAIN_PSD1), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\t", nClip);
					GetWindowText(GETHCTL(IDC_DOMAIN_FRWF), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\t\tRWFM ", nClip);
					GetWindowText(GETHCTL(IDC_DOMAIN_SIG1), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\t", nClip);
					GetWindowText(GETHCTL(IDC_DOMAIN_TRWF), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);

					// FFM PSD & sigma
					strlcat(szClipboard, "FFM  ", nClip);
					GetWindowText(GETHCTL(IDC_DOMAIN_PSD2), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\t", nClip);
					GetWindowText(GETHCTL(IDC_DOMAIN_FFF), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\t\tFFM  ", nClip);
					GetWindowText(GETHCTL(IDC_DOMAIN_SIG2), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\t", nClip);
					GetWindowText(GETHCTL(IDC_DOMAIN_TFF), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);

					// WFM PSD & sigma
					strlcat(szClipboard, "WFM  ", nClip);
					GetWindowText(GETHCTL(IDC_DOMAIN_PSD3), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\t", nClip);
					GetWindowText(GETHCTL(IDC_DOMAIN_FWF), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\t\tWFM  ", nClip);
					GetWindowText(GETHCTL(IDC_DOMAIN_SIG3), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\t", nClip);
					GetWindowText(GETHCTL(IDC_DOMAIN_TWF), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);

					// FPM PSD & sigma
					strlcat(szClipboard, "FPM  ", nClip);
					GetWindowText(GETHCTL(IDC_DOMAIN_PSD4), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\t", nClip);
					GetWindowText(GETHCTL(IDC_DOMAIN_FFP), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\t\tFPM  ", nClip);
					GetWindowText(GETHCTL(IDC_DOMAIN_SIG4), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\t", nClip);
					GetWindowText(GETHCTL(IDC_DOMAIN_TFP), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);

					// WPM PSD & sigma
					strlcat(szClipboard, "WPM  ", nClip);
					GetWindowText(GETHCTL(IDC_DOMAIN_PSD5), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\t", nClip);
					GetWindowText(GETHCTL(IDC_DOMAIN_FWP), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\t\tWPM  ", nClip);
					GetWindowText(GETHCTL(IDC_DOMAIN_SIG5), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\t", nClip);
					GetWindowText(GETHCTL(IDC_DOMAIN_TWP), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);

					// All PSD & sigma
					strlcat(szClipboard, "All\t\t", nClip);
					GetWindowText(GETHCTL(IDC_DOMAIN_FALL), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\t\tAll\t\t", nClip);
					GetWindowText(GETHCTL(IDC_DOMAIN_TALL), szBuffer,
							BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);

					// Write info to clipboard
					GlobalUnlock(hClipboard);
					OpenClipboard(NULL);
					EmptyClipboard();
					SetClipboardData(CF_TEXT, hClipboard);
					CloseClipboard();
				}
				break;

				case IDCANCEL:
				{
					EndDialog (hDlg, 0);
				}
				return TRUE;
			}
		}
		break;
	 }
	 return FALSE;
}
#endif

/*****************************************************************************/
/*                                                                           */
/*                   Run Dialog Procedure                                    */
/*                                                                           */
/*      Function for automatic stability analysis.                           */
/*      Based on automatic() of Stable/DOS.                                  */
/*                                                                           */
/*      Sigma Types         Used in Sigma function      Remarks              */
/*      NORMAL_RUN              *                                            */
/*      OVERLAPPING_RUN         *                                            */
/*      MODIFIED_RUN            *                                            */
/*      TIME_RUN                *                                            */
/*      TOTAL_RUN               *                                            */
/*      HADAMARD_RUN            *                                            */
/*		OVERLAPHAD_RUN                          Experimental                 */
/*      BOTH_RUN                                Overlapping & Modified       */
/*      ALLTAU_RUN                              Normal                       */
/*                                                                           */
/*      The Run function uses the following struct to hold the sigma data:   */
/*                                                                           */
/*      struct sigmadata             structure template for sigma data       */
/*      {                                                                    */
/*          int points;              number of sigma data points             */
/*          float tau[S_SIZE];       averaging time data array               */
/*          float num[S_SIZE];       number of data points array             */
/*          float sigma[S_SIZE];     sigma data array                        */
/*          float ci[S_SIZE];        confidence interval from SIGMA.TAU file */
/*          float sig_min[S_SIZE];   lower sigma error bar array             */
/*          float sig_max[S_SIZE];   upper sigma error bar array             */
/*          int alpha[S_SIZE];       power-law noise type exponent array     */
/*      };                                                                   */
/*                                                                           */
/*      Two of these sigmadata structs are used:                             */
/*              sNormSigData = normal or overlapping sigma data              */
/*              sModSigData = modified or time sigma data                    */
/*                                                                           */
/*      The confidence intervals for the various Allan deviation calcula-    */
/*      tions are based on a determination of the noise type AT EACH AVER-   */
/*      AGING FACTOR during an automatic stability run.  The noise type is   */
/*      estimated by the B1 ratio of the standard and Allan variances.       */
/*      This method can be used at all averaging factors (including m=1),    */
/*      but it can not distinguish between W and F PM noise.  That is not a  */
/*      serious problem for the NORMAL_RUN case because the k() factor      */
/*      is 0.99 for both of these noise types.                               */
/*                                                                           */
/*      At each stability analysis point, the following methods are used to  */
/*      set the confidence intervals:                                        */
/*                                                                           */
/*      NORMAL_RUN                 k()y()/N  1 (68%) CI               */
/*      TOTAL_RUN                  k()y()/N  1 (68%) CI               */
/*		MODTOTAL_RUN                                                         */
/*		TIMETOTAL_RUN                                                        */
/*      HADAMARD_RUN               k()y()/N  1 (68%) CI               */
/*		OVERLAPHAD_RUN			   same as OVERLAPPING_RUN                   */
/*      OVERLAPPING_RUN            deg_free() & X statistics                */
/*      MODIFIED_RUN & TIME_RUN    edf() & X statistics                     */
/*                                                                           */
/*      These are the same methods that are used to set the CIs for the      */
/*      corresponding Sigma functions.                                       */
/*                                                                           */
/*                                                                           */
/*      Revision record:                                                     */
/*          07/19/96    Created (along with RunBox dialog box template).     */
/*          07/21/96    Imported STAB_D08.C as starting point for new code.  */
/*          07/22/96    Adapted imported code for new function               */
/*          07/23/96    Devised results display format                       */
/*          07/24/96    Got Run running                                      */
/*          10/04/96    Added Options, Lines & Notes logic                   */
/*          10/05/96    Added drift removal code                             */
/*          10/12/96    Added abort logic                                    */
/*          10/21/96    Added logic to skip TDEV for phase data              */
/*          11/02/96    Found & fixed error in phase overlap sigma run calc  */
/*          01/10/97    Quadratic drift slope made per data point interval   */
/*          01/11/97    Fixed error in Hadamard dev calc for phase data      */
/*          01/21/97    Changed logic to allow print of 1 sigma point        */
/*                      Fixed printout of mod sigma table                    */
/*          01/22/97    Fixed printout of basic statistics for phase data    */
/*          01/27/97    Added some code for all tau sigma                    */
/*          01/29/97    Completed all tau sigma                              */
/*          02/01/97    Changed format of both sigma data file to same as    */
/*                      screen (tau, #, std dev, sigma & mod sigma)          */
/*          02/02/97    Added bLines flag & macro                            */
/*          02/04/97    Changed inverse chi square function                  */
/*                      Improved abort response                              */
/*          02/05/97    Fixed error in sigma type in printout heading        */
/*          02/19/97    Added error traps for zero sigma                     */
/*          02/24/97    Changed to NewRemoveQuadraticDrift()                 */
/*          02/28/97    Added endpoint matching choice for phase TOTALDEV    */
/*          03/15/97    More TOTALDERV changes:  Always do endpoint match.   */
/*                      Always label checkbox as No Drift. Added note "Data  */
/*                      Endpoints matched".                                  */
/*                      Added "(Removed)" after Drift/Day when drift removed */
/*          03/18/97    Added autocalc logic                                 */
/*          03/29/97    Added code to eliminate sigma plot lines when sigma  */
/*                      type changes                                         */
/*          04/05/97    Incremented df+1 for TOTALVAR                        */
/*                      Used conv phase data for MDEV calc from freq data    */
/*                      Applied bias correction to TOTALDEV                  */
/*          04/08/97    Added error trap for TOTALDEV bias factor calc       */
/*          04/12/97    Fixed problem with working mem alloc when freq data  */
/*                      is conv to phase for mod, time & total sigma calc    */
/*          05/01/97    Added octave/decade increment option                 */
/*          05/10/97    Added all tau increment option via global bAllTau    */
/*          05/25/97    Clear all lines and grey Options, Lines, & Notes     */
/*                      buttons when tau increment changes                   */
/*          06/03/97    Clear all lines when data type changes               */
/*			07/19/97	Changed to DataTable for stability results display,  */
/*						including all tau case                               */
/*			11/27/97	Fixed gap problem with phase Mod sigma calc          */
/*			12/06/97	Changed from ReflectedTotalvarCalc() to latest       */
/*						doubly-reflected TotvarCalc()                        */
/*						Fixed gap problem with phase time sigma calc         */
/*			02/21/98	Updated printing code for Win32 API                  */
/*			03/16/98	Made changes for 6-digit AF display                  */
/*			06/04/98	Added TIE rms and MTIE for phase data                */
/*          10/03/98	Added separate thread to calc MTIE, which is the     */
/*                      slowest, esp since it often involves big data sets.  */
/*                      The main idea is to have a wait loop in the main     */
/*                      thread constantly checking for messages with         */
/*                      YieldControl() while a 2nd thread does the calc.     */
/*						This makes the program more responsive.              */
/*			12/18/98	Added copy button to copy results to clipboard       */
/*			01/14/99	Added global run type usage                          */
/*			01/29/99	Changed to NewCalcFreqOverlapSigma()                 */
/*			03/03/99	Added handling of 1 of 2 units variance scaling      */
/*			03/06/99	Added code for fully-overlapping Hadamard sigma      */
/*			04/25/99	Added handling of FW & RR FM noise types             */
/*			06/13/99	Added bSynch tests to avoid unnecessary use of       */
/*						working data                                         */
/*			12/25/99	Added Mod Totvar                                     */
/*			01/01/00	Made a few Mod Totvar changes                        */
/*			05/05/00	Added TTOT                                           */
/*			05/09/00	Added provisions for resume after stop               */
/*			05/12/00	Added provisions for setting starting AF             */
/*			06/12/00	Changed to faster NewModTotvarCalc()                 */
/*			06/19/00	Added RR FM alpha=-4 noise ID for Hadamard sigmas    */
/*			06/21/00	Added error trap for unallowed alpha for MTOT bias   */
/*			10/29/00	Added provisions for Hadamard Totvar (HTOT)          */
/*			11/01/00	HTOT running - seems OK                              */
/*			11/11/00	Rearranged a lot of things to clarify source code    */
/*			11/19/00	Made changes in noise id methodology                 */
/*						Added internal subroutine for mod sigma calc         */
/*			11/25/00	Added alpha<-1 warning                               */
/*			12/18/00	Changed HTOT to use overlapping HDEV for AF=1        */
/*			12/24/00	Revised per final version of PTTI'00 HTOT paper      */
/*			06/16/02	Replace CalcPhaseModSigma() with new version         */
/*			08/15/02	Make decade tau increments 1,2,4,10, etc.            */
/*			08/28/02	Changed to NewConvFreqToPhase()                      */
/*			09/21/02	Added provisions for deadtime corrections            */
/*			01/19/03	Added many tau provisions for increasing all tau     */
/*						point spacing for large AFs to speed up calculation  */
/*						w/o affecting visual appearance of stability plot    */
/*			01/28/03	Cleaned up some mod sigma calc issues with & w/o     */
/*						gaps, added some additional prompts                  */
/*			02/09/03	Added Tho1                                          */
/*			02/15/03	Added Overlapping & Tho1                            */
/*			03/15/03	Use ConvFreqToPhase() w/o New with FrequenC DLL V2.0 */
/*			03/31/03	Fixed gap problem with Totvar calc                   */
/*			04/29/03	Revised Theo1 per D. Howe's final version            */
/*			05/11/03	More Tho1 changes to show errorbars                 */
/*			06/08/03	Fixed problem with Tho1 run when AF is equal to #   */
/*                      phase data points                                    */
/*			06/20/03	Fill gaps in converted phase data for MDEV calc      */
/*			07/12/03	Added provisions for Tho1 bias auto matching        */
/*			07/14/03	Added use of Combined EDF()                          */
/*			09/16/03	Changed to lag 1 autocorrelation noise ID method     */
/*			12/20/03	Changed to New Tho1 bias functions                  */
/*						Added THEO1_MIN macro to set min Tho1 AF            */
/*			01/04/04	Improved stop/resume behavior                        */
/*			01/06/04	Fixed problem with FULL_RUN no drift bias matching   */
/*			01/25/04	Added ability to write fractional Lag 1 ACF noise    */
/*						ID alpha value to stability file for testing by      */
/*						setting WRITEALPHA macro to TRUE.  This was used     */
/*						for work on EFTF'04 paper (for which ACFNUM was set  */
/*						to 10 instead of normal 30).                         */
/*			11/25/04	Added provisions for Tho1H and ThoBR               */
/*			11/21/06	Added provisions for appending stab data to file     */
/*			01/09/07	Added writing of STAB.dat file                       */
/*			01/10/06	Added ThoH error bars to file, copy and printout    */
/*						Fixed several copy and print formats                 */
/*			07/31/07	Added automatic run calc and plot with F9 key        */
/*			08/24/07	Added nClip usage                                    */
/*			08/24/08	Added Tho1 avg option message box                   */
/*			08/27/08	Improved run calc time method                        */
/*			09/05/08	Changed to use Faster ModTotvarCalc()                */
/*			04/10/10	Added cross Allan sigma type                         */
/*			04/10/10	Fixed error in processing mod sigma for synchronized */
/*                      freq data with drift removed                         */
/*          07/23/16	Added support for tau increment type in ini file     */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK RunDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local macros
	#define RUN_LINES 0                     // Control line printing (0 or 1)
	#define EXTRA_WDTH 1                 	// Extra column width - was 2
	#define ACFNUM 30						// # pts to do ACF noise calc
											// Normally set to 30
	#define	THEO1_MIN 10					// Min AF for Tho1 (10)
	#define WRITEALPHA 0					// Flag for writing alpha to file
											// Normally set to 0
	#define THEOH							// Define for ThoH usage
	#define TIME_AF 5						// Run calc time coeff avg factor

	// Local variables
	// Chars
	char szBuffer[BUFFER_SIZE+1];           // General buffer
	char szFormat[BUFFER_SIZE+1];           // Format string
	static char szText[BUFFER_SIZE+1];      // Text buffer
	static char szTitle[BUFFER_SIZE+1];     // Title buffer
	static char szWriteMode[MODESIZE+1];	// File write mode string
	static int nSign;						// Sign of cross sigma
	static BOOL bCrossSigma=TRUE;			// Flag for cross sigma support
											// Not needed if we want to
											// leave it in
	static int nNextAF=1;					// Next AF to include
											// in all tau stability table
	static int nLastAF;						// Last AF to include
											// in all tau stability table
	static int nLastIndex;					// Last index to include
											// in all tau stability table
	static nAllTauRows=0;					// Count of # of all tau table rows

	// File pointer
	FILE *fStab;							// File pointer
	// Sigma types for clipboard
	// Note:  See also IDS_RUN_TYPE
	// IDS_RUN_TYPE_14 is "Overlapping and Tho1" or "ThoH" (for THEOH)
	static char *types[] =
	{
		#ifdef THEOH // Change name to ThoH
		"Allan", "Overlapping Allan", "Modified Allan","Time",
		"Hadamard", "Overlapping Hadamard", "Total", "Modified Total",
		"Time Total", "Hadamard Total", "Overlapping and Modified Allan",
		"TIE rms", "MTIE", "Tho1", "ThoH", "Cross Allan"
		#else
		"Allan", "Overlapping Allan", "Modified Allan","Time",
		"Hadamard", "Overlapping Hadamard", "Total", "Modified Total",
		"Time Total", "Hadamard Total", "Overlapping and Modified Allan",
		"TIE rms", "MTIE", "Tho1", "Overlapping and Tho1", "Cross Allan"
		#endif
	};
	// Sigma types for printing
	static char *typesp[] =
	{
		#ifdef THEOH // Change name to ThoH
		"Allan", "Overlapping Allan", "Modified Allan","Time",
		"Hadamard", "Overlapping Hadamard", "Total", "Modified Total",
		"Time Total", "Hadamard Total", "Overlapping and Modified Allan",
		"TIE rms", "MTIE", "Tho1", "Overlapping and Tho1", "Cross Allan"
		#else
		"Allan", "Overlapping Allan", "Modified Allan","Time",
		"Hadamard", "Overlapping Hadamard", "Total", "Modified Total",
		"Time Total", "Hadamard Total", "Overlapping and Modified Allan",
		"TIE rms", "MTIE", "Tho1", "ThoH", "Cross Allan"
		#endif
	};
	// Tho1 print heading
	static char *Theo1Head =
		"  AF   Tho1 Tau   Tho1 #    Alpha   Min Tho1    Tho1    "
		"Max Tho1";
	// Overlapping + Tho1 print heading
	static char *FullHead =
		"  AF    Sigma Tau  Sigma #   ThoH Tau     Sigma     Tho1 Dev   "
		"Minimum     Maximum";
	// Ints
	static int j;                           // Clear & restore index
	static int k;							// Auxiliary array index
	static int i;                           // General index
	static int nNumb;                       // # non-gap data points
	static int nNum0;                       // # non gap tau=tau0 data points
	static int nNum;                        // # data points
	static int nNumm;                       // Total # data points
	static int nStart;                      // Analysis start
	static int nEnd;                        // Analysis end
	static int nAlpha;                      // Noise type
	static int nMu;							// Sigma-tau log-log slope 
	static int nStopRatio=5;                // Min num/m
	static int nAF;                         // Averaging factor
	static int nSigmaType=NORMAL_RUN;       // Sigma type (macro)
	static int nPrevDataType=UNKNOWN_DATA;  // Previous data type
	static int nStartAF=1;					// Starting AF
	static int nModSig;						// # analy points in mod sig calc
	static int nXDecades;					// # x decades in sigma-tau plot
	static int nPointsPerDecade;			// # points per tau decade
											// for many tau
	static int nDensityParam;				// Point density parameter
											// for many tau
	int nEntry;								// # entered by user
	int nPrev;								// Previous value
	int nMinAF;								// Minumum AF
	int nCount;								// General counting variable
	static int nTheo1Noise;					// Estimated Tho1 noise alpha
	static int nLast=0;						// Last point corrected
											//for Tho1 bias
	static int nDmax;						// Lag 1 ACF max differencing param
	static int nClip;						// Size of szClipboard (chars)
	// BOOLs
	static BOOL bDataValid=FALSE;           // Data valid flag
	static BOOL bRemoveDrift=FALSE;         // Remove drift flag
	static BOOL bLines;                     // Lines flag
	static BOOL bDecade=FALSE;              // Decade increment flag
	static BOOL bOctave=TRUE;               // Octave increment flag
	static BOOL bAutoAlpha=TRUE;            // Automatic alpha flag
	static BOOL	bAllocError=FALSE;			// Allocation error flag
	static BOOL bStop=FALSE;				// Flag for current run was stopped
	static BOOL bErrorTrap=FALSE;			// Flag for entry error
	static BOOL bShowDrift=TRUE;			// Flag to show drift
	static BOOL bResume=FALSE;				// Resume flag for testing
	static BOOL bDoCalc=TRUE;				// Tho1 calc flag
	static BOOL bCalcBias=FALSE;			// Flag to calc Tho1 bias
	static BOOL bHaveTheo1Bias=FALSE;		// Flag for valid Theo1 bias exists
	static BOOL bNoTheo1BiasCalc=FALSE;		// Flag that no Theo1 bias calc done
	static BOOL bBias=FALSE;				// Flag for avg Tho1 bias found
	static BOOL bTime=FALSE;				// Timed run flag
	// Floats
	static float fBias=1.0;	                // TOT & MTOT bias factor
	static float fConfFactor=(float)0.68268;// Confidence factor
	static float fB_fwfm, fB_rwfm, fB_ffm;  // Noise ID bounds
	static float fB_wfm, fB_pm;			    // Ditto
	static float fB1;                       // B1 ratio
	static float fB2;                       // B2 ratio
	static float fB3;                       // B3 ratio
	static float fR, fR_fpm, fR_wpm;        // Ratio functions
	static float fKn;                       // CI noise factor
	static float fLow;                      // Minimum probability
	static float fHigh;                     // Maximum probability
	static float fDF;                       // Degrees of freedom
	static float fChiHigh;                  // Chi-square for upper error bar
	static float fChiLow;                   // Chi-square for lower error bar
	static float fDeadtime;					// Deadtime ratio T/tau
	static float fPrev;						// Previous value during entry
	static float fEntry;					// Entry value
	static float fTheo1Bias;				// Tho1 bias factor
	static float fAvgBias;					// Average bias of FULL_RUN
	static float fBias1;					// First bias value of THEO1_RUN
	static float fTheo1BiasFactor;			// Tho1 bias factor
	static float fRunTime;					// Estimated run calc time, sec

	// Run calc time estimation coefficients
	static float fNormalTime;				// Allan calc time est coeff
	static float fOverlappingTime;			// Overlapping Allan calc time est coeff
	static float fModifiedTime;				// Modified Allan calc time est coeff
	static float fTimeTime;					// Time calc time est coeff
	static float fHadamardTime;				// Hadamard calc time est coeff
	static float fOverlapHadTime;			// Overlapping Hadamard calc time est coeff
	static float fTotalTime;				// Total calc time est coeff
	static float fModTotalTime;				// Modified Total calc time est coeff
	static float fTimeTotalTime;			// Time Total calc time est coeff
	static float fHadTotalTime;				// Hadamard Total calc time est coeff
	static float fBothTime;					// Overlapping & Modified Allan calc time est coeff
	static float fTIErmsTime;				// TIE rms calc time est coeff
	static float fMTIETime;					// MTIE calc time est coeff
	static float fTheo1Time;				// Tho1 calc time est coeff
	static float fFullTime;					// ThoH calc time est coeff

	// F_TYPEs
	F_TYPE fMin, fMax, fAvg;                // Statistics
	static F_TYPE fSlope, fIntercept;       // Linear fit parameters
	static F_TYPE fV;                       // Fit variance
	static F_TYPE fA, fB, fC;               // Quadratic fit parameters
	static F_TYPE fTau;                     // Tau value
	static F_TYPE fDrift;                   // Drift/day value
	static F_TYPE fSig;                     // Sigma value
	static F_TYPE fModSig;                  // Modified sigma value
	static F_TYPE fStdDev;                  // Standard deviation value
	static F_TYPE fSavePhaseStart;			// Phase data analysis start
	static F_TYPE fSavePhaseEnd;			// Phase data analysis end
	static F_TYPE *fTempData;               // Temporary data array
	static F_TYPE *fWorkData;               // Working data array
	static F_TYPE *fTestData;				// Noise id test data array
	// File pointers
	FILE *out;                              // File pointer for SIGMA.TAU
	// Printing variables
	static HDC hdcPrn;                      // Handle to printer device context

	#ifndef LITE_VER
	TEXTMETRIC tm;                          // Text metrics structure
	#endif
	
	static int xChar, yChar;                // Text character sizes
	static int nLine;                       // Line #
	static int nRows;                       // # rows of results
	static short xPage, yPage;              // Graphic page dims in pixels

	#ifndef LITE_VER
	// Printer font
	LOGFONT logfont;                        // Printer logical font structure
	HFONT hPrnFont;                         // Printer font handle
	// Win32 API printing structs
	PRINTDLG pd;
	DOCINFO di;
	#endif

	// GraphiC plotting
	char TitleString[40];                   // Dialog box title string
	HWND hChildWnd=NULL;
	HANDLE hChildAccel=NULL;
	// Data table
	static HWND hSigTbl;					// Handle to data table
	LPVMSTRUCT lpVMData;					// Pointer to VMSTRUCT
	PENSTRUCT Pen;							// Pen structure
	DWORD dwStyle;							// Data table style word

	// Clipboard variables
	HGLOBAL hClipboard;						// Handle to clipboard text buffer
	LPSTR	szClipboard;					// Ptr to clipboard text string

	// ACF noise ID variables
	float fR1;								// Lag 1 ACF for original data
	float fAlpha;							// Estimated alpha as decimal value
	static float fAlpha1;					// Est alpha as dec value for nAF1
	static int nAF1;						// 1st avg factor

	// Start of code

	// Set pen parameters
	Pen.fPenStyle=PS_NULL;

	// Put run dialog box handle into global
	hPlotBox=hDlg;

	switch(message)
	{
		case WM_INITDIALOG:
		{
            // Write prompt message
            WritePromptMessage(TB_RUN);

			// Save dialog box handle as global
			hDialog=hDlg;

			// Get dialog box title
			GetWindowText(hDlg, szBoxTitle, TITLESIZE);

			// Set local sigma type to global value
			nSigmaType=nGlobalRunType;

			// Set sigma type (global)
			nSigmaPlotType=nSigmaType;

			// Set line printing flag
			bLines=RUN_LINES;

			// Set plot type (global)
			nPlotType=SIGMA_PLOT;

			// Clear abort flag
			bAbort=FALSE;

			// Clear Theo1 bias flag
			bHaveTheo1Bias=FALSE;

			// Clear lines if data type has changed
			if(bDataType!=nPrevDataType)
			{
				// Eliminate all sigma plot lines
				for(i=0; i<SLINE_NUMLINES; i++)
				{
					sSLine[i].nLineType=SLINE_NONE;
				}
			}

			// Save data type
			nPrevDataType=bDataType;

			// Allocate memory to save original data
			if(bDataType==FREQ_DATA) // Frequency data
			{
				// Initialize sizes
				nNumm=(int)fFreqData[0];
				nStart=(int)fFreqData[1];
				nEnd=(int)fFreqData[2];
				nNum=nEnd-nStart+1;

				// Allocate memory
				if((fTempData=(F_TYPE*)malloc((nNumm+ARRAY_OFFSET+EXTRA_MEM)*
					sizeof(F_TYPE)))==NULL)
				{
					// Display error message
					#ifdef MEM_DEBUG
					AllocErrorMessageEx(__FILE__, __LINE__,
							(nNumm+ARRAY_OFFSET+EXTRA_MEM)*sizeof(F_TYPE));
					#else
					AllocErrorMessage();
					#endif

					// Close Run dialog box
					EndDialog (hDlg, 0);
				}
				else
				{
					// Save data
					for(i=0; i<nNumm+ARRAY_OFFSET; i++)
					{
						fTempData[i]=fFreqData[i];
					}
				}

				// Data type is freq, but phase data may be used for analysis
				// for some variance types.  If already have corresponding
				// phase data, it will be used for that purpose.
				// In that case, it is important that it have the same
				// analysis limits as the frequency data.  So must save
				// original phase data analysis limits, set them to those of
				// the frequency data, and restore them at end of run.
				if(bSynch)
				{
					fSavePhaseStart=fPhaseData[1];
					fSavePhaseEnd=fPhaseData[2];
					fPhaseData[1]=fFreqData[1];
					fPhaseData[2]=fFreqData[2]+1; // Phase array has +1 point
				}
			}
			else // Phase data
			{
				// Initialize sizes
				nNumm=(int)fPhaseData[0];
				nStart=(int)fPhaseData[1];
				nEnd=(int)fPhaseData[2];
				nNum=nEnd-nStart+1;

				// Allocate memory
				if((fTempData=(F_TYPE*)malloc((nNumm+ARRAY_OFFSET+EXTRA_MEM)*
					sizeof(F_TYPE)))==NULL)
				{
					// Display error message
					#ifdef MEM_DEBUG
					AllocErrorMessageEx(__FILE__, __LINE__,
							(nNumm+ARRAY_OFFSET+EXTRA_MEM)*sizeof(F_TYPE));
					#else
					AllocErrorMessage();
					#endif
					// Close Run dialog box
					EndDialog (hDlg, 0);
				}
				else
				{
					// Save data
					for(i=0; i<nNumm+ARRAY_OFFSET; i++)
					{
						fTempData[i]=fPhaseData[i];
					}
				}
			}

			// Fill up the sigma type list box
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_RUN_TYPE));

			// Note: The index is equal to the macro value
			// TIE rms, MTIE, Tho1, and Overlap & Tho1
			// apply to phase data only
			// The 4 below is the number of these
			for(i=0; i<NUM_RUN_TYPES-4*bDataType; i++)
			{
				LoadString(hInst, IDS_RUN_TYPE_0+i, szBuffer, BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_RUN_TYPE), i,
					szBuffer);
			}

			// Code for cross sigma
			// Notes for crosscorrelation sigma:
			// 1. Uses CalcPhaseCrossSigma() for calculation
			// 2. Calc supported for phase data only
			// 3. Overlapping Allan deviation is only calc supported
			// 4. Uses first two phase data tabs for data arrays
			// 5. Data must apply to simultaneous measurements
			//    of same clock versus same reference
			// 6. Uncorrelated measaurement system noise is reduced
			// 7. User interface is minimal - similar to overlap ADEV
			// 8. No error bars supported
			// 9. To use, read two phase data files
			//    adjust their start and end for same time span
			//    and put them into 1st phase tabs
			//    Then selsct Cross Allan type in Run function
			// Add Cross Allan to list of sigma types
			// at bottom of list
			// for phase data if bCross is set
			// and have at least 2 phase data tabs open
			if((bDataType==PHASE_DATA)&&(bCrossSigma)&&(nNumPhaseTabs>=2))
			{
				nDummy=ComboBox_InsertString(GETHCTL(IDC_RUN_TYPE), NUM_RUN_TYPES,
					"Cross Allan");
			}

			// Use default sigma type if nSigmaType is unallowed for freq data
			if(bDataType==FREQ_DATA)
			{
				if(nSigmaType>10) // Was 5 until 12/25/99, 6 until 6/14/00
								  // 9 until 10/29/00
				{
					nSigmaType=0;
				}
			}
			else // Added 02/16/10
			{
				if((nSigmaType==CROSS_RUN) && (nNumPhaseTabs<2))
				{
					nSigmaType=0;
				}
			}

			// Show sigma type
			nDummy=ComboBox_SetCurSel(GETHCTL(IDC_RUN_TYPE), nSigmaType);

			// Fill up the alpha type list box
			SendMessage(GETHCTL(IDC_RUN_ALPHA),CB_RESETCONTENT,
				0, 0L);

			// Note: The index is equal to the macro value
			if((nSigmaType==OVERLAPHAD_RUN) || (nSigmaType==HADAMARD_RUN) ||
				(nSigmaType==HADTOTAL_RUN))
			{
				for(i=0; i<NUM_RUN_ALPHA+2; i++)
				{
					LoadString(hInst, IDS_RUN_ALPHA_0+i, szBuffer,
						BUFFER_SIZE);
					nDummy=ComboBox_InsertString(GETHCTL(IDC_RUN_ALPHA), i,
						szBuffer);
				}
			}
			
			// Use NewTho1 noise ID
			else if(nSigmaType==THEO1_RUN) // Includes auto
			{
				#ifdef THEOH // Change label to Bias Removed
				nDummy=ComboBox_InsertString(GETHCTL(IDC_RUN_ALPHA), 0,
					"Auto/BR");
				#else
				nDummy=ComboBox_InsertString(GETHCTL(IDC_RUN_ALPHA), 0,
					"Automatic");
				#endif

				for(i=1; i<NUM_RUN_ALPHA; i++)
				{
					LoadString(hInst, IDS_RUN_ALPHA_0+i, szBuffer,
						BUFFER_SIZE);
					nDummy=ComboBox_InsertString(GETHCTL(IDC_RUN_ALPHA), i,
						szBuffer);
				}
			}

			else if(nSigmaType==FULL_RUN) // Match instead of auto
			{
				#ifdef THEOH // Change label to Bias Removed
				nDummy=ComboBox_InsertString(GETHCTL(IDC_RUN_ALPHA), 0,
					"Auto/BR");
				#else
				nDummy=ComboBox_InsertString(GETHCTL(IDC_RUN_ALPHA), 0,
					"Auto/Match");
				#endif

				for(i=1; i<NUM_RUN_ALPHA; i++)
				{
					LoadString(hInst, IDS_RUN_ALPHA_0+i, szBuffer,
						BUFFER_SIZE);
					nDummy=ComboBox_InsertString(GETHCTL(IDC_RUN_ALPHA), i,
						szBuffer);
				}
			}
			else // All other sigma types
			{
				for(i=0; i<NUM_RUN_ALPHA; i++)
				{
					LoadString(hInst, IDS_RUN_ALPHA_0+i, szBuffer,
						BUFFER_SIZE);
					nDummy=ComboBox_InsertString(GETHCTL(IDC_RUN_ALPHA), i,
						szBuffer);
				}
			}

			// Show alpha type
			if(bAutoAlpha)
			{
				nDummy=ComboBox_SetCurSel(GETHCTL(IDC_RUN_ALPHA), 0);
			}
			else
			{
			   nDummy=ComboBox_SetCurSel(GETHCTL(IDC_RUN_ALPHA), 3-nAlpha);
			}

			// Set state of remove drift checkbox
			Button_SetCheck(GETHCTL(IDC_RUN_REMOVE), bRemoveDrift);

			// Clear & grey 1 of 2 checkbox if MTIE run type is selected
			if(nSigmaType==MTIE_RUN)
			{
				b1of2=FALSE;
				EnableWindow(GETHCTL(IDC_RUN_1OF2), FALSE);
			}
			else
			{
				EnableWindow(GETHCTL(IDC_RUN_1OF2), TRUE);
			}

			// Set state of 1 of 2 checkbox
			Button_SetCheck(GETHCTL(IDC_RUN_1OF2), b1of2);

			#if(1) // New code 07/23/16 
			// Use global nTauIncrement to set the tau increment type
			// We have added RunIncrement to the ini file [Preferences]
			// to save and recall this option, and allow it to be preset
			// Map individual flags to nTauIncrement
			switch (nTauIncrement)
			{
				case TAU_DECADE:
				{
					bDecade=TRUE;
					bOctave=FALSE;
					bAllTau=FALSE;
				}
				break;

				case TAU_OCTAVE:
				{
					bDecade=FALSE;
					bOctave=TRUE;
					bAllTau=FALSE;
				}
				break;

				case TAU_ALL:
				{
					bDecade=FALSE;
					bOctave=FALSE;
					bAllTau=TRUE;
				}
				break;
			}
			#endif
			
			// Initialize the increment type radio buttons
			Button_SetCheck(GETHCTL(IDC_RUN_OCTAVE), bOctave);
			Button_SetCheck(GETHCTL(IDC_RUN_DECADE), bDecade);
			Button_SetCheck(GETHCTL(IDC_RUN_ALLTAU), bAllTau);

			// Set CF display state
			SendMessage(hDlg, WM_COMMAND,
				GET_WM_COMMAND_MPS(IDC_RUN_SETCF, NULL, 0));

			// Show confidence factor
			_snprintf(szBuffer, sizeof(szBuffer), "%5.3f", fConfFactor);
			SetWindowText(GETHCTL(IDC_RUN_CF), szBuffer);

			// Initialize & show deadtime ratio
			fDeadtime=1.0;
			_snprintf(szBuffer, sizeof(szBuffer), "%3.2f", fDeadtime);
			SetWindowText(GETHCTL(IDC_RUN_DEADTIME), szBuffer);

			// Disable deadtime ratio if not normal or overlapping sigma
			// and automatic sigma
			if((nSigmaType==NORMAL_RUN || nSigmaType==OVERLAPPING_RUN) &&
				!bAutoAlpha)
			{
				EnableWindow(GETHCTL(IDC_RUN_DEADTIME), TRUE);
			}
			else
			{
				EnableWindow(GETHCTL(IDC_RUN_DEADTIME), FALSE);
			}

			// Set start AF to 1 if fast MTIE
			if(nSigmaType==MTIE_RUN && bAllTau)
			{
				nStartAF=1;
			}

			// Set start AF to THEO1_MIN if Tho1
			if(nSigmaType==THEO1_RUN)
			{
				nStartAF=THEO1_MIN;
			}

			// Show start averaging factor
			_snprintf(szBuffer, sizeof(szBuffer), "%d", nStartAF);
			SetWindowText(GETHCTL(IDC_RUN_AF), szBuffer);

			// Disable start AF entry if fast MTIE
			if(nSigmaType==MTIE_RUN && bAllTau)
			{
				EnableWindow(GETHCTL(IDC_RUN_AF), FALSE);
			}
			else
			{
				EnableWindow(GETHCTL(IDC_RUN_AF), TRUE);
			}

			// Hide drift window to show start AF control & label
			ShowWindow((GETHCTL(IDC_RUN_DRIFT)), SW_HIDE);

			// Label remove checkbox
			if( (bDataType==PHASE_DATA) && (nSigmaType==TOTAL_RUN) )
			{
				LoadString(hInst, IDS_RUN_BOX_1, szBuffer, BUFFER_SIZE);
				SetWindowText(GETHCTL(IDC_RUN_REMOVE), szBuffer);
			}
			else
			{
				LoadString(hInst, IDS_RUN_BOX_0, szBuffer, BUFFER_SIZE);
				SetWindowText(GETHCTL(IDC_RUN_REMOVE), szBuffer);
			}

			// Label remove checkbox as No Drift
			LoadString(hInst, IDS_RUN_BOX_0, szBuffer, BUFFER_SIZE);
			SetWindowText(GETHCTL(IDC_RUN_REMOVE), szBuffer);

			// Set button states
			EnableWindow(GETHCTL(IDC_RUN_PLOT), bDataValid);
			EnableWindow(GETHCTL(IDC_RUN_PRINT), bDataValid);
			EnableWindow(GETHCTL(IDC_RUN_OPTIONS), bDataValid);
			EnableWindow(GETHCTL(IDC_RUN_LINES), bDataValid);
			EnableWindow(GETHCTL(IDC_RUN_NOTES), bDataValid);
			EnableWindow(GETHCTL(IDC_RUN_COPY), bDataValid);

			// Set up stability data table
			// Format is (excluding row #):
			// | AF | Tau | # | Alpha | Min Sigma | Sigma | Max Sigma |
			// Get handle for sigma table
			hSigTbl=GETHCTL(IDC_RUN_TABLE);
			
			// Create seven columns
			SendMessage(hSigTbl, DTM_SETCOLCOUNT, (WPARAM)RUN_NUM_COLS,
				(LPARAM)0);

			// Configure the AF data column to a string
			SendMessage(hSigTbl, DTM_SETCOLTYPE, (WPARAM)RUN_AF_COL_NUM,
				(LPARAM)DTT_ZSTRING);

			// Configure the tau data column to a string
			SendMessage(hSigTbl, DTM_SETCOLTYPE, (WPARAM)RUN_TAU_COL_NUM,
				(LPARAM)DTT_ZSTRING);

			// Configure the # points column to a string
			SendMessage(hSigTbl, DTM_SETCOLTYPE, (WPARAM)RUN_NUM_COL_NUM,
				(LPARAM)DTT_ZSTRING);

			// Configure the alpha column to a string
			SendMessage(hSigTbl, DTM_SETCOLTYPE, (WPARAM)RUN_ALPHA_COL_NUM,
				(LPARAM)DTT_ZSTRING);

			// Configure the min sigma data column to a string
			SendMessage(hSigTbl, DTM_SETCOLTYPE, (WPARAM)RUN_MIN_COL_NUM,
				(LPARAM)DTT_ZSTRING);

			// Configure the sigma data column to a string
			SendMessage(hSigTbl, DTM_SETCOLTYPE, (WPARAM)RUN_SIG_COL_NUM,
				(LPARAM)DTT_ZSTRING);

			// Configure the max sigma data column to a string
			SendMessage(hSigTbl, DTM_SETCOLTYPE, (WPARAM)RUN_MAX_COL_NUM,
				(LPARAM)DTT_ZSTRING);

			// Use 6-digit integer format for AF
			// This requires 6 characters
			SendMessage(hSigTbl, DTM_SETCOLDATALEN, (WPARAM)RUN_AF_COL_NUM,
				(LPARAM)RUN_NUM_AF_CHARS);

			// Column width is in dialog units (4/char)
			// So need 5*4=20
			SendMessage(hSigTbl, DTM_SETCOLWIDTH, (WPARAM)RUN_AF_COL_NUM,
				(LPARAM)(4*RUN_NUM_AF_CHARS+EXTRA_WDTH));

			// Use 10.4 exponential format for tau
			// This requires 10 characters
			SendMessage(hSigTbl, DTM_SETCOLDATALEN, (WPARAM)RUN_TAU_COL_NUM,
				(LPARAM)RUN_NUM_TAU_CHARS);

			// Column width is in dialog units (4/char)
			// So need 10*4=40
			SendMessage(hSigTbl, DTM_SETCOLWIDTH, (WPARAM)RUN_TAU_COL_NUM,
				(LPARAM)(4*RUN_NUM_TAU_CHARS+EXTRA_WDTH));

			// Use 7-digit integer format for # data points
			// This requires 7 characters
			SendMessage(hSigTbl, DTM_SETCOLDATALEN, (WPARAM)RUN_NUM_COL_NUM,
				(LPARAM)RUN_NUM_NUM_CHARS);

			// Column width is in dialog units (4/char)
			// So need 6*4=20
			SendMessage(hSigTbl, DTM_SETCOLWIDTH, (WPARAM)RUN_NUM_COL_NUM,
				(LPARAM)(4*RUN_NUM_NUM_CHARS+EXTRA_WDTH));

			// Use 5-digit integer format for alpha
			// This requires 5 characters
			SendMessage(hSigTbl, DTM_SETCOLDATALEN, (WPARAM)RUN_ALPHA_COL_NUM,
				(LPARAM)RUN_NUM_ALPHA_CHARS);

			// Column width is in dialog units (4/char)
			// So need 5*4=20
			SendMessage(hSigTbl, DTM_SETCOLWIDTH, (WPARAM)RUN_ALPHA_COL_NUM,
				(LPARAM)(4*RUN_NUM_ALPHA_CHARS+EXTRA_WDTH));

			// Use 10.4 exponential format for min sigma
			// This requires 10 characters
			SendMessage(hSigTbl, DTM_SETCOLDATALEN, (WPARAM)RUN_MIN_COL_NUM,
				(LPARAM)RUN_NUM_MIN_CHARS);

			// Column width is in dialog units (4/char)
			// So need 10*4=40
			SendMessage(hSigTbl, DTM_SETCOLWIDTH, (WPARAM)RUN_MIN_COL_NUM,
				(LPARAM)(4*RUN_NUM_MIN_CHARS+EXTRA_WDTH));

			// Use 10.4 exponential format for sigma
			// This requires 10 characters
			SendMessage(hSigTbl, DTM_SETCOLDATALEN, (WPARAM)RUN_SIG_COL_NUM,
				(LPARAM)RUN_NUM_SIG_CHARS);

			// Column width is in dialog units (4/char)
			// So need 10*4=40
			SendMessage(hSigTbl, DTM_SETCOLWIDTH, (WPARAM)RUN_SIG_COL_NUM,
				(LPARAM)(4*RUN_NUM_SIG_CHARS+EXTRA_WDTH));

			// Use 10.4 exponential format for max sigma
			// This requires 10 characters
			// Four extra chars are needed for full display of last column
			// because each e format field needs 1 more character
			// for its 3-digit exponent before it is shortened
			SendMessage(hSigTbl, DTM_SETCOLDATALEN, (WPARAM)RUN_MAX_COL_NUM,
				(LPARAM)(RUN_NUM_MAX_CHARS + RUN_NUM_EXTRA_CHARS));

			// Column width is in dialog units (4/char)
			// So need 10*4=40
			SendMessage(hSigTbl, DTM_SETCOLWIDTH, (WPARAM)RUN_MAX_COL_NUM,
				(LPARAM)(4*RUN_NUM_MAX_CHARS+EXTRA_WDTH));

			// Center AF column heading , no data editing, and make
			// column width fixed
			SendMessage(hSigTbl, DTM_SETCOLSTYLE, (WPARAM)RUN_AF_COL_NUM,
				(LPARAM)(DTCS_HEADCENTER|DTCS_FIXED));

			// Center tau column heading , no data editing, and make
			// column width fixed
			SendMessage(hSigTbl, DTM_SETCOLSTYLE, (WPARAM)RUN_TAU_COL_NUM,
				(LPARAM)(DTCS_HEADCENTER|DTCS_FIXED));

			// Center # points column heading , no data editing, and make
			// column width fixed
			SendMessage(hSigTbl, DTM_SETCOLSTYLE, (WPARAM)RUN_NUM_COL_NUM,
				(LPARAM)(DTCS_HEADCENTER|DTCS_FIXED));

			// Center alpha column heading , no data editing, and make
			// column width fixed
			SendMessage(hSigTbl, DTM_SETCOLSTYLE, (WPARAM)RUN_ALPHA_COL_NUM,
				(LPARAM)(DTCS_HEADCENTER|DTCS_FIXED));

			// Center min sigma column heading , no data editing, and make
			// column width fixed
			SendMessage(hSigTbl, DTM_SETCOLSTYLE, (WPARAM)RUN_MIN_COL_NUM,
				(LPARAM)(DTCS_HEADCENTER|DTCS_FIXED));

			// Center sigma column heading , no data editing, and make
			// column width fixed
			SendMessage(hSigTbl, DTM_SETCOLSTYLE, (WPARAM)RUN_SIG_COL_NUM,
				(LPARAM)(DTCS_HEADCENTER|DTCS_FIXED));

			// Center max sigma column heading , no data editing, and make
			// column width fixed
			SendMessage(hSigTbl, DTM_SETCOLSTYLE, (WPARAM)RUN_MAX_COL_NUM,
				(LPARAM)(DTCS_HEADCENTER|DTCS_FIXED));

			// Null pen used for no focus rectangle
			SendMessage(hSigTbl, DTM_SETFOCUSPEN, (WPARAM)0,
				(LPARAM)(LPPENSTRUCT)&Pen);

			// Write heading on table
			SendMessage(hDlg, WM_COMMAND,
					GET_WM_COMMAND_MPS(IDC_RUN_HEADING, NULL, 0));

			// Autocalc run
			// Doing this gives immediate result for current sigma type & CF
			// Controlled with bAutoCalc flag set in Config box
			if(bAutoCalc || bAutoRunPlot)
			{
				PostMessage(hDlg, WM_COMMAND,
					GET_WM_COMMAND_MPS(IDC_RUN_RUN, NULL, 0));
			}
			
			return TRUE;
		}

		// DataTable virtual memory messages
		// Get the first row of data
		case DTM_VM_GETFIRST:
		{
			// Get pointer to VMSTRUCT
			lpVMData=(LPVMSTRUCT)lParam;

			// Set index to begining
			lpVMData->dwKey=0;

			// Get row data
			lpVMData->nStatus=(short)GetRunData(lpVMData);
		}
		break;

		// Get the last row of data
		case DTM_VM_GETLAST:
		{
			// Get pointer to VMSTRUCT
			lpVMData=(LPVMSTRUCT)lParam;

			// Set index to last row
			lpVMData->dwKey=nRows-1; // Always OK

			// Get row data
			lpVMData->nStatus=(short)GetRunData(lpVMData);
		}
		break;

		// Get the next row of data (data after row=dwKey)
		case DTM_VM_GETNEXT:
		{
			// Get pointer to VMSTRUCT
			lpVMData=(LPVMSTRUCT)lParam;

			// Increment index
			lpVMData->dwKey+=1;

			// Get row data
			lpVMData->nStatus=(short)GetRunData(lpVMData);
		}
		break;

		// Get the previous row of data (data before row=dwKey)
		case DTM_VM_GETPREV:
		{
			// Get pointer to VMSTRUCT
			lpVMData=(LPVMSTRUCT)lParam;

			// Decrement index
			lpVMData->dwKey-=1;

			// Get row data
			lpVMData->nStatus=(short)GetRunData(lpVMData);
		}
		break;

		// Get the row of data that is specified % down table
		case DTM_VM_GETPERCENT:
		{
			// Get pointer to VMSTRUCT
			lpVMData=(LPVMSTRUCT)lParam;

			// Calc index
			lpVMData->dwKey=(lpVMData->dwKey)*(long)nRows/100L;

			// Get row data
			lpVMData->nStatus=(short)GetRunData(lpVMData);
		}
		break;

		// Get the row of data at dwKey
		case DTM_VM_GETROWDATA:
		{
			// Get pointer to VMSTRUCT
			lpVMData=(LPVMSTRUCT)lParam;

			// Get row data
			lpVMData->nStatus=(short)GetRunData(lpVMData);
		}
		break;

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				// Display help info
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::RUN_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::RUN_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "RUN_FUNCTION");
					#endif
				}
				break;

				// Read nSigmaType
				case IDC_RUN_TYPE:
				{
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_SELCHANGE)
					{
						// Get (new) sigma type
						nSigmaType=
							ComboBox_GetCurSel(GETHCTL(IDC_RUN_TYPE));

						// Set sigma type (global)
						nSigmaPlotType=nSigmaType;

						#if(0) // Test code for cross sigma testing
						// Turn CROSS_RUN type into OVERLAPPING_RUN
						// Cross ADEV calc will proceed
						// exactly like overlapping ADEV calc
						// except CalcPhaseCrossSigma() will be invoked
						// using data in first two phase data tabs
						if(nSigmaType==CROSS_RUN)
						{
							nSigmaType=OVERLAPPING_RUN;
						}
						#endif

						if(nSigmaType==MTIE_RUN)
						{
							// Change "All Tau" to "Fast" for MTIE
							SetWindowText(GETHCTL(IDC_RUN_ALLTAU),
								"Fast (&u)");
						}
						else
						{
							// Use normal label
							SetWindowText(GETHCTL(IDC_RUN_ALLTAU), "All Ta&u");
						}

						// Clear alpha combobox
						nDummy=ComboBox_ResetContent(GETHCTL(IDC_RUN_ALPHA));

						// Note: The index is equal to the macro value
						if( (nSigmaType==OVERLAPHAD_RUN) ||
						    (nSigmaType==HADAMARD_RUN) ||
							(nSigmaType==HADTOTAL_RUN))
						{
							for(i=0; i<NUM_RUN_ALPHA+2; i++)
							{
								LoadString(hInst, IDS_RUN_ALPHA_0+i, szBuffer,
									BUFFER_SIZE);
								nDummy=ComboBox_InsertString(GETHCTL(
									IDC_RUN_ALPHA), i, szBuffer);
							}
						}

						// Use NewTho1 noise ID
						else if(nSigmaType==THEO1_RUN) // Includes automatic
						{
							#ifdef THEOH // Change label to Bias Removed
							nDummy=
								ComboBox_InsertString(GETHCTL(IDC_RUN_ALPHA),
								0, "Auto/BR");
							#else
							nDummy=
								ComboBox_InsertString(GETHCTL(IDC_RUN_ALPHA),
								0, "Automatic");
							#endif

							for(i=1; i<NUM_RUN_ALPHA; i++)
							{

								LoadString(hInst, IDS_RUN_ALPHA_0+i, szBuffer,
									BUFFER_SIZE);
								nDummy=
									ComboBox_InsertString(
									GETHCTL(IDC_RUN_ALPHA),	i, szBuffer);
							}
						}

						else if(nSigmaType==FULL_RUN) // Match instead of auto
						{
							#ifdef THEOH // Change label to Bias Removed
							nDummy=
								ComboBox_InsertString(GETHCTL(IDC_RUN_ALPHA),
								0, "Auto/BR");
							#else
							nDummy=
								ComboBox_InsertString(GETHCTL(IDC_RUN_ALPHA),
								0, "Auto/Match");
							#endif

							for(i=1; i<NUM_RUN_ALPHA; i++)
							{
								LoadString(hInst, IDS_RUN_ALPHA_0+i, szBuffer,
									BUFFER_SIZE);
								nDummy=
									ComboBox_InsertString(
									GETHCTL(IDC_RUN_ALPHA), i, szBuffer);
							}
						}
						else // All other sigma types
						{
							for(i=0; i<NUM_RUN_ALPHA; i++)
							{
								LoadString(hInst, IDS_RUN_ALPHA_0+i, szBuffer,
									BUFFER_SIZE);
								nDummy=ComboBox_InsertString(GETHCTL(
									IDC_RUN_ALPHA), i, szBuffer);
							}

							// Avoid previous RR FM & FW FM noise types
							if(nAlpha<-2)
							{
								nAlpha=0;
								bAutoAlpha=TRUE;
							}
						}

						// Show alpha type
						if(bAutoAlpha)
						{
							nDummy=ComboBox_SetCurSel(GETHCTL(IDC_RUN_ALPHA),
								0);
						}
						else
						{
							nDummy=ComboBox_SetCurSel(GETHCTL(IDC_RUN_ALPHA),
								3-nAlpha);
						}
						
						// Clear & grey 1 of 2 checkbox if MTIE run type
						if(nSigmaType==MTIE_RUN)
						{
							// Set state of 1 of 2 checkbox
							b1of2=FALSE;
							Button_SetCheck(GETHCTL(IDC_RUN_1OF2), b1of2);
							EnableWindow(GETHCTL(IDC_RUN_1OF2), FALSE);
						}
						else
						{
							EnableWindow(GETHCTL(IDC_RUN_1OF2), TRUE);
						}
			
						// Clear results
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RUN_CLEAR, NULL, 0));

						// Write heading on table
						SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_HEADING, NULL, 0));

						// Eliminate all sigma plot lines
						for(i=0; i<SLINE_NUMLINES; i++)
						{
							sSLine[i].nLineType=SLINE_NONE;
						}

						// Reset the start AF to default to avoid using
						// unallowed value from previous sigma type
						nStartAF=1;

						// Set start AF to THEO1_MIN for Tho1 run
						if(nSigmaType==THEO1_RUN)
						{
							// Set start AF to THEO1_MIN
							nStartAF=THEO1_MIN;
						}

						// Show start averaging factor
						_snprintf(szBuffer, sizeof(szBuffer), "%d", nStartAF);
						SetWindowText(GETHCTL(IDC_RUN_AF), szBuffer);

						// Disable start AF entry if fast MTIE
						if(nSigmaType==MTIE_RUN && bAllTau)
						{
							EnableWindow(GETHCTL(IDC_RUN_AF), FALSE);
						}
						else
						{
							EnableWindow(GETHCTL(IDC_RUN_AF), TRUE);
						}

						// Reinitialize & show deadtime ratio
						fDeadtime=1.0;
						_snprintf(szBuffer, sizeof(szBuffer), "%3.2f",
							fDeadtime);
						SetWindowText(GETHCTL(IDC_RUN_DEADTIME), szBuffer);

						// Disable deadtime ratio if not
						// normal or overlapping sigma and automatic alpha
						if((nSigmaType==NORMAL_RUN ||
							nSigmaType==OVERLAPPING_RUN) &&	!bAutoAlpha)
						{
							EnableWindow(GETHCTL(IDC_RUN_DEADTIME), TRUE);
						}
						else
						{
							EnableWindow(GETHCTL(IDC_RUN_DEADTIME), FALSE);
						}

						// Set error bar & table states
						if(bAllTau)
						{
							// Don't allow error bars in all tau case
							sSPlot.do_errbar=FALSE;

							#if(0) // Removed to allow new all tau table
							// Test added 01/28/01
							if(nSigmaType!=MTIE_RUN)
							{
								// Don't allow sigma-tau table in all tau case
								sSPlot.do_table=FALSE;
							}
							#endif
						}

						// Set CF display state
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RUN_SETCF, NULL, 0));

						// Label remove checkbox
						if((bDataType==PHASE_DATA) && (nSigmaType==TOTAL_RUN))
						{
							LoadString(hInst, IDS_RUN_BOX_1, szBuffer,
								BUFFER_SIZE);
							SetWindowText(GETHCTL(IDC_RUN_REMOVE), szBuffer);
						}
						else
						{
							LoadString(hInst, IDS_RUN_BOX_0, szBuffer,
								BUFFER_SIZE);
							SetWindowText(GETHCTL(IDC_RUN_REMOVE), szBuffer);
						}

						// Label remove checkbox as No Drift
						LoadString(hInst, IDS_RUN_BOX_0, szBuffer,
							BUFFER_SIZE);
						SetWindowText(GETHCTL(IDC_RUN_REMOVE), szBuffer);
					}
				}
				break;

				// Read alpha
				case IDC_RUN_ALPHA:
				{
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_SELCHANGE)
					{
						// Get (new) alpha
						nAlpha=3-
							ComboBox_GetCurSel(GETHCTL(IDC_RUN_ALPHA));

						// Set bAutoAlpha flag
						bAutoAlpha=FALSE;

						if(nAlpha==+3) // Auto and match
						{
							bAutoAlpha=TRUE;
						}

						// Disable deadtime ratio if not normal or overlapping
						// sigma and automatic alpha
						if((nSigmaType==NORMAL_RUN || 
							nSigmaType==OVERLAPPING_RUN) &&	!bAutoAlpha)
						{
							// Enable deadtime ratio
							EnableWindow(GETHCTL(IDC_RUN_DEADTIME), TRUE);
						}
						else
						{
							// Reinitialize, show & disable deadtime ratio
							fDeadtime=1.0;
							_snprintf(szBuffer, sizeof(szBuffer), "%3.2f",
								fDeadtime);
							SetWindowText(GETHCTL(IDC_RUN_DEADTIME), szBuffer);
							EnableWindow(GETHCTL(IDC_RUN_DEADTIME), FALSE);
						}

						// Clear results
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS( IDC_RUN_CLEAR, NULL, 0));
					}
				}
				break;

				// Read fConfFactor
				case IDC_RUN_CF:
				{
					if(GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS)
					{
						// Get (new) confidence factor
						GetWindowText(GETHCTL(IDC_RUN_CF), szBuffer,
							BUFFER_SIZE);
						fConfFactor=(float)fabs(atof(szBuffer));

						// Don't allow CF to be 0 or 1
						if(fConfFactor<=0.0)
						{
							fConfFactor=(float)0.001;
						}

						if(fConfFactor>=1.0)
						{
							fConfFactor=(float)0.999;
						}

						// Redisplay confidence factor
						_snprintf(szBuffer, sizeof(szBuffer), "%5.3f",
							fConfFactor);
						SetWindowText(GETHCTL(IDC_RUN_CF), szBuffer);

						// Clear results
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RUN_CLEAR, NULL, 0));
					}
				}
				break;

				// Respond to nStartAF edit control message
				case IDC_RUN_AF:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDCANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Save previous value
						nPrev=nStartAF;

						// Get (new) start averaging factor
						GetWindowText(GETHCTL(IDC_RUN_AF), szBuffer,
							BUFFER_SIZE);
						nEntry=abs(atoi(szBuffer));

						// Set nStopRatio
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RUN_SETSTOP, NULL, 0));

						// Validate nStartAF entry
						// nStartAF must be >=1 and <=nNum/nStopRatio
						// except for Tho1 which must have min AF=THEO1_MIN 
						// Numeric params are value, min & max

						// Find # non-gap data points
						{
							nNum0=nNum-CountGaps(fData, bDataType);
						}

						// Set min AF
						nMinAF=1;
						if(nSigmaType==THEO1_RUN)
						{
							// Set start AF to THEO1_MIN
							nMinAF=THEO1_MIN;
						}
						
						// Validate entry
						if(ValidateInteger(hDlg, nEntry, nMinAF,
							(nNum0+bDataType-1)/nStopRatio)==TRUE)
						{
							// New value OK
							nStartAF=nEntry;
							_snprintf(szBuffer, sizeof(szBuffer), "%d",
								nStartAF);
							SetWindowText(GETHCTL(IDC_RUN_AF),	szBuffer);

							// Clear results
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_CLEAR, NULL, 0));
						}
						else
						{
							// Invalid entry - restore previous value
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nPrev);
							SetWindowText(GETHCTL(IDC_RUN_AF), szBuffer);
							SetFocus(GETHCTL(IDC_RUN_AF));
						}
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Respond to fDeadtime edit control message
				case IDC_RUN_DEADTIME:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDCANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Save previous value
						fPrev=fDeadtime;

						// Get (new) deadtime ratio
						GetWindowText(GETHCTL(IDC_RUN_DEADTIME), szBuffer,
							BUFFER_SIZE);
						fEntry=(float)(fabs(atof(szBuffer)));

						// Validate deadtime ratio entry
						// fDeadtime must be >=1 and <= 4096
						// Numeric params are value, min & max
						// Validate entry
						if(ValidateFloat(hDlg, fEntry, 1.0, 4096.0)==TRUE)
						{
							// New value OK
							fDeadtime=fEntry;
							_snprintf(szBuffer, sizeof(szBuffer), "%3.2f",
								fDeadtime);
							SetWindowText(GETHCTL(IDC_RUN_DEADTIME), szBuffer);

							// Clear results
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_CLEAR, NULL, 0));
						}
						else
						{
							// Invalid entry - restore previous value
							_snprintf(szBuffer, sizeof(szBuffer), "%3.2f",
								fPrev);
							SetWindowText(GETHCTL(IDC_RUN_DEADTIME), szBuffer);
							SetFocus(GETHCTL(IDC_RUN_DEADTIME));
						}
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Read remove drift checkbox
				case IDC_RUN_REMOVE:
				{
					if(GET_WM_COMMAND_CMD(wParam, lParam)==BN_CLICKED)
					{
						// Get (new) remove flag
						bRemoveDrift=
							(BOOL)Button_GetCheck(GETHCTL(IDC_RUN_REMOVE));

						// Eliminate all sigma plot lines
						// Better to have no lines than wrong ones
						for(i=0; i<SLINE_NUMLINES; i++)
						{
							sSLine[i].nLineType=SLINE_NONE;
						}

						// Clear results
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RUN_CLEAR, NULL, 0));

						// Clear Theo1 bias flag
						bHaveTheo1Bias=FALSE;
					}
				}
				break;

				// Read 1 of 2 units checkbox
				case IDC_RUN_1OF2:
				{
					if(GET_WM_COMMAND_CMD(wParam, lParam)==BN_CLICKED)
					{
						// Get (new) 1 of 2 flag
						b1of2=
							(BOOL)Button_GetCheck(GETHCTL(IDC_RUN_1OF2));

						// Eliminate all sigma plot lines
						// Better to have no lines than wrong ones
						for(i=0; i<SLINE_NUMLINES; i++)
						{
							sSLine[i].nLineType=SLINE_NONE;
						}

						// Clear results
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RUN_CLEAR, NULL, 0));
					}
				}
				break;

				// Respond to decade radio button
				case IDC_RUN_DECADE:
				{
					if(GET_WM_COMMAND_CMD(wParam, lParam)==BN_CLICKED)
					{
						// Get (new) decade radio button state
						bDecade=(BOOL)Button_GetCheck(GETHCTL(IDC_RUN_DECADE));

						if(bDecade)
						{
							bOctave=FALSE;
							bAllTau=FALSE;
						}

						// Clear results
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RUN_CLEAR, NULL, 0));

						// Write heading on table
						SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_HEADING, NULL, 0));

						// Set global tau increment type
						nTauIncrement=TAU_DECADE;

						// Eliminate all sigma plot lines
						for(i=0; i<SLINE_NUMLINES; i++)
						{
							sSLine[i].nLineType=SLINE_NONE;
						}

						// Set CF display state
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RUN_SETCF, NULL, 0));

						// Disable start AF entry if fast MTIE
						if(nSigmaType==MTIE_RUN && bAllTau)
						{
							// Set start AF to 1
							nStartAF=1;
							_snprintf(szBuffer, sizeof(szBuffer), "%d",
								nStartAF);
							SetWindowText(GETHCTL(IDC_RUN_AF), szBuffer);
							EnableWindow(GETHCTL(IDC_RUN_AF), FALSE);
						}
						else
						{
							EnableWindow(GETHCTL(IDC_RUN_AF), TRUE);
						}

						// Set start AF to THEO1_MIN for Tho1 run
						if(nSigmaType==THEO1_RUN)
						{
							// Set start AF to THEO1_MIN
							nStartAF=THEO1_MIN;
							_snprintf(szBuffer, sizeof(szBuffer), "%d",
								nStartAF);
							SetWindowText(GETHCTL(IDC_RUN_AF), szBuffer);
						}
					}
				}
				break;

				// Respond to octave radio button
				case IDC_RUN_OCTAVE:
				{
					if(GET_WM_COMMAND_CMD(wParam, lParam)==BN_CLICKED)
					{
						// Get (new) octave radio button state
						bOctave=(BOOL)Button_GetCheck(GETHCTL(IDC_RUN_OCTAVE));

						if(bOctave)
						{
							bDecade=FALSE;
							bAllTau=FALSE;
						}

						// Clear results
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RUN_CLEAR, NULL, 0));

						// Write heading on table
						SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_HEADING, NULL, 0));

						// Set global tau increment type
						nTauIncrement=TAU_OCTAVE;

						// Eliminate all sigma plot lines
						for(i=0; i<SLINE_NUMLINES; i++)
						{
							sSLine[i].nLineType=SLINE_NONE;
						}

						// Set CF display state
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RUN_SETCF, NULL, 0));

						// Disable start AF entry if fast MTIE
						if(nSigmaType==MTIE_RUN && bAllTau)
						{
							// Set start AF to 1
							nStartAF=1;
							_snprintf(szBuffer, sizeof(szBuffer), "%d",
								nStartAF);
							SetWindowText(GETHCTL(IDC_RUN_AF), szBuffer);
							EnableWindow(GETHCTL(IDC_RUN_AF), FALSE);
						}
						else
						{
							EnableWindow(GETHCTL(IDC_RUN_AF), TRUE);
						}

						// Set start AF to THEO1_MIN for Tho1 run
						if(nSigmaType==THEO1_RUN)
						{
							// Set start AF to THEO1_MIN
							nStartAF=THEO1_MIN;
							_snprintf(szBuffer, sizeof(szBuffer), "%d",
								nStartAF);
							SetWindowText(GETHCTL(IDC_RUN_AF), szBuffer);
						}
					}
				}
				break;

				// Respond to all tau radio button
				case IDC_RUN_ALLTAU:
				{
					if(GET_WM_COMMAND_CMD(wParam, lParam)==BN_CLICKED)
					{
						// Get (new) octave radio button state
						bAllTau=(BOOL)Button_GetCheck(GETHCTL(IDC_RUN_ALLTAU));

						if(bAllTau)
						{
							bDecade=FALSE;
							bOctave=FALSE;
						}

						// Clear results
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RUN_CLEAR, NULL, 0));

						// Write heading on table
						SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_HEADING, NULL, 0));

						// Set global tau increment type
						nTauIncrement=TAU_ALL;

						// Eliminate all sigma plot lines
						for(i=0; i<SLINE_NUMLINES; i++)
						{
							sSLine[i].nLineType=SLINE_NONE;
						}

						// Set CF display state
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RUN_SETCF, NULL, 0));

						// Disable start AF entry if fast MTIE
						if(nSigmaType==MTIE_RUN && bAllTau)
						{
							// Set start AF to 1
							nStartAF=1;
							_snprintf(szBuffer, sizeof(szBuffer), "%d",
								nStartAF);
							SetWindowText(GETHCTL(IDC_RUN_AF), szBuffer);
							EnableWindow(GETHCTL(IDC_RUN_AF), FALSE);
						}
						else
						{
							EnableWindow(GETHCTL(IDC_RUN_AF), TRUE);
						}
					}
				}
				break;

				// Subroutine to set CF and Alpha display state
				case IDC_RUN_SETCF:
				{
					// Set CF display state
					#ifdef NEWEDF // New code 07/14/03
					if( bAllTau || nSigmaType==BOTH_RUN ||
						nSigmaType==TIERMS_RUN || nSigmaType==MTIE_RUN ||
						nSigmaType==FULL_RUN)
					#else
					if( nSigmaType==NORMAL_RUN || nSigmaType==HADAMARD_RUN ||
						bAllTau || nSigmaType==BOTH_RUN ||
						nSigmaType==TIERMS_RUN || nSigmaType==MTIE_RUN ||
						nSigmaType==FULL_RUN)
					#endif
					{
						// Hide CF
						ShowWindow((GETHCTL(IDC_RUN_CF)), SW_HIDE);
						ShowWindow((GETHCTL(IDC_RUN_CFLABEL)), SW_HIDE);
					}
					else
					{
						// Show CF
						ShowWindow((GETHCTL(IDC_RUN_CF)), SW_SHOWNORMAL);
						ShowWindow((GETHCTL(IDC_RUN_CFLABEL)), SW_SHOWNORMAL);
					}

					// Set Alpha display state
					if(nSigmaType==TIERMS_RUN || nSigmaType==MTIE_RUN)
					{
						// Hide Alpha
						ShowWindow((GETHCTL(IDC_RUN_ALPHA)), SW_HIDE);
						ShowWindow((GETHCTL(IDC_RUN_ALABEL)), SW_HIDE);
					}
					else
					{
						// Show Alpha
						ShowWindow((GETHCTL(IDC_RUN_ALPHA)), SW_SHOWNORMAL);
						ShowWindow((GETHCTL(IDC_RUN_ALABEL)), SW_SHOWNORMAL);
					}
				}
				break;

				// Respond to CR in an edit control
				// Note: No button is a DEFPUSHBUTTON
				case IDOK:
				{
					// Does confidence factor edit control have focus?
					if(GetFocus()==GETHCTL(IDC_RUN_CF))
					{
						// Send EN_KILLFOCUS message to conf factor edit ctrl
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RUN_CF, NULL,
							EN_KILLFOCUS));
					}

					// Does start averaging factor edit control have focus?
					if(GetFocus()==GETHCTL(IDC_RUN_AF))
					{
						// Send EN_KILLFOCUS message to avg factor edit ctrl
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RUN_AF, NULL,
							EN_KILLFOCUS));
					}

					// Does deadtime ratio edit control have focus?
					if(GetFocus()==GETHCTL(IDC_RUN_DEADTIME))
					{
						// Send EN_KILLFOCUS message to deadtime edit ctrl
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RUN_DEADTIME, NULL,
							EN_KILLFOCUS));
					}
				}
				break;

				// Calc size of sigma data arrays
				case IDC_RUN_SIGMASIZE:
				{
					if(bAllTau)
					{
						if(bManyTau)
						{
							nSigmaSize=nManySize;
						}
						else // Full all tau
						{
							nSigmaSize=
								(int)ceil((double)nNum/(double)nStopRatio);
						}
					}

					if(bDecade)
					{
						nSigmaSize=(int)(3.0*ceil(
							log10((double)nNum/(double)nStopRatio)));
					}

					if(bOctave)
					{
						nSigmaSize=(int)ceil(
							(log((double)nNum/(double)nStopRatio)/log(2.0)));
					}
					
					// It is possible for the # sigma points
					// to exceed this by 1
					// if the # data points is exactly divisible
					// by the stop ratio
					// Need to increment nSigmaSize to be safe
					nSigmaSize++;
				}
				break;
					
				// Reallocate size of sigma data arrays
				case IDC_RUN_REALLOC:
				{
					nDummy=ReallocSigmaArrays(nSigmaSize);

					// Note: If nDummy is -1 then there was a memory
					// reallocation error and we should bail out
					if(nDummy==-1)
					{
						PostMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDCANCEL, NULL, 0));
						break;
					}

					// Clear min & max sigma data
					// Needed for all tau case
					for(j=0; j<nSigmaSize; j++)
					{
						sNormSigData.sig_min[j]=0.0;
						sNormSigData.sig_max[j]=0.0;
						sModSigData.sig_min[j]=0.0;
						sModSigData.sig_max[j]=0.0;
						sNormSigData.tau[j]=0.0;
						sModSigData.tau[j]=0.0;
						sNormSigData.num[j]=0.0;
						sModSigData.num[j]=0.0;
						sNormSigData.sigma[j]=0.0;
						sModSigData.sigma[j]=0.0;
						sAllNormSigData.sig_min[j]=0.0;
						sAllNormSigData.sig_max[j]=0.0;
						sAllModSigData.sig_min[j]=0.0;
						sAllModSigData.sig_max[j]=0.0;
						sAllNormSigData.tau[j]=0.0;
						sAllModSigData.tau[j]=0.0;
						sAllNormSigData.num[j]=0.0;
						sAllModSigData.num[j]=0.0;
						sAllNormSigData.sigma[j]=0.0;
						sAllModSigData.sigma[j]=0.0;
					}
				}
				break;
					
				// Perform run calculations
				case IDC_RUN_RUN:
				{
					// Clear time flag
					bTime=FALSE;
					
					#if(1) // New code 08/28/08
					// Do we already have a Theo1 bias value?
					// In that case, because the calc time for Tho1 and ThoH
					// is much shorter, we don't want to adjust their run calc time 
					// coefficients, so we set a flag here to inhibit it
					bNoTheo1BiasCalc=bHaveTheo1Bias;

					// Get run calc time limit from ini file
					GetPrivateProfileString("Run", "RunLimit", "60", szBuffer, BUFFER_SIZE,
						szIniFile);
					fRunLimit=(float)atof(szBuffer);

					// Find estimated run calc time
					switch(nSigmaType)
					{
						/*************************************************************/
						/*                   Linear (N) Terms                        */
						/*************************************************************/
						// Allan calc time est coeff
						case NORMAL_RUN:
						{
							// Get time coefficient
							LoadString(hInst, IDS_INI_KEY_141, szBuffer, BUFFER_SIZE);
							GetPrivateProfileString("Run", szBuffer, "2.5e-6", szBuffer, BUFFER_SIZE,
								szIniFile);
							fNormalTime=(float)atof(szBuffer);

							fRunTime=(float)fNormalTime*nNum;			
							break;
						}
							
						// Overlapping Allan calc time est coeff
						case OVERLAPPING_RUN:
						{
							// Get time coefficient
							LoadString(hInst, IDS_INI_KEY_142, szBuffer, BUFFER_SIZE);
							GetPrivateProfileString("Run", szBuffer, "2.5e-6", szBuffer, BUFFER_SIZE,
								szIniFile);
							fOverlappingTime=(float)atof(szBuffer);

							fRunTime=(float)fOverlappingTime*nNum;			
							break;
						}
							
						// Cross overlapping Allan calc time est coeff
						case CROSS_RUN:
						{
							// Get time coefficient
							LoadString(hInst, IDS_INI_KEY_142, szBuffer, BUFFER_SIZE);
							GetPrivateProfileString("Run", szBuffer, "2.5e-6", szBuffer, BUFFER_SIZE,
								szIniFile);
							fOverlappingTime=(float)atof(szBuffer);

							fRunTime=(float)fOverlappingTime*nNum;			
							break;
						}
							
						// Modified Allan calc time est coeff
						case MODIFIED_RUN:
						{
							// Get time coefficient
							LoadString(hInst, IDS_INI_KEY_143, szBuffer, BUFFER_SIZE);
							GetPrivateProfileString("Run", szBuffer, "2.5e-6", szBuffer, BUFFER_SIZE,
								szIniFile);
							fModifiedTime=(float)atof(szBuffer);

							fRunTime=(float)fModifiedTime*nNum;			
							break;
						}
							
						// Time calc time est coeff
						case TIME_RUN:
						{
							// Get time coefficient
							LoadString(hInst, IDS_INI_KEY_144, szBuffer, BUFFER_SIZE);
							GetPrivateProfileString("Run", szBuffer, "2.5e-6", szBuffer, BUFFER_SIZE,
								szIniFile);
							fTimeTime=(float)atof(szBuffer);

							fRunTime=(float)fTimeTime*nNum;			
							break;
						}
							
						// Overlapping & Modified Allan calc time est coeff
						case BOTH_RUN:
						{
							// Get time coefficient
							LoadString(hInst, IDS_INI_KEY_151, szBuffer, BUFFER_SIZE);
							GetPrivateProfileString("Run", szBuffer, "2.5e-6", szBuffer, BUFFER_SIZE,
								szIniFile);
							fBothTime=(float)atof(szBuffer);

							fRunTime=(float)fBothTime*nNum;			
							break;
						}
						
						// Hadamard calc time est coeff
						case HADAMARD_RUN:
						{
							// Get time coefficient
							LoadString(hInst, IDS_INI_KEY_145, szBuffer, BUFFER_SIZE);
							GetPrivateProfileString("Run", szBuffer, "2.5e-6", szBuffer, BUFFER_SIZE,
								szIniFile);
							fHadamardTime=(float)atof(szBuffer);

							fRunTime=(float)fHadamardTime*nNum;			
							break;
						}
							
						// Overlapping Hadamard calc time est coeff
						case OVERLAPHAD_RUN:
						{
							// Get time coefficient
							LoadString(hInst, IDS_INI_KEY_146, szBuffer, BUFFER_SIZE);
							GetPrivateProfileString("Run", szBuffer, "2.5e-6", szBuffer, BUFFER_SIZE,
								szIniFile);
							fOverlapHadTime=(float)atof(szBuffer);

							fRunTime=(float)fOverlapHadTime*nNum;			
							break;
						}
							
						// Total calc time est coeff
						case TOTAL_RUN:
						{
							// Get time coefficient
							LoadString(hInst, IDS_INI_KEY_147, szBuffer, BUFFER_SIZE);
							GetPrivateProfileString("Run", szBuffer, "2.5e-6", szBuffer, BUFFER_SIZE,
								szIniFile);
							fTotalTime=(float)atof(szBuffer);

							fRunTime=(float)fTotalTime*nNum;			
							break;
						}
							
						// TIE rms calc time est coeff
						case TIERMS_RUN:
						{
							// Get time coefficient
							LoadString(hInst, IDS_INI_KEY_152, szBuffer, BUFFER_SIZE);
							GetPrivateProfileString("Run", szBuffer, "2.5e-6", szBuffer, BUFFER_SIZE,
								szIniFile);
							fTIErmsTime=(float)atof(szBuffer);

							fRunTime=(float)fTIErmsTime*nNum;			
							break;
						}
							
						/*************************************************************/
						/*                   Quadratic (N * N) Terms                 */
						/*************************************************************/
							
						// Modified Total calc time est coeff
						case MODTOTAL_RUN:
						{
							// Get time coefficient
							LoadString(hInst, IDS_INI_KEY_148, szBuffer, BUFFER_SIZE);
							GetPrivateProfileString("Run", szBuffer, "1.5e-7", szBuffer, BUFFER_SIZE,
								szIniFile);
							fModTotalTime=(float)atof(szBuffer);

							fRunTime=(float)fModTotalTime*nNum*nNum;
							break;
						}

						// Time Total calc time est coeff
						case TIMETOTAL_RUN:
						{
							// Get time coefficient
							LoadString(hInst, IDS_INI_KEY_149, szBuffer, BUFFER_SIZE);
							GetPrivateProfileString("Run", szBuffer, "1.5e-7", szBuffer, BUFFER_SIZE,
								szIniFile);
							fTimeTotalTime=(float)atof(szBuffer);

							fRunTime=(float)fTimeTotalTime*nNum*nNum;			
							break;
						}

						// Hadamard Total calc time est coeff
						case HADTOTAL_RUN:
						{
							// Get time coefficient
							LoadString(hInst, IDS_INI_KEY_150, szBuffer, BUFFER_SIZE);
							GetPrivateProfileString("Run", szBuffer, "1.5e-7", szBuffer, BUFFER_SIZE,
								szIniFile);
							fHadTotalTime=(float)atof(szBuffer);

							fRunTime=(float)fHadTotalTime*nNum*nNum;			
							break;
						}

						// MTIE calc time est coeff
						case MTIE_RUN:
						{
							// Get time coefficient
							LoadString(hInst, IDS_INI_KEY_153, szBuffer, BUFFER_SIZE);
							GetPrivateProfileString("Run", szBuffer, "1.5e-8", szBuffer, BUFFER_SIZE,
								szIniFile);
							fMTIETime=(float)atof(szBuffer);

							fRunTime=(float)fMTIETime*nNum*nNum;			
							break;
						}

						/*************************************************************/
						/*               Linear & Log (N * log(N)) Terms             */
						/*************************************************************/
							
						// Tho1 calc time est coeff
						case THEO1_RUN:
						{
							// Get time coefficient
							LoadString(hInst, IDS_INI_KEY_154, szBuffer, BUFFER_SIZE);
							GetPrivateProfileString("Run", szBuffer, "2.0e-4", szBuffer, BUFFER_SIZE,
								szIniFile);
							fTheo1Time=(float)atof(szBuffer);

							fRunTime=(float)(fTheo1Time*nNum*log10(nNum));
							
							break;
						}

						// ThoH calc time est coeff
						case FULL_RUN:
						{
							// Get time coefficient
							LoadString(hInst, IDS_INI_KEY_155, szBuffer, BUFFER_SIZE);
							GetPrivateProfileString("Run", szBuffer, "2.0e-4", szBuffer, BUFFER_SIZE,
								szIniFile);
							fFullTime=(float)atof(szBuffer);

							fRunTime=(float)(fFullTime*nNum*log10(nNum));
							
							break;
						}

						#if(0) // Obsolete code - faster ModTotvarCalc() varies as N * N
						/*************************************************************/
						/*                   Cubic (N * N * N) Terms                 */
						/*************************************************************/
							
						// Modified Total calc time est coeff
						case MODTOTAL_RUN:
						{
							// Get time coefficient
							LoadString(hInst, IDS_INI_KEY_148, szBuffer, BUFFER_SIZE);
							GetPrivateProfileString("Run", szBuffer, "7.2e-9", szBuffer, BUFFER_SIZE,
								szIniFile);
							fModTotalTime=(float)atof(szBuffer);

							fRunTime=(float)fModTotalTime*nNum*nNum*nNum;			
							break;
						}

						// Time Total calc time est coeff
						case TIMETOTAL_RUN:
						{
							// Get time coefficient
							LoadString(hInst, IDS_INI_KEY_149, szBuffer, BUFFER_SIZE);
							GetPrivateProfileString("Run", szBuffer, "7.2e-9", szBuffer, BUFFER_SIZE,
								szIniFile);
							fTimeTotalTime=(float)atof(szBuffer);

							fRunTime=(float)fTimeTotalTime*nNum*nNum*nNum;			
							break;
						}
						#endif
					}
					#endif
					
					#if(1) // New code 08/24/08
					// Is run calc time feature enabled and this a slow calc with large data set?
					if( (fRunLimit>0) && (fRunTime>fRunLimit) )
					{
						// Set time flag
						bTime=TRUE;

						// Get variance type
						GetWindowText(GETHCTL(IDC_RUN_TYPE), szText, BUFFER_SIZE);

						// Compose variance label
						strlcat(szText, " Run", sizeof(szText));

						// Save title
						strlcpy(szTitle, szText, sizeof(szTitle));

						// Adjust estimate for fast MTIE
						if(bAllTau && nSigmaType==MTIE_RUN) // MTIE is special "fast" case
						{
							fRunTime/=5.0; // Approx fast MTIE speedup factor
						}

						
						if(bAllTau && nSigmaType!=MTIE_RUN) // MTIE is special "fast" case
						{
							// Compose message
							strlcpy(szFormat, "This All Tau ", sizeof(szFormat));
							strlcat(szFormat, szText, sizeof(szFormat));
							strlcat(szFormat, " will require a long time.\n"
								"Do you want to average the data?", sizeof(szFormat));
						}
						else // Octave or decade tau increments
						{
							// Compose message
							if(fRunTime<600.) // Show seconds for estimated run time < 10 min
							{
								strlcpy(szFormat, "This ", sizeof(szFormat));
								strlcat(szFormat, szText, sizeof(szFormat));
								strlcat(szFormat, " will require quite a while.\n", sizeof(szFormat));
								_snprintf(szText, sizeof(szText), "Estimated run time = %d seconds\n", (int)(fRunTime+0.5));
								strlcat(szFormat, szText, sizeof(szFormat));
								strlcat(szFormat, "Do you want to average the data?", sizeof(szFormat));
							}
							else if(fRunTime<36000.) // Show est run time in minutes for run time < 10 hrs
							{
								strlcpy(szFormat, "This ", sizeof(szFormat));
								strlcat(szFormat, szText, sizeof(szFormat));
								strlcat(szFormat, " will require quite a while.\n", sizeof(szFormat));
								_snprintf(szText, sizeof(szText), "Estimated run time = %d minutes\n", (int)((fRunTime+0.5)/60.));
								strlcat(szFormat, szText, sizeof(szFormat));
								strlcat(szFormat, "Do you want to average the data?", sizeof(szFormat));
							}
							else if(fRunTime<3.6e6) // Show est run time in hours if < 1000 hours
							{
								strlcpy(szFormat, "This ", sizeof(szFormat));
								strlcat(szFormat, szText, sizeof(szFormat));
								strlcat(szFormat, " will require quite a while.\n", sizeof(szFormat));
								_snprintf(szText, sizeof(szText), "Estimated run time = %d hours\n", (int)((fRunTime+0.5)/3600.));
								strlcat(szFormat, szText, sizeof(szFormat));
								strlcat(szFormat, "Do you want to average the data?", sizeof(szFormat));
							}
							else // Show estimated run time as > 1000 hours
							{
								strlcpy(szFormat, "This ", sizeof(szFormat));
								strlcat(szFormat, szText, sizeof(szFormat));
								strlcat(szFormat, " will require quite a while.\n", sizeof(szFormat));
								_snprintf(szText, sizeof(szText), "Estimated run time > 1000 hours\n");
								strlcat(szFormat, szText, sizeof(szFormat));
								strlcat(szFormat, "Do you want to average the data?", sizeof(szFormat));
							}
						}
						
						// Show message offering to average data
						nDummy=MessageBox(hDlg, szFormat, szTitle,
							MB_ICONQUESTION | MB_YESNO | MB_DEFBUTTON2 );

						// Averaging requested?
						if(nDummy==IDYES)
						{
							// Close and then reopen Run dialog box
							// This is the safest thing to do
							// because data will change if averaging is done

							// Restore data
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_RESTORE, NULL, 0));

							// Free temporary data array
							free(fTempData);

							// Clear data valid flag
							bDataValid=FALSE;

							// Close Run dialog box
							EndDialog(hDlg, 0);

							// Open Avg dialog box
							InvokeDialogBox(hInst, "AvgBox", hwndMain,
								(DLGPROC)AvgDlgProc);

							// Refresh status plots
							SendMessage(hwndMain, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_REFRESH, 0, 0));

							// Reopen Run dialog box
							InvokeDialogBox(hInst, "RunBox", hwndMain,
								(DLGPROC)RunDlgProc);

							// Return
							return TRUE;
						}
					}
					#endif

					// Reset abort flag
					bAbort=FALSE;

					// Set yield flag - will stay set until run is done
					bYield=TRUE;

					// Set bias factor to nominal
					fBias=1.0;

					// Clear results & get # if we are not resuming current run
					if(!bStop)
					{
						// Clear results
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RUN_CLEAR, NULL, 0));

						// Find # non-gap tau=tau0 data points
						{
							nNum0=nNum-CountGaps(fData, bDataType);
						}
					}

					// Show drift window & hide start AF control & label
					ShowWindow((GETHCTL(IDC_RUN_DRIFT)), SW_SHOWNORMAL);
					ShowWindow((GETHCTL(IDC_RUN_AF)), SW_HIDE);
					ShowWindow((GETHCTL(IDC_RUN_AFLABEL)), SW_HIDE);

					// Display wait cursor
					SetCursor(hWait);

					// Set busy flag
					bBusy=TRUE;

					#if(1) // New code 08/24/08
					// Time calculation - get start Windows time in msec
					nTick=GetTickCount();
					#endif

					#ifdef THEOH // For ThoH usage
					// Disable Close button
					// No abort except for MTIE, MTOT, TTOT or HTOT calcs
					if((nSigmaType!=MTIE_RUN) && (nSigmaType!=MODTOTAL_RUN) &&
						(nSigmaType!=TIMETOTAL_RUN) &&
						(nSigmaType!=HADTOTAL_RUN) &&
						(nSigmaType!=THEO1_RUN) && (nSigmaType!=FULL_RUN))
					{
						EnableWindow(GETHCTL(IDCANCEL), FALSE);
					}

					// Show calc/abort message
					if( (bAllTau) || (nSigmaType==MTIE_RUN) ||
						(nSigmaType==MODTOTAL_RUN) ||
						(nSigmaType==TIMETOTAL_RUN) ||
						(nSigmaType==HADTOTAL_RUN) ||
						(nSigmaType==THEO1_RUN) ||
						(nSigmaType==FULL_RUN))
					{
						LoadString(hInst, IDS_MESSAGE_ABORT, szBuffer,
							BUFFER_SIZE);
						SetWindowText(GETHCTL(IDC_RUN_DRIFT), szBuffer);
						SetWindowText(GETHCTL(IDCANCEL), "&Stop");
					}
					else
					{
						LoadString(hInst, IDS_MESSAGE_CALC, szBuffer,
							BUFFER_SIZE);
						SetWindowText(GETHCTL(IDC_RUN_DRIFT), szBuffer);
						SetWindowText(GETHCTL(IDCANCEL), "&Close");
					}
					#else // Normal version
					// Disable Close button
					// No abort except for MTIE, MTOT, TTOT or HTOT calcs
					if((nSigmaType!=MTIE_RUN) &&
						(nSigmaType!=MODTOTAL_RUN) &&
						(nSigmaType!=TIMETOTAL_RUN) &&
						(nSigmaType!=HADTOTAL_RUN) &&
						(nSigmaType!=THEO1_RUN))
					{
						EnableWindow(GETHCTL(IDCANCEL), FALSE);
					}

					// Show calc/abort message
					if( (bAllTau) || (nSigmaType==MTIE_RUN) ||
						(nSigmaType==MODTOTAL_RUN) ||
						(nSigmaType==TIMETOTAL_RUN) ||
						(nSigmaType==HADTOTAL_RUN) ||
						(nSigmaType==THEO1_RUN))
					{
						LoadString(hInst, IDS_MESSAGE_ABORT, szBuffer,
							BUFFER_SIZE);
						SetWindowText(GETHCTL(IDC_RUN_DRIFT), szBuffer);
						SetWindowText(GETHCTL(IDCANCEL), "&Stop");
					}
					else
					{
						LoadString(hInst, IDS_MESSAGE_CALC, szBuffer,
							BUFFER_SIZE);
						SetWindowText(GETHCTL(IDC_RUN_DRIFT), szBuffer);
						SetWindowText(GETHCTL(IDCANCEL), "&Close");
					}
					#endif
					
					SetWindowText(GETHCTL(IDC_RUN_DRIFT), szBuffer);

					UpdateWindow(GETHCTL(IDC_RUN_DRIFT));

					// Get remove flag
					// Note: The original data is restored after each calc,
					// so drift removal must be redone every time

					bRemoveDrift=(BOOL)
						Button_GetCheck(GETHCTL(IDC_RUN_REMOVE));

					// Grey unwanted controls (all buttons except close)
					EnableWindow(GETHCTL(IDC_RUN_RUN), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_PRINT), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_PLOT), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_OPTIONS), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_LINES), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_NOTES), FALSE);
					EnableWindow(GETHCTL(IDHELP), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_TYPE), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_CF), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_REMOVE), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_DECADE), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_OCTAVE), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_ALLTAU), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_COPY), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_1OF2), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_ALPHA), FALSE);

					// Get tau value
					if(bDataType==FREQ_DATA)
					{
						GetWindowText(hwndFreqTau, szBuffer, BUFFER_SIZE);
					}
					else // Phase data
					{
						GetWindowText(hwndPhaseTau, szBuffer, BUFFER_SIZE);
					}
					fTau=(F_TYPE)atof(szBuffer);
					
					// Adjust nStopRatio
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_RUN_SETSTOP, NULL, 0));

					// Initialize if we are not resuming current run
					if(!bStop)
					{
						// Calculate size of sigma data arrays
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RUN_SIGMASIZE, 0, 0));

						// Reallocate size of sigma data arrays
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RUN_REALLOC, 0, 0));

						// Initialize index & averaging factor
						i=0;
						k=-1;
						nAF=nStartAF;
					}
					
					// Find # non-gap data points
					{
						nNum0=nNum-CountGaps(fData, bDataType);
					}

					// Check for too few points
					// Note: Was nNum until 06/14/00
					if(nNum0<nStopRatio)
					{
						// Display error message
						LoadString(hInst, IDS_MESSAGE_TOOFEWRUN, szBuffer,
							BUFFER_SIZE);
						MessageBox(hDlg, szBuffer, szBoxTitle,
							MB_ICONEXCLAMATION);

						// Restore data
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RUN_RESTORE, NULL, 0));

						// Free temporary data array
						free(fTempData);

						// Clear data valid flag
						bDataValid=FALSE;

						// Close Run dialog box
						EndDialog(hDlg, 0);
						return TRUE;
					}

					// Run automatic stability analysis for all except all tau
					if(!bAllTau || nSigmaType==MTIE_RUN)
					{
						// In order to use faster B&M MTIE method
						// must let it use its own overall loop
						// so intercept MTIE_RUN here.
						// Fast method is selected with AllTau flag
						// which is relabeled Fast
						
						if(nSigmaType==MTIE_RUN && bAllTau)
						{
							// Remove drift if requested - always phase data
							// Will be restored at end of run
							if(bRemoveDrift)
							{
								// Calc & remove quadratic drift
								// Tau=1 for slope per data point interval
								CalcQuadraticDrift(fPhaseData, 1.0, &fA, &fB,
									&fC, &fV);
								RemoveQuadraticDrift(fPhaseData, fA, fB,
									fC);
							}

							// Calc drift (after possible drift removal)
							// Note: Substitite for NG FrequenC funct
							// Tau=1 for slope per data interval
							 // Quadratic fit
							CalcQuadraticDrift(fPhaseData, 1.0, &fA, &fB,
								&fC, &fV);
							
							// Get freq slope/data interval
							fSlope=2*fC/fTau;
							fDrift=fSlope*SEC_PER_DAY/fTau;

							// Fill gaps in data
							FillGaps(fPhaseData, PHASE_DATA);

							// Calc MTIE
							nDummy=CalcFastMTIE(fPhaseData, &sNormSigData);

							// Set array index to # fast MTIE points;
							k=sNormSigData.points;
							
							// Test for error
							if(nDummy==-1)
							{
								break;
							}

							// The points member is # MTIE values actually done
							// which is OK in case of an abort
							// since this function does not resume
							// after an abort - it starts over again
							// The button is renamed Restart not Resume
							// Note: Arrive here if abort after IDCANCEL code
							
							// Set nNum0 to 0 as way to proceed w/o std looping
							nNum0=0;
						}
						
						while(((nNum0/nAF)>=nStopRatio) && !bAbort)
						{
							#ifdef LOGGING
							_snprintf(szBuffer, sizeof(szBuffer),
								"Run for nAF=%d", nAF);
							WriteLog(60, szBuffer);
							#endif

							// Set auxilary calc array index equal to main one
							// Note: k always equal to i for non-all tau case
							k=i;

							// Store tau
							sNormSigData.tau[i]=(float)fTau*nAF;
							sModSigData.tau[i]=(float)fTau*nAF;

							// Store averaging factor
							sModSigData.af[i]=nAF;
							sNormSigData.af[i]=nAF;

							// Remove drift if requested
							// Note:  Have to do this for each iteration
							// Drift removal is not permanent
							if(bRemoveDrift)
							{
								if(bDataType==FREQ_DATA)
								{
									// Calc & remove linear drift
									CalcLinFreqDrift(fFreqData, &fA, &fB, &fV);
									RemoveLinFreqDrift(fFreqData, fA, fB);
								}
								else // Phase data
								{
									// Calc & remove quadratic drift
									// Tau=1 for slope per data point interval
									CalcQuadraticDrift(fPhaseData, 1.0, &fA,
										&fB, &fC, &fV);
									RemoveQuadraticDrift(fPhaseData, fA, fB,
										fC);
								}
							}

							if(nAF==nStartAF)
							{
								// Calc drift (after possible drift removal)
								if(bDataType==FREQ_DATA)
								{
									CalcLinFreqDrift(fFreqData, &fIntercept,
										&fSlope, &fV);
								}
								else // Phase data
								{
									// Note: Substitite for NG FrequenC funct
									// Tau=1 for slope per data interval
									 // Quadratic fit
									CalcQuadraticDrift(fPhaseData, 1.0, &fA,
										&fB, &fC, &fV); 
									// freq slope/data interval
									fSlope=2*fC/fTau;
									
								}
								fDrift=fSlope*SEC_PER_DAY/fTau;
							}

							// Trap for Tho1 case where nStopRatio=1
							if(nAF>=nNum0)
							{
								break;
							}
							
							if(bDataType==PHASE_DATA && (nSigmaType==
								NORMAL_RUN || nSigmaType==HADAMARD_RUN))
							{
								// Average data
								AveragePhaseData(fPhaseData, nAF);
							}

							if(bDataType==FREQ_DATA && (nSigmaType==
								NORMAL_RUN || nSigmaType==HADAMARD_RUN))
							{
								// Average data
								AverageFreqData(fFreqData, nAF);
							}

							// Process phase data
							if(bDataType==PHASE_DATA)
							{
								SendMessage(hDlg, WM_COMMAND,
									GET_WM_COMMAND_MPS(IDC_RUN_PHASE,
									NULL, 0));
							}

							// Process frequency data
							if(bDataType==FREQ_DATA)
							{
								SendMessage(hDlg, WM_COMMAND,
									GET_WM_COMMAND_MPS(IDC_RUN_FREQ,
									NULL, 0));
							}

							// Check for abort - this is 1st place after abort
							if(bAbort)
							{
								break;      // Break out to avoid FP errors
							}

							// Skip noise determination for Tho1 cases
							if(nSigmaType!=THEO1_RUN && nSigmaType!=FULL_RUN)
							{
								// Find noise type
								if( ((nNum/(nAF*2))>=nStopRatio) || (i==0) )
								{
									SendMessage(hDlg, WM_COMMAND,
										GET_WM_COMMAND_MPS(IDC_RUN_NOISE,
										NULL, 0));
								}
								// Use previous noise type if this is last af
								// Unless i=0
								else
								{
									sNormSigData.alpha[i]=
										sNormSigData.alpha[i-1];
									sModSigData.alpha[i]=
										sModSigData.alpha[i-1];

									#if(WRITEALPHA)
									sNormSigData.falpha[i]=
										sNormSigData.falpha[i-1];
									sModSigData.falpha[i]=
										sModSigData.falpha[i-1];
									#endif
								}
							}
							else if(nSigmaType==THEO1_RUN)
							{
								if(bAutoAlpha)
								{
									if(i==0) // First stability point
									{
										// Use alpha value from NewTheo1 bias
										nAlpha=Theo1BiasToAlpha(fTheo1BiasFactor,
											nAF);
									}
								}
								else
								{
									// Get & use noise type from screen
									nAlpha=3-
										ComboBox_GetCurSel(
										GETHCTL(IDC_RUN_ALPHA));
								}

								// Put alpha value into results array
								sNormSigData.alpha[i]=nAlpha;
								sModSigData.alpha[i]=nAlpha;

								#if(WRITEALPHA)
								sNormSigData.falpha[i]=(float)nAlpha;
								sModSigData.falpha[i]=(float)nAlpha;
								#endif
							}
							else if(nSigmaType==FULL_RUN)
							{
								// We don't have to find noise type here for
								// when the Auto/Match option is selected 
								if(!bAutoAlpha)
								{
									// Get & use noise type from screen
									nAlpha=3-
										ComboBox_GetCurSel(GETHCTL(
										IDC_RUN_ALPHA));
									sNormSigData.alpha[i]=nAlpha;
									sModSigData.alpha[i]=nAlpha;

									#if(WRITEALPHA)
									sNormSigData.falpha[i]=(float)nAlpha;
									sModSigData.falpha[i]=(float)nAlpha;
									#endif
								}
							}

							// Apply TOTALVAR bias function
							if(nSigmaType==TOTAL_RUN)
							{
								// Guard against alpha<-2
								if(nAlpha<-2)
								{
									nAlpha=-2;
								}

								// Calc bias factor
								// Applies for all alpha -2 to +2
								fBias=TotvarBias(nAlpha,
									(float)nNum/(float)nAF);

								// Correct TOTALDEV
								sNormSigData.sigma[i]/=(float)sqrt(fBias);
							}

							// Apply MOD TOTVAR bias function
							if( (nSigmaType==MODTOTAL_RUN) ||
								(nSigmaType==TIMETOTAL_RUN) )
							{
								// Calc Mod Totvar bias factor
								// Applies for all alpha -2 to +2
								// Otherwise it returns -1
								fBias=ModTotvarBias(nAlpha);

								// Set fBias to unity
                                // This is approximately correct for
                                // alpha >0 (W and F PM)
                                // and allows calculation to proceed
                                fBias=1.0;

								// Correct MOD TOTDEV
								sModSigData.sigma[i]/=(float)sqrt(fBias);
							}

							// Apply Hadamard Totvar bias function
							// Do this only for AF>1
							// because overlapping Hadamard is used for AF=1
							if(nSigmaType==HADTOTAL_RUN && nAF>1)
							{
								// Calc Hadamard Totvar bias factor
								// Applies for all alpha -4 to 0
								// Otherwise it returns -1
								fBias=HadTotvarBias(nAlpha);

								// Test for error
								if(fBias==-1.0)
								{
                                    // Set fBias to unity
                                    // This is approximately correct for
                                    // alpha >0 (W and F PM)
                                    // and allows calculation to proceed
                                    fBias=1.0;
								}

								// Correct HTOTDEV
								sNormSigData.sigma[i]/=(float)sqrt(fBias);
							}

							// Scale if time or time total deviation
							if( (nSigmaType==TIME_RUN) ||
								(nSigmaType==TIMETOTAL_RUN) )
							{
								// Convert result into time deviation
								sModSigData.sigma[i]=
									(float)(sModSigData.sigma[i]*
									sModSigData.tau[i]/sqrt(3.0));
							}

							// Apply dead time corrections
							// Use for normal & overlapping sigma only
							// Mu comes manually-entered noise type
							if( (nSigmaType==NORMAL_RUN) ||
								(nSigmaType==OVERLAPPING_RUN) )
							{
								// Don't bother to calc if deadtime ratio is 1
								if(fDeadtime>1.0)
								{
									// Calc mu
									nMu=max(-nAlpha-1, -2);

									// Calc B2 bias function
									fB2=CalcBias2(fDeadtime, (float)nMu);

									// Calc B3 bias function
									fB3=CalcBias3(nAF, fDeadtime, (float)nMu);

									// Apply bias functions
									sNormSigData.sigma[i]/=
										((float)sqrt(fB2)*(float)sqrt(fB3));
								}
							}

							// Calc errorbars
							// Except for FULL_RUN with Auto/Match option
							// where they are calculated later
							if(!(nSigmaType==FULL_RUN && bAutoAlpha))
							{
								SendMessage(hDlg, WM_COMMAND,
									GET_WM_COMMAND_MPS(IDC_RUN_ERRORBAR, NULL,
									0));
							}

							// Remove if data resestoration moved earlier
							// Prepare for next tau iteration
							if(bDataType==PHASE_DATA && (nSigmaType==
								NORMAL_RUN || nSigmaType==HADAMARD_RUN))
							{
								// Restore data
								SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_RESTORE, NULL, 0));
							}

							if(bDataType==FREQ_DATA && (nSigmaType==
								NORMAL_RUN || nSigmaType==HADAMARD_RUN))
							{
								// Restore data
								SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_RESTORE, NULL, 0));
							}

							// Display results line-by-line (shows progress)
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_DISPLAY, NULL, 0));
							UpdateWindow(hSigTbl);

							// Increment
							nAF*=2;

							// Change decade 8's to 10's
							if((bDecade) &&
								((log10(nAF)-(int)(log10(nAF)))>0.9))
							{
								nAF*=10;
								nAF/=8;
							}

							// Increment both indices
							i++;
							k++;
						}

						// Reset yield flag - octave/decade run is done
						bYield=FALSE;

						#if(0) // Old code from Version 1.42 of 07/12/03
						// This code snippet pasted in here 08/08/07
						// because of interest in having faster way to
						// determine Tho1 bias
						// and the possibility of reusing this original
						// much faster and simplier way of doing it:
						// ADEV and non bias corrected Tho1 calculations
						// are done in octave steps over their full respective
						// ranges.  Next, a bias factor is calculated as the
						// (unweighted) average of the ratios of the ADEV to
						// Tho1 values at the taus of the Tho1 points.
						// Then the bias factor is displayed and used to
						// correct the Tho1 values.  It takes a negligible
						// amount of time to calculate the additional ADEV
						// values and bias factor, so the overall time is
						// essentially that of the Tho1 calculations.
						// One could consider weighting the bias factor toward
						// large tau, or toward more confidence (small tau),
						// but no weighting seems a reasonable compromise
						// between the two.  There is an implicit assumption
						// that the noise type is constant (ThoH makes that
						// assumption also).
						//
						// Determine average bias factor of completed FULL_RUN
						// to match sigma and Tho1 deviations
						if(nSigmaType==FULL_RUN && bAutoAlpha)
						{
							// Initializations
							nCount=0;
							fAvgBias=0.0;

							// Sum bias factors
							for(j=0; j<k; j++)
							{
								if(sNormSigData.sigma[j]
									&& sModSigData.sigma[j])
								{
									// Find the avg factor for sigma calc
									// at same tau as Tho1 value
									nAF=(int)((sModSigData.tau[j]/fTau)+0.5);

									// Calc sigma at the tau of the Tho1 dev
									// Note: The 3rd arg is the basic tau_0!
									nDummy=CalcPhaseOverlapSigma(fPhaseData,
										&fSig, fTau, nAF);

									// Calc corresponding bais factor = ratio
									// of sigma to Tho1 dev at same tau
									fAvgBias+=((float)fSig/
										sModSigData.sigma[j]);
									nCount++;
								}
							}

							// Calc average bias factor
							fAvgBias/=(float)nCount;

							// Find alpha
							nAlpha=Theo1BiasToAlpha(fAvgBias);

							// Apply bias and store alpha
							for(j=0; j<k; j++)
							{
								// Apply average bias to Tho1 points
								if(sModSigData.sigma[j])
								{
									sModSigData.sigma[j]*=fAvgBias;
								}

								// Store alpha in all results arrays
								sNormSigData.alpha[j]=nAlpha;
								sModSigData.alpha[j]=nAlpha;
							}
							
							// Save k in j
							j=k;

							// Use this alpha
							// to set all ADEV & Tho1 error bars
							for(k=0; k<j; k++)
							{
								// Note: nAF is normal one - not x0.75
								nAF=sModSigData.af[k];
								SendMessage(hDlg, WM_COMMAND,
									GET_WM_COMMAND_MPS(IDC_RUN_ERRORBAR, NULL,
									0));
							}

							// Restore k
							k=j;

							// Redisplay results (update Tho1 & alpha values)
							k--;
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_DISPLAY, NULL, 0));
							UpdateWindow(hSigTbl);
							k++;
						}
						#endif // End of old code snippet

						#ifndef THEOH // It is usually defined, so we skip this
						// Determine average bias factor of completed FULL_RUN
						// to match sigma and Tho1 deviations
						if(nSigmaType==FULL_RUN && bAutoAlpha)
						{
							// Remove drift again if requested
							if(bRemoveDrift)
							{
								// Always phase data
								// Calc & remove quadratic drift
								// Tau=1 for slope per data point interval
								CalcQuadraticDrift(fPhaseData, 1.0, &fA, &fB,
									&fC, &fV);
								RemoveQuadraticDrift(fPhaseData, fA, fB,
									fC);
							}

							// Initializations
							nCount=0;
							fAvgBias=0.0;

							// Sum bias factors
							for(j=0; j<k; j++)
							{
								if(sNormSigData.sigma[j] &&
									sModSigData.sigma[j])
								{
									// Find the avg factor for sigma calc
									// at same tau as Tho1 value
									nAF=(int)((sModSigData.tau[j]/fTau)+0.5);

									// Calc sigma at the tau of the Tho1 dev
									// Note: The 3rd arg is the basic tau_0!
									nDummy=CalcPhaseOverlapSigma(fPhaseData,
										&fSig, fTau, nAF);

									// Calc corresponding bias factor = ratio
									// of sigma to Tho1 dev at same tau
									fAvgBias+=((float)fSig/
										sModSigData.sigma[j]);

									// Increment count
									nCount++;
								}
							}

							// Calc average bias factor
							fAvgBias/=(float)nCount;

							// Square the avg bias value so it applies
							// to variances as is our usual convention
							fAvgBias*=fAvgBias;

							// Find alpha
							nAlpha=Theo1BiasToAlpha(fAvgBias, nAF);

							// Apply bias and store alpha
							for(j=0; j<k; j++)
							{
								// Apply average bias to Tho1 points
								if(sModSigData.sigma[j])
								{
									sModSigData.sigma[j]*=
										(float)sqrt(fAvgBias);
								}

								// Store alpha in all results arrays
								sNormSigData.alpha[j]=nAlpha;
								sModSigData.alpha[j]=nAlpha;

								#if(WRITEALPHA)
								sNormSigData.falpha[j]=(float)nAlpha;
								sModSigData.falpha[j]=(float)nAlpha;
								#endif
							}
							
							// Save k in j
							j=k;

							// Use this alpha to set all ADEV & Tho1
							// error bars
							for(k=0; k<j; k++)
							{
								// Note: nAF is normal one - not x0.75
								nAF=sModSigData.af[k];
								SendMessage(hDlg, WM_COMMAND,
									GET_WM_COMMAND_MPS(IDC_RUN_ERRORBAR, NULL,
									0));
							}

							// Restore k
							k=j;

							// Redisplay results (update Tho1 & alpha values)
							k--;
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_DISPLAY, NULL, 0));
							UpdateWindow(hSigTbl);
							k++;

							// Restore data
							SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RUN_RESTORE, NULL, 0));
						}

						#else // THEOH defined - Using ThoBR
						// Don't do match if using ThoBR
						if(nSigmaType==FULL_RUN && bAutoAlpha)
						{
							// Remove drift again if requested
							if(bRemoveDrift)
							{
								// Always phase data
								// Calc & remove quadratic drift
								// Tau=1 for slope per data point interval
								CalcQuadraticDrift(fPhaseData, 1.0, &fA, &fB,
									&fC, &fV);
								RemoveQuadraticDrift(fPhaseData, fA, fB,
									fC);
							}

							// Find alpha
							nAlpha=Theo1BiasToAlpha(fTheo1BiasFactor, nAF);

							// Store alpha
							for(j=0; j<k; j++)
							{
								// Store alpha in all results arrays
								sNormSigData.alpha[j]=nAlpha;
								sModSigData.alpha[j]=nAlpha;

								#if(WRITEALPHA)
								sNormSigData.falpha[j]=(float)nAlpha;
								sModSigData.falpha[j]=(float)nAlpha;
								#endif
							}
							
							// Save k in j
							j=k;

							// Use this alpha to set all ADEV & Tho1
							// error bars
							for(k=0; k<j; k++)
							{
								// Note: nAF is normal one - not x0.75
								nAF=sModSigData.af[k];
								SendMessage(hDlg, WM_COMMAND,
									GET_WM_COMMAND_MPS(IDC_RUN_ERRORBAR, NULL,
									0));
							}

							// Restore k
							k=j;

							// Redisplay results (update Tho1 & alpha values)
							k--;
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_DISPLAY, NULL, 0));
							UpdateWindow(hSigTbl);
							k++;

							// Restore data
							SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RUN_RESTORE, NULL, 0));
						}
						#endif
					}

					// Re-enable Close button
					EnableWindow(GETHCTL(IDCANCEL), TRUE);

					// Need to allocate sigma arrays
					// to size of actual data array.
					// Will need to use a variable instead of the SIGMA_SIZE
					// and ALLSIGMA_SIZE macros.  Lets call this nSigmaSize.
					// For octave increments, calc # octaves in # data points
					// as # octaves = ln(# data points) / ln(2).
					// Could reduce this to take into account min # of
					// averaged data points (ranging from 2 to 5 depending
					// on the sigma type - total or normal), called 
					// nStopRatio.  So # sigma array points to allocate is
					// ceil((log((double)nNum/(double)nStopRatio)/log(2.0))).
					// For decade increments, have 3 sigma points per decade.
					// So # sigma array points to allocate is 3*ceil(
					// log10((double)nNum/(double)nStopRatio)).
					// For all tau, need # sigma array points equal to
					// ceil((double)nNum/(double)nStopRatio).
					
					// Run automatic stability analysis for all tau
					// Does not apply to MTIE (where bAllTau flag means fast MTIE)
					if(bAllTau && nSigmaType!=MTIE_RUN)
					{
						// To support resume, must reinitialize to i not 0
						// and to support nStartAF must subtract it in test
						// Test made <= to go to full AF limit
						// Note: k not equal i for many-tau case with large AF

						// Don't reinitialize k if resuming
						if(!bResume)
						{
							// Initialize auxiliary array index
							k=i-1;

							// Initialize bias calc control params
							bBias=FALSE;
							nLast=0;
						}
						else
						{
							bResume=FALSE;
						}
						
						// Calc # tau decades on plot
						nXDecades=(int)(ceil(log10(fTau*nNum/nStopRatio)))-
							(int)(floor(log10(nStartAF*fTau)));

						// Avoid divide by zero
						if(nXDecades<1)
						{
							// Display error message
							LoadString(hInst, IDS_MESSAGE_TOOFEWRUN, szBuffer,
								BUFFER_SIZE);
							MessageBox(hDlg, szBuffer, szBoxTitle,
								MB_ICONEXCLAMATION);

							// Restore data
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_RESTORE, NULL, 0));

							// Free temporary data array
							free(fTempData);

							// Clear data valid flag
							bDataValid=FALSE;

							// Close Run dialog box
							EndDialog(hDlg, 0);
							return TRUE;
						}

						// Calc desired # plot points per decade
						// 500 is emperical value
						// based on 1024 pixel screen width
						nPointsPerDecade=nManySize/nXDecades;

						// Calc density param to adjust plot point spacing
						// For an increment in the averaging factor of
						// x(i+1)=x(i)+x(i)/n the resulting function
						// describing the averaging factor is a power
						// function equal to f(x)=(1+1/n)^x which will
						// produce 1/(log10(1+1/n)) points/decade.  For
						// n=70, this yields 162 points/decade, which is
						// gives a visually-continuous 3-decade plot.
						// # points/decade = 1/((10^(1/n))-1)
						nDensityParam=
							(int)(1/(pow(10.0, (1.0/nPointsPerDecade))-1.0));

						// Initialize next AF and row count for all tau table
						nNextAF=1;
						nAllTauRows=0;
						
						// Main loop for all or many tau case
						// i is loop index - it may be advanced within loop
						// for many-tau case with large AF
						// k is array index for calculations and plots
						// i is used only for loop control
						for(i=i; i<=((nNum/nStopRatio)-nStartAF); i++)
						{
							// Many instead of all?
							if(bManyTau)
							{
								// Increase spacing adaptively
								// as AF gets larger
								// and as # of plot decades increases
								// Based on visual appearance of plot so we
								// don't notice point spacing.
								// Greatly speeds up all tau calc
								// Time decreases from O(N) to O(logN) by AF
								// adjustment and to O(const) by both AF and
								// # decades adjustment
								i+=nAF/nDensityParam;
							}

							// Set averaging factor and increment array index
							nAF=i+nStartAF;
							k++;

							// Adjust AF to next even # if Tho1 calc
							if(nSigmaType==THEO1_RUN || nSigmaType==FULL_RUN)
							{
								if(nAF%2)
								{
									nAF++;
									i++;
								}
							}

							// Make sure we didn't overshoot the stopping point
							if(i>=((nNum/nStopRatio)-nStartAF))
							{
								break;
							}

							// Store avg factor in data array
							sModSigData.af[k]=nAF;
							sNormSigData.af[k]=nAF;

							// Show progress
							LoadString(hInst, IDS_MESSAGE_ALLTAUCALC, szBuffer,
								BUFFER_SIZE);
							
							// Show current AF if Mod or Had Totvar calc
							if( (nSigmaType==MODTOTAL_RUN) ||
								(nSigmaType==TIMETOTAL_RUN) ||
								(nSigmaType==HADTOTAL_RUN)||
								(nSigmaType==THEO1_RUN) ||
								(nSigmaType==FULL_RUN) )
							{
								_snprintf(szFormat, sizeof(szFormat),
									": AF=%d", nAF);
								strlcat(szBuffer, szFormat, sizeof(szBuffer));
								WriteProgressMessage(0, szBuffer, FALSE);
							}
								
							// Show overall alltau progress
							WriteProgressMessage((int)(0.5+100.0*i/
								((nNum/nStopRatio)-nStartAF)), szBuffer,
								FALSE);

							// Set tau in results arrays
							sNormSigData.tau[k]=(float)fTau*nAF;
							sModSigData.tau[k]=(float)fTau*nAF;

							if(bDataType==FREQ_DATA)
							{
								// Remove drift if requested
								// Note: Have to do this for each iteration
								// Drift removal is not permanent
								if(bRemoveDrift)
								{
									// Calc & remove linear drift
									CalcLinFreqDrift(fFreqData, &fA, &fB,
										&fV);
									RemoveLinFreqDrift(fFreqData, fA, fB);
								}

								if(nAF==nStartAF)
								{
									// Calc drift
									// After possible drift removal
									CalcLinFreqDrift(fFreqData,
										&fIntercept, &fSlope, &fV);
									fDrift=fSlope*SEC_PER_DAY/fTau;
								}

								if( nSigmaType==NORMAL_RUN ||
									nSigmaType==HADAMARD_RUN)
								{
									// Average data
									AverageFreqData(fFreqData, nAF);
								}

								// Process frequency data
								SendMessage(hDlg, WM_COMMAND,
									GET_WM_COMMAND_MPS(IDC_RUN_FREQ, NULL, 0));
							}
							else // Phase data
							{
								// Remove drift if requested
								// Note:  Must do this for each iteration
								// Drift removal is not permanent
								if(bRemoveDrift)
								{
									// Calc & remove quadratic drift
									// Tau=1 for slope/data point interval
									CalcQuadraticDrift(fPhaseData, 1.0, &fA,
										&fB, &fC, &fV);
									RemoveQuadraticDrift(fPhaseData, fA,
										fB, fC);
								}

								if(nAF==nStartAF)
								{
									// Calc drift
									// After possible drift removal
									// Note: Sub for NG FrequenC function
									// Tau=1 for slope per data interval
									// Quadratic fit
									CalcQuadraticDrift(fPhaseData, 1.0, &fA,
										&fB, &fC, &fV);
									fSlope=2*fC/fTau;
									// Freq slope/data interval 
									fDrift=fSlope*SEC_PER_DAY/fTau;
								}

								if( nSigmaType==NORMAL_RUN ||
									nSigmaType==HADAMARD_RUN)
								{
									// Average data
									AveragePhaseData(fPhaseData, nAF);
								}

								// Process phase data
								SendMessage(hDlg, WM_COMMAND,
									GET_WM_COMMAND_MPS(IDC_RUN_PHASE, NULL,
									0));
							}

							// Check for abort - this is 1st place after abort
							if(bAbort)
							{
								// This seems to help avoid glitches
								// when stopping
								k--;

								// Set resume flag;
								bResume=TRUE;
								
								// Break out to avoid FP errors
								// But before doing so
								// must apply bias correction
								// Use bias correction from previous point
								sNormSigData.sigma[k]/=(float)sqrt(fBias);
								sModSigData.sigma[k]/=(float)sqrt(fBias);
								
								// Scale if time or time total deviation
								if( (nSigmaType==TIME_RUN) ||
									(nSigmaType==TIMETOTAL_RUN) )
								{
									// Convert result into time deviation
									sModSigData.sigma[k]=
										(float)(sModSigData.sigma[k]*
										sModSigData.tau[k]/sqrt(3.0));
								}
								break; 
							}

							// Set sigma for modified types
							if( (nSigmaType==MODIFIED_RUN) ||
								(nSigmaType==TIME_RUN)     ||
								(nSigmaType==MODTOTAL_RUN) ||
								(nSigmaType==TIMETOTAL_RUN) )
							{
								fSig=fModSig;
							}

							// Check for zero sigma
							if(fSig==0.0)
							{
								// Display error message
								SendMessage(hDlg, WM_COMMAND,
									GET_WM_COMMAND_MPS(IDC_RUN_ZEROSIG, NULL,
									0));
								break;
							}

							// Skip noise ID & bias corrections for Tho1 calc
							if(nSigmaType!=THEO1_RUN)
							{
								// Find noise type, mainly to apply
								// TOTVAR, MOD TOTVAR or HTOTVAR
								// bias correction
								// Don't have to ID noise for other sigma types
								// for purposes of any actual calc, since there
								// are no error bars for all tau,
								// but it doesn't seem to affect overall speed
								// and it's neededfor alpha display
								// unless alpha display is eliminated

								// Find noise type
								if( ((nNum/(nAF*2))>=nStopRatio) || (k==0) )
								{
									SendMessage(hDlg, WM_COMMAND,
										GET_WM_COMMAND_MPS(IDC_RUN_NOISE, NULL,
										0));
								}
								else // Use previous noise type
								{
									sNormSigData.alpha[k]=nAlpha;
									sModSigData.alpha[k]=nAlpha;

									#if(WRITEALPHA)
									sNormSigData.falpha[k]=(float)nAlpha;
									sModSigData.falpha[k]=(float)nAlpha;
									#endif
								}

								// Guard against alpha<-2
								if(nAlpha<-2)
								{
									nAlpha=-2;
								}

								if(nSigmaType==TOTAL_RUN)
								{
									// Calc bias factor
									// Applies for all alpha -2 to +2
									fBias=TotvarBias(nAlpha,
										(float)nNum/(float)nAF);

									// Correct TOTALDEV
									sNormSigData.sigma[k]/=(float)sqrt(fBias);
								}

								if( (nSigmaType==MODTOTAL_RUN) ||
									(nSigmaType==TIMETOTAL_RUN) )
								{
									// Calc bias factor
									// Applies for all alpha -2 to +2
									fBias=ModTotvarBias(nAlpha);

									// Correct MOD TOTDEV
									sModSigData.sigma[k]/=(float)sqrt(fBias);
								}

								// Apply Hadamard Totvar bias function
								// Do this only for AF>1
								// because overlapping Hadamard used for AF=1
								if(nSigmaType==HADTOTAL_RUN && nAF>1)
								{
									// Calc Hadamard Totvar bias factor
									// Applies for all alpha -4 to 0
									// Otherwise it returns -1
									fBias=HadTotvarBias(nAlpha);

									// Test for error
									if(fBias==-1.0)
									{
										// Set fBias to unity
										// This is approximately correct for
										// alpha >0 (W and F PM)
										// and allows calculation to proceed
										fBias=1.0;
									}

									// Correct HTOTDEV
									sNormSigData.sigma[k]/=(float)sqrt(fBias);
								}

								// Scale if time or time total deviation
								if( (nSigmaType==TIME_RUN) ||
									(nSigmaType==TIMETOTAL_RUN) )
								{
									// Convert result into time deviation
									sModSigData.sigma[k]=
										(float)(sModSigData.sigma[k]*
										sModSigData.tau[k]/sqrt(3.0));
								}
							}
							else // THEO1_RUN (applies to phase data only)
							{
								// Find noise and alpha if first point
								if(k==0)
								{
									if(bAutoAlpha)
									{
										// NewTheo1() called during calc
										// It will determine bias and alpha at
										// first stability point and will apply
										// bias correction to each point
										// so nothing needs to be here
									}
									else
									{
										// Theo1() called during calc
										// Get user-entered alpha from screen
										nAlpha=3-
											ComboBox_GetCurSel(
											GETHCTL(IDC_RUN_ALPHA));

										// Calc Tho1 bias factor
										fTheo1BiasFactor=
											Theo1Bias(nAlpha, (float)0.75*nAF);
									}
								}

								// Store alpha for each stability point
								sNormSigData.alpha[k]=nAlpha;
							}
							
							// Restore data
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_RESTORE, NULL, 0));

							// Choosing AFs for all tau table
							// First AF=1
							// nNextAF initialized to 1
							// Choose next one that is equal or greater than
							// twice the previous one
							// Then store AF and data
							// We also want to include the last point - done below
							if(nAF>=nNextAF)
							{
								nNextAF*=2;

								// Store AF in all tau stability table
								sAllNormSigData.af[nAllTauRows]=sNormSigData.af[k];
								sAllModSigData.af[nAllTauRows]=sModSigData.af[k];

								// Store tau in all tau stability table
								sAllNormSigData.tau[nAllTauRows]=sNormSigData.tau[k];
								sAllModSigData.tau[nAllTauRows]=sModSigData.tau[k];

								// Store num in all tau stability table
								// num used as annotation flag if zero
								// otherwise it can be set to 1
								sAllNormSigData.num[nAllTauRows]=1;
								sAllModSigData.num[nAllTauRows]=1;

								// Store sigma in all tau stability table
								sAllNormSigData.sigma[nAllTauRows]=sNormSigData.sigma[k];
								sAllModSigData.sigma[nAllTauRows]=sModSigData.sigma[k];

								// Increment all tau rows count
								nAllTauRows++;
							}

							// Keep track of last AF
							nLastAF=nAF;

							// Keep track of last index
							nLastIndex=k;

						} // End of all tau loop


						// Store last results for all tau table
						// Store last AF
						sAllNormSigData.af[nAllTauRows]=sNormSigData.af[nLastIndex];
						sAllModSigData.af[nAllTauRows]=sModSigData.af[nLastIndex];

						// Store last tau
						sAllNormSigData.tau[nAllTauRows]=sNormSigData.tau[nLastIndex];
						sAllModSigData.tau[nAllTauRows]=sModSigData.tau[nLastIndex];

						// Store last sigma
						sAllNormSigData.sigma[nAllTauRows]=sNormSigData.sigma[nLastIndex];
						sAllModSigData.sigma[nAllTauRows]=sModSigData.sigma[nLastIndex];

						// Store rows in all tau stability table (+1 for last one)
						sAllNormSigData.rows=nAllTauRows+1;
						sAllModSigData.rows=nAllTauRows+1;

						// Store # points = # rows
						sAllNormSigData.points=nAllTauRows+1;
						sAllModSigData.points=nAllTauRows+1;

						sAllNormSigData.num[nLastIndex]=1;
						sAllModSigData.num[nLastIndex]=1;

						#if(0) // Check table contents
						strcpy(szBuffer, "");
						for(i=0; i<sAllNormSigData.points; i++)
						{
							sprintf(szFormat, "%d\t%e\n", sAllNormSigData.af[i], sAllNormSigData.sigma[i]);
							strcat(szBuffer, szFormat);
						}
						ShortenExp(szBuffer);
						TRACE_STR(szBuffer);
						#endif

						// Reset yield flag - all tau run is done
						bYield=FALSE;
						
						if(nSigmaType==FULL_RUN && bAutoAlpha)
						{
							// Note: Can arrive here either at end of the
							// all tau run, or because the run was interrupted
							// Don't want to apply bias correction
							// more than once.  But no way to know whether run
							// will be resumed or interrupted again.
							// So determine bias factor only the first time
							// we get here, and, if we get here again,
							// to apply it only to new points.  Thus we use
							// a bBias flag to indicate whether or not
							// the bias factor has been found and nLast
							// to hold the index of the last point
							// to which it has been applied.  bBias is
							// initialized to FALSE and nLast to 0
							// at start of run.
							
							#ifndef THEOH // Don't calc avg bias for ThoH
							// THEOH is usually defined, so we skip this
							// Determine average bias factor
							// of completed FULL_RUN
							// to match sigma and Tho1 deviations
							if(!bBias)
							{
								// Initializations
								nCount=0;
								fAvgBias=0.0;

								// Sum bias factors
								for(j=0; j<k; j++)
								{
									if(sNormSigData.sigma[j] &&
										sModSigData.sigma[j])
									{
										// Find the avg factor for sigma calc
										// at same tau as Tho1 value
										nAF=(int)((sModSigData.tau[j]/
											fTau)+0.5);

										// Calc sigma at the tau
										// of the Tho1 dev
										// The 3rd arg is the basic tau_0
										nDummy=
											CalcPhaseOverlapSigma(fPhaseData,
											&fSig, fTau, nAF);

										// Calc corresponding bias factor
										// equal ratio
										// of sigma to Tho1 dev at same tau
										fAvgBias+=((float)fSig/
											sModSigData.sigma[j]);

										// Increment count
										nCount++;
									}
								}

								// Calc average bias factor
								fAvgBias/=(float)nCount;

								// Square the avg bias value so it applies
								// to variances as is our usual convention
								fAvgBias*=fAvgBias;

								// Find alpha
								nAlpha=Theo1BiasToAlpha(fAvgBias, nAF);

								// Set bias found flag
								bBias=TRUE;
							}
							
							// Apply average bias to all new Tho1 points
							// and store alpha in results arrays
							for(j=nLast; j<k; j++)
							{
								if(sModSigData.sigma[j])
								{
									sModSigData.sigma[j]*=
										(float)sqrt(fAvgBias);
								}

								sNormSigData.alpha[j]=nAlpha;
								sModSigData.alpha[j]=nAlpha;
							}

							#else // Bias already removed for ThoBR

							// To avoid unused variable warning
							nCount=0;
							
							// Use ThoH bias factor
							fAvgBias=fTheo1BiasFactor;
							
							// Find alpha
							nAlpha=Theo1BiasToAlpha(fAvgBias, nAF);

							// Store alpha in new results arrays
							for(j=nLast; j<k; j++)
							{
								sNormSigData.alpha[j]=nAlpha;
								sModSigData.alpha[j]=nAlpha;
							}

							// Set bias found flag
							bBias=TRUE;
							#endif

							// Save nLast
							nLast=k;
							
							// Redisplay results (update Tho1 & alpha values)
							k--;
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_DISPLAY, NULL, 0));
							UpdateWindow(hSigTbl);
							k++;
						}

						// Clear progress display
						// Note: NULL instead of "" is NG
						WriteProgressMessage(0, "", FALSE); 

						// Display all tau run data (after run done)
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RUN_DISPLAY, NULL, 0));
					}

					// Check if run is done not aborted
					if(!bAbort)
					{
						// Clear stop flag that indicates
						// current run was stopped
						bStop=FALSE;

						// Change Resume button back to Calc
						SetWindowText(GETHCTL(IDC_RUN_RUN), "C&alc");

						// Change Clear button back to Close 
						SetWindowText(GETHCTL(IDCANCEL), "&Close");
					}

					if(!bAbort)
					{
						sNormSigData.points=k;         /* # stability points */
						sModSigData.points=k;          /* # stability points */
						nRows=k-1;                     /* ditto for printing */

						// Put info into log file
						strlcpy(szBuffer, "Type=", sizeof(szBuffer));
						GetWindowText(GETHCTL(IDC_RUN_TYPE),
							szFormat, BUFFER_SIZE);
						strlcat(szBuffer, szFormat, sizeof(szBuffer));
						strlcat(szBuffer, ", Stab File=", sizeof(szBuffer));

						if(bWriteSigmaFile)
						{
							strlcat(szBuffer, szStabFile, sizeof(szBuffer));
						}
						else // Writing of stability file inhibited
						{
							strlcat(szBuffer, "None", sizeof(szBuffer));
						}
						if(bDataType==FREQ_DATA)
						{
							WriteLog(48, szBuffer);
						}
						else // Phase data
						{
							WriteLog(47, szBuffer);
						}
								
						// Display drift
						LoadString(hInst, IDS_FORMAT_9, szFormat, BUFFER_SIZE);
						_snprintf(szBuffer, sizeof(szBuffer), szFormat,
							fDrift);
						ShortenExp(szBuffer);

						if(bRemoveDrift)
						{
							strlcpy(szBuffer, "Freq Drift Removed",
								sizeof(szBuffer));
						}

						// Theo1 bias displayed for THEO1_RUN & FULL_RUN
						// for Automatic and Auto/Match alpha
						if(nSigmaType==THEO1_RUN && bAutoAlpha)
						{
							_snprintf(szFormat, sizeof(szFormat),
								"\nTho1 Bias=%1.3e", fBias1);
							strlcat(szBuffer, szFormat, sizeof(szBuffer));
							ShortenExp(szBuffer);
						}
						else if(nSigmaType==FULL_RUN && bAutoAlpha)
						{
							#ifdef THEOH // For ThoH usage
							_snprintf(szFormat, sizeof(szFormat),
								"\nTho1 Bias=%1.3e", fTheo1BiasFactor);
							#else // Normal version
							_snprintf(szFormat, sizeof(szFormat),
								"\nTho1 Bias=%1.3e", fAvgBias);
							#endif
							strlcat(szBuffer, szFormat, sizeof(szBuffer));
							ShortenExp(szBuffer);
						}
						
						if(bShowDrift)
						{
							SetWindowText(GETHCTL(IDC_RUN_DRIFT), szBuffer);
						}

						// Set data valid flag
						bDataValid=TRUE;

						// Allowing copy is OK, especially with many tau
						// Note that min & max sigma columns will be 0's
						EnableWindow(GETHCTL(IDC_RUN_COPY), bDataValid);

						// Set print button state
						// Don't allow print in all tau case unless fast MTIE
						if(!bAllTau || nSigmaType==MTIE_RUN)
						{
							EnableWindow(GETHCTL(IDC_RUN_PRINT), bDataValid);
						}
					}

					// Restore data
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_RUN_RESTORE, NULL, 0));

					// Check for abort
					if(bAbort)
					{
						// Break out to avoid FP errors
						break;          
					}

					// Set plot-related buttons
					// Need at least 2 stability points to do plot
					if(k>1)
					{
						// Initialize sigma plot parameters
						InitSigmaPlotParams();

						// Calc sigma plot scale
						// Uses sigma-tau values in sModSigData or sNormSigData
						// (depending on nSigmaPlotType)
						// to fill in sigma plot scale limits
						// into sSPlot elements
						// x_min, x_max, y_min and y_max
						// Return value of # sigma plot points not used
						CalcSigmaPlotScale();

						// Activate plot-related buttons
						EnableWindow(GETHCTL(IDC_RUN_PLOT), TRUE);
						EnableWindow(GETHCTL(IDC_RUN_OPTIONS), TRUE);
						EnableWindow(GETHCTL(IDC_RUN_LINES), TRUE);
						EnableWindow(GETHCTL(IDC_RUN_NOTES), TRUE);
					}

					// Reenable controls
					EnableWindow(GETHCTL(IDC_RUN_RUN), TRUE);
					EnableWindow(GETHCTL(IDHELP), TRUE);
					EnableWindow(GETHCTL(IDC_RUN_TYPE), TRUE);
					EnableWindow(GETHCTL(IDC_RUN_CF), TRUE);
					EnableWindow(GETHCTL(IDC_RUN_REMOVE), TRUE);
					EnableWindow(GETHCTL(IDC_RUN_DECADE), TRUE);
					EnableWindow(GETHCTL(IDC_RUN_OCTAVE), TRUE);
					EnableWindow(GETHCTL(IDC_RUN_ALLTAU), TRUE);
					EnableWindow(GETHCTL(IDC_RUN_1OF2), TRUE);
					EnableWindow(GETHCTL(IDC_RUN_ALPHA), TRUE);

					// Restore close button label
					SetWindowText(GETHCTL(IDCANCEL), "&Close");

					if(bWriteSigmaFile)
					{
						// Write stability data file to disk
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RUN_WRITE, NULL, 0));
					}

					// Get end Windows time in msec
					nTock=GetTickCount();

					#if(0) // For testing
					// Display elapsed time
					TRACE_INT(nTock-nTick);
					#endif

					#if(1) // New code 08/25/08
					if(bTime)
					{

						// Perform run calc time estimate

						/*****************************************************************/
						/*                                                               */
						/*  Have model for each variance type (e.g., N * N).             */
						/*  Measure run calc time for each run.                          */
						/*  Update run calc time coefficient for every long run          */
						/*  using recursive averaging, where long run is defined as one  */
						/*  whose estimated time exceeds user-set limit.                 */
						/*  Store time limit and coeffs in [Run] section of ini file.    */
						/*  Calc point limit from time limit, model and coeff at start   */
						/*  of each run, offering to do averaging if limit exceeded.     */
						/*  This also has effect of updating point # limit for each      */
						/*  run - thus there is no need to store points limits.          */
						/*                                                               */
						/*  Things to store in [Run] section of ini file:                */
						/*  1.  Run calc time coefficients for each variance type        */
						/*  2.  Run calc time limit to offer averaging                   */
						/*      (A value of zero disables this feature)                  */
						/*                                                               */
						/****************************************************************/

						// New run calc time coeff is found by recursive averaging:
						// new avg = ( old avg * (N-1) + new val ) / N
						// where N = avg factor = TIME_AF = 5 (typically)
						switch(nSigmaType)
						{
							/*************************************************************/
							/*                   Linear (N) Terms                        */
							/*************************************************************/
							// Allan calc time est coeff
							case NORMAL_RUN:
							{
								// Calc new coefficient
								fNormalTime=(float)(((fNormalTime*(TIME_AF-1))+
									((((double)(nTock-nTick))/1000.)/((double)(nNum))))/TIME_AF);

								// Show new coefficient
								// TRACE_EXP(fNormalTime);

								// Save time coefficient
								_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fNormalTime);
								ShortenExp(szBuffer);
								WritePrivateProfileString("Run", "NormalTime", szBuffer, szIniFile);
										
								break;
							}
							
							// Overlapping Allan calc time est coeff
							case OVERLAPPING_RUN:
							{
								// Calc new coefficient
								fOverlappingTime=(float)(((fOverlappingTime*(TIME_AF-1))+
									((((double)(nTock-nTick))/1000.)/((double)(nNum))))/TIME_AF);

								// Show new coefficient
								// TRACE_EXP(fOverlappingTime);

								// Save time coefficient
								_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fOverlappingTime);
								ShortenExp(szBuffer);
								WritePrivateProfileString("Run", "OverlappingTime", szBuffer, szIniFile);
										
								break;
							}
							
							#if(1) // Trial code 02/16/10 for cross sigma testing
							// Cross overlapping Allan calc time est coeff
							case CROSS_RUN:
							{
								// Calc new coefficient
								fOverlappingTime=(float)(((fOverlappingTime*(TIME_AF-1))+
									((((double)(nTock-nTick))/1000.)/((double)(nNum))))/TIME_AF);

								// Show new coefficient
								// TRACE_EXP(fOverlappingTime);

								// Save time coefficient
								_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fOverlappingTime);
								ShortenExp(szBuffer);
								WritePrivateProfileString("Run", "OverlappingTime", szBuffer, szIniFile);
										
								break;
							}
							#endif
							
							// Modified Allan calc time est coeff
							case MODIFIED_RUN:
							{
								// Calc new coefficient
								fModifiedTime=(float)(((fModifiedTime*(TIME_AF-1))+
									((((double)(nTock-nTick))/1000.)/((double)(nNum))))/TIME_AF);

								// Show new coefficient
								// TRACE_EXP(fModifiedTime);

								// Save time coefficient
								_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fModifiedTime);
								ShortenExp(szBuffer);
								WritePrivateProfileString("Run", "ModifiedTime", szBuffer, szIniFile);

								break;
							}
							
							// Time calc time est coeff
							case TIME_RUN:
							{
								// Calc new coefficient
								fTimeTime=(float)(((fTimeTime*(TIME_AF-1))+
									((((double)(nTock-nTick))/1000.)/((double)(nNum))))/TIME_AF);

								// Show new coefficient
								// TRACE_EXP(fTimeTime);

								// Save time coefficient
								_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fTimeTime);
								ShortenExp(szBuffer);
								WritePrivateProfileString("Run", "TimeTime", szBuffer, szIniFile);
										
								break;
							}
							
							// Overlapping & Modified Allan calc time est coeff
							case BOTH_RUN:
							{
								// Calc new coefficient
								fBothTime=(float)(((fBothTime*(TIME_AF-1))+
									((((double)(nTock-nTick))/1000.)/((double)(nNum))))/TIME_AF);

								// Show new coefficient
								// TRACE_EXP(fBothTime);

								// Save time coefficient
								_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fBothTime);
								ShortenExp(szBuffer);
								WritePrivateProfileString("Run", "BothTime", szBuffer, szIniFile);
										
								break;
							}
							
							// Hadamard calc time est coeff
							case HADAMARD_RUN:
							{
								// Calc new coefficient
								fHadamardTime=(float)(((fHadamardTime*(TIME_AF-1))+
									((((double)(nTock-nTick))/1000.)/((double)(nNum))))/TIME_AF);

								// Show new coefficient
								// TRACE_EXP(fHadamardTime);

								// Save time coefficient
								_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fHadamardTime);
								ShortenExp(szBuffer);
								WritePrivateProfileString("Run", "HadamardTime", szBuffer, szIniFile);
										
								break;
							}
							
							// Overlapping Hadamard calc time est coeff
							case OVERLAPHAD_RUN:
							{
								// Calc new coefficient
								fOverlapHadTime=(float)(((fOverlapHadTime*(TIME_AF-1))+
									((((double)(nTock-nTick))/1000.)/((double)(nNum))))/TIME_AF);

								// Show new coefficient
								// TRACE_EXP(fNormalTime);

								// Save time coefficient
								_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fOverlapHadTime);
								ShortenExp(szBuffer);
								WritePrivateProfileString("Run", "OverlapHadTime", szBuffer, szIniFile);
										
								break;
							}
							
							// Total calc time est coeff
							case TOTAL_RUN:
							{
								// Calc new coefficient
								fTotalTime=(float)(((fTotalTime*(TIME_AF-1))+
									((((double)(nTock-nTick))/1000.)/((double)(nNum))))/TIME_AF);

								// Show new coefficient
								// TRACE_EXP(fOverlapHadTime);

								// Save time coefficient
								_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fTotalTime);
								ShortenExp(szBuffer);
								WritePrivateProfileString("Run", "TotalTime", szBuffer, szIniFile);
										
								break;
							}
							
							// TIE rms calc time est coeff
							case TIERMS_RUN:
							{
								// Calc new coefficient
								fTIErmsTime=(float)(((fTIErmsTime*(TIME_AF-1))+
									((((double)(nTock-nTick))/1000.)/((double)(nNum))))/TIME_AF);

								// Show new coefficient
								// TRACE_EXP(fTIErmsTime);

								// Save time coefficient
								_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fTIErmsTime);
								ShortenExp(szBuffer);
								WritePrivateProfileString("Run", "TIErmsTime", szBuffer, szIniFile);
										
								break;
							}
							
							/*************************************************************/
							/*                   Quadratic (N * N) Terms                 */
							/*************************************************************/
							
							// Modified Total calc time est coeff
							case MODTOTAL_RUN:
							{
								// Calc new coefficient
								fModTotalTime=(float)(((fModTotalTime*(TIME_AF-1))+
									((((double)(nTock-nTick)))/1000.)/((double)(nNum)*(double)(nNum)))/TIME_AF);

								// Show new coefficient
								// TRACE_EXP(fModTotalTime);

								// Save time coefficient
								_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fModTotalTime);
								ShortenExp(szBuffer);
								WritePrivateProfileString("Run", "ModTotalTime", szBuffer, szIniFile);
										
								break;
							}

							// Time Total calc time est coeff
							case TIMETOTAL_RUN:
							{
								// Calc new coefficient
								fTimeTotalTime=(float)(((fTimeTotalTime*(TIME_AF-1))+
									((((double)(nTock-nTick)))/1000.)/((double)(nNum)*(double)(nNum)))/TIME_AF);

								// Show new coefficient
								// TRACE_EXP(fTimeTotalTime);

								// Save time coefficient
								_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fTimeTotalTime);
								ShortenExp(szBuffer);
								WritePrivateProfileString("Run", "TimeTotalTime", szBuffer, szIniFile);
										
								break;
							}

							// Hadamard Total calc time est coeff
							case HADTOTAL_RUN:
							{
								// Calc new coefficient
								fHadTotalTime=(float)(((fHadTotalTime*(TIME_AF-1))+
									((((double)(nTock-nTick)))/1000.)/((double)(nNum)*(double)(nNum)))/TIME_AF);

								// Show new coefficient
								// TRACE_EXP(fHadTotalTime);

								// Save time coefficient
								_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fHadTotalTime);
								ShortenExp(szBuffer);
								WritePrivateProfileString("Run", "HadTotalTime", szBuffer, szIniFile);
										
								break;
							}

							// MTIE calc time est coeff
							case MTIE_RUN:
							{
								if(bAllTau) // "Fast" MTIE
								{
									// Calc new coefficient
									fMTIETime=(float)(((fMTIETime*(TIME_AF-1))+
										((((double)((nTock-nTick)*5)))/1000.)/((double)(nNum)*(double)(nNum)))/TIME_AF);
								}
								else
								{
									// Calc new coefficient
									fMTIETime=(float)(((fMTIETime*(TIME_AF-1))+
										((((double)(nTock-nTick)))/1000.)/((double)(nNum)*(double)(nNum)))/TIME_AF);
								}

								// Show new coefficient
								// TRACE_EXP(fMTIETime);

								// Save time coefficient
								_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fMTIETime);
								ShortenExp(szBuffer);
								WritePrivateProfileString("Run", "MTIETime", szBuffer, szIniFile);
										
								break;
							}

							/*************************************************************/
							/*               Linear & Log (N * log(N)) Terms             */
							/*************************************************************/
							
							// Tho1 calc time est coeff
							case THEO1_RUN:
							{
								// Don't adjust run calc time coeff if no bias calc done
								if(!bNoTheo1BiasCalc)
								{
									// Calc new coefficient
									fTheo1Time=(float)(((fTheo1Time*(TIME_AF-1))+
										((((double)(nTock-nTick))/1000.)/((double)(nNum)*log10(nNum))))/TIME_AF);

									// Show new avg coefficient
									// TRACE_EXP(fTheo1Time);

									// Save time coefficient
									_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fTheo1Time);
									ShortenExp(szBuffer);
									WritePrivateProfileString("Run", "Theo1Time", szBuffer, szIniFile);
								}
										
								break;
							}

							// ThoH calc time est coeff
							case FULL_RUN:
							{
								// Don't adjust run calc time coeff if no bias calc done
								if(!bNoTheo1BiasCalc)
								{
									// Calc new coefficient
									fFullTime=(float)(((fFullTime*(TIME_AF-1))+
										((((double)(nTock-nTick))/1000.)/((double)(nNum)*log10(nNum))))/TIME_AF);

									// Show new coefficient
									// TRACE_EXP(fFullTime);

									// Save time coefficient
									_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fFullTime);
									ShortenExp(szBuffer);
									WritePrivateProfileString("Run", "FullTime", szBuffer, szIniFile);
								}
										
								break;
							}

							#if(0) // Obsolete code - faster ModTotvarCalc() varies as N * N
							/*************************************************************/
							/*                   Cubic (N * N * N) Terms                 */
							/*************************************************************/
							
							// Modified Total calc time est coeff
							case MODTOTAL_RUN:
							{
								// Calc new coefficient
								fModTotalTime=(float)(((fModTotalTime*(TIME_AF-1))+
									(((double)(nTock-nTick))/1000.)/((double)(nNum)*(double)(nNum)*(double)(nNum)))/TIME_AF);

								// Show new coefficient
								// TRACE_EXP(fModTotalTime);

								// Save time coefficient
								_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fModTotalTime);
								ShortenExp(szBuffer);
								WritePrivateProfileString("Run", "ModTotalTime", szBuffer, szIniFile);
										
								break;
							}

							// Time Total calc time est coeff
							case TIMETOTAL_RUN:
							{
								// Calc new coefficient
								fTimeTotalTime=(float)(((fTimeTotalTime*(TIME_AF-1))+
									(((double)(nTock-nTick))/1000.)/((double)(nNum)*(double)(nNum)*(double)(nNum)))/TIME_AF);

								// Show new coefficient
								// TRACE_EXP(fTimeTotalTime);

								// Save time coefficient
								_snprintf(szBuffer, sizeof(szBuffer), "%10.5e", fTimeTotalTime);
								ShortenExp(szBuffer);
								WritePrivateProfileString("Run", "TimeTotalTime", szBuffer, szIniFile);
										
								break;
							}
							#endif
						}
					}
					#endif
					
					// Display normal cursor
					SetCursor(hArrow);

					// Write prompt message
					LoadString(hInst, IDS_MESSAGE_RUNDONE, szBuffer,
						BUFFER_SIZE);

					#if(1) // New code 08/28/08
					// Show run done message with run calc time
					if((int)(((nTock-nTick)/1000.)+0.5)<1)
					{
						_snprintf(szText, sizeof(szText), " (<1 sec)");
					}
					else // Calc time >0 sec
					{
						_snprintf(szText, sizeof(szText), " (%d sec)", (int)(((nTock-nTick)/1000.)+0.5));
					}
					strlcat(szBuffer, szText, sizeof(szBuffer));
					#endif
					WriteMessage(szBuffer);

					// Reset busy flag
					bBusy=FALSE;

					// Give focus to plot pushbutton
					SetFocus(GETHCTL(IDC_RUN_PLOT));

					// This code produces stability plot automatically
					// It is used only by the F9 function key run command
					// which sets this flag
					if(bAutoRunPlot)
					{
						// Automatically produce stability plot after run calc
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RUN_PLOT, NULL, 0));

						// Turn off auto run plot flag
						// Have to turn on this flag each time it is used
						bAutoRunPlot=FALSE;
					}
				}
				break;

				// Process phase data
				case IDC_RUN_PHASE:
				{
					// Make sure sigma types agree
					nSigmaPlotType=nSigmaType;

					if(nSigmaType==NORMAL_RUN)
					{
						// Calc phase sigma
						nDummy=CalcPhaseSigma(fPhaseData, &fSig,
							sNormSigData.tau[k]);

						// Record call in detailed log
						if(bDetailedLog && nAF==1)
						{
							WriteLog(68, "CalcPhaseSigma()");
						}

						// Error trap for bad calc
						if(nDummy<1)
						{
							// Display error message
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_ERROR, NULL, 0));
							break;
						}

						// Assign results
						sNormSigData.num[k]=(float)nDummy;
						sNormSigData.sigma[k]=(float)fSig;
					}

					if(nSigmaType==OVERLAPPING_RUN || nSigmaType==CROSS_RUN ||
						nSigmaType==BOTH_RUN || nSigmaType==FULL_RUN)
					{
						// Check for AF too big for overlap sigma calc
						if( (nSigmaType==FULL_RUN) && ((nNum0/nAF)<4) )
						{
							// Assign null results
							sNormSigData.num[k]=0.0;
							sNormSigData.sigma[k]=0.0;
						}
						else
						{
							// Note: The 3rd arg is the basic tau_0!
							if(nSigmaType==CROSS_RUN)
							{
								#if(0) // For testing
								TRACE_STR("CROSS");
								#endif
								
								// Phase data is in the first two tabs
								nDummy=CalcPhaseCrossSigma(sPTab[0].fData, sPTab[1].fData, &fSig,
									fTau, nAF, &nSign);

								// # sigma can have either sign, as indicated by nSign
								// Save it in sigmadata struct
								sNormSigData.sign[k]=nSign;

								// Zero the max and min sigma values
								sNormSigData.sig_max[k]=0.0;
								sNormSigData.sig_min[k]=0.0;
							}
							else // Normal calc
							{
								nDummy=CalcPhaseOverlapSigma(fPhaseData, &fSig,
									fTau, nAF);
							}

							// Record call in detailed log
							if(bDetailedLog && nAF==1)
							{
								WriteLog(68, "CalcPhaseOverlapSigma()");
							}

							// Error trap for bad calc
							if(nDummy<1)
							{
								// Display error message
								SendMessage(hDlg, WM_COMMAND,
									GET_WM_COMMAND_MPS(IDC_RUN_ERROR, NULL,
									0));
								break;
							}

							// Assign results
							sNormSigData.num[k]=(float)nDummy;
							sNormSigData.sigma[k]=(float)fSig;
						}
					}

					if(nSigmaType==MODIFIED_RUN || nSigmaType==TIME_RUN ||
						nSigmaType==BOTH_RUN)
					{
						// Calculate mod sigma using internal subroutine
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RUN_MODSIG, NULL, 0));

						// Assign results
						// Note: TDEV and TTOT scaling is done in main code
						sModSigData.num[k]=(float)nModSig;
						sModSigData.sigma[k]=(float)fModSig;
					}

					if(nSigmaType==TOTAL_RUN)
					{
						FillGaps(fPhaseData, PHASE_DATA);
								
						// Calc total variance
						sNormSigData.num[k]=(float)TotvarCalc(fPhaseData,
							&fSig, fTau, nAF, (void*)NULL);

						// Record call in detailed log
						if(bDetailedLog && nAF==1)
						{
							WriteLog(68, "TotvarCalc()");
						}

						// Trap memory allocation error
						if(sNormSigData.num[k]==-1)
						{
							// Display error message
							#ifdef MEM_DEBUG
							// Note: The TotvarCalc() function attempts to
							// allocate 3*(fPhaseData[2]-fPhaseData[1]+1)-4
							// doubles as its working memory, and returns -1
							// as an error code if if cannot
							AllocErrorMessageEx(__FILE__, __LINE__,
								(int)(3*(fPhaseData[2]-fPhaseData[1]+1)-4)*
								sizeof(double));
							#else
							AllocErrorMessage();
							#endif

							// Set abort flag
							bAbort=TRUE;

							// Close Run dialog box
							EndDialog(hDlg, 0);
							return TRUE;
						}
						else
						{
							// Error trap for bad calc
							if(sNormSigData.num[k]<1)
							{
								// Display error message
								SendMessage(hDlg, WM_COMMAND,
									GET_WM_COMMAND_MPS(IDC_RUN_ERROR, NULL,
									0));
								break;
							}

							// Assign result
							sNormSigData.sigma[k]=(float)fSig;
						}
					}

					if( (nSigmaType==MODTOTAL_RUN) ||
						(nSigmaType==TIMETOTAL_RUN) )
					{
						// Calc Mod Totvar with progress bar if not all tau
						sModSigData.num[k]=(float)ModTotvarCalc(fPhaseData,
							&fModSig, fTau, nAF, &bAbort, !bAllTau,
							(void*)WriteProgressMessage);

						// Record call in detailed log
						if(bDetailedLog && nAF==1)
						{
							WriteLog(68, "NewModTotvarCalc()");
						}

						// Trap memory allocation error
						if(sModSigData.num[k]==-1)
						{
							// Display error message
							#ifdef MEM_DEBUG
							// Note: The TotvarCalc() function attempts to
							// allocate 3*(fPhaseData[2]-fPhaseData[1]+1)-4
							// doubles as its working memory, and returns -1
							// as an error code if if cannot
							AllocErrorMessageEx(__FILE__, __LINE__,
								(int)(3*(fPhaseData[2]-fPhaseData[1]+1)-4)*
								sizeof(double));
							#else
							AllocErrorMessage();
							#endif

							// Set abort flag
							bAbort=TRUE;

							// Close Run dialog box
							EndDialog(hDlg, 0);
							return TRUE;
						}
						else
						{
							// Error trap for bad calc
							if(sModSigData.num[k]<1)
							{
								// Display error message
								SendMessage(hDlg, WM_COMMAND,
									GET_WM_COMMAND_MPS(IDC_RUN_ERROR, NULL,
									0));
								break;
							}

							// Assign result
							// Note: TTOT scaling is done in main code
							sModSigData.sigma[k]=(float)fModSig;
						}
					}

					if(nSigmaType==HADAMARD_RUN)
					{
						// Calc Hadamard deviation 
						sNormSigData.num[k]=(float)CalcHadamardDev(fPhaseData,
							&fSig, fTau*nAF);

						// Record call in detailed log
						if(bDetailedLog && nAF==1)
						{
							WriteLog(68, "CalcHadamardDev()");
						}

						// Error trap for bad calc
						if(sNormSigData.num[k]<1)
						{
							// Display error message
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_ERROR, NULL, 0));
							break;
						}

						// Assign result
						sNormSigData.sigma[k]=(float)fSig;
					}

					if(nSigmaType==OVERLAPHAD_RUN)
					{
						// Calc overlapping Hadamard deviation
						sNormSigData.num[k]=
							(float)CalcPhaseOverlapHadamardDev(fPhaseData,
							&fSig, fTau, nAF);

						// Record call in detailed log
						if(bDetailedLog && nAF==1)
						{
							WriteLog(68, "CalcPhaseOverlapHadamardDev()");
						}

						// Error trap for bad calc
						if(sNormSigData.num[k]<1)
						{
							// Display error message
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_ERROR, NULL, 0));
							break;
						}

						// Assign result
						sNormSigData.sigma[k]=(float)fSig;
					}

					if(nSigmaType==HADTOTAL_RUN)
					{
						if(nAF==1)
						{
							// Calc overlapping Hadamard deviation
							sNormSigData.num[k]=
								(float)CalcPhaseOverlapHadamardDev(fPhaseData,
								&fSig, fTau, nAF);
						}
						else // AF>1
						{
							// Calc total Hadamard deviation
							// Allocate memory for working freq data
							// converted from phase data for HTOT calc
							if((fWorkData=(F_TYPE*)malloc(
								(nNumm+ARRAY_OFFSET+1+EXTRA_MEM)*
								sizeof(F_TYPE)))==NULL)
							{
								// Display error message
								#ifdef MEM_DEBUG
								AllocErrorMessageEx(__FILE__, __LINE__,
									(nNumm+ARRAY_OFFSET+1+EXTRA_MEM)*
									sizeof(F_TYPE));
								#else
								AllocErrorMessage();
								#endif

								// Set abort flag
								bAbort=TRUE;
								
								// Close Run dialog box
								EndDialog(hDlg, 0);
								return TRUE;
							}

							// Convert phase data to freq data for HTOTV calc
							ConvPhaseToFreq(fPhaseData, fWorkData, fTau,
								FALSE);

							// Calc Hadamard Totvar
							sNormSigData.num[k]=(float)HadTotvarCalc(fWorkData, 
								&fSig, nAF, &bAbort, !bAllTau,
								(void*)WriteProgressMessage);

							// Free working data array
							free(fWorkData);
						}

						// Record call in detailed log
						if(bDetailedLog && nAF==1)
						{
							WriteLog(68, "CalcPhaseOverlapHadamardDev()");
						}

						// Record call in detailed log
						if(bDetailedLog && nAF==2)
						{
							WriteLog(68, "HadTotvarCalc()");
						}

						// Error trap for bad calc
						if(sNormSigData.num[k]<1)
						{
							// Display error message
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_ERROR, NULL, 0));
							break;
						}

						// Assign result
						sNormSigData.sigma[k]=(float)fSig;
					}

					if(nSigmaType==TIERMS_RUN)
					{
						// Calc rms time interval error
						sNormSigData.num[k]=(float)
							TIErms(fPhaseData, &fSig, nAF);

						// Record call in detailed log
						if(bDetailedLog && nAF==1)
						{
							WriteLog(68, "TIErms()");
						}

						// Error trap for bad calc
						if(sNormSigData.num[k]<1)
						{
							// Display error message
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_ERROR, NULL, 0));
							break;
						}

						// Assign result
						sNormSigData.sigma[k]=(float)fSig;
					}

					if(nSigmaType==MTIE_RUN)
					{
						// As precaution, fill gaps in working copy of
						// phase data.  CalcMTIE does not include any
						// gap checking.  Don't want a zero to affect
						// the max or min values processed.
						FillGaps(fPhaseData, PHASE_DATA);
							
						// Calc maximum time interval error
						sNormSigData.num[k]=(float)
							CalcMTIE(fPhaseData, &fSig, nAF, &bAbort, TRUE,
							(void*)WriteProgressMessage);
						
						// Record call in detailed log
						if(bDetailedLog && nAF==1)
						{
							WriteLog(68, "CalcMTIE()");
						}

						// Error trap for bad calc
						if(sNormSigData.num[k]<1)
						{
							// Display error message
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_ERROR, NULL, 0));
							break;
						}

						// Assign result
						sNormSigData.sigma[k]=(float)fSig;
					}
					
					if(nSigmaType==THEO1_RUN)
					{
						// Make sure AF is even
						if(nAF%2)
						{
							nAF++;
						}
					
						// Use NewTheo1() or TheoBR()
						// to calc Tho1 for auto noise id
						if(bAutoAlpha)
						{
							// Set calc bias flag
							// Need to calc bias only once (first time)
							if(k==0 && !bHaveTheo1Bias)
							{
								bCalcBias=TRUE;
							}
							else
							{
								bCalcBias=FALSE;
							}

							// Calc NewTho1 or ThoBR deviation
							#ifdef THEOH // For ThoBR usage
							// Make sure have enough data points for bias calc
							if(nNum0<19)
							{
								MessageBox(hDlg,
									"Not enough data points for bias calc",
									"Run", MB_ICONEXCLAMATION);
								break;
							}

							// Note: TheoBR() includes bias correction
							sNormSigData.num[k]=TheoBR(fPhaseData, &fSig, fTau,
								nAF, &fTheo1BiasFactor, &nTheo1Noise, &bAbort,
								!bAllTau, bCalcBias, bAutoAlpha,
								(void*)WriteProgressMessage);
							#else // Normal version
							// Note: NewTheo1() includes bias correction
							sNormSigData.num[k]=NewTheo1(fPhaseData, &fSig,
								fTau, nAF, &fTheo1BiasFactor, &nTheo1Noise,
								&bAbort, !bAllTau, bCalcBias,
								(void*)WriteProgressMessage);
							#endif

							// Set parameters
							if(k==0)
							{
								fBias1=fTheo1BiasFactor;
								nAF1=nAF;
								nAlpha=nTheo1Noise;
								bHaveTheo1Bias=TRUE;
							}
						}
						else // Manual noise selection
						{
							// Calc Tho1 deviation 
							sNormSigData.num[k]=Theo1(fPhaseData, &fSig, fTau,
								nAF, &bAbort, !bAllTau,
								(void*)WriteProgressMessage);

							// Calc Tho1 bias factor
							fTheo1Bias=Theo1Bias(nAlpha,
								(float)(0.75*nAF));

							// Apply bias factor
							fSig*=sqrt(fTheo1Bias);
						}

						// Scale the Tho1 tau value in norm sigma array
						sNormSigData.tau[k]*=(float)(0.75);

						// Record call in detailed log
						if(bDetailedLog && nAF>=THEO1_MIN && nAF<20)
						{
							WriteLog(68, "Tho1()");
						}

						// Error trap for bad calc
						if(sNormSigData.num[k]<1.0 && !bStop)
						{
							// Display error message
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_ERROR, NULL, 0));
							break;
						}

						// Assign result
						sNormSigData.sigma[k]=(float)fSig;
					}

					if(nSigmaType==FULL_RUN)
					{
						// Set flag to do Tho1 calc
						bDoCalc=TRUE;

						#ifdef THEOH // For ThoBR usage
						// Don't calc Tho1 for AF<20% of record length
						if(nAF<nNum0/5)
						{
							bDoCalc=FALSE;
						}
						#else // Normal version
						// Don't calc Tho1 for AF<9
						if(nAF<9)
						{
							bDoCalc=FALSE;
						}
						#endif

						// Make sure AF is even
						if(bDoCalc && nAF%2)
						{
							nAF++;
						}

						// Make sure AF isn't too big
						if(nAF>=nNum)
						{
							bDoCalc=FALSE;
						}
						
						if(bDoCalc)
						{
							// Calc bias only if necessary
							if(bHaveTheo1Bias==FALSE)
							{
								bCalcBias=TRUE;
							}

							// Calc Tho1 or ThoBR
							#ifdef THEOH // For ThoBR usage

							// Make sure have enough data points for bias calc
							if(nNum0<19)
							{
								MessageBox(hDlg,
									"Not enough data points for bias calc",
									"Run", MB_ICONEXCLAMATION);
								break;
							}

							// Calc ThoBR deviation
							sModSigData.num[k]=TheoBR(fPhaseData, &fSig, fTau,
								nAF, &fTheo1BiasFactor, &nTheo1Noise, &bAbort,
								!bAllTau, bCalcBias, bAutoAlpha,
								(void*)WriteProgressMessage);
							
							#else // Normal version
							// Calc Tho1 deviation 
							sModSigData.num[k]=Theo1(fPhaseData, &fSig, fTau,
								nAF, &bAbort, !bAllTau,
								(void*)WriteProgressMessage);
							#endif

							// Set parameters
							if(bHaveTheo1Bias==FALSE)
							{
								fBias1=fTheo1BiasFactor;
								nAF1=nAF;
								nAlpha=nTheo1Noise;
								if(bAutoAlpha)
								{
									bHaveTheo1Bias=TRUE;
								}
								bCalcBias=FALSE;
							}

							if(!bAutoAlpha)
							{
								#if(1)
								// Calc Tho1 deviation 
								sNormSigData.num[k]=Theo1(fPhaseData, &fSig, fTau,
									nAF, &bAbort, !bAllTau,
									(void*)WriteProgressMessage);
								#endif

								// Get noise type from screen
								nAlpha=3-
									ComboBox_GetCurSel(GETHCTL(IDC_RUN_ALPHA));

								// Set Tho1 bias factor
								// fTheo1Bias=Theo1Bias(nAlpha);
								fTheo1Bias=Theo1Bias(nAlpha,
									(float)(0.75*nAF));

								// Apply bias factor
								//fSig*=fTheo1Bias;
								fSig*=sqrt(fTheo1Bias); // 01/09/04
							}

							// Record call in detailed log
							if(bDetailedLog && nAF>=10 && nAF <20)
							{
								WriteLog(68, "Tho1()");
							}

							// Error trap for bad calc
							if(sModSigData.num[k]<1.0)
							{
								// Display error message
								SendMessage(hDlg, WM_COMMAND,
									GET_WM_COMMAND_MPS(IDC_RUN_ERROR, NULL,
									0));
								break;
							}

							// Assign result to mod sigma array
							sModSigData.sigma[k]=(float)fSig;

							// Scale the Tho1 tau value in mod sigma array
							sModSigData.tau[k]*=(float)(0.75);
						}
					}

					// Skip sigma & std dev calc for Tho1 (AF may be too big)
					// if(nSigmaType!=THEO1_RUN && nSigmaType!=FULL_RUN)
					if(nSigmaType!=THEO1_RUN)
					{
						// Calc fB1 to find noise type
						// Data is already averaged if normal or Hadamard sigma
						if(nSigmaType!=NORMAL_RUN && nSigmaType!=HADAMARD_RUN)
						{
							// Avg phase data
							AveragePhaseData(fPhaseData, nAF);
						}

						// Calc phase sigma
						CalcPhaseSigma(fPhaseData, &fSig, sNormSigData.tau[k]);

						// Check for zero sigma
						if(fSig==0.0)
						{
							// Display error message
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_ZEROSIG, NULL, 0));
							break;
						}
						
						// Calc standard deviation
						nNumb=CalcPhaseStdDev(fPhaseData, &fStdDev,
							 sNormSigData.tau[k]);
						
						// Assign std dev
						sNormSigData.std_dev[k]=(float)fStdDev;

						// Find B1 ratio
						fB1=(float)SQR(fStdDev/fSig); // B1 bias function

						#ifdef LOGGING
						_snprintf(szBuffer, sizeof(szBuffer), "fB1=%f", fB1);
						WriteLog(60, szBuffer);
						#endif

						// Restore data if it was averaged for B1 calc
						if(nSigmaType!=NORMAL_RUN && nSigmaType!=HADAMARD_RUN)
						{
							// Restore unaveraged data
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_RESTORE, NULL, 0));
						}
					}

					// Scale sigmas for 1 of 2 units
					if(b1of2)
					{
						sNormSigData.sigma[k]/=(float)SQRT2;
						sNormSigData.std_dev[k]/=(float)SQRT2;
						sModSigData.sigma[k]/=(float)SQRT2;
						sModSigData.std_dev[k]/=(float)SQRT2;
					}
				}
				break;

				// Process frequency data
				case IDC_RUN_FREQ:
				{
					// Make sure sigma types agree
					nSigmaPlotType=nSigmaType;

					if(nSigmaType==NORMAL_RUN)
					{
						// Calc freq sigma
						sNormSigData.num[k]=(float)CalcFreqSigma(fFreqData,
							&fSig);

						// Record call in detailed log
						if(bDetailedLog && nAF==1)
						{
							WriteLog(68, "CalcFreqSigma()");
						}

						// Error trap for bad calc
						if(sNormSigData.num[k]<1)
						{
							// Display error message
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_ERROR, NULL, 0));
							break;
						}

						// Assign result
						sNormSigData.sigma[k]=(float)fSig;
					}

					if(nSigmaType==OVERLAPPING_RUN || nSigmaType==BOTH_RUN )
					{
						// This code converts freq data to phase data
						// for faster calculation with large data sets
						// Note: If already have equivalent phase data, don't
						// need to alloc mem and do conversion.  Can just
						// use the existing phase data if bSynch flag is TRUE. 
						// In that case, need to assign fWorkData ptr to it

						if(!bSynch || bRemoveDrift) // Don't have phase data
						{
							// Need to convert freq data to phase data
							// Allocate memory for working phase data
							// converted from freq data for ADEV calc
							if((fWorkData=(F_TYPE*)malloc(
								(nNumm+ARRAY_OFFSET+1+EXTRA_MEM)*
								sizeof(F_TYPE)))==NULL)
							{
								// Display error message
								#ifdef MEM_DEBUG
								AllocErrorMessageEx(__FILE__, __LINE__,
									(nNumm+ARRAY_OFFSET+1+EXTRA_MEM)*
									sizeof(F_TYPE));
								#else
								AllocErrorMessage();
								#endif

								// Set abort flag
								bAbort=TRUE;

								// Close Run dialog box
								EndDialog(hDlg, 0);
								return TRUE;
							}

							// Convert freq data to phase data for sigma calc
							ConvFreqToPhase(fFreqData, fWorkData, fTau, FALSE);
						}
						else // Assign fWorkData pointer to phase data
						{
							fWorkData=fPhaseData;
						}

						// Calc overlapping sigma from fWorkData phase data
						// Note: The 3rd arg is the basic tau_0
						nDummy=CalcPhaseOverlapSigma(fWorkData, &fSig,
							fTau, nAF);

						// Record call in detailed log
						if(bDetailedLog && nAF==1)
						{
							WriteLog(68, "CalcPhaseOverlapSigma()");
						}

						// Error trap for bad calc
						if(nDummy<1)
						{
							// Display error message
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_ERROR, NULL, 0));

							// Free working array if didn't have phase data
							if(!bSynch || bRemoveDrift)
							{
								// Free working data array
								free(fWorkData);
							}
							break;
						}

						// Assign results
						sNormSigData.num[k]=(float)nDummy;
						sNormSigData.sigma[k]=(float)fSig;

						// Free working array if didn't have phase data
						if(!bSynch  || bRemoveDrift)
						{
							// Free working data array
							free(fWorkData);
						}
					}

					if(nSigmaType==MODIFIED_RUN || nSigmaType==BOTH_RUN ||
						nSigmaType==TIME_RUN)
					{
						// TRACE_STR("Calculate mod sigma using internal subroutine");
						
						// Calculate mod sigma using internal subroutine
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RUN_MODSIG, NULL, 0));

						// Assign results
						// Note: TDEV and TTOT scaling is done in main code
						sModSigData.num[k]=(float)nModSig;
						sModSigData.sigma[k]=(float)fModSig;
					}

					if(nSigmaType==TOTAL_RUN)
					{
						// Note: If already have equivalent phase data, don't
						// need to alloc mem and do conversion.  Can just
						// use the existing phase data if bSynch flag is TRUE. 

						if(bSynch && !bRemoveDrift) // Already have phase data
						{
							FillGaps(fPhaseData, PHASE_DATA);
								
							// Calc Totvar from existing data
							sNormSigData.num[k]=(float)TotvarCalc(fPhaseData,
								&fSig, fTau, nAF, (void*)NULL);

							// Record call in detailed log
							if(bDetailedLog && nAF==1)
							{
								WriteLog(68, "TotvarCalc()");
							}

							// Trap memory allocation error
							if(sNormSigData.num[k]==-1)
							{
								// Display error message
								#ifdef MEM_DEBUG
								// Note: The TotvarCalc() function attempts to
								// allocate 3*(fPhaseData[2]-fPhaseData[1]+1)-4
								// doubles as its working memory,
								// and returns -1as an error code if if cannot
								AllocErrorMessageEx(__FILE__, __LINE__,
									(int)(3*(fPhaseData[2]-fPhaseData[1]+1)-4)*
									sizeof(double));
								#else
								AllocErrorMessage();
								#endif

								// Set abort flag
								bAbort=TRUE;

								// Close Run dialog box
								EndDialog(hDlg, 0);
								return TRUE;
							}

							// Error trap for bad calc
							if(sNormSigData.num[k]<1)
							{
								// Display error message
								SendMessage(hDlg, WM_COMMAND,
									GET_WM_COMMAND_MPS(IDC_RUN_ERROR, NULL,
									0));
								break;
							}
						}
						else  // Need to convert freq data to phase data
						{
							// Allocate memory for working phase data
							// converted from freq data for TOTALDEV calc
							if((fWorkData=(F_TYPE*)malloc(
								(nNumm+ARRAY_OFFSET+1+EXTRA_MEM)*
								sizeof(F_TYPE)))==NULL)
							{
								// Display error message
								#ifdef MEM_DEBUG
								AllocErrorMessageEx(__FILE__, __LINE__,
									(nNumm+ARRAY_OFFSET+1+EXTRA_MEM)*
									sizeof(F_TYPE));
								#else
								AllocErrorMessage();
								#endif

								// Set abort flag
								bAbort=TRUE;

								// Close Run dialog box
								EndDialog(hDlg, 0);
								return TRUE;
							}

							// Convert freq data to phase data
							// for TOTALDEV calc
							ConvFreqToPhase(fFreqData, fWorkData, fTau, FALSE);

							FillGaps(fWorkData, PHASE_DATA);
								
							// Calc Totvar from converted data
							sNormSigData.num[k]=(float)TotvarCalc(fWorkData,
								&fSig, fTau, nAF, (void*)NULL);

							// Record call in detailed log
							if(bDetailedLog && nAF==1)
							{
								WriteLog(68, "TotvarCalc()");
							}

							// Trap memory allocation error
							if(sNormSigData.num[k]==-1)
							{
								// Display error message
								#ifdef MEM_DEBUG
								// Note: The TotvarCalc() function attempts to
								// allocate 3*(fPhaseData[2]-fPhaseData[1]+1)-4
								// doubles as its working memory,
								// and returns -1 as an error code if if cannot
								AllocErrorMessageEx(__FILE__, __LINE__,
									(int)(3*(fPhaseData[2]-fPhaseData[1]+1)-4)*
									sizeof(double));
								#else
								AllocErrorMessage();
								#endif

								// Set abort flag
								bAbort=TRUE;

								// Free working data array
								free(fWorkData);

								// Close Run dialog box
								EndDialog(hDlg, 0);
								return TRUE;
							}

							// Free working data array
							free(fWorkData);

							// Error Trap for bad calc
							if(sNormSigData.num[k]<1)
							{
								// Display error message
								SendMessage(hDlg, WM_COMMAND,
									GET_WM_COMMAND_MPS(IDC_RUN_ERROR, NULL,
									0));
								break;
							}
						}

						// Assign result
						sNormSigData.sigma[k]=(float)fSig;
					}

					if((nSigmaType==MODTOTAL_RUN)||(nSigmaType==TIMETOTAL_RUN))
					{
						// Note: If already have equivalent phase data, don't
						// need to alloc mem and do conversion.  Can just
						// use the existing phase data if bSynch flag is TRUE
						// and assign fWorkData pointer to it
						if(!bSynch || bRemoveDrift) // Don't have phase data
						{
							// Allocate memory for working phase data
							// converted from freq data for TOTALDEV calc
							if((fWorkData=(F_TYPE*)malloc(
								(nNumm+ARRAY_OFFSET+1+EXTRA_MEM)*
								sizeof(F_TYPE)))==NULL)
							{
								// Display error message
								#ifdef MEM_DEBUG
								AllocErrorMessageEx(__FILE__, __LINE__,
									(nNumm+ARRAY_OFFSET+1+EXTRA_MEM)*
									sizeof(F_TYPE));
								#else
								AllocErrorMessage();
								#endif

								// Set abort flag
								bAbort=TRUE;

								// Close Run dialog box
								EndDialog(hDlg, 0);
								return TRUE;
							}

							// Conv freq data to phase data for MOD TOTDEV calc
							ConvFreqToPhase(fFreqData, fWorkData, fTau, FALSE);
						}
						else // Already have synchronized phase data
						{
							// Assign working array pointer to phase data
							fWorkData=fPhaseData;
						}

						// Calc Mod Totvar from fWorkData phase data
						// with progress bar if not all tau
						sModSigData.num[k]=
							(float)ModTotvarCalc(fWorkData, &fModSig,
							fTau, nAF, &bAbort, !bAllTau,
							(void*)WriteProgressMessage);

						// Record call in detailed log
						if(bDetailedLog && nAF==1)
						{
							WriteLog(68, "NewModTotvarCalc()");
						}

						// Trap memory allocation error
						if(sModSigData.num[k]==-1)
						{
							// Display error message
							#ifdef MEM_DEBUG
							// Note: The TotvarCalc() function attempts to
							// allocate 3*(fPhaseData[2]-fPhaseData[1]+1)-4
							// doubles as its working memory, and returns -1
							// as an error code if if cannot
							AllocErrorMessageEx(__FILE__, __LINE__,
								(int)(3*(fPhaseData[2]-fPhaseData[1]+1)-4)*
								sizeof(double));
							#else
							AllocErrorMessage();
							#endif

							// Set abort flag
							bAbort=TRUE;

							// Didn't have phase data
							if(!bSynch || bRemoveDrift) 
							{
								// Free working data array
								free(fWorkData);
							}

							// Close Run dialog box
							EndDialog(hDlg, 0);
							return TRUE;
						}

						// Didn't have phase data
						if(!bSynch || bRemoveDrift) 
						{
							// Free working data array
							free(fWorkData);
						}

						// Error trap for bad calc
						if(sModSigData.num[k]<1)
						{
							// Display error message
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_ERROR, NULL, 0));
							break;
						}

						// Assign result
						sModSigData.sigma[k]=(float)fModSig;
					}

					if(nSigmaType==HADAMARD_RUN)
					{
						// Calc Hadamard deviation
						sNormSigData.num[k]=
							(float)CalcFreqHadamardDev(fFreqData, &fSig);

						// Record call in detailed log
						if(bDetailedLog && nAF==1)
						{
							WriteLog(68, "CalcFreqHadamardDev()");
						}

						// Error trap for bad calc
						if(sNormSigData.num[k]<1)
						{
							// Display error message
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_ERROR, NULL, 0));
							break;
						}

						// Assign result
						sNormSigData.sigma[k]=(float)fSig;

						// Check for zero sigma
						if(fSig==0.0)
						{
							// Display error message
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_ERROR, NULL, 0));
							break;
						}
					}

					if(nSigmaType==HADTOTAL_RUN)
					{
						// Use overlapping HDEV for nF=1
						if(nAF==1)
						{
							// Calc overlapping Hadamard deviation
							sNormSigData.num[k]=
								(float)CalcFreqOverlapHadamardDev(fFreqData,
								&fSig, nAF);
						}
						else // AF>1
						{
							// Calc Hadamard Totdev
							sNormSigData.num[k]=(float)HadTotvarCalc(fFreqData, 
								&fSig, nAF, &bAbort, !bAllTau,
								(void*)WriteProgressMessage);
						}

						// Record call in detailed log
						if(bDetailedLog && nAF==1)
						{
							WriteLog(68, "CalcFreqOverlapHadamardDev()");
						}

						// Record call in detailed log
						if(bDetailedLog && nAF==2)
						{
							WriteLog(68, "HadTotvarCalc()");
						}

						// Error trap for bad calc
						if(sNormSigData.num[k]<1)
						{
							// Display error message
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_ERROR, NULL, 0));
							break;
						}

						// Assign result
						sNormSigData.sigma[k]=(float)fSig;

						// Check for zero sigma
						if(fSig==0.0)
						{
							// Display error message
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_ERROR, NULL, 0));
							break;
						}
					}

					if(nSigmaType==OVERLAPHAD_RUN)
					{
						// Calc overlapping Hadamard deviation from phase data
						// because it is faster than doing so from freq data
						// Note: If already have equivalent phase data, don't
						// need to alloc mem and do conversion.  Can just
						// use the existing phase data if bSynch flag is TRUE
						// and assign fWorkData pointer to it
						if(!bSynch || bRemoveDrift) // Don't have phase data
						{
							// Allocate memory for working phase data
							// converted from freq data for HDEV calc
							if((fWorkData=(F_TYPE*)malloc(
								(nNumm+ARRAY_OFFSET+1+EXTRA_MEM)*
								sizeof(F_TYPE)))==NULL)
							{
								// Display error message
								#ifdef MEM_DEBUG
								AllocErrorMessageEx(__FILE__, __LINE__,
									(nNumm+ARRAY_OFFSET+1+EXTRA_MEM)*
									sizeof(F_TYPE));
								#else
								AllocErrorMessage();
								#endif

								// Set abort flag
								bAbort=TRUE;

								// Close Run dialog box
								EndDialog(hDlg, 0);
								return TRUE;
							}

							// Conv freq data to phase data for HDEV calc
							ConvFreqToPhase(fFreqData, fWorkData, fTau, FALSE);
						}
						else // Already have synchronized phase data
						{
							// Assign working array pointer to phase data
							fWorkData=fPhaseData;
						}

						// Calc overlapping Hadamard deviation from phase data
						// in working array
						sNormSigData.num[k]=
							(float)CalcPhaseOverlapHadamardDev(fWorkData,
							&fSig, fTau, nAF);

						// Record call in detailed log
						if(bDetailedLog && nAF==1)
						{
							WriteLog(68, "CalcPhaseOverlapHadamardDev()");
						}

						if(!bSynch || bRemoveDrift) // Didn't have phase data
						{
							// Free working data array
							free(fWorkData);
						}

						// Error trap for bad calc
						if(sNormSigData.num[k]<1)
						{
							// Display error message
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_ERROR, NULL, 0));
							break;
						}

						// Assign result
						sNormSigData.sigma[k]=(float)fSig;

						// Check for zero sigma
						if(fSig==0.0)
						{
							// Display error message
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_ERROR, NULL, 0));
							break;
						}
					}

					// Calc fB1 to find noise type
					// Data already averaged if normal or Hadamard sigma calc 
					if(nSigmaType!=NORMAL_RUN && nSigmaType!=HADAMARD_RUN)
					{
						// Average freq data
						AverageFreqData(fFreqData, nAF); // Avg by m
					}

					// Calc sigma
					CalcFreqSigma(fFreqData, &fSig);

					// Check for zero sigma
					if(fSig==0.0)
					{
						// Display error message
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RUN_ERROR, NULL, 0));
						break;
					}

					// Calc std dev
					nNumb=CalcFreqStdDev(fFreqData, &fStdDev);
					sNormSigData.std_dev[k]=(float)fStdDev;

					// Calc B1 bias function
					fB1=(float)SQR(fStdDev/fSig);

					// Restore data if averaged for B1 calc
					if(nSigmaType!=NORMAL_RUN && nSigmaType!=HADAMARD_RUN)
					{
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RUN_RESTORE, NULL, 0));
					}

					// Scale sigmas for 1 of 2 units
					if(b1of2)
					{
						sNormSigData.sigma[k]/=(float)SQRT2;
						sNormSigData.std_dev[k]/=(float)SQRT2;
						sModSigData.sigma[k]/=(float)SQRT2;
						sModSigData.std_dev[k]/=(float)SQRT2;
					}
				}
				break;

				// Find noise type
				case IDC_RUN_NOISE:
				{
					// Use manually-entered alpha if not automatic
					if(!bAutoAlpha)
					{
						// Get & use noise type from screen
						nAlpha=3-
							ComboBox_GetCurSel(GETHCTL(IDC_RUN_ALPHA));
						sNormSigData.alpha[k]=nAlpha;
						sModSigData.alpha[k]=nAlpha;

						#if(WRITEALPHA)
						sNormSigData.falpha[k]=(float)nAlpha;
						sModSigData.falpha[k]=(float)nAlpha;
						#endif

						break;
					}

					if(nNum/nAF>=ACFNUM) // Enough ACF points?
					{
						// Find noise type using lag 1 autocorrelation

						// Set dmax for lag 1 ACF noise ID
						// (Allan=2, Hadamard=3)
						nDmax=2;
						if( (nSigmaType==HADAMARD_RUN ||
							 nSigmaType==OVERLAPHAD_RUN ||
							 nSigmaType==HADTOTAL_RUN) )
						{
							nDmax=3;
						}

						// Call ACF noise ID function
						if(nSigmaType==NORMAL_RUN || nSigmaType==HADAMARD_RUN)
						{
							// Data already averaged
							nDummy=ACFNoiseID(fData, bDataType, 1, &fR1,
								&fAlpha, &nAlpha, nDmax, 0);
						}
						else
						{
							nDummy=ACFNoiseID(fData, bDataType, nAF, &fR1,
								&fAlpha, &nAlpha, nDmax, 0);
						}

						#if(WRITEALPHA)
						sNormSigData.falpha[k]=fAlpha;
						sModSigData.falpha[k]=fAlpha;
						#endif

						if(k==0)
						{
							fAlpha1=fAlpha;
							nAF1=nAF;
						}

						// Simple log message
						#ifdef LOGGING
						_snprintf(szBuffer, sizeof(szBuffer),
							"Called ACFNoiseID()");
						WriteLog(60, szBuffer);
						_snprintf(szBuffer, sizeof(szBuffer), "Alpha=%+1.2f",
							fAlpha);
						WriteLog(60, szBuffer);
						#endif

						// General trap for low alpha
						if(nAlpha<-4)
						{
							nAlpha=-4; // RR FM
						}

						// General trap for high alpha
						if(nAlpha>2)
						{
							nAlpha=2; // W PM
						}
						
						// Trap alpha < -2 if not a Hadamard variance
						if( !(nSigmaType==HADAMARD_SIGMA ||
							 nSigmaType==OVERLAPHAD_SIGMA ||
							 nSigmaType==HADTOTAL_SIGMA) && (nAlpha<-2) )
						{
							// Force alpha to -2
							nAlpha=-2;
						}
					}
					else // Original B1 method
					{
						// Find noise type using B1 ratio
						// It doesn't seem good to attempt to ID noise 
						// for the last couple of averaging factors
						// Not enough data for good results
						// so do this only for nNum/m>2*nStopRatio

						// Check bAutoAlpha state
						// Don't calc noise type if not automatic - use user's
						// selection
						if(!bAutoAlpha)
						{
							sNormSigData.alpha[k]=nAlpha;
							sModSigData.alpha[k]=nAlpha;

							#if(WRITEALPHA)
							sNormSigData.falpha[k]=(float)nAlpha;
							sModSigData.falpha[k]=(float)nAlpha;
							#endif

							break;
						}

						// Use same # points for bias calc
						// as displayed in table
						// Note: the nornal sigma num is not valid here for
						// mod & time sigma cases
						// The 2nd arg is mu
						if( (nSigmaType!=MODIFIED_RUN) &&
							(nSigmaType!=TIME_RUN) &&
							(nSigmaType!=MODTOTAL_RUN) &&
							(nSigmaType!=TIMETOTAL_RUN) )
						{
							fB_fwfm=CalcBias((int)sNormSigData.num[k], 2);
							fB_rwfm=CalcBias((int)sNormSigData.num[k], 1);
							fB_ffm =CalcBias((int)sNormSigData.num[k], 0);
							fB_wfm =CalcBias((int)sNormSigData.num[k],-1);
							fB_pm  =CalcBias((int)sNormSigData.num[k],-2);
						}
						else
						{
							fB_fwfm=CalcBias((int)sModSigData.num[k], 2);
							fB_rwfm=CalcBias((int)sModSigData.num[k], 1);
							fB_ffm =CalcBias((int)sModSigData.num[k], 0);
							fB_wfm =CalcBias((int)sModSigData.num[k],-1);
							fB_pm  =CalcBias((int)sModSigData.num[k],-2);
						}
						
						#ifdef LOGGING
						_snprintf(szBuffer, sizeof(szBuffer),
							"CalcBias() results: fB_fwfm=%f, fB_rwfm=%f, "
							"fB_ffm=%f, fB_wfm=%f, fB_pm=%f",
							fB_fwfm, fB_rwfm, fB_ffm, fB_wfm, fB_pm);
						WriteLog(60, szBuffer);
						#endif
						
						// Note: The B1 ratio is used to ID the
						// noise type for mod and time sigmas and then R(n)
						// is used if needed to resolve alpha=1 or 2 ambiuguity

						if(fB1>((fB_fwfm+fB_rwfm)/2))
						{
							nAlpha=-3; // Flicker walk FM
							fKn=0.75; // Unknown: use Kn for alpha=-2
						}
						else if(fB1>sqrt(fB_rwfm*fB_ffm))
						{
							nAlpha=-2; // Random walk FM 
							fKn=0.75;
						}
						else if(fB1>sqrt(fB_ffm*fB_wfm))
						{
							nAlpha=-1; // Flicker FM 
							fKn=(float)0.77;
						}
						else if(fB1>sqrt(fB_wfm*fB_pm))
						{
							nAlpha=0; // White FM 
							fKn=(float)0.87;
						}
						else
						{
							nAlpha=+1; // Flicker PM or +2 for white PM
							fKn=(float)0.99; // same for alpha=2
						}

						#ifdef LOGGING
						_snprintf(szBuffer, sizeof(szBuffer), "nAlpha=%d",
							nAlpha);
						WriteLog(60, szBuffer);
						#endif

						// Squelch the alpha=-3 code of an auto alpha run
						//if(!bAutoAlpha) // This test was wrong until 8/3/03
						if(bAutoAlpha)
						{
							// Check for alpha<-2 with non-Hadamard sigma type
							// An Allan variance shouldn't be used for alpha<-2
							// Hadamard variance is OK thru alpha=-4
							// This possibility could be avoided by changing
							// code above so it doesn't return alpha<-2
							// Could show alpha as -3 but use -2 for OK CI calc
							// Or we could just silently change alpha to -2
							// But better to display a warning message
							// This warning doesn't apply
							// to TIE rms or MTIE either
							if( !(nSigmaType==HADAMARD_RUN ||
								 nSigmaType==OVERLAPHAD_RUN ||
								 nSigmaType==HADTOTAL_RUN ||
								 nSigmaType==TIERMS_RUN ||
								 nSigmaType==MTIE_RUN ||
								 nSigmaType==FULL_RUN) && (nAlpha<-2) )
							{
								// Show warning message if detailed dialog box
								strlcpy(szBuffer,"Warning: Alpha<-2 detected. "
									"Use a Hadamard variance.",
									sizeof(szBuffer));
								bShowDrift=FALSE;
								SetWindowText(GETHCTL(IDC_RUN_DRIFT),
									szBuffer);
								
								// Force alpha to -2
								nAlpha=-2;
							}
						}

						// Code to handle alpha=1 or 2 ambiguity
						// This noise regognition processing applies
						// to most sigma types and m>1
						// Use data averaging that is not restored yet
						if(nAlpha==1 && !(nSigmaType==NORMAL_RUN ||
							nSigmaType==HADAMARD_RUN ||
							nSigmaType==TIERMS_RUN ||
							nSigmaType==MTIE_RUN ) && nAF>1)
						{
							// Does mod sigma need to be calculated?
							if(!(nSigmaType==MODIFIED_RUN ||
							   nSigmaType==TIME_RUN ||
							   nSigmaType==MODTOTAL_RUN ||
							   nSigmaType==TIMETOTAL_RUN))
							{
								// Calc mod sigma using internal subroutine
								SendMessage(hDlg, WM_COMMAND,
									GET_WM_COMMAND_MPS(IDC_RUN_MODSIG,
									NULL, 0));
							}

							// Calc R(n)
							fR=(float)SQR(fModSig/fSig);

							#ifdef LOGGING
							_snprintf(szBuffer, sizeof(szBuffer), "fR=%f", fR);
							WriteLog(60, szBuffer);
							#endif

							// Calc boundary ratios - use BW factor=10
							fR_fpm=CalcRatio(1, nAF, 10);
							fR_wpm=CalcRatio(2, nAF, 10);

							// ID noise type
							if(fR<sqrt(fR_fpm*fR_wpm))
							{
								nAlpha=2; // W PM
							}
						}

						// Code to handle alpha=3 or -4 for Hadamard sigmas
						// Note 1: Doesn't apply to last AF
						// Note 2: Could use nAlpha<=-2 to use more widely
						// and include additional *B1 test below
						// Note 3: Don't use index i for local loops, etc.
						// It is used in the main run loop
						// Note 4: Since we are doing old-fashioned averaging
						// in code below, must use working array in all cases
						if(nAlpha<=-2 && (nSigmaType==HADAMARD_RUN ||
						   nSigmaType==OVERLAPHAD_RUN ||
						   nSigmaType==HADTOTAL_RUN))
						{
							// Use Chuck Greenhall's idea to calculate the
							// B1 ratio for the freq data as phase data,
							// and use the standard noise ID method
							// except for adding 2 to the resulting alpha.
							// We will call this ratio *B1
							// See D. Howe, et al PTTI 2000 paper
							// For phase data, convert it to freq data
							// in allocated fTestData array.  For freq data,
							// just copy freq data to freq data array.

							// Allocate memory for working freq data
							if((fTestData=(F_TYPE*)malloc(
								(nNumm+ARRAY_OFFSET+EXTRA_MEM)*
								sizeof(F_TYPE)))==NULL)
							{
								// Display error message
								#ifdef MEM_DEBUG
								AllocErrorMessageEx(__FILE__, __LINE__,
									(nNumm+ARRAY_OFFSET-1+EXTRA_MEM)*
									sizeof(F_TYPE));
								#else
								AllocErrorMessage();
								#endif

								// Set abort flag
								bAbort=TRUE;

								// Close Run dialog box
								EndDialog(hDlg, 0);
								return TRUE;
							}

							if(bDataType==PHASE_DATA)
							{
								// Conv phase data to freq data for B1 calc
								// The original phase data is in fTempData
								ConvPhaseToFreq(fTempData, fTestData, fTau,
									FALSE);
							}
							else // Freq data - no conversion needed
							{
								// Copy freq data to test data array
								// The original freq data is in fTempData
								for (j=0; j<nNumm+ARRAY_OFFSET-1; j++)
								{
									fTestData[j]=fTempData[j];
								}
							}
							
							// Calc *B1 = ratio of standard to Allan variance
							// Treating freq data as phase data
							// The freq data is in fTestData array
							// First we need to average it to the current AF
							AverageFreqData(fTestData, nAF);

							// Then calc its sigma and std dev
							// as if it were phase data
							CalcPhaseSigma(fTestData, &fSig, fTau);
							CalcPhaseStdDev(fTestData, &fStdDev, fTau);

							// And find the *B1 ratio
							fB1=(float)SQR(fStdDev/fSig);

							// Determine noise type
							// Already have nominal B1 ratios
							// B1 for fwfm freq data processed as phase data
							// has alpha=-2. mu=2 which is really alpha=-4
							// B1 for rwfm freq data processed as phase data
							// has alpha=-1, mu=1 which is really alpha=-3
							if(fB1>sqrt(fB_rwfm*fB_ffm))
							{
								nAlpha=-4; // Random Run FM
							}
							else if(fB1>sqrt(fB_ffm*fB_wfm))
							{
								nAlpha=-3; // Flicker Walk FM 
							}
							// Otherwise, stay with original alpha

							// Clean up
							// Free test array
							free(fTestData);
						}
					}

					// Assign results
					sNormSigData.alpha[k]=nAlpha;
					sModSigData.alpha[k]=nAlpha;
				}
				break;

				// Calculate errorbar limits
				case IDC_RUN_ERRORBAR:
				{
					// Avoid sqrt domain error
					if( (nSigmaType!=TOTAL_RUN) &&
						(nSigmaType!=MODTOTAL_RUN) &&
						(nSigmaType!=TIMETOTAL_RUN) &&
						(nSigmaType!=THEO1_RUN) &&
						(nSigmaType!=FULL_RUN) &&(nNumb<1) )
					{
						break;
					}
					
					// Set p limits
					fLow=(1-fConfFactor)/2;
					fHigh=1-fLow;

					// Calc overlapping sigma error bars
					if(nSigmaType==OVERLAPPING_RUN || nSigmaType==BOTH_RUN )
					{
						#ifdef NEWEDF // New code 07/14/03
						fDF=CombinedEDF(nNum0+bDataType, nAF, nAlpha, 2, nAF,
							nAF, 1);
						#else
						fDF=CalcDegFree(nAlpha, nNum0, nAF);
						#endif

						if(fDF<=0) // Trap error for nAlpha=-3 
						{
							fDF=1.0;
						}

						// Calc upper & lower chi squared values
						fChiHigh=CalcInvChiSqr(fHigh, fDF);
						fChiLow=CalcInvChiSqr(fLow, fDF);

						// Calc max sigma error bar
						sNormSigData.sig_max[k]=(float)
							(sNormSigData.sigma[k]*sqrt(fDF/fChiHigh));

						// Make sure low limit is OK (may be NG for small CF)
						if(sqrt(fDF/fChiLow>=1.0))
						{
							sNormSigData.sig_min[k]=(float)
								(sNormSigData.sigma[k]/sqrt(fDF/fChiHigh));
						}
						else // Calc min sigma error bar
						{
							sNormSigData.sig_min[k]=(float)
								(sNormSigData.sigma[k]*sqrt(fDF/fChiLow));
						}
					}

					// Calc overlapping Hadamard error bars
					if(nSigmaType==OVERLAPHAD_RUN)
					{
						// Calc Hadamard edf
						#ifdef NEWEDF
						fDF=CombinedEDF(nNum0+bDataType, nAF, nAlpha, 3, nAF,
							nAF, 1);
						#else
						// Use for alpha=0 to -4, beta=-2 to -6 
						if(nAlpha<1)
						{
							// Args = # phase data pts, avg factor & beta
							fDF=HadamardEDF(nNum0+bDataType, nAF, nAlpha-2);
						}
						else // F PM or W PM (alpha 1 or 2)
						{
							// Calc df
							// 2nd arg = # non-gap phase points
							fDF=CalcDegFree(nAlpha, nNum0+bDataType, nAF);
						}
						#endif

						// Calc upper & lower chi squared values
						fChiHigh=CalcInvChiSqr(fHigh, fDF);
						fChiLow=CalcInvChiSqr(fLow, fDF);

						// Calc max sigma error bar
						sNormSigData.sig_max[k]=(float)
						(	sNormSigData.sigma[k]*sqrt(fDF/fChiHigh));

						// Make sure low limit is OK (may be NG for small CF)
						if(sqrt(fDF/fChiLow>=1.0))
						{
							sNormSigData.sig_min[k]=(float)
								(sNormSigData.sigma[k]/sqrt(fDF/fChiHigh));
						}
						else // Min sigma error bar
						{
							sNormSigData.sig_min[k]=(float)
								(sNormSigData.sigma[k]*sqrt(fDF/fChiLow));
						}
					}

					// Calc totvar error bars
					if(nSigmaType==TOTAL_RUN)
					{
						// Calc Totvar edf
						// Applies for alpha 0 to -2
						// Returns -1 for alpha +1 & +2
						fDF=TotvarEDF(nAlpha, (float)nNum0/(float)nAF);

						// Calc df for cases where alpha is >0
						// Where TotvarEDF has returned -1 error code
						if(fDF<0)
						{
							fDF=CalcDegFree(nAlpha, nNum0, nAF);

							if(fDF<=0) // Trap error for nAlpha=-3
							{
								fDF=1.0;
							}

							// Increment df for TOTVAR case
							if(nSigmaType==TOTAL_RUN)
							{
								fDF+=2.0;
							}
						}

						// Calc upper & lower chi squared values
						fChiHigh=CalcInvChiSqr(fHigh, fDF);
						fChiLow=CalcInvChiSqr(fLow, fDF);

						// Calc max sigma error bar
						sNormSigData.sig_max[k]=(float)
							(sNormSigData.sigma[k]*sqrt(fDF/fChiHigh));

						// Make sure low limit is OK (may be NG for small CF)
						if(sqrt(fDF/fChiLow>=1.0))
						{
							sNormSigData.sig_min[k]=(float)
								(sNormSigData.sigma[k]/sqrt(fDF/fChiHigh));
						}
						else // Min sigma error bar
						{
							sNormSigData.sig_min[k]=(float)
								(sNormSigData.sigma[k]*sqrt(fDF/fChiLow));
						}
					}

					// Calc mod totvar error bars
					if((nSigmaType==MODTOTAL_RUN)||(nSigmaType==TIMETOTAL_RUN))
					{
						// Calc ModTotvar edf
						// nNum0 is # non-gap tau=tau0 data points
						// Adding bDataType makes it = N = # phase data points
						// nAf is averaging factor m
						// 2nd arg is nRatio = N/m = T/tau
						// where T is recond length
						// Applies for alpha -2 to +2 and m>8
						// Returns -1 (error) for nRatio < 3

						// Guard against alpha<-2
						if(nAlpha<-2)
						{
							nAlpha=-2;
						}

						// Calc MTOT edf
						fDF=ModTotvarEDF(nAlpha, (float)(nNum0)/(float)nAF);

						// Alternative edf calc
						if(nAF<=8)
						{
							// Use HVAR edf function with adjusted args to calc
							// MVAR edf per C. Greenhall suggestion
							// Args = # phase data pts+1, avg factor & beta-2
							fDF=HadamardEDF(nNum0+bDataType+1, nAF, nAlpha-4);
						}

						// Calc upper & lower chi squared values
						fChiHigh=CalcInvChiSqr(fHigh, fDF);
						fChiLow=CalcInvChiSqr(fLow, fDF);

						// Calc max sigma error bar
						sModSigData.sig_max[k]=(float)
							(sModSigData.sigma[k]*sqrt(fDF/fChiHigh));

						// Make sure low limit is OK (may not be for small CF)
						if(sqrt(fDF/fChiLow>=1.0))
						{
							sModSigData.sig_min[k]=(float)
								(sModSigData.sigma[k]/sqrt(fDF/fChiHigh));
						}
						else // Min sigma error bar
						{
							sModSigData.sig_min[k]=(float)
								(sModSigData.sigma[k]*sqrt(fDF/fChiLow));
						}
					}

					if(nSigmaType==NORMAL_RUN)
					{
						#ifdef NEWEDF
						fDF=CombinedEDF(nNum0+bDataType, nAF, nAlpha, 2, nAF,
							1, 1);

						// Calc upper & lower chi squared values
						fChiHigh=CalcInvChiSqr(fHigh, fDF);
						fChiLow=CalcInvChiSqr(fLow, fDF);

						// Calc max sigma error bar
						sNormSigData.sig_max[k]=(float)
							(sNormSigData.sigma[k]*sqrt(fDF/fChiHigh));

						// Make sure low limit is OK (may not be for small CF)
						if(sqrt(fDF/fChiLow>=1.0))
						{
							sNormSigData.sig_min[k]=(float)
								(sNormSigData.sigma[k]/sqrt(fDF/fChiHigh));
						}
						else // Min sigma error bar
						{
							sNormSigData.sig_min[k]=(float)
								(sNormSigData.sigma[k]*sqrt(fDF/fChiLow));
						}

						#else
						// Use 1/sqrt(N) method for NORM sigma
						// Max and min error bars
						sNormSigData.sig_max[k]=(float)(sNormSigData.sigma[k]+
							fKn*sNormSigData.sigma[k]/
							sqrt(sNormSigData.num[k]));
						sNormSigData.sig_min[k]=(float)(sNormSigData.sigma[k]-
							fKn*sNormSigData.sigma[k]/
							sqrt(sNormSigData.num[k]));

						// Set fDF to zero as flag that it isn't valid
						fDF=0.0;
						#endif
					}                                              

					// Calc Hadamard totvar error bars
					if(nSigmaType==HADTOTAL_RUN)
					{
						// Calc HadTotvar edf
						// nNum0 is # non-gap tau=tau0 freq data points
						// nAf is averaging factor m
						// 2nd arg is nRatio = N/m = T/tau
						// where T is recond length
						// Applies for alpha -4 to 0 and m>24
						// Returns -1 if error

						fDF=HadTotvarEDF(nAlpha, (float)(nNum0)/(float)(nAF));

						// Calc df for cases where alpha is >0
						// Where HadTotvarEDF has returned -1 error code
						// or if m=nAF is <16
						if( (fDF<0) || (nAF<16) )
						{
							fDF=CalcDegFree(nAlpha, nNum0, nAF);

							// For the case where alpha is -3 or -4
							// and AF<16 which cannot be handled by either
							// HadTotvarEDF() or CalcDegFree(),
							// CalcDegFree() returns -1 (error) and we use
							// HadamardEDF()
							if(fDF==-1)
							{
								// Args are # phase data points, avg factor,
								// and beta = alpha-2
								fDF=HadamardEDF(nNum0+1, nAF, nAlpha-2);
							}
							else // Use CalcDegFree() result
							{
								// Add 2 because this is a total statistic
								fDF+=2.0;
							}
						}

						// Calc upper & lower chi squared values
						fChiHigh=CalcInvChiSqr(fHigh, fDF);
						fChiLow=CalcInvChiSqr(fLow, fDF);

						// Calc max sigma error bar
						sNormSigData.sig_max[k]=(float)
							(sNormSigData.sigma[k]*sqrt(fDF/fChiHigh));

						// Make sure low limit is OK (may not be for small CF)
						if(sqrt(fDF/fChiLow>=1.0))
						{
							sNormSigData.sig_min[k]=(float)
								(sNormSigData.sigma[k]/sqrt(fDF/fChiHigh));
						}
						else // Min sigma error bar
						{
							sNormSigData.sig_min[k]=(float)
								(sNormSigData.sigma[k]*sqrt(fDF/fChiLow));
						}
					}                                              

					// Calc modified or time sigma error bars
					if(nSigmaType==MODIFIED_RUN || nSigmaType==TIME_RUN ||
						nSigmaType==BOTH_RUN)
					{
						if(nAlpha==-3) // Trap error for alpha=-3
						{
							nAlpha=-2;
						}                                          

						// EDF calc
						#ifdef NEWEDF
						fDF=CombinedEDF(nNum0+bDataType, nAF, nAlpha, 2, 1,
							nAF, 1);

						#else
						// Use HVAR edf function with adjusted args to calc
						// MVAR edf per C. Greenhall suggestion
						// Args = # phase data pts+1, avg factor & beta-2
						fDF=HadamardEDF(nNum0+bDataType+1, nAF, nAlpha-4);
						#endif

						// Calc upper & lower chi squared values
						fChiHigh=CalcInvChiSqr(fHigh, fDF);
						fChiLow=CalcInvChiSqr(fLow, fDF);

						// Calc max sigma error bar
						sModSigData.sig_max[k]=(float)(sModSigData.sigma[k]*
							sqrt(fDF/fChiHigh));

						// Make sure low limit is OK (may not be for small CF)
						if(sqrt(fDF/fChiLow>=1.0))
						{
							sModSigData.sig_min[k]=(float)
								(sModSigData.sigma[k]/sqrt(fDF/fChiHigh));

						}
						else // Min sigma error bar
						{
							sModSigData.sig_min[k]=(float)
								(sModSigData.sigma[k]*sqrt(fDF/fChiLow));
						}
					}

					// Use simple 1/sqrt(N)method for HADAMARD case
					// No noise ID
					if(nSigmaType==HADAMARD_RUN)
					{
						#ifdef NEWEDF
						// Calc non-overlapped Hadamard EDF
						fDF=CombinedEDF(nNum0+bDataType, nAF, nAlpha, 3, nAF,
							1, 1);

						// Calc upper & lower chi squared values
						fChiHigh=CalcInvChiSqr(fHigh, fDF);
						fChiLow=CalcInvChiSqr(fLow, fDF);

						// Calc max sigma error bar
						sNormSigData.sig_max[k]=(float)
							(sNormSigData.sigma[k]*sqrt(fDF/fChiHigh));

						// Make sure low limit is OK (may not be for small CF)
						if(sqrt(fDF/fChiLow>=1.0))
						{
							sNormSigData.sig_min[k]=(float)
								(sNormSigData.sigma[k]/sqrt(fDF/fChiHigh));
						}
						else // Min sigma error bar
						{
							sNormSigData.sig_min[k]=(float)
								(sNormSigData.sigma[k]*sqrt(fDF/fChiLow));
						}
						#else // Original code
						// Calc max & min sigma error bars
						sNormSigData.sig_max[k]=(float)(sNormSigData.sigma[k]+
							sNormSigData.sigma[k]/sqrt(sNormSigData.num[k]));
						sNormSigData.sig_min[k]=(float)(sNormSigData.sigma[k]-
							sNormSigData.sigma[k]/sqrt(sNormSigData.num[k]));
						
						// Set fDF to zero as flag that it isn't valid
						fDF=0.0;
						#endif

					}
					
					// Calc Tho1 error bars
					if(nSigmaType==THEO1_RUN)
					{
						// Calc Tho1 edf
						// 2nd arg = # non-gap phase points
						fDF=Theo1EDF(nAlpha, nNum0, (float)nAF);

						if(fDF<=1.0) // Trap error: Was 0.0 until 07/25/10
						// Apparently the -1 error flag return from Theo1EDF
						// isn't sufficient to avoid problem with huge error bars
						{
							fDF=1.0;
						}

						// Calc upper & lower chi squared values
						fChiHigh=CalcInvChiSqr(fHigh, fDF);
						fChiLow=CalcInvChiSqr(fLow, fDF);

						// Calc max sigma error bar
						sNormSigData.sig_max[k]=(float)
							(sNormSigData.sigma[k]*sqrt(fDF/fChiHigh));

						// Make sure low limit is OK (may be NG for small CF)
						if(sqrt(fDF/fChiLow>=1.0))
						{
							sNormSigData.sig_min[k]=(float)
								(sNormSigData.sigma[k]/sqrt(fDF/fChiHigh));
						}
						else // Calc min sigma error bar
						{
							sNormSigData.sig_min[k]=(float)
								(sNormSigData.sigma[k]*sqrt(fDF/fChiLow));
						}
					}
					
					// Calc Overlapping ADEV + Tho1 error bars
					if(nSigmaType==FULL_RUN)
					{
						// Calc Overlapping ADEV edf
						#ifdef NEWEDF
						fDF=CombinedEDF(nNum0+bDataType, nAF, nAlpha, 2, nAF,
							nAF, 1);

						#else
						fDF=CalcDegFree(nAlpha, nNum0, nAF);
						#endif

						if(fDF<=0) // Trap error for nAlpha=-3
						{
							fDF=1.0;
						}

						// Store overlapping ADEV edf
						sNormSigData.df[k]=fDF;

						// Calc upper & lower chi squared values
						fChiHigh=CalcInvChiSqr(fHigh, fDF);
						fChiLow=CalcInvChiSqr(fLow, fDF);

						// Calc max sigma error bar
						sNormSigData.sig_max[k]=(float)
							(sNormSigData.sigma[k]*sqrt(fDF/fChiHigh));

						// Make sure low limit is OK (may be NG for small CF)
						if(sqrt(fDF/fChiLow>=1.0))
						{
							sNormSigData.sig_min[k]=(float)
								(sNormSigData.sigma[k]/sqrt(fDF/fChiHigh));
						}
						else // Calc min sigma error bar
						{
							sNormSigData.sig_min[k]=(float)
								(sNormSigData.sigma[k]*sqrt(fDF/fChiLow));
						}

						// Calc Tho1 edf
						// Note: nAF is normal one - Theo1EDF() includes x0.75
						// 2nd arg = # non-gap phase points
						fDF=Theo1EDF(nAlpha, nNum0, (float)nAF);

						if(fDF<=1.0) // Trap error: Was 0.0 until 07/25/10
						// Apparently the -1 error flag return from Theo1EDF
						// isn't sufficient to avoid problem with huge error bars
						{
							fDF=1.0;
						}

						#if(0) // For testing
						TRACE_EXP(fDF);
						#endif

						// Store Tho1 edf
						sModSigData.df[k]=fDF;

						// Calc upper & lower chi squared values
						fChiHigh=CalcInvChiSqr(fHigh, fDF);
						fChiLow=CalcInvChiSqr(fLow, fDF);

						// Calc max sigma error bar
						sModSigData.sig_max[k]=(float)
							(sModSigData.sigma[k]*sqrt(fDF/fChiHigh));

						// Make sure low limit is OK (may be NG for small CF)
						if(sqrt(fDF/fChiLow>=1.0))
						{
							sModSigData.sig_min[k]=(float)
								(sModSigData.sigma[k]/sqrt(fDF/fChiHigh));
						}
						else // Calc min sigma error bar
						{
							sModSigData.sig_min[k]=(float)
								(sModSigData.sigma[k]*sqrt(fDF/fChiLow));
						}
					}

					// Put df into results arrays
					if(nSigmaType!=FULL_RUN)
					{
						sNormSigData.df[k]=fDF;
						sModSigData.df[k]=fDF;
					}
				}
				break;

				// Calc mod sigma
				// This MDEV calc used both for finding mod sigma
				// and to support R(n) noise IDing
				// Uses fTau and nAF as inputs
				// Results go into nModSig and fModSig
				case IDC_RUN_MODSIG:
				{
					// Note: 04/10/10
					// There was a problem here
					// If we had synchronized data, we worked with the "real" phase data
					// and if drift was removed it stayed removed
					// We need to always work with a work array
					// and remove drift from it if called for

					#if(0) // Original code
					// Processing freq data w/o corresponding phase data?
					if( (bDataType==FREQ_DATA) && (!bSynch) )
					#endif

					#if(1) // New code 04/10/10
					// Processing freq data using working array
					if(bDataType==FREQ_DATA)
					#endif
					// Need to convert freq data to phase data in working array
					{
						// Allocate memory for working phase data
						// converted from freq data for MDEV calc
					   if((fWorkData=(F_TYPE*)malloc(
							(nNumm+ARRAY_OFFSET+1+EXTRA_MEM)*sizeof(F_TYPE)))
							==NULL)
						{
							// Display error message
							#ifdef MEM_DEBUG
							AllocErrorMessageEx(__FILE__, __LINE__,
								(nNumm+ARRAY_OFFSET+1+EXTRA_MEM)*
								sizeof(F_TYPE));
							#else
							AllocErrorMessage();
							#endif

							// Set abort flag
							bAbort=TRUE;

							// Close Run dialog box
							EndDialog(hDlg, 0);
							return TRUE;
						}

					    // Convert freq data to phase data for MDEV calc
					    // The 3rd argument is the tau0 for the data
						ConvFreqToPhase(fFreqData, fWorkData, fTau, FALSE);
					}
					else // Assign fWorkData pointer to existing phase data
					{
						fWorkData=fPhaseData;
					}

					// Fill gaps in converted data
					FillGaps(fWorkData, PHASE_DATA);

					#if(1) // New code 04/10/10
					// Remove drift from fWorkData if bRemoveDrift flag is set
					if(bRemoveDrift)
					{
						// TRACE_STR("Remove drift");

						// Calc & remove quadratic drift
						// Tau=1 for slope per data point interval
						CalcQuadraticDrift(fWorkData, 1.0, &fA, &fB,
							&fC, &fV);
						RemoveQuadraticDrift(fWorkData, fA, fB,
							fC);
					}
					#endif

					// Calc MDEV from fWorkData gapless phase data
					// Calc phase mod sigma
					// The 3rd argument is the analysis tau=m*tau0
					nModSig=CalcFastModSigma(fWorkData,	&fModSig, fTau*nAF,
						nAF);

					// Record call in detailed log
					if(bDetailedLog && nAF==1)
					{
						WriteLog(68, "CalcFastModSigma()");
					}

					// Error trap for bad calc
					if(nModSig<1)
					{
						// Display error message
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RUN_ERROR, NULL, 0));

						// Was working memory allocated?
						if( (bDataType==FREQ_DATA) && (!bSynch) )
						{
							// Free working data array
							free(fWorkData);
						}
						break;
					}

					// Was working memory allocated?
					if( (bDataType==FREQ_DATA) && (!bSynch) )
					{
						// Free working data array
						free(fWorkData);
					}
				}
				break;

				// Display stability run data in table
				// Values are AF, Tau, #, Alpha, Min Sigma, Sigma & Max Sigma
				// Except for FULL_RUN where they are
				// AF, Sigma Tau, Sigma #, Tho1 Tau, Sigma & Tho1
				// All lines are rewritten as calculations are done
				// k is the line index from 0 to # points-1
				// Displaying results line-by-line best for showing progress
				case IDC_RUN_DISPLAY:
				{
					// Look for error caused by resume indicated by -1 in # col
					for(j=0; j<sNormSigData.points; j++)
					{
						if(sNormSigData.num[j]==-1)
						{
							// Replace bad data with previous row's
							sNormSigData.num[j]=sNormSigData.num[j-1];
							sNormSigData.sigma[j]=sNormSigData.sigma[j-1];
						}
					}
					for(j=0; j<sModSigData.points; j++)
					{
						if(sModSigData.num[j]==-1)
						{
							// Replace bad data with previous row's
							sModSigData.num[j]=sModSigData.num[j-1];
							sModSigData.sigma[j]=sModSigData.sigma[j-1];
						}
					}
					
					// Write heading on table
					SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RUN_HEADING, NULL, 0));

					// Set # sigma points
					// This is done to allow row # checking in GetRunData()
					// Note: The case for all tau w/o scrolling eliminates
					// a spurious line at the bottom
					
					// Fudge for fast MTIE case
					if(nSigmaType==MTIE_RUN && bAllTau)
					{
						// Fill in tau parameter
						for(j=0; j<sNormSigData.points; j++)
						{
							nAF=sNormSigData.af[j];
							sNormSigData.tau[j]=(float)fTau*nAF;
						}
					}
					else // All except fast MTIE
					{
						if(bAllTau && k<15)
						{
							sNormSigData.points=k;
							sModSigData.points=k;
						}
						else
						{
							sNormSigData.points=k+1;
							sModSigData.points=k+1;
						}
					}

					if(k<15) // Table can show up to 15 rows w/o scrolling
					{
						// Remove WS_VSCROLL style bit to disable vertical
						// scroll bar
						dwStyle=SendMessage(hSigTbl, DTM_GETWNDSTYLE, 0, 0L);
						dwStyle&=~WS_VSCROLL;
						SendMessage(hSigTbl, DTM_SETWNDSTYLE, 0,
							(LPARAM)dwStyle);
					}
					else // Need vertical scrolling
					{
						// Add WS_VSCROLL style bit to enable vertical
						// scroll bar
						dwStyle=SendMessage(hSigTbl, DTM_GETWNDSTYLE, 0, 0L);
						dwStyle|=WS_VSCROLL;
						SendMessage(hSigTbl, DTM_SETWNDSTYLE, 0,
							(LPARAM)dwStyle);
					}
					
					// Display stability data
					SendMessage(hSigTbl, DTM_VM_INITIALIZE, (WPARAM)FALSE,
						(LPARAM)k+1); // k+1 = # rows
				}
				break;

				// Write table heading
				case IDC_RUN_HEADING:
				{
					// Label the column headings
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RUN_AF_COL_NUM, (LPARAM)(LPSTR)"AF");
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RUN_TAU_COL_NUM, (LPARAM)(LPSTR)"Tau");
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RUN_NUM_COL_NUM, (LPARAM)(LPSTR)"#");
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RUN_ALPHA_COL_NUM, (LPARAM)(LPSTR)"Alpha");

					ShowWindow((GETHCTL(IDC_RUN_ALLTAU)), SW_SHOWNORMAL);
					
					switch(nSigmaType)
					{
						case NORMAL_RUN:
						case OVERLAPPING_RUN:
						{
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_MIN_COL_NUM,
								(LPARAM)(LPSTR)"Min Sigma");
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_SIG_COL_NUM,
								(LPARAM)(LPSTR)"Sigma");
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_MAX_COL_NUM,
								(LPARAM)(LPSTR)"Max Sigma");
						}
						break;

						case CROSS_RUN: // Added 02/16/10
						{
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_MIN_COL_NUM,
								(LPARAM)(LPSTR)"");
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_SIG_COL_NUM,
								(LPARAM)(LPSTR)"Sigma");
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_MAX_COL_NUM,
								(LPARAM)(LPSTR)"");
						}
						break;

						case TOTAL_RUN:
						{
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_MIN_COL_NUM,
								(LPARAM)(LPSTR)"Min Sigma");
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_SIG_COL_NUM,
								(LPARAM)(LPSTR)"Total Sigma");
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_MAX_COL_NUM,
								(LPARAM)(LPSTR)"Max Sigma");
						}
						break;

						case MODTOTAL_RUN: 
						{
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_MIN_COL_NUM,
								(LPARAM)(LPSTR)"Min Sigma");
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_SIG_COL_NUM,
								(LPARAM)(LPSTR)"Mod Totdev");
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_MAX_COL_NUM,
								(LPARAM)(LPSTR)"Max Sigma");
						}
						break;

						case TIMETOTAL_RUN: 
						{
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_MIN_COL_NUM,
								(LPARAM)(LPSTR)"Min Sigma");
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_SIG_COL_NUM,
								(LPARAM)(LPSTR)"Time Totdev");
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_MAX_COL_NUM,
								(LPARAM)(LPSTR)"Max Sigma");
						}
						break;

						case MODIFIED_RUN:
						{
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_MIN_COL_NUM,
								(LPARAM)(LPSTR)"Min Sigma");
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_SIG_COL_NUM,
								(LPARAM)(LPSTR)"Mod Sigma");
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_MAX_COL_NUM,
								(LPARAM)(LPSTR)"Max Sigma");
						}
						break;

						case TIME_RUN:
						{
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_MIN_COL_NUM,
								(LPARAM)(LPSTR)"Min Sigma");
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_SIG_COL_NUM,
								(LPARAM)(LPSTR)"Time Sigma");
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_MAX_COL_NUM,
								(LPARAM)(LPSTR)"Max Sigma");
						}
						break;

						case HADAMARD_RUN:
						case OVERLAPHAD_RUN:
						case HADTOTAL_RUN:
						{
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_MIN_COL_NUM,
								(LPARAM)(LPSTR)"Min Sigma");
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_SIG_COL_NUM,
								(LPARAM)(LPSTR)"Hadamard Dev");
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_MAX_COL_NUM,
								(LPARAM)(LPSTR)"Max Sigma");
						}
						break;

						case BOTH_RUN:
						{
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_MIN_COL_NUM,
								(LPARAM)(LPSTR)"Std Dev");
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_SIG_COL_NUM,
								(LPARAM)(LPSTR)"Sigma");
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_MAX_COL_NUM,
								(LPARAM)(LPSTR)"Mod Sigma");
						}
						break;

						case TIERMS_RUN:
						{
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_MIN_COL_NUM,
								(LPARAM)(LPSTR)"");
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_SIG_COL_NUM,
								(LPARAM)(LPSTR)"TIE rms");
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_MAX_COL_NUM,
								(LPARAM)(LPSTR)"");
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_ALPHA_COL_NUM, (LPARAM)(LPSTR)"");
						}
						break;

						case MTIE_RUN:
						{
							// Change "All Tau" to "Fast" for MTIE
							SetWindowText(GETHCTL(IDC_RUN_ALLTAU),
								"Fast (&u)");
							
							// Set the increment type radio buttons
							Button_SetCheck(GETHCTL(IDC_RUN_OCTAVE), bOctave);
							Button_SetCheck(GETHCTL(IDC_RUN_DECADE), bDecade);
							Button_SetCheck(GETHCTL(IDC_RUN_ALLTAU), bAllTau);

							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_MIN_COL_NUM,
								(LPARAM)(LPSTR)"");
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_SIG_COL_NUM,
								(LPARAM)(LPSTR)"MTIE");
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_MAX_COL_NUM,
								(LPARAM)(LPSTR)"");
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_ALPHA_COL_NUM, (LPARAM)(LPSTR)"");
						}
						break;

						case THEO1_RUN:
						{
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_TAU_COL_NUM,
								(LPARAM)(LPSTR)"Tho1 Tau");
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_SIG_COL_NUM,
								(LPARAM)(LPSTR)"Tho1 Dev");
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_MIN_COL_NUM,
								(LPARAM)(LPSTR)"Min Tho1");
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_MAX_COL_NUM,
								(LPARAM)(LPSTR)"Max Tho1");
						}
						break;

						case FULL_RUN:
						{
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_TAU_COL_NUM,
								(LPARAM)(LPSTR)"Sigma Tau");
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_NUM_COL_NUM,
								(LPARAM)(LPSTR)"Sigma #");
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_MIN_COL_NUM,
								(LPARAM)(LPSTR)"Tho1 Tau");
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_SIG_COL_NUM,
								(LPARAM)(LPSTR)"Sigma");
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_MAX_COL_NUM,
								(LPARAM)(LPSTR)"Tho1 Dev");
							SendMessage(hSigTbl, DTM_SETCOLHEAD,
								(WPARAM)RUN_ALPHA_COL_NUM,
								(LPARAM)(LPSTR)"Alpha");
						}
						break;
					}

					// Eliminate min & max columns if all tau
					// Unless BOTH_RUN or FULL_RUN
					if(bAllTau && nSigmaType!=BOTH_RUN && nSigmaType!=FULL_RUN)
					{
						// Clear min & max headings
						SendMessage(hSigTbl, DTM_SETCOLHEAD,
							(WPARAM)RUN_MIN_COL_NUM,
							(LPARAM)(LPSTR)"");
						SendMessage(hSigTbl, DTM_SETCOLHEAD,
							(WPARAM)RUN_MAX_COL_NUM,
							(LPARAM)(LPSTR)"");
					}
				}
				break;

				// Clear results
				case IDC_RUN_CLEAR:
				{
					// Clear stop flag that indicates current run was stopped
					bStop=FALSE;

					// Allow drift display
					bShowDrift=TRUE;

					// Change Resume button back to Calc
					SetWindowText(GETHCTL(IDC_RUN_RUN), "C&alc");

					// Change Clear button back to Close 
					SetWindowText(GETHCTL(IDCANCEL), "&Close");

					// Hide drift window & show start AF control & label
					ShowWindow((GETHCTL(IDC_RUN_DRIFT)), SW_HIDE);
					ShowWindow((GETHCTL(IDC_RUN_AF)), SW_SHOWNORMAL);
					ShowWindow((GETHCTL(IDC_RUN_AFLABEL)), SW_SHOWNORMAL);

					// Clear stability data in table
					// This works a bit strangely but seems to do the trick
					// if done with PostMessage() rather than SendMessage()
					// It causes a DTE_ROWOUTOFRANGE error that is trapped in
					// GetRunData()
					PostMessage(hSigTbl, DTM_VM_INITIALIZE, (WPARAM)FALSE,
						(LPARAM)0);

					// Clear drift display
					SetWindowText(GETHCTL(IDC_RUN_DRIFT), "");

					// Clear all previous sigma data
					// This fixes a wierd interaction between
					// previous overlapping plus mod sigma run
					// in current overlapping plus tho1 run
					if(sNormSigData.points)
					{
						for(i=0; i<sNormSigData.points; i++)
						{
							sNormSigData.num[i]=0;
							sNormSigData.sigma[i]=0.0;
						}
					}
					if(sModSigData.points)
					{
						for(i=0; i<sModSigData.points; i++)
						{
							sModSigData.num[i]=0;
							sModSigData.sigma[i]=0.0;
						}
					}
					
					// Clear sigma values
					sNormSigData.points=0;
					sModSigData.points=0;

					// Clear data valid flag
					bDataValid=FALSE;

					// Grey unwanted controls
					EnableWindow(GETHCTL(IDC_RUN_PRINT), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_PLOT), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_OPTIONS), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_LINES), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_NOTES), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_COPY), FALSE);

					// Write prompt message
					WritePromptMessage(TB_RUN);
				}
				break;

				// Restore original data after run
				case IDC_RUN_RESTORE:
				{
					if(bDataType==FREQ_DATA) // Frequency data
					{
						for(j=0; j<nNumm+ARRAY_OFFSET; j++)
						{
							fFreqData[j]=fTempData[j];
						}
					}
					else // Phase data
					{
						for(j=0; j<nNumm+ARRAY_OFFSET; j++)
						{
							fPhaseData[j]=fTempData[j];
						}
					}
				}
				break;

				// Respond to copy button
				case IDC_RUN_COPY:
				{
					nClip=(10+sNormSigData.points)*80;
					hClipboard=GlobalAlloc(GMEM_DDESHARE,
						(DWORD)nClip);
					szClipboard=GlobalLock(hClipboard);

						{
							nLine=0; // Heading
							LoadString(hInst, IDS_FORMAT_2, szFormat,
								BUFFER_SIZE);
							_snprintf(szBuffer, sizeof(szBuffer), szFormat,
								szFileTitle);
							strlcpy(szClipboard, szBuffer, nClip);
							strlcat(szClipboard, "\r\n", nClip);

							nLine=1; // # points
							if(bDataType==FREQ_DATA)
							{
								// Calc stats
								FindMinMax(fFreqData, &fMin, &fMax, FREQ_DATA);
								CalcMean(fFreqData, &fAvg, FREQ_DATA);

								LoadString(hInst, IDS_FORMAT_3, szFormat,
									BUFFER_SIZE);
								_snprintf(szBuffer, sizeof(szBuffer), szFormat,
									nStart, nEnd, nNum);
								strlcat(szClipboard, szBuffer, nClip);
								strlcat(szClipboard, "\r\n", nClip);
							}
							else // Phase data
							{
								// Calc stats
								FindMinMax(fPhaseData, &fMin, &fMax,
									PHASE_DATA);
								CalcMean(fPhaseData, &fAvg, PHASE_DATA);

								LoadString(hInst, IDS_FORMAT_4, szFormat,
									BUFFER_SIZE);
								_snprintf(szBuffer, sizeof(szBuffer), szFormat,
									nStart, nEnd, nNum);
								strlcat(szClipboard, szBuffer, nClip);
								strlcat(szClipboard, "\r\n", nClip);
							}

							nLine=2; // Max
							LoadString(hInst, IDS_FORMAT_10, szFormat,
								BUFFER_SIZE);
							_snprintf(szBuffer, sizeof(szBuffer), szFormat,
								fMax);
							ShortenExp(szBuffer);
							strlcat(szClipboard, szBuffer, nClip);
							strlcat(szClipboard, "\r\n", nClip);

							nLine=3; // Min
							LoadString(hInst, IDS_FORMAT_11, szFormat,
								BUFFER_SIZE);
							_snprintf(szBuffer, sizeof(szBuffer), szFormat,
								fMin);
							ShortenExp(szBuffer);
							strlcat(szClipboard, szBuffer, nClip);
							strlcat(szClipboard, "\r\n", nClip);

							nLine=4; // Avg
							LoadString(hInst, IDS_FORMAT_12, szFormat,
								BUFFER_SIZE);
							_snprintf(szBuffer, sizeof(szBuffer), szFormat,
								fAvg);
							ShortenExp(szBuffer);
							strlcat(szClipboard, szBuffer, nClip);
							strlcat(szClipboard, "\r\n", nClip);

							nLine=5; // Sigma type
							LoadString(hInst, IDS_FORMAT_13, szBuffer,
								BUFFER_SIZE);
							strlcat(szBuffer, types[nSigmaType],
								sizeof(szBuffer));
							strlcat(szClipboard, szBuffer, nClip);

							// Add note if 1 of 2 selected
							if(b1of2)
							{
								strlcat(szClipboard, " (", nClip);
								LoadString(hInst, IDS_SPLOT_MESSAGE_7,
									szBuffer, BUFFER_SIZE);
								strlcat(szClipboard, szBuffer, nClip);
								strlcat(szClipboard, ")", nClip);
							}

							strlcat(szClipboard, "\r\n", nClip);

							if(nSigmaType!=TIERMS_RUN &&
								nSigmaType!=MTIE_RUN &&
								nSigmaType!=FULL_RUN)
							{
								nLine=6; // CF
								LoadString(hInst, IDS_FORMAT_14, szFormat,
									BUFFER_SIZE);
								_snprintf(szBuffer, sizeof(szBuffer), szFormat,
									fConfFactor);
								strlcat(szClipboard, szBuffer, nClip);
								strlcat(szClipboard, "\r\n", nClip);
							}

							nLine=7; // Alpha or Deadtime T/Tau ratio
							if(nSigmaType==THEO1_RUN || nSigmaType==FULL_RUN)
							{
								_snprintf(szBuffer, sizeof(szBuffer),
									" Alpha = %d", nAlpha);	
								strlcat(szClipboard, szBuffer, nClip);
								strlcat(szClipboard, "\r\n\r\n", nClip);
							}
							else // All other sigma types
							{
								_snprintf(szBuffer, sizeof(szBuffer),
									" Deadtime T/Tau = %f", fDeadtime);	
								strlcat(szClipboard, szBuffer, nClip);
								strlcat(szClipboard, "\r\n\r\n", nClip);
							}

							nLine=9; // Results heading
							switch(nSigmaType)
							{
								case NORMAL_RUN:
								case OVERLAPPING_RUN:
								case CROSS_RUN: // Added 02/16/10
								{
									LoadString(hInst, IDS_HEADING_7, szBuffer,
										BUFFER_SIZE);
								}
								break;

								case BOTH_RUN:
								{
									LoadString(hInst, IDS_HEADING_8, szBuffer,
										BUFFER_SIZE);
								}
								break;

								case MODIFIED_RUN:
								{
									LoadString(hInst, IDS_HEADING_9, szBuffer,
										BUFFER_SIZE);
								}
								break;

								case TIME_RUN:
								{
									LoadString(hInst, IDS_HEADING_10, szBuffer,
										BUFFER_SIZE);
								}
								break;

								case HADAMARD_RUN:
								case OVERLAPHAD_RUN:
								case HADTOTAL_RUN:
								{
									LoadString(hInst, IDS_HEADING_11, szBuffer,
										BUFFER_SIZE);
								}
								break;

								case TOTAL_RUN:
								{
									LoadString(hInst, IDS_HEADING_12, szBuffer,
										BUFFER_SIZE);
								}
								break;

								case MODTOTAL_RUN:
								{
									LoadString(hInst, IDS_HEADING_21, szBuffer,
										BUFFER_SIZE);
								}
								break;

								case TIMETOTAL_RUN:
								{
									LoadString(hInst, IDS_HEADING_22, szBuffer,
										BUFFER_SIZE);
								}
								break;

								case TIERMS_RUN:
								{
									LoadString(hInst, IDS_HEADING_19, szBuffer,
										BUFFER_SIZE);
								}
								break;

								case MTIE_RUN:
								{
									LoadString(hInst, IDS_HEADING_20, szBuffer,
										BUFFER_SIZE);
								}
								break;
								
								case THEO1_RUN:
								{
									LoadString(hInst, IDS_HEADING_27, szBuffer,
										BUFFER_SIZE);
								}
								break;

								case FULL_RUN:
								{
									LoadString(hInst, IDS_HEADING_29, szBuffer,
										BUFFER_SIZE);
								}
								break;
							}

							strlcat(szClipboard, szBuffer, nClip);
							strlcat(szClipboard, "\r\n", nClip);

							i=0;
							for(nLine=11; nLine<=10+sNormSigData.points;
								nLine++)
							{
								if(nSigmaType==NORMAL_RUN ||
									nSigmaType==OVERLAPPING_RUN ||
									nSigmaType==HADAMARD_RUN ||
									nSigmaType==OVERLAPHAD_RUN ||
									nSigmaType==HADTOTAL_RUN ||
									nSigmaType==TOTAL_RUN ||
									nSigmaType==CROSS_RUN) // Added 02/16/10
								{
									nAF=(int)((sNormSigData.tau[i]/fTau)+0.5);
									LoadString(hInst, IDS_FORMAT_5, szFormat,
										BUFFER_SIZE);
									_snprintf(szBuffer, sizeof(szBuffer),
										szFormat, nAF, fTau*nAF,
										(int)sNormSigData.num[i],
										sNormSigData.alpha[i],
										sNormSigData.sig_min[i],
										sNormSigData.sigma[i],
										sNormSigData.sig_max[i]);
								}

								else if(nSigmaType==BOTH_RUN)
								{
									nAF=(int)((sNormSigData.tau[i]/fTau)+0.5);
									LoadString(hInst, IDS_FORMAT_5, szFormat,
										BUFFER_SIZE);
									_snprintf(szBuffer, sizeof(szBuffer),
										szFormat, nAF, fTau*nAF,
										(int)sNormSigData.num[i],
										sNormSigData.alpha[i],
										sNormSigData.std_dev[i],
										sNormSigData.sigma[i],
										sModSigData.sigma[i]);
								}

								else if(nSigmaType==MODIFIED_RUN ||
									nSigmaType==TIME_RUN ||
									nSigmaType==MODTOTAL_RUN ||
									nSigmaType==TIMETOTAL_RUN )
								{
									nAF=(int)((sModSigData.tau[i]/fTau)+0.5);
									LoadString(hInst, IDS_FORMAT_5, szFormat,
										BUFFER_SIZE);
									_snprintf(szBuffer, sizeof(szBuffer),
										szFormat, nAF, fTau*nAF,
										(int)sModSigData.num[i],
										sModSigData.alpha[i],
										sModSigData.sig_min[i],
										sModSigData.sigma[i],
										sModSigData.sig_max[i]);
								}

								else if(nSigmaType==TIERMS_RUN ||
									nSigmaType==MTIE_RUN)
								{
									nAF=(int)((sNormSigData.tau[i]/fTau)+0.5);

									strlcpy(szFormat,
										"%5d   %10.4e   %6d   %10.4e",
										sizeof(szFormat));
									_snprintf(szBuffer, sizeof(szBuffer),
										szFormat, nAF, fTau*nAF,
										(int)sNormSigData.num[i],
										sNormSigData.sigma[i]);
								}

								else if(nSigmaType==THEO1_RUN)
								{
									LoadString(hInst, IDS_FORMAT_24, szFormat,
										BUFFER_SIZE);
									_snprintf(szBuffer, sizeof(szBuffer),
										szFormat,
										sNormSigData.af[i],
										sNormSigData.tau[i],
										sNormSigData.num[i],
										sNormSigData.alpha[i],
										sNormSigData.sig_min[i],
										sNormSigData.sigma[i],
										sNormSigData.sig_max[i]);
								}

								else if(nSigmaType==FULL_RUN)
								{
									nAF=(int)((sNormSigData.tau[i]/fTau)+0.5);
									strlcpy(szFormat,
										" %5d  %10.4e  %6d  %10.4e  %10.4e  "
										"%10.4e  %10.4e  %10.4e",
										sizeof(szFormat));
									if(sNormSigData.sigma[i]) // ADEV
									{
										_snprintf(szBuffer, sizeof(szBuffer),
											szFormat, nAF, fTau*nAF,
											(int)sNormSigData.num[i],
											sModSigData.tau[i],
											sNormSigData.sigma[i],
											sModSigData.sigma[i],
											sNormSigData.sig_min[i],
											sNormSigData.sig_max[i]);
									}
									else // Tho1
									{
										_snprintf(szBuffer, sizeof(szBuffer),
											szFormat, nAF, fTau*nAF,
											(int)sNormSigData.num[i],
											sModSigData.tau[i],
											sNormSigData.sigma[i],
											sModSigData.sigma[i],
											sModSigData.sig_min[i],
											sModSigData.sig_max[i]);
									}
								}

								ShortenExp(szBuffer);
								strlcat(szClipboard, szBuffer, nClip);
								strlcat(szClipboard, "\r\n", nClip);
								
								// Increment index
								i++;
							}
					}

					GlobalUnlock(hClipboard);
						OpenClipboard(NULL);
						EmptyClipboard();
						SetClipboardData(CF_TEXT, hClipboard);
						CloseClipboard();
				}
				break;

				#ifndef LITE_VER
				// Print results on printer using Win32 API
				// Note: Bare-bones printing code: no error trapping, no font
				// selection, no abort proc, 1 page only
				// Printer must use fixed-space font
				// Multi-page all tau printout not allowed
				// User can choose printer in PrintDlg
				case IDC_RUN_PRINT:
				{
					// Initialize PRINTDLG structure
					memset(&pd, 0, sizeof(PRINTDLG));
					pd.lStructSize=sizeof(PRINTDLG);
					pd.Flags=PD_RETURNDEFAULT; // Don't show dialog box

					// 1st (hidden) call to PrintDlg()
					// To set up hDevNames & hDevMode
 					if(!PrintDlg(&pd))
					{
						// PrintDlg() called failed
						MessageBox(hwndMain, "Printer Not Found", "Run Print",
						MB_ICONEXCLAMATION);
						break;
					}

					// Reinitialize PRINTDLG structure
					// Get DC & no choice of page #s & no text selection
					pd.Flags=PD_RETURNDC | PD_NOPAGENUMS | PD_NOSELECTION;

					// 2nd (visible) call to PrintDlg()
					if(PrintDlg(&pd))
					{
						// Get printer device context
						hdcPrn=pd.hDC;
					}
					else
					{
						if(CommDlgExtendedError())
						{
							// Printer error
							MessageBox(hwndMain, "Printer Error", "Run Print",
							MB_ICONEXCLAMATION);
						}
						else // Error code 0
						{
							// User hit cancel button
							break;
						}
					}
					
					// Determine logfont.lfHeight from point size = nPointSize
					// where nPointSize is global variable that user can enter
					// in General page of Configure property sheet
					// Win32 documentation gives the formula:
					// lfHeight = -MulDiv(PointSize,
					// GetDeviceCaps(hDC, LOGPIXELSY), 72);
					// which becomes the following for our variables:
					// nFontHeight = -MulDiv(nPointSize,
					// GetDeviceCaps(hdcPrn, LOGPIXELSY), 72);
					// Both nPointSize and nFontHeight are global variables
					// A couple of typical values are nPointSize=9,
					// nFontHeight=-75
					// and nPointSize=10, nFontHeight=-83
					// (the abs value of nFontHeight is used)
					nFontHeight = -MulDiv(nPointSize, GetDeviceCaps(hdcPrn,
						LOGPIXELSY), 72);
					
					// Set font attributes
					// Assumes 8.5"x11" portrait page
					// Text size set to fit nicely across std page
					// Fixed pitch for easy alignment
					logfont.lfHeight=nFontHeight;
					logfont.lfWidth=0;
					logfont.lfEscapement=0;
					logfont.lfOrientation=0;
					logfont.lfWeight=0;
					logfont.lfItalic=0;
					logfont.lfUnderline=0;
					logfont.lfStrikeOut=0;
					logfont.lfCharSet=OEM_CHARSET;
					logfont.lfOutPrecision=OUT_DEFAULT_PRECIS;
					logfont.lfClipPrecision=CLIP_DEFAULT_PRECIS;
					logfont.lfQuality=PROOF_QUALITY;
					logfont.lfPitchAndFamily=FIXED_PITCH | FF_DONTCARE;
					strlcpy(logfont.lfFaceName,"", LF_FACESIZE);

					// Create printer font
					hPrnFont=CreateFontIndirect(&logfont);

					// Select font into printer device
					SelectObject(hdcPrn, hPrnFont);

					// Get text metrics
					GetTextMetrics(hdcPrn, &tm);
					yChar=tm.tmHeight + tm.tmExternalLeading;
					xChar=tm.tmAveCharWidth;

					// Get page dimensions
					xPage=(short)GetDeviceCaps(hdcPrn, HORZRES);
					yPage=(short)GetDeviceCaps(hdcPrn, VERTRES);

					// Compose Print Manager message
					LoadString(hInst, IDS_MESSAGE_REPORT, szPrnMsg,
							BUFFER_SIZE);

					// Set up DOCINFO structure
					memset(&di, 0, sizeof(DOCINFO));
					di.cbSize=sizeof(DOCINFO);
					di.lpszDocName=szPrnMsg;
					
					// Start printing
					if(hdcPrn != NULL)
					{
						if(StartDoc(hdcPrn, &di) != SP_ERROR)
						{
							// Actual printing code starts here
							StartPage(hdcPrn);

							nLine=0; // Heading
							SetTextAlign(hdcPrn,
								TA_LEFT || TA_TOP);
							LoadString(hInst, IDS_FORMAT_2, szFormat,
								BUFFER_SIZE);
							_snprintf(szBuffer, sizeof(szBuffer), szFormat,
								szFileTitle);
							TextOut(hdcPrn, xChar/2, (int)((nLine+0.5)*yChar),
								szBuffer, strlen(szBuffer));

							nLine=1; // # points
							if(bDataType==FREQ_DATA)
							{
								// Calc stats
								FindMinMax(fFreqData, &fMin, &fMax, FREQ_DATA);
								CalcMean(fFreqData, &fAvg, FREQ_DATA);

								LoadString(hInst, IDS_FORMAT_3, szFormat,
									BUFFER_SIZE);
								_snprintf(szBuffer, sizeof(szBuffer), szFormat,
									nStart, nEnd, nNum);
								TextOut(hdcPrn, (int)(xChar/2),
									(int)((nLine+0.5)*yChar), szBuffer,
									strlen(szBuffer));
							}
							else // Phase data
							{
								// Calc stats
								FindMinMax(fPhaseData, &fMin, &fMax,
									PHASE_DATA);
								CalcMean(fPhaseData, &fAvg, PHASE_DATA);

								LoadString(hInst, IDS_FORMAT_4, szFormat,
									BUFFER_SIZE);
								_snprintf(szBuffer, sizeof(szBuffer), szFormat,
									nStart, nEnd, nNum);
								TextOut(hdcPrn, (int)(xChar/2),
									(int)((nLine+0.5)*yChar), szBuffer,
									strlen(szBuffer));
							}

							nLine=2; // Max
							LoadString(hInst, IDS_FORMAT_10, szFormat,
								BUFFER_SIZE);
							_snprintf(szBuffer, sizeof(szBuffer), szFormat,
								fMax);
							ShortenExp(szBuffer);
							TextOut(hdcPrn, (int)(xChar/2),
								(int)((nLine+0.5)*yChar),
								szBuffer, strlen(szBuffer));

							nLine=3; // Min
							LoadString(hInst, IDS_FORMAT_11, szFormat,
								BUFFER_SIZE);
							_snprintf(szBuffer, sizeof(szBuffer), szFormat,
								fMin);
							ShortenExp(szBuffer);
							TextOut(hdcPrn, (int)(xChar/2),
								(int)((nLine+0.5)*yChar),
								szBuffer, strlen(szBuffer));

							nLine=4; // Avg
							LoadString(hInst, IDS_FORMAT_12, szFormat,
								BUFFER_SIZE);
							_snprintf(szBuffer, sizeof(szBuffer), szFormat,
								fAvg);
							ShortenExp(szBuffer);
							TextOut(hdcPrn, (int)(xChar/2),
								(int)((nLine+0.5)*yChar),
								szBuffer, strlen(szBuffer));

							nLine=5; // Sigma type
							LoadString(hInst, IDS_FORMAT_13, szFormat,
								BUFFER_SIZE);
							strlcat(szFormat, typesp[nSigmaType],
								sizeof(szFormat));

							// Add note if 1 of 2 selected
							if(b1of2)
							{
								strlcat(szFormat, " (", sizeof(szFormat));
								LoadString(hInst, IDS_SPLOT_MESSAGE_7,
									szBuffer, BUFFER_SIZE);
								strlcat(szFormat, szBuffer, sizeof(szFormat));
								strlcat(szFormat, ")", sizeof(szFormat));
							}

							TextOut(hdcPrn, (int)(xChar/2),
								(int)((nLine+0.5)*yChar),
								szFormat, strlen(szFormat));
							
							if(nSigmaType!=TIERMS_RUN &&
								nSigmaType!=MTIE_RUN &&
								nSigmaType!=THEO1_RUN && nSigmaType!=FULL_RUN)
							{
								nLine=6; // CF
								LoadString(hInst, IDS_FORMAT_14, szFormat,
									BUFFER_SIZE);
								_snprintf(szBuffer, sizeof(szBuffer), szFormat,
									fConfFactor);
								TextOut(hdcPrn, (int)(xChar/2),
									(int)((nLine+0.5)*yChar),
									szBuffer, strlen(szBuffer));
							}

							nLine=7; // Alpha or Deadtime T/Tau ratio
							if(nSigmaType==THEO1_RUN || nSigmaType==FULL_RUN)
							{
								_snprintf(szBuffer, sizeof(szBuffer),
									" Alpha = %d", nAlpha);	
								TextOut(hdcPrn, (int)(xChar/2),
									(int)((nLine+0.5)*yChar),
									szBuffer, strlen(szBuffer));
							}
							else // All other sigma types
							{
								_snprintf(szBuffer, sizeof(szBuffer),
									" Deadtime T/Tau = %f",
									fDeadtime);	
								TextOut(hdcPrn, (int)(xChar/2),
									(int)((nLine+0.5)*yChar),
									szBuffer, strlen(szBuffer));
							}

							nLine=9; // Results heading
							switch(nSigmaType)
							{
								case NORMAL_RUN:
								case OVERLAPPING_RUN:
								case CROSS_RUN: // Added 02/16/10
								{
									LoadString(hInst, IDS_HEADING_7, szBuffer,
										BUFFER_SIZE);
								}
								break;

								case BOTH_RUN:
								{
									LoadString(hInst, IDS_HEADING_8, szBuffer,
										BUFFER_SIZE);
								}
								break;

								case MODIFIED_RUN:
								{
									LoadString(hInst, IDS_HEADING_9, szBuffer,
										BUFFER_SIZE);
								}
								break;

								case TIME_RUN:
								{
									LoadString(hInst, IDS_HEADING_10, szBuffer,
										BUFFER_SIZE);
								}
								break;

								case HADAMARD_RUN:
								case OVERLAPHAD_RUN:
								case HADTOTAL_RUN:
								{
									LoadString(hInst, IDS_HEADING_11, szBuffer,
										BUFFER_SIZE);
								}
								break;

								case TOTAL_RUN:
								{
									LoadString(hInst, IDS_HEADING_12, szBuffer,
										BUFFER_SIZE);
								}
								break;

								case MODTOTAL_RUN:
								{
									LoadString(hInst, IDS_HEADING_21, szBuffer,
										BUFFER_SIZE);
								}
								break;

								case TIMETOTAL_RUN:
								{
									LoadString(hInst, IDS_HEADING_22, szBuffer,
										BUFFER_SIZE);
								}
								break;

								case TIERMS_RUN:
								{
									LoadString(hInst, IDS_HEADING_19, szBuffer,
										BUFFER_SIZE);
								}
								break;

								case MTIE_RUN:
								{
									LoadString(hInst, IDS_HEADING_20, szBuffer,
										BUFFER_SIZE);
								}
								break;

								case THEO1_RUN:
								{
									strlcpy(szBuffer, Theo1Head,
										sizeof(szBuffer));
								}
								break;

								case FULL_RUN:
								{
									strlcpy(szBuffer, FullHead,
										sizeof(szBuffer));
								}
								break;
							}

							TextOut(hdcPrn, (int)(xChar/2),
								(int)((nLine+0.5)*yChar),
								szBuffer, strlen(szBuffer));

							i=0;
							for(nLine=11; nLine<=10+sNormSigData.points;
								nLine++)
							{
								if(nSigmaType==NORMAL_RUN ||
									nSigmaType==OVERLAPPING_RUN ||
									nSigmaType==HADAMARD_RUN ||
									nSigmaType==OVERLAPHAD_RUN ||
									nSigmaType==HADTOTAL_RUN ||
									nSigmaType==TOTAL_RUN ||
									nSigmaType== CROSS_RUN) // Added 02/16/10
								{
									nAF=(int)((sNormSigData.tau[i]/fTau)+0.5);
									LoadString(hInst, IDS_FORMAT_5, szFormat,
										BUFFER_SIZE);
									_snprintf(szBuffer, sizeof(szBuffer),
										szFormat, nAF, fTau*nAF,
										(int)sNormSigData.num[i],
										sNormSigData.alpha[i],
										sNormSigData.sig_min[i],
										sNormSigData.sigma[i],
										sNormSigData.sig_max[i]);
								}

								else if(nSigmaType==BOTH_RUN)
								{
									nAF=(int)((sNormSigData.tau[i]/fTau)+0.5);
									LoadString(hInst, IDS_FORMAT_5, szFormat,
										BUFFER_SIZE);
									_snprintf(szBuffer, sizeof(szBuffer),
										szFormat, nAF, fTau*nAF,
										(int)sNormSigData.num[i],
										sNormSigData.alpha[i],
										sNormSigData.std_dev[i],
										sNormSigData.sigma[i],
										sModSigData.sigma[i]);
								}

								else if(nSigmaType==MODIFIED_RUN ||
									nSigmaType==TIME_RUN ||
									nSigmaType==MODTOTAL_RUN ||
									nSigmaType==TIMETOTAL_RUN )
								{
									nAF=(int)((sModSigData.tau[i]/fTau)+0.5);
									LoadString(hInst, IDS_FORMAT_5, szFormat,
										BUFFER_SIZE);
									_snprintf(szBuffer, sizeof(szBuffer),
										szFormat, nAF, fTau*nAF,
										(int)sModSigData.num[i],
										sModSigData.alpha[i],
										sModSigData.sig_min[i],
										sModSigData.sigma[i],
										sModSigData.sig_max[i]);
								}

								else if(nSigmaType==TIERMS_RUN ||
									nSigmaType==MTIE_RUN)
								{
									nAF=(int)((sNormSigData.tau[i]/fTau)+0.5);
									strlcpy(szFormat,
										"%5d   %10.4e   %6d   %10.4e",
										sizeof(szFormat));
									_snprintf(szBuffer, sizeof(szBuffer),
										szFormat, nAF, fTau*nAF,
										(int)sNormSigData.num[i],
										sNormSigData.sigma[i]);
								}

								else if(nSigmaType==THEO1_RUN)
								{
									LoadString(hInst, IDS_FORMAT_24, szFormat,
										BUFFER_SIZE);
									_snprintf(szBuffer, sizeof(szBuffer),
										szFormat,
										sNormSigData.af[i],
										sNormSigData.tau[i],
										sNormSigData.num[i],
										sNormSigData.alpha[i],
										sNormSigData.sig_min[i],
										sNormSigData.sigma[i],
										sNormSigData.sig_max[i]);
								}

								else if(nSigmaType==FULL_RUN)
								{
									nAF=(int)((sNormSigData.tau[i]/fTau)+0.5);
									strlcpy(szFormat,
										" %5d  %10.4e  %6d  %10.4e  %10.4e  "
										"%10.4e  %10.4e  %10.4e",
										sizeof(szFormat));
									if(sNormSigData.sigma[i]) // ADEV
									{
										_snprintf(szBuffer, sizeof(szBuffer),
											szFormat, nAF, fTau*nAF,
											(int)sNormSigData.num[i],
											sModSigData.tau[i],
											sNormSigData.sigma[i],
											sModSigData.sigma[i],
											sNormSigData.sig_min[i],
											sNormSigData.sig_max[i]);
									}
									else // Tho1
																		{
										_snprintf(szBuffer, sizeof(szBuffer),
											szFormat, nAF, fTau*nAF,
											(int)sNormSigData.num[i],
											sModSigData.tau[i],
											sNormSigData.sigma[i],
											sModSigData.sigma[i],
											sModSigData.sig_min[i],
											sModSigData.sig_max[i]);
									}
								}

								ShortenExp(szBuffer);
								TextOut(hdcPrn, (int)(xChar/2),
									(int)((nLine+0.4)*yChar), szBuffer,
									strlen(szBuffer));
								i++;
							}

							// End (single) page
							EndPage(hdcPrn);

							// End printing
							EndDoc(hdcPrn);
						}
						else // Error or print to file cancelled
						{
							;
						}

					// Release device context
						DeleteDC(hdcPrn) ;
					}
					else // hdcPrn==NULL
					{
						;
					}

					// Delete printer logical font
					DeleteObject(hPrnFont);
				}
				break;
				#endif

				// Plot results on screen using GraphiC
				case IDC_RUN_PLOT:
				{
					// Note: Run dlg box buttons are disabled before plotting
					// and reenabled after plotting in the SIGMA_PLOT code
					// of GPCWndProc()

					// Set # of rows of results = # tau values
					sNormSigData.rows=k;
					sModSigData.rows=k;

					// Write all stability plot data to file
					// The sigmadata struct members are as follows:
				    // int points;		Number of sigma data points
					// int rows;		# rows of results = # tau values
				    // float *tau;      Pointer to averaging time data array
				    // float *num;      Pointer to number of data points array
				    // float *sigma;    Pointer to sigma data array
				    // float *ci;       Pointer to confidence interval
					//                  from SIGMA.TAU file
				    // float *sig_min;  Pointer to lower sigma error bar array
				    // float *sig_max;  Pointer to upper sigma error bar array
				    // float *std_dev;  Pointer to standard deviation array
					// float *df;	    Pointer to degrees of freedom array
					// float *falpha;	Alpha as decimal fraction
				    // int *alpha;      Pointer to power-law noise type
					//                  exponent array
				    // int *af;         Pointer to averaging factor array
					// ci is apparently never used anymnore
					// falpha is apparently never used unless WRITEALPHA=1
					// so those items are not included in the file

					// Full path added 05/29/11
					// Don't want to write this file where data read from
					// because may not have write permission to that folder
					// especially if it is on a network drive
					// Compose STAB filename
					strncpy(szBuffer, szPath, BUFFER_SIZE);
					strncat(szBuffer, "STAB.dat", BUFFER_SIZE);
	
					// Open stability data file
					fStab=fopen(szBuffer, "w");

					// Write normal sigma data
					if( nSigmaPlotType==NORMAL_RUN      ||
						nSigmaPlotType==OVERLAPPING_RUN ||
						nSigmaPlotType==TOTAL_RUN       ||
						nSigmaPlotType==BOTH_RUN        ||
						nSigmaPlotType==HADAMARD_RUN    ||
						nSigmaPlotType==TIERMS_RUN      ||
						nSigmaPlotType==MTIE_RUN        ||
						nSigmaPlotType==OVERLAPHAD_RUN  ||
						nSigmaPlotType==HADTOTAL_RUN    ||
						nSigmaPlotType==THEO1_RUN       ||
						nSigmaPlotType==FULL_RUN		||
						nSigmaPlotType==CROSS_RUN) // Added 02/16/10
					{
						for(i=0; i<sNormSigData.rows; i++)
						{
							_snprintf(szBuffer, sizeof(szBuffer),
								"%e %e %e %e %e %e %e %d %d\n",
								sNormSigData.tau[i], sNormSigData.num[i],
								sNormSigData.sigma[i],
								sNormSigData.sig_min[i],
								sNormSigData.sig_max[i],
								sNormSigData.std_dev[i], sNormSigData.df[i],
								sNormSigData.alpha[i], sNormSigData.af[i]);
							fputs(szBuffer, fStab);
						}
					}

					// Write modified stability data
					if(nSigmaPlotType==MODIFIED_RUN   ||
						nSigmaPlotType==TIME_RUN      ||
						nSigmaPlotType==BOTH_RUN      ||
						nSigmaPlotType==MODTOTAL_RUN  ||
						nSigmaPlotType==TIMETOTAL_RUN ||
						nSigmaPlotType==FULL_RUN )
					{
						for(i=0; i<sModSigData.rows; i++)
						{
							_snprintf(szBuffer, sizeof(szBuffer),
								"%e %e %e %e %e %e %e %d %d\n",
								sModSigData.tau[i], sModSigData.num[i],
								sModSigData.sigma[i],
								sModSigData.sig_min[i],
								sModSigData.sig_max[i],
								sModSigData.std_dev[i], sModSigData.df[i],
								sModSigData.alpha[i], sModSigData.af[i]);
							fputs(szBuffer, fStab);
						}
					}

					// Close stability data file
					fclose(fStab);

					// Set sigma type (global)
					nSigmaPlotType=nSigmaType;

					// Set plot window title
					LoadString(hInst, IDS_TITLE_SIGPLOT, TitleString,
						BUFFER_SIZE);
					
					// Create child window for plot
					GPCWINCreate(hChildWnd, hInst, hDlg, SW_SHOWNORMAL,
						&hChildAccel, NULL);
				}
				break;

				// Open plot options dialog box
				case IDC_RUN_OPTIONS:
				{
					// Disable buttons
					EnableWindow(GETHCTL(IDC_RUN_RUN), FALSE);
					EnableWindow(GETHCTL(IDCANCEL), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_PLOT), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_PRINT), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_OPTIONS), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_LINES), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_NOTES), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_REMOVE), FALSE);
					EnableWindow(GETHCTL(IDHELP), FALSE);

					// Set state of global remove drift flag
					bRemove=bRemoveDrift;

					// Open run options dialog box
					InvokeDialogBox(hInst, "SigmaPlotBox", hwndMain,
						(DLGPROC)SigmaPlotDlgProc);

					// Enable buttons
					EnableWindow(GETHCTL(IDC_RUN_RUN), TRUE);
					EnableWindow(GETHCTL(IDCANCEL), TRUE);
					if(bDataValid)
					{
						EnableWindow(GETHCTL(IDC_RUN_PLOT), TRUE);
						EnableWindow(GETHCTL(IDC_RUN_PRINT), TRUE);
						EnableWindow(GETHCTL(IDC_RUN_COPY), TRUE);
					}
					EnableWindow(GETHCTL(IDC_RUN_OPTIONS), TRUE);
					EnableWindow(GETHCTL(IDC_RUN_LINES), TRUE);
					EnableWindow(GETHCTL(IDC_RUN_NOTES), TRUE);
					EnableWindow(GETHCTL(IDC_RUN_REMOVE), TRUE);
					EnableWindow(GETHCTL(IDHELP), TRUE);

					// Give Run dialog box the focus
					SetFocus(hDlg);
				}
				break;

				// Open plot lines dialog box
				case IDC_RUN_LINES:
				{
					// Disable buttons
					EnableWindow(GETHCTL(IDC_RUN_RUN), FALSE);
					EnableWindow(GETHCTL(IDCANCEL), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_PLOT), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_PRINT), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_OPTIONS), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_LINES), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_NOTES), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_REMOVE), FALSE);
					EnableWindow(GETHCTL(IDHELP), FALSE);

					// Open run lines dialog box
					InvokeDialogBox(hInst, "SigmaLineBox", hwndMain,
						(DLGPROC)SigmaLineDlgProc);

					// Enable buttons
					EnableWindow(GETHCTL(IDC_RUN_RUN), TRUE);
					EnableWindow(GETHCTL(IDCANCEL), TRUE);
					if(bDataValid)
					{
						EnableWindow(GETHCTL(IDC_RUN_PLOT), TRUE);
						EnableWindow(GETHCTL(IDC_RUN_PRINT), TRUE);
						EnableWindow(GETHCTL(IDC_RUN_COPY), TRUE);
					}
					EnableWindow(GETHCTL(IDC_RUN_OPTIONS), TRUE);
					EnableWindow(GETHCTL(IDC_RUN_LINES), TRUE);
					EnableWindow(GETHCTL(IDC_RUN_NOTES), TRUE);
					EnableWindow(GETHCTL(IDC_RUN_REMOVE), TRUE);
					EnableWindow(GETHCTL(IDHELP), TRUE);

					// Give Run dialog box the focus
					SetFocus(hDlg);
				}
				break;

				// Open plot notes dialog box
				case IDC_RUN_NOTES:
				{
					// Disable buttons
					EnableWindow(GETHCTL(IDC_RUN_RUN), FALSE);
					EnableWindow(GETHCTL(IDCANCEL), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_PLOT), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_PRINT), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_OPTIONS), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_LINES), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_NOTES), FALSE);
					EnableWindow(GETHCTL(IDC_RUN_REMOVE), FALSE);
					EnableWindow(GETHCTL(IDHELP), FALSE);

					// Open run notes dialog box
					InvokeDialogBox(hInst, "PlotNoteBox", hwndMain,
						(DLGPROC)SigmaNoteDlgProc);

					// Enable buttons
					EnableWindow(GETHCTL(IDC_RUN_RUN), TRUE);
					EnableWindow(GETHCTL(IDCANCEL), TRUE);
					if(bDataValid)
					{
						EnableWindow(GETHCTL(IDC_RUN_PLOT), TRUE);
						EnableWindow(GETHCTL(IDC_RUN_PRINT), TRUE);
						EnableWindow(GETHCTL(IDC_RUN_COPY), TRUE);
					}
					EnableWindow(GETHCTL(IDC_RUN_OPTIONS), TRUE);
					EnableWindow(GETHCTL(IDC_RUN_LINES), TRUE);
					EnableWindow(GETHCTL(IDC_RUN_NOTES), TRUE);
					EnableWindow(GETHCTL(IDC_RUN_REMOVE), TRUE);
					EnableWindow(GETHCTL(IDHELP), TRUE);

					// Give Run dialog box the focus
					SetFocus(hDlg);
				}
				break;

				// Write stability file to disk
				// Use _snprintf() & fputs() instead of fprintf() so that
				// ShortenExp() can be used to give 2-digit exponent
				case IDC_RUN_WRITE:
				{
					// Set file write mode
					// Program initializes bWriteAppend to FALSE
					// so write mode is always "w" 1st time
					// which to purge previous contents
					// Then it can be changed in Run Options dialog
					if(bWriteAppend)
					{
						// Option is "a+" (append)
						strlcpy(szWriteMode, "a+", sizeof(szWriteMode));
					}
					else 
					{
						// Default is "w" (write)
						strlcpy(szWriteMode, "w", sizeof(szWriteMode));
					}

					// Open output file
					if((out=fopen(szStabFile, szWriteMode))==NULL)
					{
						strlcpy(szBuffer, "Can Not Open ", sizeof(szBuffer));
						strlcat(szBuffer, szStabFile, sizeof(szBuffer));
						strlcat(szBuffer, " Output File", sizeof(szBuffer));
						MessageBox(hwndMain, szBuffer, szBoxTitle,
							MB_ICONEXCLAMATION);
					}
					else
					{
						// Everything except dual types
						if(nSigmaType!=BOTH_RUN && nSigmaType!=FULL_RUN)
						{
							// Write table of
							// tau, #, sigma, min sigma, max sigma & df
							if(nSigmaType==MODIFIED_RUN ||
								nSigmaType==TIME_RUN ||
								nSigmaType==MODTOTAL_RUN ||
								nSigmaType==TIMETOTAL_RUN )
							{
								for(j=0; j<sModSigData.points; j++)
								{
									LoadString(hInst, IDS_FORMAT_6, szFormat,
										BUFFER_SIZE);
									_snprintf(szBuffer, sizeof(szBuffer),
										szFormat,
										sModSigData.tau[j],
										sModSigData.num[j],
										sModSigData.sigma[j],
										sModSigData.sig_min[j],
										sModSigData.sig_max[j],
										sNormSigData.df[j]);
									ShortenExp(szBuffer);
									fputs(szBuffer, out);
								}
							}
							
							// Write table of tau, #, sigma & df
							else if(nSigmaType==TIERMS_RUN ||
								nSigmaType==MTIE_RUN)
							{
								for(j=0; j<sNormSigData.points; j++)
								{
									LoadString(hInst, IDS_FORMAT_23, szFormat,
										BUFFER_SIZE);
									_snprintf(szBuffer, sizeof(szBuffer),
										szFormat,
										sNormSigData.tau[j],
										sNormSigData.num[j],
										sNormSigData.sigma[j],
										sNormSigData.df[j]);
									ShortenExp(szBuffer);
									fputs(szBuffer, out);
								}
							}
							
							else // Not mod, time or both sigma,
								 //  or TIErms or MTIE
								 // Write table of tau, #, sigma, min sigma,
								 //  max sigma & df
							{
								for(j=0; j<sNormSigData.points; j++)
								{
									LoadString(hInst, IDS_FORMAT_6, szFormat,
										BUFFER_SIZE);

									// Write alpha instead of max sigma
									if(WRITEALPHA)
									{
										_snprintf(szBuffer, sizeof(szBuffer),
											szFormat,
											sNormSigData.tau[j],
											sNormSigData.num[j],
											sNormSigData.sigma[j],
											sNormSigData.sig_min[j],
											sNormSigData.falpha[j],
											sNormSigData.df[j]);
									}
									else // Normal code
									{
										_snprintf(szBuffer, sizeof(szBuffer),
											szFormat,
											sNormSigData.tau[j],
											sNormSigData.num[j],
											sNormSigData.sigma[j],
											sNormSigData.sig_min[j],
											sNormSigData.sig_max[j],
											sNormSigData.df[j]);
									}
									
									ShortenExp(szBuffer);
									fputs(szBuffer, out);
								}
							}
						}
						// FULL_RUN - Both normal & Tho1 sigma
						else if(nSigmaType==FULL_RUN)
						{
							for(j=0; j<sNormSigData.points; j++)
							{
								// Write table of
								// tau, # for sigma, sigma, Tho1. sig_min,
								// and sig_max
								// Add 2 more fields to format
								strlcpy(szFormat, "%#8.3e  %6.0f   %#8.3e   "
									"%#8.3e   %#8.3e   %#8.3e\n",
									sizeof(szFormat));
								if(sNormSigData.sig_min[j]) // ADEV
								{
									_snprintf(szBuffer, sizeof(szBuffer),
										szFormat,
										sNormSigData.tau[j],
										sNormSigData.num[j],
										sNormSigData.sigma[j],
										sModSigData.sigma[j],
										sNormSigData.sig_min[j],
										sNormSigData.sig_max[j]);
								}
								else // Tho1
								{
									_snprintf(szBuffer, sizeof(szBuffer),
										szFormat,
										sNormSigData.tau[j],
										sNormSigData.num[j],
										sNormSigData.sigma[j],
										sModSigData.sigma[j],
										sModSigData.sig_min[j],
										sModSigData.sig_max[j]);
								}

								ShortenExp(szBuffer);
								fputs(szBuffer, out);
							}
						}
						else // BOTH_RUN - Both normal & mod sigma
						{
							for(j=0; j<sNormSigData.points; j++)
							{
								// Write table of tau, # for sigma, std dev,
								// sigma, mod sigma & df for sigma
								LoadString(hInst, IDS_FORMAT_6, szFormat,
									BUFFER_SIZE);
								_snprintf(szBuffer, sizeof(szBuffer), szFormat,
								sNormSigData.tau[j],
								sNormSigData.num[j],
								sNormSigData.std_dev[j],
								sNormSigData.sigma[j],
								sModSigData.sigma[j],
								sNormSigData.df[j]);
								ShortenExp(szBuffer);
								fputs(szBuffer, out);
							}
						}
					
						fclose(out);                    /* close output file */
					}
				}
				break;

				// Display run error message
				case IDC_RUN_ERROR:
				{
					// Set abort flags
					bAbort=TRUE;
					bYield=TRUE;

					// Display error message
					LoadString(hInst, IDS_MESSAGE_RUNERROR,
						szBuffer, BUFFER_SIZE);
					SetWindowText(GETHCTL(IDC_RUN_DRIFT), szBuffer);
				}
				break;

				// Display zero sigma error message
				case IDC_RUN_ZEROSIG:
				{
					// Set abort flags
					bAbort=TRUE;
					bYield=TRUE;

					// Display error message
					LoadString(hInst, IDS_MESSAGE_ZERORUNSIG, szBuffer,
						BUFFER_SIZE);
					MessageBox(hDlg, szBuffer, szBoxTitle, MB_ICONEXCLAMATION);
				}
				break;

				case IDC_RUN_SETSTOP:
				{
					// Set nStopRatio
					if(nSigmaType==NORMAL_RUN || nSigmaType==HADAMARD_RUN)
					{
						nStopRatio=5;
					}
					else if(nSigmaType==HADTOTAL_RUN)
					{
						nStopRatio=3;
					}
					else if(nSigmaType==TOTAL_RUN)
					{
						nStopRatio=2;
					}
					else if( (nSigmaType==MODTOTAL_RUN) ||
							 (nSigmaType==TIMETOTAL_RUN) )
					{
						nStopRatio=3;
					}
					
					// In principle, could go down to nearly 1
					// but, as int, must stop at 2
					else if(nSigmaType==MTIE_RUN)
					{
						nStopRatio=2;
					}
					// Tho1 can go all the way down to 1
					else if(nSigmaType==THEO1_RUN || nSigmaType==FULL_RUN)
					{
						nStopRatio=1;
					}
					else // Other sigma types
					{
						nStopRatio=4;
					}
				}
				break;

				case IDC_RUN_STOP:
				case IDCANCEL:
				{
					// Check if Clear button pressed
					GetWindowText(GETHCTL(IDCANCEL), szBuffer, BUFFER_SIZE);
					if((strcmp(szBuffer, "&Clear"))==0)
					{
						// Clear results
						// Note: This also clears bStop
						// and changes Resume button back to Calc
						// and changes Clear button back to Close 
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RUN_CLEAR, NULL, 0));

						// That's all we want to do
						break;
					}
					
					// Set abort flag if we are yielding
					bAbort=bYield;

					// Set global run sigma type to local value
					nGlobalRunType=nSigmaType;

					// If freq data & have corresponding phase data
					// restore the analysis limits of the phase data
					if( (bDataType==FREQ_DATA) && (bSynch) )
					{
						fPhaseData[1]=fSavePhaseStart;
						fPhaseData[2]=fSavePhaseEnd;
					}

					// Note: Data array freed later if we are aborting
					if(!bAbort)
					{
						// Restore data
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RUN_RESTORE, NULL, 0));

						// Free temporary data array
						free(fTempData);

						// Clear data valid flag
						bDataValid=FALSE;

						// Clear stop flag;
						bStop=FALSE;

						// Clear have Tho1 bias flag
						bHaveTheo1Bias==FALSE;

						// Close Run dialog box
						EndDialog(hDlg, 0);
						return TRUE;
					}
					else // Abort - but keep what results were done
					{
						// Set stop flag to indicate current run was stopped
						bStop=TRUE;

						// Change Calc button to Restart or Resume
						if(nSigmaType==MTIE_RUN && bAllTau)
						{
							SetWindowText(GETHCTL(IDC_RUN_RUN), "&Restart");
						}
						else
						{
							SetWindowText(GETHCTL(IDC_RUN_RUN), "&Resume");
						}

						// Change Stop (Close) button to Clear 
						SetWindowText(GETHCTL(IDCANCEL), "&Clear");

						// Quit if only 1 row of data - can't plot - must close
						if(k==1)
						{
							break;
						}

						// Must manually set k to # fast method MTIE points
						if(nSigmaType==MTIE_RUN && bAllTau)
						{
							k=sNormSigData.points;
						}
						
						sNormSigData.points=k;         /* # stability points */
						sModSigData.points=k;          /* # stability points */
						nRows=k-1;                     /* ditto for printing */

						// Display drift
						LoadString(hInst, IDS_FORMAT_9, szFormat, BUFFER_SIZE);
						_snprintf(szBuffer, sizeof(szBuffer), szFormat,
							fDrift);
						ShortenExp(szBuffer);

						if(bRemoveDrift)
						{
							strlcat(szBuffer, " (Removed)", sizeof(szBuffer));
						}

						if(bShowDrift)
						{
							SetWindowText(GETHCTL(IDC_RUN_DRIFT), szBuffer);
						}

						// Set data valid flag
						bDataValid=TRUE;

						// Set plot button state
						// Need at least 2 stability points to do plot
						if(k>1)
						{
							EnableWindow(GETHCTL(IDC_RUN_PLOT), bDataValid);
						}

						// Set print button state
						// Don't allow print in all tau case unless fast MTIE
						// Unless it is a MTIE run
						// Added MTIE test 01/28/01
						if(!bAllTau || nSigmaType==MTIE_RUN)
						{
							EnableWindow(GETHCTL(IDC_RUN_PRINT), bDataValid);
							EnableWindow(GETHCTL(IDC_RUN_COPY), bDataValid);
						}

						// Restore data
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_RUN_RESTORE, NULL, 0));

						// Free temporary data array
						// free(fTempData); // Not wanted

						// Note:  This is where we want to do sigma plot
						// initializations - after a new sigma calc and before
						// the following Options, Lines or Notes entries.

						// Initialize sigma plot parameters
						InitSigmaPlotParams();

						// Calc sigma plot scale
						// Uses sigma-tau values in sModSigData or sNormSigData
						// (depending on nSigmaPlotType)
						// to fill in sigma plot scale limits
						// into sSPlot elements
						// x_min, x_max, y_min and y_max
						// Return value of # sigma plot points not used
						CalcSigmaPlotScale();

						// Reenable controls
						EnableWindow(GETHCTL(IDC_RUN_RUN), TRUE);
						EnableWindow(GETHCTL(IDC_RUN_OPTIONS), TRUE);
						EnableWindow(GETHCTL(IDC_RUN_LINES), TRUE);
						EnableWindow(GETHCTL(IDC_RUN_NOTES), TRUE);
						EnableWindow(GETHCTL(IDHELP), TRUE);
						EnableWindow(GETHCTL(IDC_RUN_TYPE), TRUE);
						EnableWindow(GETHCTL(IDC_RUN_CF), TRUE);
						EnableWindow(GETHCTL(IDC_RUN_REMOVE), TRUE);
						EnableWindow(GETHCTL(IDC_RUN_DECADE), TRUE);
						EnableWindow(GETHCTL(IDC_RUN_OCTAVE), TRUE);
						EnableWindow(GETHCTL(IDC_RUN_ALLTAU), TRUE);
						EnableWindow(GETHCTL(IDC_RUN_1OF2), TRUE);
						EnableWindow(GETHCTL(IDC_RUN_ALPHA), TRUE);

						if(bWriteSigmaFile)
						{
							// Write stability data file to disk
							SendMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDC_RUN_WRITE, NULL, 0));
						}

						// Display normal cursor
						SetCursor(hArrow);

						// Give focus to plot pushbutton
						SetFocus(GETHCTL(IDC_RUN_PLOT));
					}
				}
				break;
			}
		}
		break;
	 }
	 return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*                            GetRunData()                                   */
/*                                                                           */
/*      Function to put stability data point into row of Run table           */
/*                                                                           */
/*      There is a VMSTRUCT inside the DataTable control.  It contains the   */
/*      elements nStatus, dwKey and lpData.  A pointer to it is passed to    */
/*      us via the lParam of each DTM message.  We assign this to a          */
/*      LPVMSTRUCT pointer called lpVMData.  We then compose a single        */
/*      formatted string with the af, tau, num, alpha, sig_min, sigma and    */
/*		sig_max data for 1 row of the stability data table:                  */
/*                                                                           */
/*      We use dwKey to access our sigmadata structure to get one row of     */
/*      stability data.  The relevant sigmadata items are:                   */
/*                                                                           */
/*          int points;                       Number of sigma data points    */
/*          float tau[SIGMA_SIZE];            Averaging time data array      */
/*          float num[SIGMA_SIZE];            Number of data points array    */
/*          float sigma[SIGMA_SIZE];          Sigma data array               */
/*          float sig_min[SIGMA_SIZE];        Lower sigma error bar array    */
/*          float sig_max[SIGMA_SIZE];        Upper sigma error bar array    */
/*          int af[SIGMA_SIZE];               Averaging factor array         */
/*          int alpha[SIGMA_SIZE];            Alpha array                    */
/*                                                                           */
/*      The Run funct uses the global sNormSigData and sModSigdata structs   */
/*                                                                           */
/*      The local variables lpRowData and nRow are passed via the LPVMSTRUCT */
/*      parameter lpVMData.  They are then obtained as (SIGROWSTRUCT *)      */
/*      lpVMData->lpData and lpVMData->dwKey.                                */
/*                                                                           */
/*      Parameter:                                                           */
/*          LPVMSTRUCT  lpVMData        Pointer to row info structure:       */
/*                                          int nStatus      error code      */
/*                                          DWORD dwKey      data row #      */
/*                                          LPVOID lpData    row data string */
/*                                                                           */
/*      Revision record:                                                     */
/*          07/19/97    Cloned from GetSigmaData() of Read function          */
/*			11/27/97	Fixed error in display of all tau mod & time sigma   */
/*			01/16/98	Added calls to ShortenExp() to elim 3-digit exps     */
/*			01/17/98	Changed # points format from 5d to 6d                */
/*			03/16/98	Changed AF format from 5d to 6d                      */
/*			06/04/98	Added display for TIE rms and MTIE                   */
/*          09/25/98    Changed # points format from 6d to 7d                */
/*			03/13/99	Added provisions for overlapping Hadamard deviation  */
/*			12/25/99	Added provisions for Mod Totvar                      */
/*			10/29/00	Added provisions for Hadamard Totvar                 */
/*			02/09/00	Added provisions for Tho1                           */
/*			02/09/00	Added provisions for Overlapping & Tho1             */
/*			03/25/03	Changed FULL_RUN columns                             */
/*			05/11/03	Changed Tho1 columns to show min & max              */
/*			07/13/03	Added display of alpha for Overlapping & Tho1       */
/*			07/23/07	Added nRunTableChars for _snprintf() usage           */
/*			08/23/08	Added options to handle large af and num             */
/*                                                                           */
/*****************************************************************************/

int WINAPI GetRunData(LPVMSTRUCT lpVMData)
{
	// Local variables
	// The maximum allowable # of chars that can be put into the Run table
	// is the sum of the # chars in each of its columns
	// Four extra chars are needed for full display of last column
	// because each e format field needs 1 more character
	// for its 3-digit exponent before it is shortened
	int nRunTableChars=RUN_NUM_AF_CHARS + RUN_NUM_TAU_CHARS +
		RUN_NUM_NUM_CHARS + RUN_NUM_ALPHA_CHARS + RUN_NUM_MIN_CHARS +
		RUN_NUM_SIG_CHARS +	RUN_NUM_MAX_CHARS +RUN_NUM_EXTRA_CHARS;
	// Alias for table data pointer (just to simplify code)
	LPSTR szRowData=lpVMData->lpData;
	// Alias for table row # (just to simplify code)
	int nRow=(int)lpVMData->dwKey;

	// 07/24/07 Note: format for min, nominal & max sigma changed from 11.4e
	// to 10.4e to agree with # col chars
	
	if(nSigmaPlotType==MODIFIED_RUN || nSigmaPlotType==TIME_RUN ||
		nSigmaPlotType==MODTOTAL_RUN || nSigmaPlotType==TIMETOTAL_RUN )
	{
		// Check that row # is valid
		// Row # starts at 0 and goes up to # points-1
		if(nRow<0 || nRow>=sModSigData.points)
		{
			// Return error code
			return (int)DTE_ROWOUTOFRANGE;
		}

		if(sModSigData.num[nRow]<1e7) // Will num fit as %7d 7-digit int format?
		{
			if(sModSigData.af[nRow]<1000000) // Will af fit as %d 6-digit int format?
			{
				// Show all columns if either or both min & max data is non-zero
				if((sModSigData.sig_min[nRow]) || (sModSigData.sig_min[nRow]) )
				{
					// Load row data into string for display in table
					_snprintf(szRowData, nRunTableChars,
						"%6d%10.4e%7d%5d%10.4e%10.4e%10.4e",
						sModSigData.af[nRow], sModSigData.tau[nRow],
						(int)sModSigData.num[nRow], sModSigData.alpha[nRow],
						sModSigData.sig_min[nRow], sModSigData.sigma[nRow],
						sModSigData.sig_max[nRow]);
					ShortenExp(szRowData);
				}
				else // Put blanks in min & max sigma fields
				{
				   _snprintf(szRowData, nRunTableChars,
					   "%6d%10.4e%7d%5d          %10.4e           ",
						sModSigData.af[nRow], sModSigData.tau[nRow],
						(int)sModSigData.num[nRow], sModSigData.alpha[nRow],
						sModSigData.sigma[nRow]);
					ShortenExp(szRowData);
				}
			}
			else // Show af as %#6.0e exp format (# forces dp)
			{
				// Show all columns if either or both min & max data is non-zero
				if((sModSigData.sig_min[nRow]) || (sModSigData.sig_min[nRow]) )
				{
					// Load row data into string for display in table
					_snprintf(szRowData, nRunTableChars,
						"%#6.0e%10.4e%7d%5d%10.4e%10.4e%10.4e",
						(double)sModSigData.af[nRow], sModSigData.tau[nRow],
						(int)sModSigData.num[nRow], sModSigData.alpha[nRow],
						sModSigData.sig_min[nRow], sModSigData.sigma[nRow],
						sModSigData.sig_max[nRow]);
					ShortenExp(szRowData);
				}
				else // Put blanks in min & max sigma fields
				{
				   _snprintf(szRowData, nRunTableChars,
					   "%#6.0e%10.4e%7d%5d          %10.4e           ",
						(double)sModSigData.af[nRow], sModSigData.tau[nRow],
						(int)sModSigData.num[nRow], sModSigData.alpha[nRow],
						sModSigData.sigma[nRow]);
					ShortenExp(szRowData);
				}
			}
		}
		else // Show num as %#7.1e exp format (# forces dp)
		{
			if(sModSigData.af[nRow]<1000000) // Will af fit as %d 6-digit int format?
			{
				// Show all columns if either or both min & max data is non-zero
				if((sModSigData.sig_min[nRow]) || (sModSigData.sig_min[nRow]) )
				{
					// Load row data into string for display in table
					_snprintf(szRowData, nRunTableChars,
						"%6d%10.4e%#7.1e%5d%10.4e%10.4e%10.4e",
						sModSigData.af[nRow], sModSigData.tau[nRow],
						sModSigData.num[nRow], sModSigData.alpha[nRow],
						sModSigData.sig_min[nRow], sModSigData.sigma[nRow],
						sModSigData.sig_max[nRow]);
					ShortenExp(szRowData);
				}
				else // Put blanks in min & max sigma fields
				{
				   _snprintf(szRowData, nRunTableChars,
					   "%6d%10.4e%#7.1e%5d          %10.4e           ",
						sModSigData.af[nRow], sModSigData.tau[nRow],
						sModSigData.num[nRow], sModSigData.alpha[nRow],
						sModSigData.sigma[nRow]);
					ShortenExp(szRowData);
				}
			}
			else // Show af as %#6.0e exp format (# forces dp)
			{
				// Show all columns if either or both min & max data is non-zero
				if((sModSigData.sig_min[nRow]) || (sModSigData.sig_min[nRow]) )
				{
					// Load row data into string for display in table
					_snprintf(szRowData, nRunTableChars,
						"%#6.0e%10.4e%#7.1e%5d%10.4e%10.4e%10.4e",
						(double)sModSigData.af[nRow], sModSigData.tau[nRow],
						sModSigData.num[nRow], sModSigData.alpha[nRow],
						sModSigData.sig_min[nRow], sModSigData.sigma[nRow],
						sModSigData.sig_max[nRow]);
					ShortenExp(szRowData);
				}
				else // Put blanks in min & max sigma fields
				{
				   _snprintf(szRowData, nRunTableChars,
					   "%#6.0e%10.4e%#7.1e%5d          %10.4e           ",
						(double)sModSigData.af[nRow], sModSigData.tau[nRow],
						sModSigData.num[nRow], sModSigData.alpha[nRow],
						sModSigData.sigma[nRow]);
					ShortenExp(szRowData);
				}
			}
		}
	}

	if(nSigmaPlotType==NORMAL_RUN  || nSigmaPlotType==OVERLAPPING_RUN ||
		nSigmaPlotType==TOTAL_RUN  || nSigmaPlotType==HADAMARD_RUN    ||
		nSigmaPlotType==OVERLAPHAD_RUN || nSigmaPlotType==HADTOTAL_RUN ||
		nSigmaPlotType==CROSS_RUN)
	{
		// Check that row # is valid
		// Row # starts at 0 and goes up to # points-1
		if(nRow<0 || nRow>=sNormSigData.points)
		{
			// Return error code
			return (int) DTE_ROWOUTOFRANGE;
		}

		if(sNormSigData.num[nRow]<1e7) // Will num fit as %7d 7-digit int format?
		{
			if(sNormSigData.af[nRow]<1000000) // Will af fit as %d 6-digit int format?
			{
				// Show all columns if either or both min & max data is non-zero
				if((sNormSigData.sig_min[nRow]) || (sNormSigData.sig_max[nRow]) )
				{
					// Load row data into string for display in table
					_snprintf(szRowData, nRunTableChars,
					   "%6d%10.4e%7d%5d%10.4e%10.4e%10.4e",
						sNormSigData.af[nRow], sNormSigData.tau[nRow],
						(int)sNormSigData.num[nRow], sNormSigData.alpha[nRow],
						sNormSigData.sig_min[nRow], sNormSigData.sigma[nRow],
						sNormSigData.sig_max[nRow]);
					ShortenExp(szRowData);
				}
				else // Put blanks in min & max sigma fields
				{
					_snprintf(szRowData, nRunTableChars,
						"%6d%10.4e%7d%5d          %10.4e           ",
						sNormSigData.af[nRow], sNormSigData.tau[nRow],
						(int)sNormSigData.num[nRow], sNormSigData.alpha[nRow],
						sNormSigData.sigma[nRow]);
					ShortenExp(szRowData);
				}
			}
			else // Show af as %#6.0e exp format (# forces dp)
			{
				// Show all columns if either or both min & max data is non-zero
				if((sNormSigData.sig_min[nRow]) || (sNormSigData.sig_max[nRow]) )
				{
					// Load row data into string for display in table
					_snprintf(szRowData, nRunTableChars,
					   "%#6.0e%10.4e%7d%5d%10.4e%10.4e%10.4e",
						(double)sNormSigData.af[nRow], sNormSigData.tau[nRow],
						(int)sNormSigData.num[nRow], sNormSigData.alpha[nRow],
						sNormSigData.sig_min[nRow], sNormSigData.sigma[nRow],
						sNormSigData.sig_max[nRow]);
					ShortenExp(szRowData);
				}
				else // Put blanks in min & max sigma fields
				{
					_snprintf(szRowData, nRunTableChars,
						"%#6.0e%10.4e%7d%5d          %10.4e           ",
						(double)sNormSigData.af[nRow], sNormSigData.tau[nRow],
						(int)sNormSigData.num[nRow], sNormSigData.alpha[nRow],
						sNormSigData.sigma[nRow]);
					ShortenExp(szRowData);
				}
			}
		}
		else // Show num as %#7.1e exp format (# forces dp)
		{
			if(sNormSigData.af[nRow]<1000000) // Will af fit as %d 6-digit int format?
			{
				// Show all columns if either or both min & max data is non-zero
				if((sNormSigData.sig_min[nRow]) || (sNormSigData.sig_max[nRow]) )
				{
					// Load row data into string for display in table
					_snprintf(szRowData, nRunTableChars,
					   "%6d%10.4e%#7.1e%5d%10.4e%10.4e%10.4e",
						sNormSigData.af[nRow], sNormSigData.tau[nRow],
						sNormSigData.num[nRow], sNormSigData.alpha[nRow],
						sNormSigData.sig_min[nRow], sNormSigData.sigma[nRow],
						sNormSigData.sig_max[nRow]);
					ShortenExp(szRowData);
				}
				else // Put blanks in min & max sigma fields
				{
					_snprintf(szRowData, nRunTableChars,
						"%6d%10.4e%#7.1e%5d          %10.4e           ",
						sNormSigData.af[nRow], sNormSigData.tau[nRow],
						sNormSigData.num[nRow], sNormSigData.alpha[nRow],
						sNormSigData.sigma[nRow]);
					ShortenExp(szRowData);
				}
			}
			else // Show af as %#6.0e exp format (# forces dp)
			{
				// Show all columns if either or both min & max data is non-zero
				if((sNormSigData.sig_min[nRow]) || (sNormSigData.sig_max[nRow]) )
				{
					// Load row data into string for display in table
					_snprintf(szRowData, nRunTableChars,
					   "%#6.0e%10.4e%#7.1e%5d%10.4e%10.4e%10.4e",
						(double)sNormSigData.af[nRow], sNormSigData.tau[nRow],
						sNormSigData.num[nRow], sNormSigData.alpha[nRow],
						sNormSigData.sig_min[nRow], sNormSigData.sigma[nRow],
						sNormSigData.sig_max[nRow]);
					ShortenExp(szRowData);
				}
				else // Put blanks in min & max sigma fields
				{
					_snprintf(szRowData, nRunTableChars,
						"%#6.0e%10.4e%#7.1e%5d          %10.4e           ",
						(double)sNormSigData.af[nRow], sNormSigData.tau[nRow],
						sNormSigData.num[nRow], sNormSigData.alpha[nRow],
						sNormSigData.sigma[nRow]);
					ShortenExp(szRowData);
				}
			}
		}
	}

	if(nSigmaPlotType==TIERMS_RUN || nSigmaPlotType==MTIE_RUN)
	{
		// Check that row # is valid
		// Row # starts at 0 and goes up to # points-1
		if(nRow<0 || nRow>=sNormSigData.points)
		{
			// Return error code
			return (int) DTE_ROWOUTOFRANGE;
		}

		if(sNormSigData.num[nRow]<1e7) // Will num fit as %7d 7-digit int format?
		{
			if(sNormSigData.af[nRow]<1000000) // Will af fit as %d 6-digit int format?
			{
				// Load row data into string for display in table
				// Put blanks in alpha, min & max sigma fields
				_snprintf(szRowData, nRunTableChars,
					"%6d%10.4e%7d               %10.4e           ",
					sNormSigData.af[nRow], sNormSigData.tau[nRow],
					(int)sNormSigData.num[nRow], sNormSigData.sigma[nRow]);
				ShortenExp(szRowData);
			}
			else // Show af as %#6.0e exp format (# forces dp)
			{
				// Load row data into string for display in table
				// Put blanks in alpha, min & max sigma fields
				_snprintf(szRowData, nRunTableChars,
					"%#6.0e%10.4e%7d               %10.4e           ",
					(double)sNormSigData.af[nRow], sNormSigData.tau[nRow],
					(int)sNormSigData.num[nRow], sNormSigData.sigma[nRow]);
				ShortenExp(szRowData);
			}
		}
		else // Show num as %#7.1e exp format (# forces dp)
		{
			if(sNormSigData.af[nRow]<1000000) // Will af fit as %d 6-digit int format?
			{
				// Load row data into string for display in table
				// Put blanks in alpha, min & max sigma fields
				_snprintf(szRowData, nRunTableChars,
					"%6d%10.4e%#7.1e               %10.4e           ",
					sNormSigData.af[nRow], sNormSigData.tau[nRow],
					sNormSigData.num[nRow], sNormSigData.sigma[nRow]);
				ShortenExp(szRowData);
			}
			else // Show af as %#6.0e exp format (# forces dp)
			{
				// Load row data into string for display in table
				// Put blanks in alpha, min & max sigma fields
				_snprintf(szRowData, nRunTableChars,
					"%#6.0e%10.4e%#7.1e               %10.4e           ",
					(double)sNormSigData.af[nRow], sNormSigData.tau[nRow],
					sNormSigData.num[nRow], sNormSigData.sigma[nRow]);
				ShortenExp(szRowData);
			}
		}
	}

	if(nSigmaPlotType==THEO1_RUN)
	{
		// Check that row # is valid
		// Row # starts at 0 and goes up to # points-1
		if(nRow<0 || nRow>=sNormSigData.points)
		{
			// Return error code
			return (int) DTE_ROWOUTOFRANGE;
		}

		if(sNormSigData.num[nRow]<1e7) // Will num fit as %7d 7-digit int format?
		{
			if(sNormSigData.af[nRow]<1000000) // Will af fit as %d 6-digit int format?
			{
				// Show all columns if either or both min & max data is non-zero
				if((sNormSigData.sig_min[nRow]) || (sNormSigData.sig_max[nRow]) )
				{
					// Load row data into string for display in table
					// Fields are:
					// AF, Tho1 Tau, #, Alpha, Min Tho1, Tho1 Dev & Max Tho1
					_snprintf(szRowData, nRunTableChars,
						"%6d%10.4e%7d%5d%10.4e%10.4e%10.4e",
						sNormSigData.af[nRow], sNormSigData.tau[nRow],
						(int)sNormSigData.num[nRow], sNormSigData.alpha[nRow],
						sNormSigData.sig_min[nRow], sNormSigData.sigma[nRow],
						sNormSigData.sig_max[nRow]);
				}
				else // Put blanks in min & max sigma fields
				{
					// Load row data into string for display in table
					// Fields are:
					// AF, Tho1 Tau, #, Alpha, Blank, Tho1 Dev & Blank

					_snprintf(szRowData, nRunTableChars,
						"%6d%10.4e%7d%5d          %10.4e           ",
						sNormSigData.af[nRow], sNormSigData.tau[nRow],
						(int)sNormSigData.num[nRow], sNormSigData.alpha[nRow],
						sNormSigData.sigma[nRow]);
				}
				ShortenExp(szRowData);
			}
			else // Show af as %#6.0e exp format (# forces dp)
			{
				// Show all columns if either or both min & max data is non-zero
				if((sNormSigData.sig_min[nRow]) || (sNormSigData.sig_max[nRow]) )
				{
					// Load row data into string for display in table
					// Fields are:
					// AF, Tho1 Tau, #, Alpha, Min Tho1, Tho1 Dev & Max Tho1
					_snprintf(szRowData, nRunTableChars,
						"%#6.0e%10.4e%7d%5d%10.4e%10.4e%10.4e",
						(double)sNormSigData.af[nRow], sNormSigData.tau[nRow],
						(int)sNormSigData.num[nRow], sNormSigData.alpha[nRow],
						sNormSigData.sig_min[nRow], sNormSigData.sigma[nRow],
						sNormSigData.sig_max[nRow]);
				}
				else // Put blanks in min & max sigma fields
				{
					// Load row data into string for display in table
					// Fields are:
					// AF, Tho1 Tau, #, Alpha, Blank, Tho1 Dev & Blank

					_snprintf(szRowData, nRunTableChars,
						"%#6.0e%10.4e%7d%5d          %10.4e           ",
						(double)sNormSigData.af[nRow], sNormSigData.tau[nRow],
						(int)sNormSigData.num[nRow], sNormSigData.alpha[nRow],
						sNormSigData.sigma[nRow]);
				}
				ShortenExp(szRowData);
			}
		}
		else // Show num as %#7.1e exp format (# forces dp)
		{
			if(sNormSigData.af[nRow]<1000000) // Will af fit as %d 6-digit int format?
			{
				// Show all columns if either or both min & max data is non-zero
				if((sNormSigData.sig_min[nRow]) || (sNormSigData.sig_max[nRow]) )
				{
					// Load row data into string for display in table
					// Fields are:
					// AF, Tho1 Tau, #, Alpha, Min Tho1, Tho1 Dev & Max Tho1
					_snprintf(szRowData, nRunTableChars,
						"%6d%10.4e%#7.1e%5d%10.4e%10.4e%10.4e",
						sNormSigData.af[nRow], sNormSigData.tau[nRow],
						sNormSigData.num[nRow], sNormSigData.alpha[nRow],
						sNormSigData.sig_min[nRow], sNormSigData.sigma[nRow],
						sNormSigData.sig_max[nRow]);
				}
				else // Put blanks in min & max sigma fields
				{
					// Load row data into string for display in table
					// Fields are:
					// AF, Tho1 Tau, #, Alpha, Blank, Tho1 Dev & Blank

					_snprintf(szRowData, nRunTableChars,
						"%6d%10.4e%#7.1e%5d          %10.4e           ",
						sNormSigData.af[nRow], sNormSigData.tau[nRow],
						sNormSigData.num[nRow], sNormSigData.alpha[nRow],
						sNormSigData.sigma[nRow]);
				}
				ShortenExp(szRowData);
			}
			else // Show af as %#6.0e exp format (# forces dp)
			{
				// Show all columns if either or both min & max data is non-zero
				if((sNormSigData.sig_min[nRow]) || (sNormSigData.sig_max[nRow]) )
				{
					// Load row data into string for display in table
					// Fields are:
					// AF, Tho1 Tau, #, Alpha, Min Tho1, Tho1 Dev & Max Tho1
					_snprintf(szRowData, nRunTableChars,
						"%#6.0e%10.4e%#7.1e%5d%10.4e%10.4e%10.4e",
						(double)sNormSigData.af[nRow], sNormSigData.tau[nRow],
						sNormSigData.num[nRow], sNormSigData.alpha[nRow],
						sNormSigData.sig_min[nRow], sNormSigData.sigma[nRow],
						sNormSigData.sig_max[nRow]);
				}
				else // Put blanks in min & max sigma fields
				{
					// Load row data into string for display in table
					// Fields are:
					// AF, Tho1 Tau, #, Alpha, Blank, Tho1 Dev & Blank

					_snprintf(szRowData, nRunTableChars,
						"%#6.0e%10.4e%#7.1e%5d          %10.4e           ",
						(double)sNormSigData.af[nRow], sNormSigData.tau[nRow],
						sNormSigData.num[nRow], sNormSigData.alpha[nRow],
						sNormSigData.sigma[nRow]);
				}
				ShortenExp(szRowData);
			}
		}
	}

	if(nSigmaPlotType==BOTH_RUN)
	{
		// Check that row # is valid
		// Row # starts at 0 and goes up to # points-1
		if(nRow<0 || nRow>=sModSigData.points)
		{
			// Return error code
			return (int) DTE_ROWOUTOFRANGE;
		}

		if(sNormSigData.num[nRow]<1e7) // Will num fit as %7d 7-digit int format?
		{
			if(sNormSigData.af[nRow]<1000000) // Will af fit as %d 6-digit int format?
			{
				// Load row data into string for display in table
				_snprintf(szRowData, nRunTableChars,
					"%6d%10.4e%7d%5d%10.4e%10.4e%10.4e",
					sNormSigData.af[nRow], sNormSigData.tau[nRow],
					(int)sNormSigData.num[nRow], sNormSigData.alpha[nRow],
					sNormSigData.std_dev[nRow], sNormSigData.sigma[nRow],
					sModSigData.sigma[nRow]);
				ShortenExp(szRowData);
			}
			else // Show af as %#6.0e exp format (# forces dp)
			{
				// Load row data into string for display in table
				_snprintf(szRowData, nRunTableChars,
					"%#6.0e%10.4e%7d%5d%10.4e%10.4e%10.4e",
					(double)sNormSigData.af[nRow], sNormSigData.tau[nRow],
					(int)sNormSigData.num[nRow], sNormSigData.alpha[nRow],
					sNormSigData.std_dev[nRow], sNormSigData.sigma[nRow],
					sModSigData.sigma[nRow]);
				ShortenExp(szRowData);
			}
		}
		else // Show num as %#7.1e exp format (# forces dp)
		{
			if(sNormSigData.af[nRow]<1000000) // Will af fit as %d 6-digit int format?
			{
				// Load row data into string for display in table
				_snprintf(szRowData, nRunTableChars,
					"%6d%10.4e%#7.1e%5d%10.4e%10.4e%10.4e",
					sNormSigData.af[nRow], sNormSigData.tau[nRow],
					sNormSigData.num[nRow], sNormSigData.alpha[nRow],
					sNormSigData.std_dev[nRow], sNormSigData.sigma[nRow],
					sModSigData.sigma[nRow]);
				ShortenExp(szRowData);
			}
			else // Show af as %#6.0e exp format (# forces dp)
			{
				// Load row data into string for display in table
				_snprintf(szRowData, nRunTableChars,
					"%#6.0e%10.4e%#7.1e%5d%10.4e%10.4e%10.4e",
					(double)sNormSigData.af[nRow], sNormSigData.tau[nRow],
					sNormSigData.num[nRow], sNormSigData.alpha[nRow],
					sNormSigData.std_dev[nRow], sNormSigData.sigma[nRow],
					sModSigData.sigma[nRow]);
				ShortenExp(szRowData);
			}
		}
	}

	if(nSigmaPlotType==FULL_RUN)
	{
		// Check that row # is valid
		// Row # starts at 0 and goes up to # points-1
		if(nRow<0 || nRow>=sModSigData.points)
		{
			// Return error code
			return (int) DTE_ROWOUTOFRANGE;
		}

		if(sNormSigData.num[nRow]<1e7) // Will num fit as %7d 7-digit int format?
		{
			if(sNormSigData.af[nRow]<1000000) // Will af fit as %d 6-digit int format?
			{
				if(sNormSigData.num[nRow] && sModSigData.num[nRow])
				{
					// Load row data into string for display in table
					// Fields are:
					// AF, Sigma Tau, Sigma #, Alpha, Tho1 Tau, Sigma, Tho1 Dev
					_snprintf(szRowData, nRunTableChars,
						"%6d%10.4e%7d%5d%10.4e%10.4e%10.4e",
						sNormSigData.af[nRow], sNormSigData.tau[nRow],
						(int)sNormSigData.num[nRow], sModSigData.alpha[nRow],
						sModSigData.tau[nRow], sNormSigData.sigma[nRow],
						sModSigData.sigma[nRow]);
					ShortenExp(szRowData);
				}
				else if(sNormSigData.num[nRow]) // Just sigma data
				{
					// Load row data into string for display in table
					_snprintf(szRowData, nRunTableChars,
						"%6d%10.4e%7d%5d          %10.4e",
						sNormSigData.af[nRow], sNormSigData.tau[nRow],
						(int)sNormSigData.num[nRow], sNormSigData.alpha[nRow],
						sNormSigData.sigma[nRow]);
					ShortenExp(szRowData);
				}
				else if(sModSigData.num[nRow]) // Just Tho1 data
				{
					// Load row data into string for display in table
					_snprintf(szRowData, nRunTableChars,
						"%6d                 %5d%10.4e          %10.4e",
						sNormSigData.af[nRow], sModSigData.alpha[nRow],
						sModSigData.tau[nRow], sModSigData.sigma[nRow]);
					ShortenExp(szRowData);
				}
			}
			else // Show af as %#6.0e exp format (# forces dp)
			{
				if(sNormSigData.num[nRow] && sModSigData.num[nRow])
				{
					// Load row data into string for display in table
					// Fields are:
					// AF, Sigma Tau, Sigma #, Alpha, Tho1 Tau, Sigma, Tho1 Dev
					_snprintf(szRowData, nRunTableChars,
						"%#6.0e%10.4e%7d%5d%10.4e%10.4e%10.4e",
						(double)sNormSigData.af[nRow], sNormSigData.tau[nRow],
						(int)sNormSigData.num[nRow], sModSigData.alpha[nRow],
						sModSigData.tau[nRow], sNormSigData.sigma[nRow],
						sModSigData.sigma[nRow]);
					ShortenExp(szRowData);
				}
				else if(sNormSigData.num[nRow]) // Just sigma data
				{
					// Load row data into string for display in table
					_snprintf(szRowData, nRunTableChars,
						"%#6.0e%10.4e%7d%5d          %10.4e",
						(double)sNormSigData.af[nRow], sNormSigData.tau[nRow],
						(int)sNormSigData.num[nRow], sNormSigData.alpha[nRow],
						sNormSigData.sigma[nRow]);
					ShortenExp(szRowData);
				}
				else if(sModSigData.num[nRow]) // Just Tho1 data
				{
					// Load row data into string for display in table
					_snprintf(szRowData, nRunTableChars,
						"%#6.0e                 %5d%10.4e          %10.4e",
						(double)sNormSigData.af[nRow], sModSigData.alpha[nRow],
						sModSigData.tau[nRow], sModSigData.sigma[nRow]);
					ShortenExp(szRowData);
				}
			}
		}
		else // Show num as %#7.1e exp format (# forces dp)
		{
			if(sNormSigData.af[nRow]<1000000) // Will af fit as %d 6-digit int format?
			{
				if(sNormSigData.num[nRow] && sModSigData.num[nRow])
				{
					// Load row data into string for display in table
					// Fields are:
					// AF, Sigma Tau, Sigma #, Alpha, Tho1 Tau, Sigma, Tho1 Dev
					_snprintf(szRowData, nRunTableChars,
						"%6d%10.4e%#7.1e%5d%10.4e%10.4e%10.4e",
						sNormSigData.af[nRow], sNormSigData.tau[nRow],
						sNormSigData.num[nRow], sModSigData.alpha[nRow],
						sModSigData.tau[nRow], sNormSigData.sigma[nRow],
						sModSigData.sigma[nRow]);
					ShortenExp(szRowData);
				}
				else if(sNormSigData.num[nRow]) // Just sigma data
				{
					// Load row data into string for display in table
					_snprintf(szRowData, nRunTableChars,
						"%6d%10.4e%#7.1e%5d          %10.4e",
						sNormSigData.af[nRow], sNormSigData.tau[nRow],
						sNormSigData.num[nRow], sNormSigData.alpha[nRow],
						sNormSigData.sigma[nRow]);
					ShortenExp(szRowData);
				}
				else if(sModSigData.num[nRow]) // Just Tho1 data
				{
					// Load row data into string for display in table
					_snprintf(szRowData, nRunTableChars,
						"%6d                 %5d%10.4e          %10.4e",
						sNormSigData.af[nRow], sModSigData.alpha[nRow],
						sModSigData.tau[nRow], sModSigData.sigma[nRow]);
					ShortenExp(szRowData);
				}
			}
			else // Show af as %#6.0e exp format (# forces dp)
			{
				if(sNormSigData.num[nRow] && sModSigData.num[nRow])
				{
					// Load row data into string for display in table
					// Fields are:
					// AF, Sigma Tau, Sigma #, Alpha, Tho1 Tau, Sigma, Tho1 Dev
					_snprintf(szRowData, nRunTableChars,
						"%#6.0e%10.4e%#7.1e%5d%10.4e%10.4e%10.4e",
						(double)sNormSigData.af[nRow], sNormSigData.tau[nRow],
						sNormSigData.num[nRow], sModSigData.alpha[nRow],
						sModSigData.tau[nRow], sNormSigData.sigma[nRow],
						sModSigData.sigma[nRow]);
					ShortenExp(szRowData);
				}
				else if(sNormSigData.num[nRow]) // Just sigma data
				{
					// Load row data into string for display in table
					_snprintf(szRowData, nRunTableChars,
						"%#6.0e%10.4e%#7.1e%5d          %10.4e",
						(double)sNormSigData.af[nRow], sNormSigData.tau[nRow],
						sNormSigData.num[nRow], sNormSigData.alpha[nRow],
						sNormSigData.sigma[nRow]);
					ShortenExp(szRowData);
				}
				else if(sModSigData.num[nRow]) // Just Tho1 data
				{
					// Load row data into string for display in table
					_snprintf(szRowData, nRunTableChars,
						"%#6.0e                 %5d%10.4e          %10.4e",
						(double)sNormSigData.af[nRow], sModSigData.alpha[nRow],
						sModSigData.tau[nRow], sModSigData.sigma[nRow]);
					ShortenExp(szRowData);
				}
			}
		}
	}

	// Return success
   return DTE_OKAY;
}

#ifndef LITE_VER
/*****************************************************************************/
/*                                                                           */
/*                   Read Dialog Procedure                                   */
/*                                                                           */
/*      Function to read and process stability data from file.               */
/*      Read, display, plot and print SIGMA.TAU file.                        */
/*                                                                           */
/*      Question: What is max # points?  Will they fit on printout?          */
/*      Array sizes are now dynamically allocated.  No fixed limit.          */
/*      Should we have provisions for multipage printout?                    */
/*                                                                           */
/*      Revision record:                                                     */
/*          11/07/96    Added skeleton Options, Lines & Notes functions      */
/*          01/30/97    Added provisions for multiple sets of stability data */
/*          02/02/97    Added bLines flag & macro                            */
/*          06/07/97    Clear lines when type or data changes                */
/*			07/22/97	Made changes to handle all tau data                  */
/*			01/17/98	Changed # points format from 5d to 6d                */
/*			02/21/98	Updated printing code for Win32 API                  */
/*			06/06/98	Added provisions for TIE rms and MTIE                */
/*          09/25/98    Changed # points format from 6d to 7d                */
/*			05/10/00	Added MTOT and TTOT                                  */
/*			05/30/00	Eliminated tests for num>0                           */
/*			02/14/03	Added Tho1                                          */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK ReadDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local macro
	#define XTRA_WDTH 2                 // Extra column width - was 4
	#define MAX_NUM_ROWS 55             // Max # rows that can be printed
	#define READ_LINES 0                // Control printing of lines (0 or 1)
	#define MAX_TABLE_SIZE 20           // Max # rows in table on plot

	// Local variables
	// Chars
	char szBuffer[BUFFER_SIZE+1];       // Text buffer
	char szFormat[BUFFER_SIZE+1];       // Format string
	// Ints
	static int nSigmaType=NORMAL_RUN;   // Sigma type
	static int nLines;                  // # lines in data file
	static int nRows;                   // # rows of data (NOT # visible rows)
	static int i;                       // Index
	int nCode;							// Return from ReallocSigmaArrays()
	// BOOLs
	static BOOL bStart=TRUE;            // 1st time flag
	static BOOL bDataValid=FALSE;       // Data valid flag
	static BOOL bLines;                 // Lines flag
	static BOOL bSaveAllTau;			// Variable to save all tau flag state
	// Others
	static HWND hSigTbl;                // Handle to data table
	PENSTRUCT Pen;                      // Pen structure
	LPVMSTRUCT lpVMData;                // Pointer to VMSTRUCT
	// GraphiC plotting
	char TitleString[40];               // Dialog box title string
	HWND hChildWnd=NULL;
	HANDLE hChildAccel=NULL;
	// For printing
	HDC hdcPrn;                         // Handle to printer device context
	TEXTMETRIC tm;                      // Text metrics structure
	static int xChar, yChar;            // Text character sizes
	static int nLine;                   // Line #
	static short xPage, yPage;          // Graphic page dims in pixels
	// Printer font
	LOGFONT logfont;                    // Printer logical font structure
	HFONT hPrnFont;                     // Printer font handle
	// Win32 API printing structs
	PRINTDLG pd;
	DOCINFO di;

	static char *types[] =
	{
		"Normal", "Overlapping", "Modified", "Time", "Hadamard",
		"Overlap Hadamard", "Total", "Mod Total", "Time Total",
		"Overlapping & Modified", "TIE rms", "MTIE", "Tho1"
	};

	// Set pen parameters
	Pen.fPenStyle=PS_NULL;

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Save dialog box handle as global
			hDialog=hDlg;

			// Save all tau flag state
			if(bStart)
			{
				bSaveAllTau=bAllTau;
			}

			// Get dialog box title
			GetWindowText(hDlg, szBoxTitle, TITLESIZE);

			// Set plot type (global)
			nPlotType=READ_PLOT;

			// Set line printing flag
			bLines=READ_LINES;

			if(bStart)
			{
				// Clear stability data
				SendMessage(hDlg, WM_COMMAND,
					GET_WM_COMMAND_MPS(IDC_READ_CLEAR, NULL, 0));

				// Clear start flag
				bStart=FALSE;
			}

			// Fill up the sigma type list box
			// Note:  The index is equal to the macro value
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_READ_TYPE));

			for(i=0; i<NUM_RUN_TYPES; i++)
			{
				LoadString(hInst, IDS_RUN_TYPE_0+i, szBuffer, BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_READ_TYPE), i,
					szBuffer);
			}

			// Show sigma type
			nDummy=ComboBox_SetCurSel(GETHCTL(IDC_READ_TYPE), nSigmaType);

			// Set button states
			EnableWindow(GETHCTL(IDC_READ_PLOT), bDataValid);
			EnableWindow(GETHCTL(IDC_READ_PRINT), bDataValid);
			EnableWindow(GETHCTL(IDC_READ_OPTIONS), bDataValid);
			EnableWindow(GETHCTL(IDC_READ_LINES), bDataValid);
			EnableWindow(GETHCTL(IDC_READ_NOTES), bDataValid);

			// Set up stability data table
			// Format is (excluding row #):
			// | Tau | # Points | Min Sigma | Sigma | Max Sigma |
			// Get handle for sigma table
			hSigTbl=GETHCTL(IDC_READ_TABLE);

			// Create five columns
			SendMessage(hSigTbl, DTM_SETCOLCOUNT, (WPARAM)RT_NUM_COLS,
				(LPARAM)0);

			// Configure the tau data column to a string
			SendMessage(hSigTbl, DTM_SETCOLTYPE, (WPARAM)RT_TAU_COL_NUM,
				(LPARAM)DTT_ZSTRING);

			// Configure the # points column to a string
			SendMessage(hSigTbl, DTM_SETCOLTYPE, (WPARAM)RT_NUM_COL_NUM,
				(LPARAM)DTT_ZSTRING);

			// Configure the min sigma data column to a string
			SendMessage(hSigTbl, DTM_SETCOLTYPE, (WPARAM)RT_MIN_COL_NUM,
				(LPARAM)DTT_ZSTRING);

			// Configure the sigma data column to a string
			SendMessage(hSigTbl, DTM_SETCOLTYPE, (WPARAM)RT_SIG_COL_NUM,
				(LPARAM)DTT_ZSTRING);

			// Configure the max sigma data column to a string
			SendMessage(hSigTbl, DTM_SETCOLTYPE, (WPARAM)RT_MAX_COL_NUM,
				(LPARAM)DTT_ZSTRING);

			// Use 10.4 exponential format for tau
			// This requires 10 characters
			SendMessage(hSigTbl, DTM_SETCOLDATALEN, (WPARAM)RT_TAU_COL_NUM,
				(LPARAM)RT_NUM_TAU_CHARS);

			// Column width is in dialog units (4/char)
			// So need 10*4=40
			SendMessage(hSigTbl, DTM_SETCOLWIDTH, (WPARAM)RT_TAU_COL_NUM,
				(LPARAM)(4*RT_NUM_TAU_CHARS+XTRA_WDTH));

			// Use 7-digit integer format for # data points
			// This requires 7 characters
			SendMessage(hSigTbl, DTM_SETCOLDATALEN, (WPARAM)RT_NUM_COL_NUM,
				(LPARAM)RT_NUM_NUM_CHARS);

			// Column width is in dialog units (4/char)
			// So need 6*4=20
			SendMessage(hSigTbl, DTM_SETCOLWIDTH, (WPARAM)RT_NUM_COL_NUM,
				(LPARAM)(4*RT_NUM_NUM_CHARS+XTRA_WDTH));

			// Use 10.4 exponential format for min sigma
			// This requires 10 characters
			SendMessage(hSigTbl, DTM_SETCOLDATALEN, (WPARAM)RT_MIN_COL_NUM,
				(LPARAM)RT_NUM_MIN_CHARS);

			// Column width is in dialog units (4/char)
			// So need 10*4=40
			SendMessage(hSigTbl, DTM_SETCOLWIDTH, (WPARAM)RT_MIN_COL_NUM,
				(LPARAM)(4*RT_NUM_MIN_CHARS+XTRA_WDTH));

			// Use 10.4 exponential format for sigma
			// This requires 10 characters
			SendMessage(hSigTbl, DTM_SETCOLDATALEN, (WPARAM)RT_SIG_COL_NUM,
				(LPARAM)RT_NUM_SIG_CHARS);

			// Column width is in dialog units (4/char)
			// So need 10*4=40
			SendMessage(hSigTbl, DTM_SETCOLWIDTH, (WPARAM)RT_SIG_COL_NUM,
				(LPARAM)(4*RT_NUM_SIG_CHARS+XTRA_WDTH));

			// Use 10.4 exponential format for max sigma
			// This requires 10 characters + 1 for EOS
			SendMessage(hSigTbl, DTM_SETCOLDATALEN, (WPARAM)RT_MAX_COL_NUM,
				(LPARAM)(RT_NUM_MAX_CHARS+10));

			// Column width is in dialog units (4/char)
			// So need 10*4=40
			SendMessage(hSigTbl, DTM_SETCOLWIDTH, (WPARAM)RT_MAX_COL_NUM,
				(LPARAM)(4*RT_NUM_MAX_CHARS+XTRA_WDTH));

			// Label the column headings
			SendMessage(hSigTbl, DTM_SETCOLHEAD, (WPARAM)RT_TAU_COL_NUM,
				(LPARAM)(LPSTR)"Tau");
			SendMessage(hSigTbl, DTM_SETCOLHEAD, (WPARAM)RT_NUM_COL_NUM,
				(LPARAM)(LPSTR)"#");

			switch(nSigmaType)
			{
				case NORMAL_RUN:
				case OVERLAPPING_RUN:
				{
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_MIN_COL_NUM,
						(LPARAM)(LPSTR)"Min Sigma");
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_SIG_COL_NUM,
						(LPARAM)(LPSTR)"Sigma");
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_MAX_COL_NUM,
						(LPARAM)(LPSTR)"Max Sigma");
				}
				break;

				case TOTAL_RUN:
				{
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_MIN_COL_NUM,
						(LPARAM)(LPSTR)"Min Sigma");
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_SIG_COL_NUM,
						(LPARAM)(LPSTR)"Total Sigma");
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_MAX_COL_NUM,
						(LPARAM)(LPSTR)"Max Sigma");
				}
				break;

				case MODIFIED_RUN:
				{
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_MIN_COL_NUM,
						(LPARAM)(LPSTR)"Min Sigma");
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_SIG_COL_NUM,
						(LPARAM)(LPSTR)"Mod Sigma");
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_MAX_COL_NUM,
						(LPARAM)(LPSTR)"Max Sigma");
				}
				break;

				case MODTOTAL_RUN:
				{
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_MIN_COL_NUM,
						(LPARAM)(LPSTR)"Min Sigma");
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_SIG_COL_NUM,
						(LPARAM)(LPSTR)"Mod Totdev");
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_MAX_COL_NUM,
						(LPARAM)(LPSTR)"Max Sigma");
				}
				break;

				case TIMETOTAL_RUN:
				{
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_MIN_COL_NUM,
						(LPARAM)(LPSTR)"Min Sigma");
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_SIG_COL_NUM,
						(LPARAM)(LPSTR)"Time Totdev");
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_MAX_COL_NUM,
						(LPARAM)(LPSTR)"Max Sigma");
				}
				break;

				case TIME_RUN:
				{
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_MIN_COL_NUM,
						(LPARAM)(LPSTR)"Min Sigma");
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_SIG_COL_NUM,
						(LPARAM)(LPSTR)"Time Sigma");
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_MAX_COL_NUM,
						(LPARAM)(LPSTR)"Max Sigma");
				}
				break;

				case HADAMARD_RUN:
				case OVERLAPHAD_RUN:
				case HADTOTAL_RUN:
				{
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_MIN_COL_NUM,
						(LPARAM)(LPSTR)"Min Sigma");
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_SIG_COL_NUM,
						(LPARAM)(LPSTR)"Hadamard");
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_MAX_COL_NUM,
						(LPARAM)(LPSTR)"Max Sigma");
				}
				break;

				case BOTH_RUN:
				{
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_MIN_COL_NUM,
						(LPARAM)(LPSTR)"Std Dev");
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_SIG_COL_NUM,
						(LPARAM)(LPSTR)"Sigma");
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_MAX_COL_NUM,
						(LPARAM)(LPSTR)"Mod Sigma");
				}
				break;

				case TIERMS_RUN:
				{
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_MIN_COL_NUM,
						(LPARAM)(LPSTR)"");
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_SIG_COL_NUM,
						(LPARAM)(LPSTR)"TIE rms");
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_MAX_COL_NUM,
						(LPARAM)(LPSTR)"");
				}
				break;

				case MTIE_RUN:
				{
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_MIN_COL_NUM,
						(LPARAM)(LPSTR)"");
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_SIG_COL_NUM,
						(LPARAM)(LPSTR)"MTIE");
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_MAX_COL_NUM,
						(LPARAM)(LPSTR)"");
				}
				break;

				case THEO1_RUN:
				{
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_NUM_COL_NUM,
						(LPARAM)(LPSTR)"");
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_MIN_COL_NUM,
						(LPARAM)(LPSTR)"Tho1 #");
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_SIG_COL_NUM,
						(LPARAM)(LPSTR)"Tho1 Dev");
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_MAX_COL_NUM,
						(LPARAM)(LPSTR)"");
				}
				break;

				case FULL_RUN:
				{
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_NUM_COL_NUM,
						(LPARAM)(LPSTR)"Sigma #");
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_MIN_COL_NUM,
						(LPARAM)(LPSTR)"");
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_SIG_COL_NUM,
						(LPARAM)(LPSTR)"Sigma");
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)RT_MAX_COL_NUM,
						(LPARAM)(LPSTR)"Tho1 Dev");
				}
				break;
			}

			// Center tau column heading , no data editing, and make
			// column width fixed
			SendMessage(hSigTbl, DTM_SETCOLSTYLE, (WPARAM)RT_TAU_COL_NUM,
				(LPARAM)(DTCS_HEADCENTER|DTCS_FIXED));

			// Center # points column heading , no data editing, and make
			// column width fixed
			SendMessage(hSigTbl, DTM_SETCOLSTYLE, (WPARAM)RT_NUM_COL_NUM,
				(LPARAM)(DTCS_HEADCENTER|DTCS_FIXED));

			// Center min sigma column heading , no data editing, and make
			// column width fixed
			SendMessage(hSigTbl, DTM_SETCOLSTYLE, (WPARAM)RT_MIN_COL_NUM,
				(LPARAM)(DTCS_HEADCENTER|DTCS_FIXED));

			// Center sigma column heading , no data editing, and make
			// column width fixed
			SendMessage(hSigTbl, DTM_SETCOLSTYLE, (WPARAM)RT_SIG_COL_NUM,
				(LPARAM)(DTCS_HEADCENTER|DTCS_FIXED));

			// Center max sigma column heading , no data editing, and make
			// column width fixed
			SendMessage(hSigTbl, DTM_SETCOLSTYLE, (WPARAM)RT_MAX_COL_NUM,
				(LPARAM)(DTCS_HEADCENTER|DTCS_FIXED));

			// Null pen used to give no focus rectangle
			SendMessage(hSigTbl, DTM_SETFOCUSPEN, (WPARAM)0,
				(LPARAM)(LPPENSTRUCT)&Pen);

			//  Initialize # rows
			nRows=sNormSigData.points;

			if(nSigmaType==MODIFIED_RUN || nSigmaType==TIME_RUN    ||
			   nSigmaType==MODTOTAL_RUN || nSigmaType==TIMETOTAL_RUN)
			{
				nRows=sModSigData.points;
			}

			// Make sure types are the same
			nSigmaPlotType=nSigmaType;

			// Initiate communications with data table
			SendMessage(hSigTbl, DTM_VM_INITIALIZE, (WPARAM)FALSE,
				(LPARAM)nRows);

			return TRUE;
		}

		// DataTable virtual memory messages
		// Get the first row of data
		case DTM_VM_GETFIRST:
		{
			// Get pointer to VMSTRUCT
			lpVMData=(LPVMSTRUCT)lParam;

			// Set index to begining
			lpVMData->dwKey=0;

			// Get row data
			lpVMData->nStatus=(short)GetSigmaData(lpVMData);
		}
		break;

		// Get the last row of data
		case DTM_VM_GETLAST:
		{
			// Get pointer to VMSTRUCT
			lpVMData=(LPVMSTRUCT)lParam;

			// Set index to last row
			lpVMData->dwKey=nRows-1;    // Always OK

			// Get row data
			lpVMData->nStatus=(short)GetSigmaData(lpVMData);
		}
		break;

		// Get the next row of data (data after row=dwKey)
		case DTM_VM_GETNEXT:
		{
			// Get pointer to VMSTRUCT
			lpVMData=(LPVMSTRUCT)lParam;

			// Increment index
			lpVMData->dwKey+=1;

			// Get row data
			lpVMData->nStatus=(short)GetSigmaData(lpVMData);
		}
		break;

		// Get the previous row of data (data before row=dwKey)
		case DTM_VM_GETPREV:
		{
			// Get pointer to VMSTRUCT
			lpVMData=(LPVMSTRUCT)lParam;

			// Decrement index
			lpVMData->dwKey-=1;

			// Get row data
			lpVMData->nStatus=(short)GetSigmaData(lpVMData);
		}
		break;

		// Get the row of data that is specified % down table
		case DTM_VM_GETPERCENT:
		{
			// Get pointer to VMSTRUCT
			lpVMData=(LPVMSTRUCT)lParam;

			// Calc index
			lpVMData->dwKey=(lpVMData->dwKey)*(long)nRows/100L;

			// Get row data
			lpVMData->nStatus=(short)GetSigmaData(lpVMData);
		}
		break;

		// Get the row of data at dwKey
		case DTM_VM_GETROWDATA:
		{
			// Get pointer to VMSTRUCT
			lpVMData=(LPVMSTRUCT)lParam;

			// Get row data
			lpVMData->nStatus=(short)GetSigmaData(lpVMData);
		}
		break;

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				// Display help info
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::READ_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::READ_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "READ_FUNCTION");
					#endif
				}
				break;

				// Sigma type change
				case IDC_READ_TYPE:
				{
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_SELCHANGE)
					{
						// Get (new) sigma type
						nSigmaType=
							ComboBox_GetCurSel(GETHCTL(IDC_READ_TYPE));

						// Set sigma type (global)
						nSigmaPlotType=nSigmaType;

						// Clear stability data
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_READ_CLEAR, NULL, 0));

						// Clear filename
						SetWindowText(GETHCTL(IDC_READ_FILE), "File:");

						// Eliminate all sigma plot lines
						for(i=0; i<SLINE_NUMLINES; i++)
						{
							sSLine[i].nLineType=SLINE_NONE;
						}

						// Update display
						SendMessage(hDlg, WM_INITDIALOG, (WPARAM)0,
							(LPARAM)0);
					}
				}
				break;

				// Read stability data file
				case IDOK:
				{
					// Clear stability data
					SendMessage(hDlg, WM_COMMAND,
					GET_WM_COMMAND_MPS(IDC_READ_CLEAR, NULL, 0));

					// Clear filename
					SetWindowText(GETHCTL(IDC_READ_FILE), "File:");

					// Eliminate all sigma plot lines
					for(i=0; i<SLINE_NUMLINES; i++)
					{
						sSLine[i].nLineType=SLINE_NONE;
					}

					// Update display
					SendMessage(hDlg, WM_INITDIALOG, (WPARAM)0,
						(LPARAM)0);

					// Set open dialog box title
					LoadString(hInst, IDS_TITLE_SIGFILE, szBuffer,
						BUFFER_SIZE);

					// Initialize OPENFILENAME structure
					// 1st arg = FALSE indicates stability file being opened
					FileInitialize(FALSE, TRUE, hDlg, hInst, szBuffer, 0);

					// Invoke File Open Dialog
					// Returns TRUE if successful, FALSE if not
					if(FileOpenDlg(TRUE, hDlg, szStabFile, szStabFileTitle))
					{
						// Show filename
						_snprintf(szBuffer, sizeof(szBuffer),
							"Stability File: %s", szStabFileTitle);
						SetWindowText(GETHCTL(IDC_READ_FILE), szBuffer);

						// Find # lines in stability data file
						nLines=FileSize(szStabFile);

						// Set global # sigma data points to process
						nSigmaSize=nLines;

						// Enlarge stability data array sizes if necessary
						if(nLines>SIGMA_SIZE)
						{
							// Reallocate sigma arrays
							nCode=ReallocSigmaArrays(nLines);

							// Note: If nCode is -1 then there was a menory
							// reallocation error that was already announced
							// and we'd better bail out
							if(nCode==-1)
							{
								PostMessage(hDlg, WM_COMMAND,
									GET_WM_COMMAND_MPS(IDCANCEL, NULL, 0));
								break;
							}
						}

						// Read stability data file
						SigmaRead(szStabFile, nSigmaType);

						// Put info into log file
						WriteLog(49, szStabFile);

						// Initialize read plot parameters
						InitReadPlotParams();
						CalcSigmaPlotScale();

						// Update display
						bDataValid=TRUE;

						// Eliminate all sigma plot lines
						for(i=0; i<SLINE_NUMLINES; i++)
						{
							sSLine[i].nLineType=SLINE_NONE;
						}

						// Detect all tau data
						// Check if tau spacing is same between 1st 3 rows
						// Fixes error when reading mod sigma type data
						// before a non-mod sigma type data
						// which falsely sets bAllTau TRUE
						// and disables error bars and table
						if( (nSigmaType!=MODIFIED_SIGMA) &&
							(nSigmaType!=TIME_SIGMA) &&
							(nSigmaType!=MODTOTAL_SIGMA) &&
							(nSigmaType!=TIMETOTAL_SIGMA) )
						{
							if((sNormSigData.tau[2]-sNormSigData.tau[1])==
							   (sNormSigData.tau[1]-sNormSigData.tau[0]))
							{
								bAllTau=TRUE;
							}
							else
							{
								bAllTau=FALSE;
							}
						}
						else // Mod sigma type
						{
							if((sModSigData.tau[2]-sModSigData.tau[1])==
							   (sModSigData.tau[1]-sModSigData.tau[0]))
							{
								bAllTau=TRUE;
							}
							else
							{
								bAllTau=FALSE;
							}
						}

						// Check for NG data
						// Note: Tests for sNormSigData.num[i]<=0 etc.
						// eliminated in Version 1.30a 05/30/00 because
						// they don't allow #=0 code for plain "spec" lines
						for(i=0; i<nLines; i++)
						{
							if(nSigmaType==NORMAL_RUN ||
							   nSigmaType==OVERLAPPING_RUN ||
							   nSigmaType==HADAMARD_RUN ||
							   nSigmaType==OVERLAPHAD_RUN ||
							   nSigmaType==HADTOTAL_RUN ||
							   nSigmaType==TOTAL_RUN ||
							   nSigmaType==TIERMS_RUN ||
							   nSigmaType==MTIE_RUN ||
							   nSigmaType==THEO1_RUN)
							{
								if(sNormSigData.sigma[i]<=0.0 ||
								   sNormSigData.tau[i]<=0.0)
								{
									bDataValid=FALSE;
								}
							}
							else if(nSigmaType==BOTH_RUN)
							{
								 if(sNormSigData.sigma[i]<=0.0 ||
									sNormSigData.tau[i]<=0.0)									
								 {
									bDataValid=FALSE;
								 }
								 if(sModSigData.sigma[i]<=0.0 ||
									sModSigData.tau[i]<=0.0)									
								 {
									bDataValid=FALSE;
								 }
							}
							else if(nSigmaType==MODIFIED_RUN  ||
								    nSigmaType==MODTOTAL_RUN  ||
									nSigmaType==TIME_RUN      ||
									nSigmaType==TIMETOTAL_RUN  )
							{
								if(sModSigData.sigma[i]<=0.0 ||
								   sModSigData.tau[i]<=0.0)								   
								{
									bDataValid=FALSE;
								}
							}
						}

						if(!bDataValid)
						{
							// Display invalid data error message
							LoadString(hInst, IDS_MESSAGE_INVALID, szBuffer,
								BUFFER_SIZE);
							MessageBox(hDlg, szBuffer, szBoxTitle,
								MB_ICONEXCLAMATION);
						}

						SendMessage(hDlg, WM_INITDIALOG, (WPARAM)0,
							(LPARAM)0);
					}
					else
					{
						// Clear display
						sNormSigData.points=0;
						sModSigData.points=0;
						SendMessage(hSigTbl, DTM_VM_INITIALIZE, (WPARAM)FALSE,
							(LPARAM)nRows);
						bDataValid=FALSE;
						SendMessage(hDlg, WM_INITDIALOG, (WPARAM)0,
							(LPARAM)0);
					}
				}
				break;

				// Clear stability data
				case IDC_READ_CLEAR:
				{
					sNormSigData.points=0;
					sModSigData.points=0;
					bDataValid=FALSE;
				}
				break;

				//  Respond to plot button
				case IDC_READ_PLOT:
				{
					// Note: Run dlg box buttons are disabled before plotting
					// and reenabled after plotting in the SIGMA_PLOT code
					// of GPCWndProc()

					// Set sigma type (global)
					nSigmaPlotType=nSigmaType;

					// Initialize read plot parameters
					// InitReadPlotParams();
					// CalcSigmaPlotScale();
					// Set # points
					// sNormSigData.points=nLines;
					// sModSigData.points=nLines;
					
					// Set # rows
					sNormSigData.rows=nLines;
					sModSigData.rows=nLines;
					
					// No table on stability plot if too many lines
					if(nLines>MAX_TABLE_SIZE)
					{
						sSPlot.do_table=FALSE;
					}

					// Set plot window title
					LoadString(hInst, IDS_TITLE_SIGPLOT, TitleString,
						BUFFER_SIZE);
					
					// Create child window for plot
					GPCWINCreate(hChildWnd, hInst, hDlg, SW_SHOWNORMAL,
						&hChildAccel, NULL);
				}
				break;

				//  Respond to options button
				case IDC_READ_OPTIONS:
				{
					// Disable buttons
					EnableWindow(GETHCTL(IDOK), FALSE);
					EnableWindow(GETHCTL(IDCANCEL), FALSE);
					EnableWindow(GETHCTL(IDC_READ_PLOT), FALSE);
					EnableWindow(GETHCTL(IDC_READ_PRINT), FALSE);
					EnableWindow(GETHCTL(IDC_READ_OPTIONS), FALSE);
					EnableWindow(GETHCTL(IDC_READ_LINES), FALSE);
					EnableWindow(GETHCTL(IDC_READ_NOTES), FALSE);
					EnableWindow(GETHCTL(IDHELP), FALSE);

					// Open read options dialog box
					InvokeDialogBox(hInst, "SigmaPlotBox", hwndMain,
						(DLGPROC)ReadPlotDlgProc);

					// Enable buttons
					EnableWindow(GETHCTL(IDOK), TRUE);
					EnableWindow(GETHCTL(IDCANCEL), TRUE);
					if(bDataValid)
					{
						EnableWindow(GETHCTL(IDC_READ_PLOT), TRUE);
						EnableWindow(GETHCTL(IDC_READ_PRINT), TRUE);
					}
					EnableWindow(GETHCTL(IDC_READ_OPTIONS), TRUE);
					EnableWindow(GETHCTL(IDC_READ_LINES), TRUE);
					EnableWindow(GETHCTL(IDC_READ_NOTES), TRUE);
					EnableWindow(GETHCTL(IDHELP), TRUE);

					// Give Read dialog box the focus
					SetFocus(hDlg);
				}
				break;

				//  Respond to lines button
				case IDC_READ_LINES:
				{
					// Disable buttons
					EnableWindow(GETHCTL(IDOK), FALSE);
					EnableWindow(GETHCTL(IDCANCEL), FALSE);
					EnableWindow(GETHCTL(IDC_READ_PLOT), FALSE);
					EnableWindow(GETHCTL(IDC_READ_PRINT), FALSE);
					EnableWindow(GETHCTL(IDC_READ_OPTIONS), FALSE);
					EnableWindow(GETHCTL(IDC_READ_LINES), FALSE);
					EnableWindow(GETHCTL(IDC_READ_NOTES), FALSE);
					EnableWindow(GETHCTL(IDHELP), FALSE);

					// Open run lines dialog box
					InvokeDialogBox(hInst, "SigmaLineBox", hwndMain,
						(DLGPROC)SigmaLineDlgProc);

					// Enable buttons
					EnableWindow(GETHCTL(IDOK), TRUE);
					EnableWindow(GETHCTL(IDCANCEL), TRUE);
					if(bDataValid)
					{
						EnableWindow(GETHCTL(IDC_READ_PLOT), TRUE);
						EnableWindow(GETHCTL(IDC_READ_PRINT), TRUE);
					}
					EnableWindow(GETHCTL(IDC_READ_OPTIONS), TRUE);
					EnableWindow(GETHCTL(IDC_READ_LINES), TRUE);
					EnableWindow(GETHCTL(IDC_READ_NOTES), TRUE);
					EnableWindow(GETHCTL(IDHELP), TRUE);

					// Give Run dialog box the focus
					SetFocus(hDlg);
				}
				break;

				//  Respond to notes button
				case IDC_READ_NOTES:
				{
					// Disable buttons
					EnableWindow(GETHCTL(IDOK), FALSE);
					EnableWindow(GETHCTL(IDCANCEL), FALSE);
					EnableWindow(GETHCTL(IDC_READ_PLOT), FALSE);
					EnableWindow(GETHCTL(IDC_READ_PRINT), FALSE);
					EnableWindow(GETHCTL(IDC_READ_OPTIONS), FALSE);
					EnableWindow(GETHCTL(IDC_READ_LINES), FALSE);
					EnableWindow(GETHCTL(IDC_READ_NOTES), FALSE);
					EnableWindow(GETHCTL(IDHELP), FALSE);

					// Open run notes dialog box
					InvokeDialogBox(hInst, "PlotNoteBox", hwndMain,
						(DLGPROC)SigmaNoteDlgProc);

					// Enable buttons
					EnableWindow(GETHCTL(IDOK), TRUE);
					EnableWindow(GETHCTL(IDCANCEL), TRUE);
					if(bDataValid)
					{
						EnableWindow(GETHCTL(IDC_READ_PLOT), TRUE);
						EnableWindow(GETHCTL(IDC_READ_PRINT), TRUE);
					}
					EnableWindow(GETHCTL(IDC_READ_OPTIONS), TRUE);
					EnableWindow(GETHCTL(IDC_READ_LINES), TRUE);
					EnableWindow(GETHCTL(IDC_READ_NOTES), TRUE);
					EnableWindow(GETHCTL(IDHELP), TRUE);

					// Give Run dialog box the focus
					SetFocus(hDlg);
				}
				break;

				// Print stability data on printer
				// Note: Bare-bones printing code
				// Single fixed-pitch, 8.5"x11" portrait page
				case IDC_READ_PRINT:
				{
					// Check for too many points
					if(nRows>MAX_NUM_ROWS)
					{
						LoadString(hInst, IDS_MESSAGE_PRINT, szBuffer,
							BUFFER_SIZE);
						MessageBox(hDlg, szBuffer, "Read Print",
							MB_ICONEXCLAMATION);
						break;
					}

					// Let user choose printer in PrintDlg
					// Initialize PRINTDLG structure
					memset(&pd, 0, sizeof(PRINTDLG));
					pd.lStructSize=sizeof(PRINTDLG);
					pd.Flags=PD_RETURNDEFAULT; // Don't show dialog box

					// 1st (hidden) call to PrintDlg()
					// To set up hDevNames & hDevMode
 					if(!PrintDlg(&pd))
					{
						// PrintDlg() called failed
						MessageBox(hwndMain, "Printer Not Found", "Run Print",
						MB_ICONEXCLAMATION);
						break;
					}

					// Reinitialize PRINTDLG structure
					pd.Flags=PD_RETURNDC | PD_NOPAGENUMS | PD_NOSELECTION;
					// Get DC & no choice of page #s & no selection of text

					// 2nd (visible) call to PrintDlg()
					if(PrintDlg(&pd))
					{
						// Get printer device context
						hdcPrn=pd.hDC;
					}
					else
					{
						if(CommDlgExtendedError())
						{
							// Printer error
							MessageBox(hwndMain, "Printer Error", "Run Print",
							MB_ICONEXCLAMATION);
						}
						else // Error code 0
						{
							// User hit cancel button
							break;
						}
					}

					// Get page dimensions
					xPage=(short)GetDeviceCaps(hdcPrn, HORZRES);
					yPage=(short)GetDeviceCaps(hdcPrn, VERTRES);

					// Determine logfont.lfHeight from point size = nPointSize
					// where nPointSize is a global variable
					// that user can enter in General page of
					// Configure property sheet
					// Win32 documentation gives the formula:
					// lfHeight = -MulDiv(PointSize,
					// GetDeviceCaps(hDC, LOGPIXELSY), 72);
					// which becomes the following for our variables:
					// nFontHeight = -MulDiv(nPointSize,
					// GetDeviceCaps(hdcPrn, LOGPIXELSY), 72);
					// Both nPointSize and nFontHeight are global variables
					// A couple of typical values are nPointSize=9,
					// nFontHeight=-75
					// and nPointSize=10, nFontHeight=-83
					// (the abs value of nFontHeight is used)
					nFontHeight = -MulDiv(nPointSize, GetDeviceCaps(hdcPrn,
						LOGPIXELSY), 72);
					
					// Set font attributes
					logfont.lfHeight=nFontHeight;
					logfont.lfWidth=0;
					logfont.lfEscapement=0;
					logfont.lfOrientation=0;
					logfont.lfWeight=0;
					logfont.lfItalic=0;
					logfont.lfUnderline=0;
					logfont.lfStrikeOut=0;
					logfont.lfCharSet=OEM_CHARSET;
					logfont.lfOutPrecision=OUT_DEFAULT_PRECIS;
					logfont.lfClipPrecision=CLIP_DEFAULT_PRECIS;
					logfont.lfQuality=PROOF_QUALITY;
					logfont.lfPitchAndFamily=FIXED_PITCH | FF_DONTCARE;
					strlcpy(logfont.lfFaceName,"", LF_FACESIZE);

					// Create printer font
					hPrnFont=CreateFontIndirect(&logfont);

					// Select font into printer device
					SelectObject(hdcPrn, hPrnFont);

					// Get text metrics
					GetTextMetrics(hdcPrn, &tm);
					yChar=tm.tmHeight + tm.tmExternalLeading;
					xChar=tm.tmAveCharWidth;

					// Compose Print Manager message
					LoadString(hInst, IDS_MESSAGE_DATA, szPrnMsg,
						BUFFER_SIZE);

					// Set up DOCINFO structure
					memset(&di, 0, sizeof(DOCINFO));
					di.cbSize=sizeof(DOCINFO);
					di.lpszDocName=szPrnMsg;
					
					// Start printing
					if(hdcPrn != NULL)
					{
						if(StartDoc(hdcPrn, &di) != SP_ERROR)
						{
							// Actual printing code goes here
							StartPage(hdcPrn);

							nLine=0; // Heading
							SetTextAlign(hdcPrn,
								TA_LEFT || TA_TOP);
							LoadString(hInst, IDS_FORMAT_15, szFormat,
								BUFFER_SIZE);
							_snprintf(szBuffer, sizeof(szBuffer), szFormat,
								szStabFileTitle);
							TextOut(hdcPrn, (int)(xChar/2),
								(int)((nLine+0.5)*yChar),
								szBuffer, strlen(szBuffer));

							nLine=1; // Sigma type
							strlcpy(szBuffer, "Sigma Type: ",
								sizeof(szBuffer));
							strlcat(szBuffer, types[nSigmaType],
								sizeof(szBuffer));
							TextOut(hdcPrn, (int)(xChar/2),
								(int)((nLine+0.5)*yChar),
								szBuffer, strlen(szBuffer));

							nLine=3; // Results heading
							switch(nSigmaType)
							{
								case NORMAL_RUN:
								case OVERLAPPING_RUN:
								{
									LoadString(hInst, IDS_HEADING_13, szBuffer,
										BUFFER_SIZE);
								}
								break;

								case BOTH_RUN:
								{
									LoadString(hInst, IDS_HEADING_14, szBuffer,
										BUFFER_SIZE);
								}
								break;

								case MODIFIED_RUN:
								{
									LoadString(hInst, IDS_HEADING_15, szBuffer,
										BUFFER_SIZE);
								}
								break;

								case TIME_RUN:
								{
									LoadString(hInst, IDS_HEADING_16, szBuffer,
										BUFFER_SIZE);
								}
								break;

								case HADAMARD_RUN:
								case OVERLAPHAD_RUN:
								case HADTOTAL_RUN:
								{
									LoadString(hInst, IDS_HEADING_17, szBuffer,
										BUFFER_SIZE);
								}
								break;

								case TOTAL_RUN:
								{
									LoadString(hInst, IDS_HEADING_18, szBuffer,
										BUFFER_SIZE);
								}
								break;

								case MODTOTAL_RUN:
								{
									LoadString(hInst, IDS_HEADING_23, szBuffer,
										BUFFER_SIZE);
								}
								break;

								case TIMETOTAL_RUN:
								{
									LoadString(hInst, IDS_HEADING_24, szBuffer,
										BUFFER_SIZE);
								}
								break;

								case TIERMS_RUN:
								{
									LoadString(hInst, IDS_HEADING_19, szBuffer,
										BUFFER_SIZE);
								}
								break;

								case MTIE_RUN:
								{
									LoadString(hInst, IDS_HEADING_20, szBuffer,
										BUFFER_SIZE);
								}
								break;
							}

							TextOut(hdcPrn, (int)(xChar/2),
								(int)((nLine+0.5)*yChar),
								szBuffer, strlen(szBuffer));

							i=0;
							for(nLine=5; nLine<5+nRows; nLine++)
							{
								if(nSigmaType==NORMAL_RUN ||
									nSigmaType==OVERLAPPING_RUN ||
									nSigmaType==HADAMARD_RUN ||
									nSigmaType==OVERLAPHAD_RUN ||
									nSigmaType==HADTOTAL_RUN ||
									nSigmaType==TOTAL_RUN)
								{
									LoadString(hInst, IDS_FORMAT_8, szFormat,
										BUFFER_SIZE);
									_snprintf(szBuffer, sizeof(szBuffer),
										szFormat, sNormSigData.tau[i],
										(int)sNormSigData.num[i],
										sNormSigData.sig_min[i],
										sNormSigData.sigma[i],
										sNormSigData.sig_max[i]);
								}

								else if(nSigmaType==BOTH_RUN)
								{
									LoadString(hInst, IDS_FORMAT_8, szFormat,
										BUFFER_SIZE);
									_snprintf(szBuffer, sizeof(szBuffer),
										szFormat, sNormSigData.tau[i],
										(int)sNormSigData.num[i],
										sNormSigData.std_dev[i],
										sNormSigData.sigma[i],
										sModSigData.sigma[i]);
								}

								else if(nSigmaType==MODIFIED_RUN ||
									nSigmaType==TIME_RUN ||
									nSigmaType==MODTOTAL_RUN ||
									nSigmaType==TIMETOTAL_RUN)
								{
									LoadString(hInst, IDS_FORMAT_8, szFormat,
										BUFFER_SIZE);
									_snprintf(szBuffer, sizeof(szBuffer),
										szFormat, sModSigData.tau[i],
										(int)sModSigData.num[i],
										sModSigData.sig_min[i],
										sModSigData.sigma[i],
										sModSigData.sig_max[i]);
								}
								
								else if(nSigmaType==TIERMS_RUN ||
									nSigmaType==MTIE_RUN)
								{
									LoadString(hInst, IDS_FORMAT_24, szFormat,
										BUFFER_SIZE);
									_snprintf(szBuffer, sizeof(szBuffer),
										szFormat, sNormSigData.tau[i],
										(int)sNormSigData.num[i],
										sNormSigData.sigma[i]);
								}

								ShortenExp(szBuffer);
								TextOut(hdcPrn, (int)(cyChar/2),
									(int)((nLine+0.4)*yChar), szBuffer,
									strlen(szBuffer));
								i++;
							}

							// End (single) page
							EndPage(hdcPrn);

							// End printing
							EndDoc(hdcPrn);
						}
						else // Error or print to file cancelled
						{
							;
						}

						// Release device context
						DeleteDC(hdcPrn);
					}
					else // hdcPrn==NULL
					{
						;
					}

					// Delete printer logical font
					DeleteObject(hPrnFont);
				}
				break;

				// End dialog box
				case IDCANCEL:
				{
					// Shrink stability data array sizes if necessary
					if(nLines>SIGMA_SIZE)
					{
						// Reallocate sigma arrays
						nCode=ReallocSigmaArrays(SIGMA_SIZE);

						// Note: If nCode is -1 there was a memory reallocation
						// error that was already announced but no action is
						// required since we are closing anyway
					}

					bStart=TRUE; // So arrays will be cleared when reopened

					// Restore all tau flag state
					bAllTau=bSaveAllTau;

					// Close dialog box
					EndDialog(hDlg, 0);
				}
				return TRUE;
			}
		}
		break;
	 }
	 return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*                   Corn Dialog Procedure                                   */
/*                                                                           */
/*      Function to perform 3-cornered hat stability analysis.               */
/*                                                                           */
/*      Revision record:                                                     */
/*          08/17/01    Created from ReadDlgProc()                           */
/*			08/19/01	Working                                              */
/*			08/25/01	Done                                                 */
/*			12/19/01	Added df & errorbars                                 */
/*			12/22/01	Errorbars running - added MM & DF indicators         */
/*			04/13/02	Added trap for df<1                                  */
/*                                                                           */
/*          07/23/16	Error bars allowed whereever possible                */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK CornDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local macros
	#define XTRA_WDTH 2                 // Extra column width
	#define MAX_NUM_ROWS 55             // Max # rows that can be printed
	#define READ_LINES 0                // Control printing of lines (0 or 1)
	#define MAX_TABLE_SIZE 20           // Max # rows in table on plot
	#define CORN_DATA 0					// 3-cornered hat input data
	#define CORN_RESULTS 1				// 3-cornered hat
										//separated sigma results
	#define CORN_ALL 0					// All units data
	#define CORN_A 1					// Unit A data
	#define CORN_B 2					// Unit B data
	#define CORN_C 3					// Unit C data
	#define CB_SIZE 

	// Local variables
	// Chars
	char szBuffer[BUFFER_SIZE+1];       // Text buffer
	char szFormat[BUFFER_SIZE+1];       // Format string
	static char szCornFile[FILE_NAME_SIZE+1];
										// 3-cornered hat stability filename
	static char szCornFileTitle[FILE_NAME_SIZE+1];
										// 3-corn hat stab filename title
	static char szResultsFile[FILE_NAME_SIZE+1];
										// 3-cornered hat results filename
	static char szDrive[BUFFER_SIZE+1];	// Drive string
	static char szDir[BUFFER_SIZE+1];	// Directory string
	static char szExt[BUFFER_SIZE+1];	// Extension string
	// Ints
	static int nSigmaType=NORMAL_RUN;   // Sigma type
	static int nLines;                  // # lines in data file
	static int nLineCount;              // Lines count for composing plot data
	static int nRows;                   // # rows of data (NOT # visible rows)
	static int i;                       // Index
	static int j;						// 2nd index
	static int nCornType=CORN_DATA;		// 3-cornered hat data type
	static int nUnitType=CORN_ALL;		// Data unit type
	static int nCB;						// Size of clipboard string
	int nCode;							// Return from ReallocSigmaArrays()
	int nRow;							// Row index
	int nCol;							// Column index
	// BOOLs
	static BOOL bStart=TRUE;            // 1st time flag
	static BOOL bDataValid=FALSE;       // Data valid flag
	static BOOL bResultsValid=FALSE;    // Results valid flag
	static BOOL bLines;                 // Lines flag
	static BOOL bSaveAllTau;			// Variable to save all tau flag state
	static BOOL bPlotChanged=TRUE;		// Flag to reinitialize plot params
	static BOOL bSaveDataType;			// Variable to save original data type
	static BOOL bNeg[4];				// Column negative flags
	static BOOL bHaveMinMax=FALSE;		// Flag that all min & max data exists
	static BOOL bHaveDF=FALSE;			// Flag that all df data exists
	static BOOL bVarOK=FALSE;			// Flag that no variances are negative
	// F_TYPEs
	static F_TYPE fVar;					// Variance of variance
	static F_TYPE fGamma;				// Reduced df ratio
	// Floats
	static float fConfFactor=(float)0.68268;	// Confidence factor
	static float fLow;                  // Minimum probability
	static float fHigh;                 // Maximum probability
	static float fChiHigh;              // Chi-square for upper error bar
	static float fChiLow;               // Chi-square for lower error bar
	// Others
	static HWND hSigTbl;                // Handle to data table
	PENSTRUCT Pen;                      // Pen structure
	LPVMSTRUCT lpVMData;                // Pointer to VMSTRUCT
	// GraphiC plotting
	char TitleString[40];               // Dialog box title string
	HWND hChildWnd=NULL;
	HANDLE hChildAccel=NULL;
	// File pointers
	FILE *out;                          // File pointer for output files
	// For printing
	HDC hdcPrn;                         // Handle to printer device context
	TEXTMETRIC tm;                      // Text metrics structure
	static int xChar, yChar;            // Text character sizes
	static int nLine;                   // Line #
	static short xPage, yPage;          // Graphic page dims in pixels
	// Printer font
	LOGFONT logfont;                    // Printer logical font structure
	HFONT hPrnFont;                     // Printer font handle
	// Win32 API printing structs
	PRINTDLG pd;
	DOCINFO di;
	// Clipboard variables
	HGLOBAL hClipboard;					// Handle to clipboard text buffer
	LPSTR	szClipboard;				// Ptr to clipboard text string

	static char *types[] =
	{
		"Normal", "Overlapping", "Modified", "Time", "Hadamard",
		"Overlap Hadamard", "Total", "Mod Total", "Time Total",
		"Overlapping & Modified", "TIE rms", "MTIE"
	};

	static char *units[] =
	{
		"All", "A", "B", "C"
	};

	// To color negative values
	DTCOLORSTRUCT NegColor;    	 	// Color structure for negative cells
	DTCOLORSTRUCT NormColor;    	// Color structure for normal cells
	
	// Set outlier color parameters
	NegColor.BkgrdColor=DEFAULTCOLOR;
	NegColor.TextColor=0x000000FF; // Red
	NegColor.SelBkgrdColor=DEFAULTCOLOR;
	NegColor.SelTextColor=DEFAULTCOLOR;

	// Set normal parameters
	NormColor.BkgrdColor=DEFAULTCOLOR;
	NormColor.TextColor=DEFAULTCOLOR;
	NormColor.SelBkgrdColor=DEFAULTCOLOR;
	NormColor.SelTextColor=DEFAULTCOLOR;

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Do this only when dialog opens
			if(bStart)
			{
				// Save all tau flag state and data type
				bSaveAllTau=bAllTau;
				bSaveDataType=bDataType;

				// Set data type to A-B
				bDataType=PHASE_DATA;
				bArchiveData=FALSE;

				// Reset flag indicators
				Button_SetCheck(GETHCTL(IDC_CORN_HAVEMM), FALSE);
				Button_SetCheck(GETHCTL(IDC_CORN_HAVEDF), FALSE);
			}

			// Get dialog box title
			GetWindowText(hDlg, szBoxTitle, TITLESIZE);

			// Set plot type (global)
			nPlotType=READ_PLOT;

			// Set line printing flag
			bLines=READ_LINES;

			if(bStart)
			{
				// Clear stability data
				SendMessage(hDlg, WM_COMMAND,
					GET_WM_COMMAND_MPS(IDC_CORN_CLEAR, NULL, 0));
			}

			// Fill up the sigma type list box
			// Note:  The index is equal to the macro value
			// -5 eliminates Both, TIErms, MTIE, Tho1, and Overlap & Tho1 
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_CORN_TYPE));

			for(i=0; i<NUM_RUN_TYPES-5; i++)
			{
				LoadString(hInst, IDS_RUN_TYPE_0+i, szBuffer, BUFFER_SIZE);
				nDummy=ComboBox_InsertString(GETHCTL(IDC_CORN_TYPE), i,
					szBuffer);
			}

			// Show sigma type
			nDummy=ComboBox_SetCurSel(GETHCTL(IDC_CORN_TYPE), nSigmaType);

			// Fill up the unit type list box
			// Note:  The index is equal to the macro value
			nDummy=ComboBox_ResetContent(GETHCTL(IDC_CORN_UNIT));

			for(i=0; i<4; i++)
			{
				nDummy=ComboBox_InsertString(GETHCTL(IDC_CORN_UNIT), i,
					units[i]);
			}

			// Show unit type
			nDummy=ComboBox_SetCurSel(GETHCTL(IDC_CORN_UNIT), nUnitType);

			// Load the stability filenames
			SetWindowText(GETHCTL(IDC_CORN_A), szCornFileA);
			SetWindowText(GETHCTL(IDC_CORN_B), szCornFileB);
			SetWindowText(GETHCTL(IDC_CORN_C), szCornFileC);

			// Set button states
			EnableWindow(GETHCTL(IDC_CORN_PLOT), bDataValid);
			EnableWindow(GETHCTL(IDC_CORN_PRINT), bResultsValid);
			EnableWindow(GETHCTL(IDC_CORN_OPTIONS), bDataValid);
			EnableWindow(GETHCTL(IDC_CORN_LINES), bDataValid);
			EnableWindow(GETHCTL(IDC_CORN_NOTES), bDataValid);
			EnableWindow(GETHCTL(IDC_CORN_COPY), bResultsValid);
			EnableWindow(GETHCTL(IDC_CORN_CALC), bDataValid);

			// Set up stability data table
			// Format is (excluding row #):
			// | Tau | Sigma A | Sigma B | Sigma C |
			// Get handle for sigma table
			hSigTbl=GETHCTL(IDC_CORN_TABLE);

			// Save sigma table handle as global
			hDialog=hSigTbl;

			// Create four columns
			SendMessage(hSigTbl, DTM_SETCOLCOUNT, (WPARAM)CT_NUM_COLS,
				(LPARAM)0);

			// Configure the tau data column to a string
			SendMessage(hSigTbl, DTM_SETCOLTYPE, (WPARAM)CT_TAU_COL_NUM,
				(LPARAM)DTT_ZSTRING);

			// Configure the sigma a data column to a string
			SendMessage(hSigTbl, DTM_SETCOLTYPE, (WPARAM)CT_A_COL_NUM,
				(LPARAM)DTT_ZSTRING);

			// Configure the sigma b data column to a string
			SendMessage(hSigTbl, DTM_SETCOLTYPE, (WPARAM)CT_B_COL_NUM,
				(LPARAM)DTT_ZSTRING);

			// Configure the sigma c data column to a string
			SendMessage(hSigTbl, DTM_SETCOLTYPE, (WPARAM)CT_C_COL_NUM,
				(LPARAM)DTT_ZSTRING);

			// Use 9.3 exponential format for tau
			// This requires 9 characters
			SendMessage(hSigTbl, DTM_SETCOLDATALEN, (WPARAM)CT_TAU_COL_NUM,
				(LPARAM)CT_NUM_TAU_CHARS);

			// Column width is in dialog units (4/char)
			// So need 9*4=36
			SendMessage(hSigTbl, DTM_SETCOLWIDTH, (WPARAM)CT_TAU_COL_NUM,
				(LPARAM)(4*CT_NUM_TAU_CHARS+XTRA_WDTH));

			// Use 9.3 exponential format for sigma a
			// This requires 9 characters
			SendMessage(hSigTbl, DTM_SETCOLDATALEN, (WPARAM)CT_A_COL_NUM,
				(LPARAM)CT_NUM_A_CHARS);

			// Column width is in dialog units (4/char)
			// So need 9*4=36
			SendMessage(hSigTbl, DTM_SETCOLWIDTH, (WPARAM)CT_A_COL_NUM,
				(LPARAM)(4*CT_NUM_A_CHARS+XTRA_WDTH));

			// Use 9.3 exponential format for sigma b
			// This requires 9 characters
			SendMessage(hSigTbl, DTM_SETCOLDATALEN, (WPARAM)CT_B_COL_NUM,
				(LPARAM)CT_NUM_B_CHARS);

			// Column width is in dialog units (4/char)
			// So need 9*4=36
			SendMessage(hSigTbl, DTM_SETCOLWIDTH, (WPARAM)CT_B_COL_NUM,
				(LPARAM)(4*CT_NUM_B_CHARS+XTRA_WDTH));

			// Use 9.3 exponential format for sigma c
			// This requires 9 characters
			// Four extra chars are needed for full display of last column
			// because each e format field needs 1 more character
			// for its 3-digit exponent before it is shortened
			SendMessage(hSigTbl, DTM_SETCOLDATALEN, (WPARAM)CT_C_COL_NUM,
				(LPARAM)(CT_NUM_C_CHARS+CT_NUM_EXTRA_CHARS));

			// Column width is in dialog units (4/char)
			// So need 9*4=36
			SendMessage(hSigTbl, DTM_SETCOLWIDTH, (WPARAM)CT_C_COL_NUM,
				(LPARAM)(4*CT_NUM_C_CHARS+XTRA_WDTH));

			// Label the column headings
			SendMessage(hSigTbl, DTM_SETCOLHEAD, (WPARAM)CT_TAU_COL_NUM,
				(LPARAM)(LPSTR)"Tau");

			switch(nCornType)
			{
				case CORN_DATA:
				{
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)CT_A_COL_NUM,
						(LPARAM)(LPSTR)"Sigma A-B");
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)CT_B_COL_NUM,
						(LPARAM)(LPSTR)"Sigma A-C");
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)CT_C_COL_NUM,
						(LPARAM)(LPSTR)"Sigma B-C");
				}
				break;

				case CORN_RESULTS:
				{
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)CT_A_COL_NUM,
						(LPARAM)(LPSTR)"Sigma A");
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)CT_B_COL_NUM,
						(LPARAM)(LPSTR)"Sigma B");
					SendMessage(hSigTbl, DTM_SETCOLHEAD,
						(WPARAM)CT_C_COL_NUM,
						(LPARAM)(LPSTR)"Sigma C");
				}
				break;
			}

			// Center tau column heading, no data editing, and make
			// column width fixed
			SendMessage(hSigTbl, DTM_SETCOLSTYLE, (WPARAM)CT_TAU_COL_NUM,
				(LPARAM)(DTCS_HEADCENTER|DTCS_FIXED));

			// Center sigma a column heading, no data editing, and make
			// column width fixed
			SendMessage(hSigTbl, DTM_SETCOLSTYLE, (WPARAM)CT_A_COL_NUM,
				(LPARAM)(DTCS_HEADCENTER|DTCS_FIXED));

			// Center sigma b column heading, no data editing, and make
			// column width fixed
			SendMessage(hSigTbl, DTM_SETCOLSTYLE, (WPARAM)CT_B_COL_NUM,
				(LPARAM)(DTCS_HEADCENTER|DTCS_FIXED));

			// Center sigma c column heading, no data editing, and make
			// column width fixed
			SendMessage(hSigTbl, DTM_SETCOLSTYLE, (WPARAM)CT_C_COL_NUM,
				(LPARAM)(DTCS_HEADCENTER|DTCS_FIXED));

			// Null pen used to give no focus rectangle
			SendMessage(hSigTbl, DTM_SETFOCUSPEN, (WPARAM)0,
				(LPARAM)(LPPENSTRUCT)&Pen);

			//  Initialize # rows
			nRows=sCornData.points;

			if(!bStart)
			{
				// Initiate communications with data table
				SendMessage(hSigTbl, DTM_VM_INITIALIZE, (WPARAM)FALSE,
					(LPARAM)nRows);
			}
			else // Leave table empty at start
			{
				// Clear start flag
				bStart=FALSE;
			}

			// Color negative variances
			SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDC_CORN_COLOR,
				NULL, NULL));

			return TRUE;
		}

		// DataTable virtual memory messages
		// Get the first row of data
		case DTM_VM_GETFIRST:
		{
			// Get pointer to VMSTRUCT
			lpVMData=(LPVMSTRUCT)lParam;

			// Set index to begining
			lpVMData->dwKey=0;

			// Get row data
			if(nCornType==CORN_DATA)
			{
				lpVMData->nStatus=(short)GetCornData(lpVMData);
			}
			else
			{
				lpVMData->nStatus=(short)GetCornResults(lpVMData);
			}

			// Color negative variances
			SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDC_CORN_COLOR,
				NULL, NULL));
		}
		break;

		// Get the last row of data
		case DTM_VM_GETLAST:
		{
			// Get pointer to VMSTRUCT
			lpVMData=(LPVMSTRUCT)lParam;

			// Set index to last row
			lpVMData->dwKey=nRows-1; // Always OK

			// Get row data
			if(nCornType==CORN_DATA)
			{
				lpVMData->nStatus=(short)GetCornData(lpVMData);
			}
			else
			{
				lpVMData->nStatus=(short)GetCornResults(lpVMData);
			}

			// Color negative variances
			SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDC_CORN_COLOR,
				NULL, NULL));
		}
		break;

		// Get the next row of data (data after row=dwKey)
		case DTM_VM_GETNEXT:
		{
			// Get pointer to VMSTRUCT
			lpVMData=(LPVMSTRUCT)lParam;

			// Increment index
			lpVMData->dwKey+=1;

			// Get row data
			if(nCornType==CORN_DATA)
			{
				lpVMData->nStatus=(short)GetCornData(lpVMData);
			}
			else
			{
				lpVMData->nStatus=(short)GetCornResults(lpVMData);
			}

			// Color negative variances
			SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDC_CORN_COLOR,
				NULL, NULL));
		}
		break;

		// Get the previous row of data (data before row=dwKey)
		case DTM_VM_GETPREV:
		{
			// Get pointer to VMSTRUCT
			lpVMData=(LPVMSTRUCT)lParam;

			// Decrement index
			lpVMData->dwKey-=1;

			// Get row data
			if(nCornType==CORN_DATA)
			{
				lpVMData->nStatus=(short)GetCornData(lpVMData);
			}
			else
			{
				lpVMData->nStatus=(short)GetCornResults(lpVMData);
			}

			// Color negative variances
			SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDC_CORN_COLOR,
				NULL, NULL));
		}
		break;

		// Get the row of data that is specified % down table
		case DTM_VM_GETPERCENT:
		{
			// Get pointer to VMSTRUCT
			lpVMData=(LPVMSTRUCT)lParam;

			// Calc index
			lpVMData->dwKey=(lpVMData->dwKey)*(long)nRows/100L;

			// Get row data
			if(nCornType==CORN_DATA)
			{
				lpVMData->nStatus=(short)GetCornData(lpVMData);
			}
			else
			{
				lpVMData->nStatus=(short)GetCornResults(lpVMData);
			}

			// Color negative variances
			SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDC_CORN_COLOR,
				NULL, NULL));
		}
		break;

		// Get the row of data at dwKey
		case DTM_VM_GETROWDATA:
		{
			// Get pointer to VMSTRUCT
			lpVMData=(LPVMSTRUCT)lParam;

			// Get row data
			if(nCornType==CORN_DATA)
			{
				lpVMData->nStatus=(short)GetCornData(lpVMData);
			}
			else
			{
				lpVMData->nStatus=(short)GetCornResults(lpVMData);
			}

			// Color negative variances
			SendMessage(hDlg, WM_COMMAND, GET_WM_COMMAND_MPS(IDC_CORN_COLOR,
				NULL, NULL));
		}
		break;

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				// Display help info
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::3-CORNERED_HAT_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::3-CORNERED_HAT_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "3-CORNERED_HAT_FUNCTION");
					#endif
				}
				break;

				// Respond to CR in an edit control
				// Note: No button is a DEFPUSHBUTTON
				case IDOK:
				{
					// Does filename a edit control have focus?
					if(GetFocus()==GETHCTL(IDC_CORN_A))
					{
						// Send EN_KILLFOCUS message to start edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_CORN_A, NULL,
							EN_KILLFOCUS));
					}

					// Does filename b edit control have focus?
					if(GetFocus()==GETHCTL(IDC_CORN_B))
					{
						// Send EN_KILLFOCUS message to start edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_CORN_B, NULL,
							EN_KILLFOCUS));
					}

					// Does filename c edit control have focus?
					if(GetFocus()==GETHCTL(IDC_CORN_C))
					{
						// Send EN_KILLFOCUS message to start edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_CORN_C, NULL,
							EN_KILLFOCUS));
					}
				}
				break;

				case IDC_CORN_COLOR:
				{
					// Clear all neg flags
					for(nCol=1; nCol<4; nCol++)
					{
						bNeg[nCol]=FALSE;
					}

					// Loop thru all data (not just table rows)
					// looking for negative results (coded as 0)
					// setting neg flag if any neg values found in column
					for(nRow=0; nRow<sCornResults.points; nRow++)
					{
						if(sCornResults.sig_a[nRow]==0.0)
						{
							bNeg[1]=TRUE;
						}
						if(sCornResults.sig_b[nRow]==0.0)
						{
							bNeg[2]=TRUE;
						}
						if(sCornResults.sig_c[nRow]==0.0)
						{
							bNeg[3]=TRUE;
						}
					}
						
					// Set color of column headings
					for(nCol=1; nCol<4; nCol++)
					{
						// Set access position to corresponding heading
						SendMessage(hSigTbl, DTM_SETACCESSPOS,	nCol,
							DTPOS_HEADINGS);

						if(bNeg[nCol] && bResultsValid)
						{
							// Negative heading color
							SendMessage(hSigTbl, DTM_SETCELLCOLOR, DTA_ACCESS,
								(LPARAM)(LPDTCOLORSTRUCT)&NegColor);
						}
						else
						{
							// Normal heading color
							SendMessage(hSigTbl, DTM_SETCELLCOLOR, DTA_ACCESS,
								(LPARAM)(LPDTCOLORSTRUCT)&NormColor);
						}
					}

					// Color negative variances red
					for(nRow=0; nRow<nRows; nRow++)
					{
						for(nCol=1; nCol<4; nCol++)
						{
							// Set access position to negative cell
							SendMessage(hSigTbl, DTM_SETACCESSPOS,	nCol,
								nRow);
									
							// Get cell data
							SendMessage(hSigTbl, DTM_READCELL, DTA_ACCESS,
								(LPARAM)(LPVOID)szBuffer);

							// Is cell negative?
							if(szBuffer[0]=='N')
							{
								// Color cell red
								SendMessage(hSigTbl, DTM_SETCELLCOLOR,
									DTA_ACCESS,
									(LPARAM)(LPDTCOLORSTRUCT)&NegColor);
							}
						}
					}
				}
				break;
				
				// Filename a change
				case IDC_CORN_A:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(GetFocus()!=GETHCTL(IDC_PRINT_CANCEL)))
					{
						// Refresh filename display to give user feedback
						GetWindowText(GETHCTL(IDC_CORN_A),	szCornFileA,
							FILE_NAME_SIZE);
						SetWindowText(GETHCTL(IDC_CORN_A), szCornFileA);

						// Set plot changed flag
						bPlotChanged=TRUE;
					}
				}
				break;

				// Filename b change
				case IDC_CORN_B:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(GetFocus()!=GETHCTL(IDC_PRINT_CANCEL)))
					{
						// Refresh filename display to give user feedback
						GetWindowText(GETHCTL(IDC_CORN_B),	szCornFileB,
							FILE_NAME_SIZE);
						SetWindowText(GETHCTL(IDC_CORN_B), szCornFileB);

						// Set plot changed flag
						bPlotChanged=TRUE;
					}
				}
				break;

				// Filename c change
				case IDC_CORN_C:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(GetFocus()!=GETHCTL(IDC_PRINT_CANCEL)))
					{
						// Refresh filename display to give user feedback
						GetWindowText(GETHCTL(IDC_CORN_C),	szCornFileC,
							FILE_NAME_SIZE);
						SetWindowText(GETHCTL(IDC_CORN_C), szCornFileC);

						// Set plot changed flag
						bPlotChanged=TRUE;
					}
				}
				break;

				// Respond to browse button
				case IDC_CORN_BROWSE:
				{
					// Set open dialog box title
					LoadString(hInst, IDS_TITLE_SIGFILE, szBuffer,
						BUFFER_SIZE);

					// Initialize OPENFILENAME structure
					// 1st arg = TRUE indicates customized file open dialog box
					FileInitialize(TRUE, TRUE, hDlg, hInst, szBuffer, 0);

					// Clear filename
					// Otherwise File Open Dialog won't open after 1st time
					strlcpy(szCornFile, "", sizeof(szCornFile));
					
					// Invoke File Open Dialog
					// Returns TRUE if successful, FALSE if not
					if(FileOpenDlg(TRUE, hDlg, szCornFile, szCornFileTitle))
					{
						// Invalidate data and results
						bDataValid=FALSE;
						bResultsValid=FALSE;
						
						// Clear stability data
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_CORN_CLEAR, NULL, 0));

						// Set filename
						if(bArchiveData) // Archive button used for B-C
						{
							// Data type is B-C
							SetWindowText(GETHCTL(IDC_CORN_C), szCornFile);
							strlcpy(szCornFileC, szCornFile, FILE_NAME_SIZE);

							// Set next data type to A-B
							bDataType=PHASE_DATA;
							bArchiveData=FALSE;
						}
						else
						{
							if(bDataType) // Freq button used for A-C
							{
								// Data type is A-C
								SetWindowText(GETHCTL(IDC_CORN_B), szCornFile);
								strlcpy(szCornFileB, szCornFile,
									FILE_NAME_SIZE);

								// Set next data type to B-c
								bArchiveData=TRUE;
							}
							else // Phase button used for A-B
							{
								// Data type is A-B
								SetWindowText(GETHCTL(IDC_CORN_A), szCornFile);
								strlcpy(szCornFileA, szCornFile,
									FILE_NAME_SIZE);

								// Set next data type to A-C
								bDataType=FREQ_DATA;
								bArchiveData=FALSE;
							}
						}
					}
				}
				break;

				// Sigma type change
				case IDC_CORN_TYPE:
				{
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_SELCHANGE)
					{
						// Get (new) sigma type
						nSigmaType=
							ComboBox_GetCurSel(GETHCTL(IDC_CORN_TYPE));

						// Set sigma type (global)
						nSigmaPlotType=nSigmaType;

						// Eliminate all sigma plot lines
						for(i=0; i<SLINE_NUMLINES; i++)
						{
							sSLine[i].nLineType=SLINE_NONE;
						}

						// Set plot changed flag
						bPlotChanged=TRUE;
					}

				}
				break;

				// Unit type change
				case IDC_CORN_UNIT:
				{
					if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_SELCHANGE)
					{
						// Get (new) unit type
						nUnitType=
							ComboBox_GetCurSel(GETHCTL(IDC_CORN_UNIT));

						// Set plot changed flag
						bPlotChanged=TRUE;
					}
				}
				break;

				// Read stability data file
				case IDC_CORN_READ:
				{
					// Clear stability data
					SendMessage(hDlg, WM_COMMAND,
					GET_WM_COMMAND_MPS(IDC_CORN_CLEAR, NULL, 0));

					// Eliminate all sigma plot lines
					for(i=0; i<SLINE_NUMLINES; i++)
					{
						sSLine[i].nLineType=SLINE_NONE;
					}
					
					// Invalidate results
					bResultsValid=FALSE;
					
					// Put info into log file: "Stability File Read"
					WriteLog(49, szCornFile);

					// Read the three stability files
					// Get 1st filename
					GetWindowText(GETHCTL(IDC_CORN_A),	szCornFile,
						FILE_NAME_SIZE);

					// Find # lines in stability data file
					nLines=FileSize(szCornFile);

					// Set global # sigma data points to process
					nSigmaSize=nLines;

					// Enlarge stability data array sizes if necessary
					if(nLines>SIGMA_SIZE)
					{
						// Reallocate sigma arrays
						nCode=ReallocSigmaArrays(nLines);

						// Note: If nCode is -1 then there was a menory
						// reallocation error that was already announced
						// and we'd better bail out
						if(nCode==-1)
						{
							PostMessage(hDlg, WM_COMMAND,
								GET_WM_COMMAND_MPS(IDCANCEL, NULL, 0));
							break;
						}
					}

					// Read stability data file
					SigmaRead(szCornFile, NORMAL_RUN);

					// Copy data from sNormSigmaData to sCornData
					for(i=0; i<nLines; i++)
					{
						sCornData.tau[i]=sNormSigData.tau[i];
						sCornData.num_a[i]=sNormSigData.num[i];
						sCornData.sig_a[i]=sNormSigData.sigma[i];
						sCornData.sig_min_a[i]=sNormSigData.sig_min[i];
						sCornData.sig_max_a[i]=sNormSigData.sig_max[i];
						sCornData.df_a[i]=sNormSigData.df[i];
					}

					// Set # of points
					sCornData.points=nLines;
							
					// Get 2nd filename
					GetWindowText(GETHCTL(IDC_CORN_B),	szCornFile,
						FILE_NAME_SIZE);

					// Read stability data file
					SigmaRead(szCornFile, NORMAL_RUN);

					// Copy data from sNormSigmaData to sCornData
					for(i=0; i<nLines; i++)
					{
						sCornData.num_b[i]=sNormSigData.num[i];
						sCornData.sig_b[i]=sNormSigData.sigma[i];
						sCornData.sig_min_b[i]=sNormSigData.sig_min[i];
						sCornData.sig_max_b[i]=sNormSigData.sig_max[i];
						sCornData.df_b[i]=sNormSigData.df[i];
					}

					// Get 3rd filename
					GetWindowText(GETHCTL(IDC_CORN_C),	szCornFile,
						FILE_NAME_SIZE);

					// Read stability data file
					SigmaRead(szCornFile, NORMAL_RUN);

					// Copy data from sNormSigmaData to sCornData
					for(i=0; i<nLines; i++)
					{
						sCornData.num_c[i]=sNormSigData.num[i];
						sCornData.sig_c[i]=sNormSigData.sigma[i];
						sCornData.sig_min_c[i]=sNormSigData.sig_min[i];
						sCornData.sig_max_c[i]=sNormSigData.sig_max[i];
						sCornData.df_c[i]=sNormSigData.df[i];
					}

					// Initialize read plot parameters
					InitReadPlotParams();
					CalcSigmaPlotScale();

					// Validiate data
					bDataValid=TRUE;

					// Set data type to data
					nCornType=CORN_DATA;

					// Check for NG data
					for(i=0; i<nLines; i++)
					{
						if(sCornData.sig_a[i]<=0.0 ||
							sCornData.sig_b[i]<=0.0 ||
							sCornData.sig_c[i]<=0.0 || sCornData.tau[i]<=0.0)
						{
							bDataValid=FALSE;
						}
					}

					if(!bDataValid)
					{
						// Display invalid data error message
						LoadString(hInst, IDS_MESSAGE_INVALID, szBuffer,
							BUFFER_SIZE);
						MessageBox(hDlg, szBuffer, szBoxTitle,
							MB_ICONEXCLAMATION);
					}

					// Check if have all min & max sigma data
					bHaveMinMax=TRUE;
					for(i=0; i<sCornData.points; i++)
					{
						if( (!sCornData.sig_min_a[i]) ||
							(!sCornData.sig_min_b[i]) ||
							(!sCornData.sig_min_c[i]) )
						{
							bHaveMinMax=FALSE;
						}

						if( (!sCornData.sig_max_a[i]) ||
							(!sCornData.sig_max_b[i]) ||
							(!sCornData.sig_max_c[i]) )
						{
							bHaveMinMax=FALSE;
						}
					}
					
					// Check if have all df data
					bHaveDF=TRUE;
					for(i=0; i<sCornData.points; i++)
					{
						if( (!sCornData.df_a[i]) ||
							(!sCornData.df_b[i]) ||
							(!sCornData.df_c[i]) )
						{
							bHaveDF=FALSE;
						}
					}

					// Set flag indicators
					Button_SetCheck(GETHCTL(IDC_CORN_HAVEMM), bHaveMinMax);
					Button_SetCheck(GETHCTL(IDC_CORN_HAVEDF), bHaveDF);
					
					// Set plot changed flag
					bPlotChanged=TRUE;

					// Update display
					SendMessage(hDlg, WM_INITDIALOG, (WPARAM)0,
						(LPARAM)0);
				}
				break;

				case IDC_CORN_CALC:
				{
					// Put info into log file: "3-Cornered Hat Analysis Done"
					WriteLog(67, szCornFile);

					// Set all variances OK flag
					bVarOK=TRUE;
					
					// Separate variances and set taus
					for(i=0; i<sCornData.points; i++)
					{
						sCornResults.sig_a[i]=
							(float)(0.5*(((sCornData.sig_a[i])*
							(sCornData.sig_a[i]))+((sCornData.sig_b[i])*
							(sCornData.sig_b[i]))-((sCornData.sig_c[i])*
							(sCornData.sig_c[i]))));

						if(sCornResults.sig_a[i]>0)
						{
							sCornResults.sig_a[i]=
								(float)sqrt(sCornResults.sig_a[i]);
						}
						else // Negative variance
						{
							sCornResults.sig_a[i]=0;
							bVarOK=FALSE;
						}

						sCornResults.sig_b[i]=
							(float)(0.5*(((sCornData.sig_a[i])*
							(sCornData.sig_a[i]))+((sCornData.sig_c[i])*
							(sCornData.sig_c[i]))-((sCornData.sig_b[i])*
							(sCornData.sig_b[i]))));

						if(sCornResults.sig_b[i]>0)
						{
							sCornResults.sig_b[i]=
								(float)sqrt(sCornResults.sig_b[i]);
						}
						else // Negative variance
						{
							sCornResults.sig_b[i]=0;
							bVarOK=FALSE;
						}

						sCornResults.sig_c[i]=
							(float)(0.5*(((sCornData.sig_b[i])*
							(sCornData.sig_b[i]))+((sCornData.sig_c[i])*
							(sCornData.sig_c[i]))-((sCornData.sig_a[i])*
							(sCornData.sig_a[i]))));

						if(sCornResults.sig_c[i]>0)
						{
							sCornResults.sig_c[i]=
								(float)sqrt(sCornResults.sig_c[i]);
						}
						else // Negative variance
						{
							sCornResults.sig_c[i]=0;
							bVarOK=FALSE;
						}

						sCornResults.tau[i]=sCornData.tau[i];
					}

					// Set # points
					sCornResults.points=sCornData.points;
					
					// Set # data points
					sCornResults.num_a=sCornData.num_a;
					sCornResults.num_b=sCornData.num_b;
					sCornResults.num_c=sCornData.num_c;

					// Set all errorbar & df items to zero
					for(i=0; i<sCornData.points; i++)
					{
						sCornResults.df_a[i]=0.0;
						sCornResults.df_b[i]=0.0;
						sCornResults.df_c[i]=0.0;
						sCornResults.sig_min_a[i]=0.0;
						sCornResults.sig_min_b[i]=0.0;
						sCornResults.sig_min_c[i]=0.0;
						sCornResults.sig_max_a[i]=0.0;
						sCornResults.sig_max_b[i]=0.0;
						sCornResults.sig_max_c[i]=0.0;
					}

					// Calc errorbars if possible
					// No negative variances and all dfs
					// Note: Will not get errorbars if df<1
					
					#if(0) // Original code - no error bars if any variance negative
					if(bHaveDF && bVarOK)
					#endif


					#if(1) // New code 07/23/16 - error bars are allowed whenever possible
					// Only specific negative variance error bars are disallowed
					// If any unit has a negative variance, then no error bar is allowed
					// at that tau for *any* unit
					// One can always eliminate all error bars with the usual options checkbox
					// if partial error bars are considered confusing
					// Note also that, since most negative variances occur at the longest tau,
					// one can edit those values out of the original sigma.tau file
					if(bHaveDF)
					#endif
					{
						// Calc reduced dfs
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_CORN_DF, NULL, 0));

						// Calc errorbars
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_CORN_ERRORBAR, NULL, 0));
					}

					// Write results to disk file
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_CORN_WRITE, NULL, 0));

					// Set data type to results
					nCornType=CORN_RESULTS;

					// Validate results
					bResultsValid=TRUE;

					// Allow copy
					EnableWindow(GETHCTL(IDC_CORN_COPY), bResultsValid);

					// Set plot changed flag
					bPlotChanged=TRUE;

					// Update display
					SendMessage(hDlg, WM_INITDIALOG, (WPARAM)0,
						(LPARAM)0);
				}
				break;

				// Calc df using Grubbs estimate
				// as described by Ekstrom & Kopang at the 2001 PTTI
				// Note that valid (non-negative) variances are required
				// for all three units in order to determine the gamma
				case IDC_CORN_DF:
				{
					// Calc variance of the variance estimates, gamma
					// and reduced df at each AF
					// Note that fVar is not divided by n-1
					// because only the ratio is used for gamma
					for(i=0; i<sCornData.points; i++)
					{
						fVar=((2*sCornResults.sig_a[i]*sCornResults.sig_a[i]*
							sCornResults.sig_a[i]*sCornResults.sig_a[i])+
							(sCornResults.sig_a[i]*sCornResults.sig_a[i]*
							sCornResults.sig_b[i]*sCornResults.sig_b[i])+
							(sCornResults.sig_a[i]*sCornResults.sig_a[i]*
							sCornResults.sig_c[i]*sCornResults.sig_c[i])+
							(sCornResults.sig_b[i]*sCornResults.sig_b[i]*
							sCornResults.sig_c[i]*sCornResults.sig_c[i]));
						fGamma=(2*sCornResults.sig_a[i]*sCornResults.sig_a[i]*
							sCornResults.sig_a[i]*sCornResults.sig_a[i])/fVar;
						sCornResults.df_a[i]=(float)(sCornData.df_a[i]*fGamma);
						fVar=((2*sCornResults.sig_b[i]*sCornResults.sig_b[i]*
							sCornResults.sig_b[i]*sCornResults.sig_b[i])+
							(sCornResults.sig_a[i]*sCornResults.sig_a[i]*
							sCornResults.sig_b[i]*sCornResults.sig_b[i])+
							(sCornResults.sig_a[i]*sCornResults.sig_a[i]*
							sCornResults.sig_c[i]*sCornResults.sig_c[i])+
							(sCornResults.sig_b[i]*sCornResults.sig_b[i]*
							sCornResults.sig_c[i]*sCornResults.sig_c[i]));
						fGamma=(2*sCornResults.sig_a[i]*sCornResults.sig_a[i]*
							sCornResults.sig_a[i]*sCornResults.sig_a[i])/fVar;
						sCornResults.df_b[i]=(float)(sCornData.df_b[i]*fGamma);
						fVar=((2*sCornResults.sig_c[i]*sCornResults.sig_c[i]*
							sCornResults.sig_c[i]*sCornResults.sig_c[i])+
							(sCornResults.sig_a[i]*sCornResults.sig_a[i]*
							sCornResults.sig_b[i]*sCornResults.sig_b[i])+
							(sCornResults.sig_a[i]*sCornResults.sig_a[i]*
							sCornResults.sig_c[i]*sCornResults.sig_c[i])+
							(sCornResults.sig_b[i]*sCornResults.sig_b[i]*
							sCornResults.sig_c[i]*sCornResults.sig_c[i]));
						fGamma=(2*sCornResults.sig_a[i]*sCornResults.sig_a[i]*
							sCornResults.sig_a[i]*sCornResults.sig_a[i])/fVar;
						sCornResults.df_c[i]=(float)(sCornData.df_c[i]*fGamma);
					}
				}
				break;
				
				// Calc error bars 
				case IDC_CORN_ERRORBAR:
				{
					for(i=0; i<sCornData.points; i++)
					{
						// Set p limits
						fLow=(1-fConfFactor)/2;
						fHigh=1-fLow;

						// Process unit A
						// Calc upper & lower chi squared values
						// Skip if df<1
						if(sCornResults.df_a[i]>=1.0)
						{
							fChiHigh=CalcInvChiSqr(fHigh,
								sCornResults.df_a[i]);
							fChiLow=CalcInvChiSqr(fLow, sCornResults.df_a[i]);

							// Calc max sigma error bar
							sCornResults.sig_max_a[i]=(float)
								(sCornResults.sig_a[i]*
								sqrt(sCornResults.df_a[i]/fChiHigh));

							// Make sure low limit is OK
							// (may be NG for small CF)
							if(sqrt(sCornResults.df_a[i]/fChiLow>=1.0))
							{
								sCornResults.sig_min_a[i]=(float)
									(sCornResults.sig_a[i]*
									sqrt(sCornResults.df_a[i]/fChiHigh));
							}
							else // Calc min sigma error bar
							{
								sCornResults.sig_min_a[i]=(float)
									(sCornResults.sig_a[i]*
									sqrt(sCornResults.df_a[i]/fChiLow));
							}
						}

						// Process unit B
						// Calc upper & lower chi squared values
						// Skip if df<1
						if(sCornResults.df_b[i]>=1.0)
						{
							fChiHigh=CalcInvChiSqr(fHigh,
								sCornResults.df_b[i]);
							fChiLow=CalcInvChiSqr(fLow, sCornResults.df_b[i]);
					
							// Calc max sigma error bar
							sCornResults.sig_max_b[i]=(float)
								(sCornResults.sig_b[i]*
								sqrt(sCornResults.df_b[i]/fChiHigh));

							// Make sure low limit is OK
							// (may be NG for small CF)
							if(sqrt(sCornResults.df_b[i]/fChiLow>=1.0))
							{
								sCornResults.sig_min_b[i]=(float)
									(sCornResults.sig_b[i]*
									sqrt(sCornResults.df_b[i]/fChiHigh));
							}
							else // Calc min sigma error bar
							{
								sCornResults.sig_min_b[i]=(float)
									(sCornResults.sig_b[i]*
									sqrt(sCornResults.df_b[i]/fChiLow));
							}
						}

						// Process unit C
						// Calc upper & lower chi squared values
						// Skip if df<1
						if(sCornResults.df_c[i]>=1.0)
						{
							fChiHigh=CalcInvChiSqr(fHigh,
								sCornResults.df_c[i]);
							fChiLow=CalcInvChiSqr(fLow, sCornResults.df_c[i]);
						
							// Calc max sigma error bar
							sCornResults.sig_max_c[i]=(float)
								(sCornResults.sig_c[i]*
								sqrt(sCornResults.df_c[i]/fChiHigh));

							// Make sure low limit is OK
							// (may be NG for small CF)
							if(sqrt(sCornResults.df_c[i]/fChiLow>=1.0))
							{
								sCornResults.sig_min_c[i]=(float)
									(sCornResults.sig_c[i]*
									sqrt(sCornResults.df_c[i]/fChiHigh));
							}
							else // Calc min sigma error bar
							{
								sCornResults.sig_min_c[i]=(float)
									(sCornResults.sig_c[i]*
									sqrt(sCornResults.df_c[i]/fChiLow));
							}
						}
					}
				}
				break;

				// Write stability files to disk
				// Use _snprintf() & fputs() instead of fprintf() so that
				// ShortenExp() can be used to give 2-digit exponent
				case IDC_CORN_WRITE:
				{
					// Write 3 stability files
					//Filenames are always UnitA.sig, UnitB.sig & UnitC.sig
					//and are written to same directory
					// where stability data was read
					for(j=0; j<3; j++)
					{
						switch(j)
						{
							case 0: // 1st unit
							{
								// Get 1st filename
								GetWindowText(GETHCTL(IDC_CORN_A),	szCornFile,
									FILE_NAME_SIZE);
								_splitpath(szCornFile, szDrive, szDir, NULL,
									szExt);
								strlcpy(szBuffer, "UnitA", sizeof(szBuffer));
								_makepath(szResultsFile, szDrive, szDir,
									szBuffer, szExt);
							}
							break;
							
							case 1: // 2nd unit
							{
								// Get 2nd filename
								GetWindowText(GETHCTL(IDC_CORN_A),	szCornFile,
									FILE_NAME_SIZE);
								_splitpath(szCornFile, szDrive, szDir, NULL,
									szExt);
								strlcpy(szBuffer, "UnitB", sizeof(szBuffer));
								_makepath(szResultsFile, szDrive, szDir,
									szBuffer, szExt);
							}

							break;
							
							case 2: // 3rd unit
							{
								// Get 3rd filename
								GetWindowText(GETHCTL(IDC_CORN_A),	szCornFile,
									FILE_NAME_SIZE);
								_splitpath(szCornFile, szDrive, szDir, NULL,
									szExt);
								strlcpy(szBuffer, "UnitC", sizeof(szBuffer));
								_makepath(szResultsFile, szDrive, szDir,
									szBuffer, szExt);
							}
							break;
						}

						// Open output file
						if((out=fopen(szResultsFile, "w"))==NULL)
						{
							strlcpy(szBuffer, "Can Not Open ",
								sizeof(szBuffer));
							strlcat(szBuffer, szResultsFile, sizeof(szBuffer));
							strlcat(szBuffer, " Output File",
								sizeof(szBuffer));
							MessageBox(hwndMain, szBuffer, szBoxTitle,
								MB_ICONEXCLAMATION);
						}
						else
						{
							switch(j)
							{
								case 0: // 1st unit
								{
									for(i=0; i<sCornResults.points; i++)
									{
										LoadString(hInst, IDS_FORMAT_6,
											szFormat, BUFFER_SIZE);
										_snprintf(szBuffer, sizeof(szBuffer),
											szFormat, sCornResults.tau[i],
											sCornResults.num_a[i],
											sCornResults.sig_a[i],
											sCornResults.sig_min_a[i],
											sCornResults.sig_max_a[i],
											sCornResults.df_a[i]);
										ShortenExp(szBuffer);
										fputs(szBuffer, out);
									}
								}
								break;

								case 1: // 2nd unit
								{
									for(i=0; i<sCornResults.points; i++)
									{
										LoadString(hInst, IDS_FORMAT_6,
											szFormat, BUFFER_SIZE);
										_snprintf(szBuffer, sizeof(szBuffer),
											szFormat, sCornResults.tau[i],
											sCornResults.num_b[i],
											sCornResults.sig_b[i],
											sCornResults.sig_min_b[i],
											sCornResults.sig_max_b[i],
											sCornResults.df_b[i]);
										ShortenExp(szBuffer);
										fputs(szBuffer, out);
									}
								}
								break;

								case 2: // 3rd unit
								{
									for(i=0; i<sCornResults.points; i++)
									{
										LoadString(hInst, IDS_FORMAT_6,
											szFormat, BUFFER_SIZE);
										_snprintf(szBuffer, sizeof(szBuffer),
											szFormat, sCornResults.tau[i],
											sCornResults.num_c[i],
											sCornResults.sig_c[i],
											sCornResults.sig_min_c[i],
											sCornResults.sig_max_c[i],
											sCornResults.df_c[i]);
										ShortenExp(szBuffer);
										fputs(szBuffer, out);
									}
								}
								break;
							}
						
							fclose(out);                /* close output file */
						}
					}
				}
				break;

				// Clear stability data
				case IDC_CORN_CLEAR:
				{
					// Zero # points
					sNormSigData.points=0;
					sModSigData.points=0;
					sCornData.points=0;
					sCornResults.points=0;
					nSigmaSize=0;

					// Reset flags
					bDataValid=FALSE;
					bResultsValid=FALSE;
					bPlotChanged=TRUE;

					// Set button states
					EnableWindow(GETHCTL(IDC_CORN_PLOT), bDataValid);
					EnableWindow(GETHCTL(IDC_CORN_PRINT), bResultsValid);
					EnableWindow(GETHCTL(IDC_CORN_OPTIONS), bDataValid);
					EnableWindow(GETHCTL(IDC_CORN_LINES), bDataValid);
					EnableWindow(GETHCTL(IDC_CORN_NOTES), bDataValid);
					EnableWindow(GETHCTL(IDC_CORN_COPY), bResultsValid);
					EnableWindow(GETHCTL(IDC_CORN_CALC), bDataValid);

					// Initiate communications with data table
					SendMessage(hSigTbl, DTM_VM_INITIALIZE, (WPARAM)FALSE,
						(LPARAM)nRows);
				}
				break;

				//  Respond to plot button
				case IDC_CORN_PLOT:
				{
					// Note: Run dlg box buttons are disabled before plotting
					// and reenabled after plotting in the SIGMA_PLOT code
					// of GPCWndProc()

					// Set sigma type (global)
					nSigmaPlotType=nSigmaType;

					// Reallocate sNormSigmaData arrays to triple-size
					// Not sure about overall impact of this - seems OK
					// Might want to realloc sNormSigmaData only
					ReallocSigmaArrays(3*nLines);

					// Initialize line count
					nLineCount=0;

					// Concatenate data for plot
					if(nCornType==CORN_DATA)
					{
						if(nUnitType==CORN_ALL || nUnitType==CORN_A)
						{
							// Copy data from sCornData to sNormSigData and
							// sModSigData
							// Note: num set to put symbols at points on plot
							for(i=0; i<nLines; i++)
							{
								sNormSigData.sigma[i]=sCornData.sig_a[i];
								sNormSigData.sig_min[i]=sCornData.sig_min_a[i];
								sNormSigData.sig_max[i]=sCornData.sig_max_a[i];
								sNormSigData.tau[i]=sCornData.tau[i];
								sNormSigData.num[i]=1;
								sModSigData.sigma[i]=sCornData.sig_a[i];
								sModSigData.sig_min[i]=sCornData.sig_min_a[i];
								sModSigData.sig_max[i]=sCornData.sig_max_a[i];
								sModSigData.tau[i]=sCornData.tau[i];
								sModSigData.num[i]=1;
							}
							nLineCount+=nLines;
						}
						if(nUnitType==CORN_ALL || nUnitType==CORN_B)
						{
							for(i=0; i<nLines; i++)
							{
								sNormSigData.sigma[i+nLineCount]=
									sCornData.sig_b[i];
								sNormSigData.sig_min[i+nLineCount]=
									sCornData.sig_min_b[i];
								sNormSigData.sig_max[i+nLineCount]=
									sCornData.sig_max_b[i];
								sNormSigData.tau[i+nLineCount]=
									sCornData.tau[i];
								sNormSigData.num[i+nLineCount]=1;
								sModSigData.sigma[i+nLineCount]=
									sCornData.sig_b[i];
								sModSigData.sig_min[i+nLineCount]=
									sCornData.sig_min_b[i];
								sModSigData.sig_max[i+nLineCount]=
									sCornData.sig_max_b[i];
								sModSigData.tau[i+nLineCount]=
									sCornData.tau[i];
								sModSigData.num[i+nLineCount]=1;
							}
							nLineCount+=nLines;
						}

						if(nUnitType==CORN_ALL || nUnitType==CORN_C)
						{
							for(i=0; i<nLines; i++)
							{
								sNormSigData.sigma[i+nLineCount]=
									sCornData.sig_c[i];
								sNormSigData.sig_min[i+nLineCount]=
									sCornData.sig_min_c[i];
								sNormSigData.sig_max[i+nLineCount]=
									sCornData.sig_max_c[i];
								sNormSigData.tau[i+nLineCount]=
									sCornData.tau[i];
								sNormSigData.num[i+nLineCount]=1;
								sModSigData.sigma[i+nLineCount]=
									sCornData.sig_c[i];
								sModSigData.sig_min[i+nLineCount]=
									sCornData.sig_min_c[i];
								sModSigData.sig_max[i+nLineCount]=
									sCornData.sig_max_c[i];
								sModSigData.tau[i+nLineCount]=
									sCornData.tau[i];
								sModSigData.num[i+nLineCount]=1;
							}
							nLineCount+=nLines;
						}
					}
					else // Results
					{
						if(nUnitType==CORN_ALL || nUnitType==CORN_A)
						{
							// Copy data from sCornResults to sNormSigmaData 
							for(i=0; i<nLines; i++)
							{
								sNormSigData.sigma[i]=
									sCornResults.sig_a[i];
								sNormSigData.sig_min[i]=
									sCornResults.sig_min_a[i];
								sNormSigData.sig_max[i]=
									sCornResults.sig_max_a[i];
								sNormSigData.tau[i]=sCornResults.tau[i];
								sNormSigData.num[i]=1;
								sModSigData.sigma[i]=
									sCornResults.sig_a[i];
								sModSigData.sig_min[i]=
									sCornResults.sig_min_a[i];
								sModSigData.sig_max[i]=
									sCornResults.sig_max_a[i];
								sModSigData.tau[i]=
									sCornResults.tau[i];
								sModSigData.num[i]=1;
							}
							nLineCount+=nLines;
						}

						if(nUnitType==CORN_ALL || nUnitType==CORN_B)
						{
							for(i=0; i<nLines; i++)
							{
								sNormSigData.sigma[i+nLineCount]=
									sCornResults.sig_b[i];
								sNormSigData.sig_min[i+nLineCount]=
									sCornResults.sig_min_b[i];
								sNormSigData.sig_max[i+nLineCount]=
									sCornResults.sig_max_b[i];
								sNormSigData.tau[i+nLineCount]=
									sCornResults.tau[i];
								sNormSigData.num[i+nLineCount]=1;
								sModSigData.sigma[i+nLineCount]=
									sCornResults.sig_b[i];
								sModSigData.sig_min[i+nLineCount]=
									sCornResults.sig_min_b[i];
								sModSigData.sig_max[i+nLineCount]=
									sCornResults.sig_max_b[i];
								sModSigData.tau[i+nLineCount]=
									sCornResults.tau[i];
								sModSigData.num[i+nLineCount]=1;
							}
							nLineCount+=nLines;
						}

						if(nUnitType==CORN_ALL || nUnitType==CORN_C)
						{
							for(i=0; i<nLines; i++)
							{
								sNormSigData.sigma[i+nLineCount]=
									sCornResults.sig_c[i];
								sNormSigData.sig_min[i+nLineCount]=
									sCornResults.sig_min_c[i];
								sNormSigData.sig_max[i+nLineCount]=
									sCornResults.sig_max_c[i];
								sNormSigData.tau[i+nLineCount]=
									sCornResults.tau[i];
								sNormSigData.num[i+nLineCount]=1;
								sModSigData.sigma[i+nLineCount]=
									sCornResults.sig_c[i];
								sModSigData.sig_min[i+nLineCount]=
									sCornResults.sig_min_c[i];
								sModSigData.sig_max[i+nLineCount]=
									sCornResults.sig_max_c[i];
								sModSigData.tau[i+nLineCount]=
									sCornResults.tau[i];
								sModSigData.num[i+nLineCount]=1;
							}
							nLineCount+=nLines;
						}
					}
					
					// Set # points
					sNormSigData.points=nLineCount;
					sModSigData.points=nLineCount;
					nSigmaSize=nLineCount;

					// Set subtitle
					if(nUnitType==CORN_ALL)
					{
						_splitpath(szCornFileA, NULL, NULL, szBuffer, NULL);
						strlcpy(szFileTitle, szBuffer, FILE_TITLE_SIZE);
						_splitpath(szCornFileB, NULL, NULL, szBuffer, NULL);
						strlcat(szFileTitle, ", ", FILE_TITLE_SIZE);
						strlcat(szFileTitle, szBuffer, FILE_TITLE_SIZE);
						_splitpath(szCornFileC, NULL, NULL, szBuffer, NULL);
						strlcat(szFileTitle, ", ", FILE_TITLE_SIZE);
						strlcat(szFileTitle, szBuffer, FILE_TITLE_SIZE);
					}
					if(nUnitType==CORN_A)
					{
						_splitpath(szCornFileA, NULL, NULL, szFileTitle, NULL);
					}
					if(nUnitType==CORN_B)
					{
						_splitpath(szCornFileB, NULL, NULL, szFileTitle, NULL);
					}
					if(nUnitType==CORN_C)
					{
						_splitpath(szCornFileC, NULL, NULL, szFileTitle, NULL);
					}

					if(bPlotChanged)
					{
						// Initialize sigma plot parameters
						InitSigmaPlotParams();

						// Get scale limits
						// Start with this GraphiC function,
						// which will find max OK
						// but will set min to 0
						// if there are any coded neg variances
						minmax(&sSPlot.y_min, &sSPlot.y_max, sNormSigData.sigma,
							nSigmaSize);

						// Next, set min to max
						sSPlot.y_min=sSPlot.y_max;

						// Then search for non-zero min
						for(i=0; i<nSigmaSize; i++)
						{
							if( (sNormSigData.sigma[i]) &&
								(sNormSigData.sigma[i]<sSPlot.y_min) )
							{
								sSPlot.y_min=sNormSigData.sigma[i];
							}
						}
					}

					// No table or error bars on stability plot
					// if all being plotted
					if(nUnitType==CORN_ALL)
					{
						sSPlot.do_table=FALSE;
						sSPlot.do_errbar=FALSE;
					}

					if(bPlotChanged)
					{
						// Set message
						strlcpy(sSPlot.message_str, "3-Cornered Hat Analysis",
							MESSAGESIZE);
					}
					
					// Reset plot changed flag
					bPlotChanged=FALSE;
					
					// Set plot window title
					LoadString(hInst, IDS_TITLE_SIGPLOT, TitleString,
						BUFFER_SIZE);


					// Create child window for plot
					GPCWINCreate(hChildWnd, hInst, hDlg, SW_SHOWNORMAL,
						&hChildAccel, NULL);
				}
				break;

				//  Respond to options button
				case IDC_CORN_OPTIONS:
				{
					// Disable buttons
					EnableWindow(GETHCTL(IDC_CORN_READ), FALSE);
					EnableWindow(GETHCTL(IDCANCEL), FALSE);
					EnableWindow(GETHCTL(IDC_CORN_PLOT), FALSE);
					EnableWindow(GETHCTL(IDC_CORN_PRINT), FALSE);
					EnableWindow(GETHCTL(IDC_CORN_OPTIONS), FALSE);
					EnableWindow(GETHCTL(IDC_CORN_LINES), FALSE);
					EnableWindow(GETHCTL(IDC_CORN_NOTES), FALSE);
					EnableWindow(GETHCTL(IDHELP), FALSE);

					// Open read options dialog box
					InvokeDialogBox(hInst, "SigmaPlotBox", hwndMain,
						(DLGPROC)ReadPlotDlgProc);

					// Enable buttons
					EnableWindow(GETHCTL(IDC_CORN_READ), TRUE);
					EnableWindow(GETHCTL(IDCANCEL), TRUE);
					if(bDataValid)
					{
						EnableWindow(GETHCTL(IDC_CORN_PLOT), TRUE);
						EnableWindow(GETHCTL(IDC_CORN_PRINT), TRUE);
					}
					EnableWindow(GETHCTL(IDC_CORN_OPTIONS), TRUE);
					EnableWindow(GETHCTL(IDC_CORN_LINES), TRUE);
					EnableWindow(GETHCTL(IDC_CORN_NOTES), TRUE);
					EnableWindow(GETHCTL(IDHELP), TRUE);

					// Give Read dialog box the focus
					SetFocus(hDlg);
				}
				break;

				//  Respond to lines button
				case IDC_CORN_LINES:
				{
					// Disable buttons
					EnableWindow(GETHCTL(IDC_CORN_READ), FALSE);
					EnableWindow(GETHCTL(IDCANCEL), FALSE);
					EnableWindow(GETHCTL(IDC_CORN_PLOT), FALSE);
					EnableWindow(GETHCTL(IDC_CORN_PRINT), FALSE);
					EnableWindow(GETHCTL(IDC_CORN_OPTIONS), FALSE);
					EnableWindow(GETHCTL(IDC_CORN_LINES), FALSE);
					EnableWindow(GETHCTL(IDC_CORN_NOTES), FALSE);
					EnableWindow(GETHCTL(IDHELP), FALSE);

					// Open run lines dialog box
					InvokeDialogBox(hInst, "SigmaLineBox", hwndMain,
						(DLGPROC)SigmaLineDlgProc);

					// Enable buttons
					EnableWindow(GETHCTL(IDC_CORN_READ), TRUE);
					EnableWindow(GETHCTL(IDCANCEL), TRUE);
					if(bDataValid)
					{
						EnableWindow(GETHCTL(IDC_CORN_PLOT), TRUE);
						EnableWindow(GETHCTL(IDC_CORN_PRINT), TRUE);
					}
					EnableWindow(GETHCTL(IDC_CORN_OPTIONS), TRUE);
					EnableWindow(GETHCTL(IDC_CORN_LINES), TRUE);
					EnableWindow(GETHCTL(IDC_CORN_NOTES), TRUE);
					EnableWindow(GETHCTL(IDHELP), TRUE);

					// Give Run dialog box the focus
					SetFocus(hDlg);
				}
				break;

				//  Respond to notes button
				case IDC_CORN_NOTES:
				{
					// Disable buttons
					EnableWindow(GETHCTL(IDC_CORN_READ), FALSE);
					EnableWindow(GETHCTL(IDCANCEL), FALSE);
					EnableWindow(GETHCTL(IDC_CORN_PLOT), FALSE);
					EnableWindow(GETHCTL(IDC_CORN_PRINT), FALSE);
					EnableWindow(GETHCTL(IDC_CORN_OPTIONS), FALSE);
					EnableWindow(GETHCTL(IDC_CORN_LINES), FALSE);
					EnableWindow(GETHCTL(IDC_CORN_NOTES), FALSE);
					EnableWindow(GETHCTL(IDHELP), FALSE);

					// Open run notes dialog box
					InvokeDialogBox(hInst, "PlotNoteBox", hwndMain,
						(DLGPROC)SigmaNoteDlgProc);

					// Enable buttons
					EnableWindow(GETHCTL(IDC_CORN_READ), TRUE);
					EnableWindow(GETHCTL(IDCANCEL), TRUE);
					if(bDataValid)
					{
						EnableWindow(GETHCTL(IDC_CORN_PLOT), TRUE);
						EnableWindow(GETHCTL(IDC_CORN_PRINT), TRUE);
					}
					EnableWindow(GETHCTL(IDC_CORN_OPTIONS), TRUE);
					EnableWindow(GETHCTL(IDC_CORN_LINES), TRUE);
					EnableWindow(GETHCTL(IDC_CORN_NOTES), TRUE);
					EnableWindow(GETHCTL(IDHELP), TRUE);

					// Give Run dialog box the focus
					SetFocus(hDlg);
				}
				break;

				// Respond to copy button
				case IDC_CORN_COPY:
				{
					// Assign size of clipboard string
					nCB=(10+sNormSigData.points)*80;

					// Allocate clipboard string
					hClipboard=GlobalAlloc(GMEM_DDESHARE,
						(DWORD)nCB);
					szClipboard=GlobalLock(hClipboard);

					// Heading
					LoadString(hInst, IDS_HEADING_26, szBuffer, BUFFER_SIZE);
					strlcpy(szClipboard, szBuffer, nCB);
					strlcat(szClipboard, "\r\n", nCB);

					// a-b
					strlcpy(szBuffer, "A-B Stability Data: ",
						sizeof(szBuffer));
					strlcat(szBuffer, szCornFileA, sizeof(szBuffer));
					strlcat(szClipboard, szBuffer, nCB);
					strlcat(szClipboard, "\r\n", nCB);

					// a-c
					strlcpy(szBuffer, "A-C Stability Data: ",
						sizeof(szBuffer));
					strlcat(szBuffer, szCornFileB, sizeof(szBuffer));
					strlcat(szClipboard, szBuffer, nCB);
					strlcat(szClipboard, "\r\n", nCB);

					// b-c
					strlcpy(szBuffer, "B-C Stability Data: ",
						sizeof(szBuffer));
					strlcat(szBuffer, szCornFileC, sizeof(szBuffer));
					strlcat(szClipboard, szBuffer, nCB);
					strlcat(szClipboard, "\r\n", nCB);

					// Results heading
					LoadString(hInst, IDS_HEADING_25, szBuffer, BUFFER_SIZE);
					strlcat(szClipboard, szBuffer, nCB);
					strlcat(szClipboard, "\r\n", nCB);

					// Results table
					for(i=0; i<sCornResults.points; i++)
					{
						LoadString(hInst, IDS_FORMAT_27, szFormat,
							BUFFER_SIZE);
						_snprintf(szBuffer, sizeof(szBuffer), szFormat,
							sCornResults.tau[i], sCornResults.sig_a[i],
							sCornResults.sig_b[i], sCornResults.sig_c[i]);
						ShortenExp(szBuffer);

						// 0 is code for negative variance
						// Never have - sign so fields are always same width
						// Check for and label negative variances
						if(szBuffer[11]=='0')
						{
							// Label cell
							szBuffer[11]='N';
							szBuffer[12]='e';
							szBuffer[13]='g';
							szBuffer[14]='a';
							szBuffer[15]='t';
							szBuffer[16]='i';
							szBuffer[17]='v';
							szBuffer[18]='e';
							szBuffer[19]=' ';
						}

						if(szBuffer[22]=='0')
						{
							// Label cell
							szBuffer[22]='N';
							szBuffer[23]='e';
							szBuffer[24]='g';
							szBuffer[25]='a';
							szBuffer[26]='t';
							szBuffer[27]='i';
							szBuffer[28]='v';
							szBuffer[29]='e';
							szBuffer[30]=' ';
						}

						if(szBuffer[33]=='0')
						{
							// Label cell
							szBuffer[33]='N';
							szBuffer[34]='e';
							szBuffer[35]='g';
							szBuffer[36]='a';
							szBuffer[37]='t';
							szBuffer[38]='i';
							szBuffer[39]='v';
							szBuffer[40]='e';
							szBuffer[41]=' ';
						}
	
						strlcat(szClipboard, szBuffer, nCB);
						strlcat(szClipboard, "\r\n", nCB);
					}

					GlobalUnlock(hClipboard);
						OpenClipboard(NULL);
						EmptyClipboard();
						SetClipboardData(CF_TEXT, hClipboard);
						CloseClipboard();
				}
				break;

				// Print stability data on printer
				// Note: Bare-bones printing code
				// Single fixed-pitch, 8.5"x11" portrait page
				case IDC_CORN_PRINT:
				{
					// Check for too many points
					if(nRows>MAX_NUM_ROWS)
					{
						LoadString(hInst, IDS_MESSAGE_PRINT, szBuffer,
							BUFFER_SIZE);
						MessageBox(hDlg, szBuffer, "3-Cornered Hat Print",
							MB_ICONEXCLAMATION);
						break;
					}

					// Let user choose printer in PrintDlg
					// Initialize PRINTDLG structure
					memset(&pd, 0, sizeof(PRINTDLG));
					pd.lStructSize=sizeof(PRINTDLG);
					pd.Flags=PD_RETURNDEFAULT; // Don't show dialog box

					// 1st (hidden) call to PrintDlg()
					// To set up hDevNames & hDevMode
 					if(!PrintDlg(&pd))
					{
						// PrintDlg() called failed
						MessageBox(hwndMain, "Printer Not Found",
							"3-Cornered Hat Print",	MB_ICONEXCLAMATION);
						break;
					}

					// Reinitialize PRINTDLG structure
					pd.Flags=PD_RETURNDC | PD_NOPAGENUMS | PD_NOSELECTION;
					// Get DC & no choice of page #s & no selection of text

					// 2nd (visible) call to PrintDlg()
					if(PrintDlg(&pd))
					{
						// Get printer device context
						hdcPrn=pd.hDC;
					}
					else
					{
						if(CommDlgExtendedError())
						{
							// Printer error
							MessageBox(hwndMain, "Printer Error",
								"3-Cornered Hat Print",	MB_ICONEXCLAMATION);
						}
						else // Error code 0
						{
							// User hit cancel button
							break;
						}
					}

					// Get page dimensions
					xPage=(short)GetDeviceCaps(hdcPrn, HORZRES);
					yPage=(short)GetDeviceCaps(hdcPrn, VERTRES);

					// Determine logfont.lfHeight from point size = nPointSize
					// where nPointSize is global variable that user can enter
					// in General page of Configure property sheet
					// Win32 documentation gives the formula:
					// lfHeight = -MulDiv(PointSize,
					// GetDeviceCaps(hDC, LOGPIXELSY), 72);
					// which becomes the following for our variables:
					// nFontHeight = -MulDiv(nPointSize,
					// GetDeviceCaps(hdcPrn, LOGPIXELSY), 72);
					// Both nPointSize and nFontHeight are global variables
					// A couple of typical values are nPointSize=9,
					// nFontHeight=-75
					// and nPointSize=10, nFontHeight=-83
					// (the abs value of nFontHeight is used)
					nFontHeight = -MulDiv(nPointSize, GetDeviceCaps(hdcPrn,
						LOGPIXELSY), 72);
					
					// Set font attributes
					logfont.lfHeight=nFontHeight;
					logfont.lfWidth=0;
					logfont.lfEscapement=0;
					logfont.lfOrientation=0;
					logfont.lfWeight=0;
					logfont.lfItalic=0;
					logfont.lfUnderline=0;
					logfont.lfStrikeOut=0;
					logfont.lfCharSet=OEM_CHARSET;
					logfont.lfOutPrecision=OUT_DEFAULT_PRECIS;
					logfont.lfClipPrecision=CLIP_DEFAULT_PRECIS;
					logfont.lfQuality=PROOF_QUALITY;
					logfont.lfPitchAndFamily=FIXED_PITCH | FF_DONTCARE;
					strlcpy(logfont.lfFaceName,"", LF_FACESIZE);

					// Create printer font
					hPrnFont=CreateFontIndirect(&logfont);

					// Select font into printer device
					SelectObject(hdcPrn, hPrnFont);

					// Get text metrics
					GetTextMetrics(hdcPrn, &tm);
					yChar=tm.tmHeight + tm.tmExternalLeading;
					xChar=tm.tmAveCharWidth;

					// Compose Print Manager message
					LoadString(hInst, IDS_MESSAGE_DATA, szPrnMsg,
						BUFFER_SIZE);

					// Set up DOCINFO structure
					memset(&di, 0, sizeof(DOCINFO));
					di.cbSize=sizeof(DOCINFO);
					di.lpszDocName=szPrnMsg;
					
					// Start printing
					if(hdcPrn != NULL)
					{
						if(StartDoc(hdcPrn, &di) != SP_ERROR)
						{
							// Actual printing code goes here
							StartPage(hdcPrn);

							nLine=0; // Heading
							SetTextAlign(hdcPrn,
								TA_LEFT || TA_TOP);
							// Heading
							LoadString(hInst, IDS_HEADING_26, szBuffer,
								BUFFER_SIZE);
							TextOut(hdcPrn, (int)(xChar/2),
								(int)((nLine+0.5)*yChar),
								szBuffer, strlen(szBuffer));

							nLine=1; // a-b
							strlcpy(szBuffer, "A-B Stability Data: ",
								sizeof(szBuffer));
							strlcat(szBuffer, szCornFileA, sizeof(szBuffer));
							TextOut(hdcPrn, (int)(xChar/2),
								(int)((nLine+0.5)*yChar),
								szBuffer, strlen(szBuffer));

							nLine=2; // a-c
							strlcpy(szBuffer, "A-C Stability Data: ",
								sizeof(szBuffer));
							strlcat(szBuffer, szCornFileB, sizeof(szBuffer));
							TextOut(hdcPrn, (int)(xChar/2),
								(int)((nLine+0.5)*yChar),
								szBuffer, strlen(szBuffer));

							nLine=3; // b-c
							strlcpy(szBuffer, "B-C Stability Data: ",
								sizeof(szBuffer));
							strlcat(szBuffer, szCornFileC, sizeof(szBuffer));
							TextOut(hdcPrn, (int)(xChar/2),
								(int)((nLine+0.5)*yChar),
								szBuffer, strlen(szBuffer));

							nLine=4; // Results heading
							LoadString(hInst, IDS_HEADING_25, szBuffer,
								BUFFER_SIZE);
							TextOut(hdcPrn, (int)(xChar/2),
								(int)((nLine+0.5)*yChar),
								szBuffer, strlen(szBuffer));

							// Data lines
							i=0;
							for(nLine=5; nLine<5+nRows; nLine++)
							{

								LoadString(hInst, IDS_FORMAT_27, szFormat,
									BUFFER_SIZE);
								_snprintf(szBuffer, sizeof(szBuffer), szFormat,
									sCornResults.tau[i], sCornResults.sig_a[i],
									sCornResults.sig_b[i], sCornResults.sig_c[i]);
								ShortenExp(szBuffer);

								// 0 is code for negative variance
								// Never have - sign
								// so fields are always same width
								// Check for and label negative variances
								if(szBuffer[11]=='0')
								{
									// Label cell
									szBuffer[11]='N';
									szBuffer[12]='e';
									szBuffer[13]='g';
									szBuffer[14]='a';
									szBuffer[15]='t';
									szBuffer[16]='i';
									szBuffer[17]='v';
									szBuffer[18]='e';
									szBuffer[19]=' ';
								}

								if(szBuffer[22]=='0')
								{
									// Label cell
									szBuffer[22]='N';
									szBuffer[23]='e';
									szBuffer[24]='g';
									szBuffer[25]='a';
									szBuffer[26]='t';
									szBuffer[27]='i';
									szBuffer[28]='v';
									szBuffer[29]='e';
									szBuffer[30]=' ';
								}

								if(szBuffer[33]=='0')
								{
									// Label cell
									szBuffer[33]='N';
									szBuffer[34]='e';
									szBuffer[35]='g';
									szBuffer[36]='a';
									szBuffer[37]='t';
									szBuffer[38]='i';
									szBuffer[39]='v';
									szBuffer[40]='e';
									szBuffer[41]=' ';
								}
	
								TextOut(hdcPrn, (int)(cyChar/2),
									(int)((nLine+0.4)*yChar), szBuffer,
									strlen(szBuffer));
								i++;
							}

							// End (single) page
							EndPage(hdcPrn);

							// End printing
							EndDoc(hdcPrn);
						}
						else // Error or print to file cancelled
						{
							;
						}

						// Release device context
						DeleteDC(hdcPrn);
					}
					else // hdcPrn==NULL
					{
						;
					}

					// Delete printer logical font
					DeleteObject(hPrnFont);
				}
				break;

				// End dialog box
				case IDCANCEL:
				{
					// Shrink stability data array sizes if necessary
					if(nLines>SIGMA_SIZE)
					{
						// Reallocate sigma arrays
						nCode=ReallocSigmaArrays(SIGMA_SIZE);

						// Note: If nCode is -1 there was a memory reallocation
						// error that was already announced but no action is
						// required since we are closing anyway
					}

					bStart=TRUE; // So arrays will be cleared when reopened

					// Restore all tau flag state
					bAllTau=bSaveAllTau;

					// Restore data type
					bDataType=bSaveDataType;

					// Reselect proper data type
					if(bDataType==FREQ_DATA)
					{
						SendMessage(hwndMain, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_FREQSELECT, 0, 0));
					}
					else
					{
						SendMessage(hwndMain, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_PHASESELECT, 0, 0));
					}

					// Reset start flag
					bStart=TRUE;

					// Close dialog box
					EndDialog(hDlg, 0);
				}
				return TRUE;
			}
		}
		break;
	 }
	 return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*                            GetSigmaData()                                 */
/*                                                                           */
/*      Function to put stability data point into row of Read data table     */
/*                                                                           */
/*      There is a VMSTRUCT inside the DataTable control.  It contains the   */
/*      elements nStatus, dwKey and lpData.  A pointer to it is passed to    */
/*      us via the lParam of each DTM message.  We assign this to a          */
/*      LPVMSTRUCT pointer called lpVMData.  We then compose a single        */
/*      formatted string with the tau, num, sig_min, sigma and sig_max data  */
/*      for 1 row of the stability data table:                               */
/*                                                                           */
/*      We use dwKey to access our sigmadata structure to get one row of     */
/*      stability data.  The relevant sigmadata items are:                   */
/*                                                                           */
/*          int points;                       Number of sigma data points    */
/*          float tau[SIGMA_SIZE];            Averaging time data array      */
/*          float num[SIGMA_SIZE];            Number of data points array    */
/*          float sigma[SIGMA_SIZE];          Sigma data array               */
/*          float sig_min[SIGMA_SIZE];        Lower sigma error bar array    */
/*          float sig_max[SIGMA_SIZE];        Upper sigma error bar array    */
/*                                                                           */
/*      The Read function uses the global sNormSigData sigmadata structure.  */
/*                                                                           */
/*      The local variables lpRowData and nRow are passed via the LPVMSTRUCT */
/*      parameter lpVMData.  They are then obtained as (SIGROWSTRUCT *)      */
/*      lpVMData->lpData and lpVMData->dwKey.                                */
/*                                                                           */
/*      Parameter:                                                           */
/*          LPVMSTRUCT  lpVMData        Pointer to row info structure:       */
/*                                          int nStatus      error code      */
/*                                          DWORD dwKey      data row #      */
/*                                          LPVOID lpData    row data string */
/*                                                                           */
/*      Revision record:                                                     */
/*          05/20/97    Changed format from 10.4 to 10.3 to agree with data  */
/*			01/17/98	Changed # points format from 5d to 6d  & data to 9.3 */
/*			06/06/98	Added provisions for TIE rms and MTIE                */
/*          09/25/98    Changed # points format from 6d to 7d                */
/*			05/10/00	Added MTOT and TTOT                                  */
/*			02/16/03	Added Tho1 and overlapping plus tho1               */
/*			07/23/07	Added nReadTableChars for _snprintf() usage          */
/*                                                                           */
/*****************************************************************************/

int WINAPI GetSigmaData(LPVMSTRUCT lpVMData)
{
	// Local variables
	// The maximum allowable # of chars that can be put into the Read table
	// is the sum of the # chars in each of its columns
	// Four extra chars are needed for full display of last column
	// because each e format field needs 1 more character
	// for its 3-digit exponent before it is shortened
	int nReadTableChars=RT_NUM_TAU_CHARS + RT_NUM_NUM_CHARS+
		RT_NUM_MIN_CHARS + RT_NUM_SIG_CHARS +
		RT_NUM_MAX_CHARS + RT_NUM_EXTRA_CHARS;
	// Alias for table data pointer (just to simplify code)
	LPSTR szRowData=lpVMData->lpData;
	// Alias for table row # (just to simplify code)
	int nRow=(int)lpVMData->dwKey;

	if(nSigmaPlotType==MODIFIED_RUN || nSigmaPlotType==TIME_RUN     ||
	   nSigmaPlotType==MODTOTAL_RUN || nSigmaPlotType==TIMETOTAL_RUN )
	{
		// Check that row # is valid
		if(nRow<0 || nRow>=sModSigData.points)
		{
			// Return error code
			return (int)DTE_ROWOUTOFRANGE;
		}

		// Show all columns if either or both min & max data is non-zero
		if((sModSigData.sig_min[nRow]) || (sModSigData.sig_max[nRow]) )
		{
			// Load row data into string for display in table
			_snprintf(szRowData, nReadTableChars,
				"%9.3e%7d%9.3e%9.3e%9.3e",
				sModSigData.tau[nRow], (int)sModSigData.num[nRow],
				sModSigData.sig_min[nRow], sModSigData.sigma[nRow],
				sModSigData.sig_max[nRow]);
			ShortenExp(szRowData);
		}
		else // Put blanks in min & max sigma fields
		{
			_snprintf(szRowData, nReadTableChars,
				"%9.3e%7d         %9.3e          ",
				sModSigData.tau[nRow], (int)sModSigData.num[nRow],
				sModSigData.sigma[nRow]);
			ShortenExp(szRowData);
		}
	}

	if(nSigmaPlotType==NORMAL_RUN || nSigmaPlotType==OVERLAPPING_RUN ||
		nSigmaPlotType==TOTAL_RUN  || nSigmaPlotType==HADAMARD_RUN ||
		nSigmaPlotType==TIERMS_RUN || nSigmaPlotType==MTIE_RUN ||
		nSigmaPlotType==OVERLAPHAD_RUN || nSigmaPlotType==HADTOTAL_RUN )
	{
		// Check that row # is valid
		if(nRow<0 || nRow>=sNormSigData.points)
		{
			// Return error code
			return (int) DTE_ROWOUTOFRANGE;
		}

		// Show all columns if either or both min & max data is non-zero
		if((sNormSigData.sig_min[nRow]) || (sNormSigData.sig_max[nRow]) )
		{
			// Load row data into string for display in table
		   _snprintf(szRowData, nReadTableChars,
			   "%9.3e%7d%9.3e%9.3e%9.3e",
				sNormSigData.tau[nRow], (int)sNormSigData.num[nRow],
				sNormSigData.sig_min[nRow], sNormSigData.sigma[nRow],
				sNormSigData.sig_max[nRow]);
			ShortenExp(szRowData);
		}
		else // Put blanks in min & max sigma fields
		{
			_snprintf(szRowData, nReadTableChars,
				"%9.3e%7d         %9.3e          ",
				sNormSigData.tau[nRow], (int)sNormSigData.num[nRow],
				sNormSigData.sigma[nRow]);
			ShortenExp(szRowData);
		}
	}

	if(nSigmaPlotType==THEO1_RUN )
	{
		// Check that row # is valid
		if(nRow<0 || nRow>=sNormSigData.points)
		{
			// Return error code
			return (int) DTE_ROWOUTOFRANGE;
		}

		// Load row data into string for display in table
	    _snprintf(szRowData, nReadTableChars,
			"%9.3e       %9.3e%9.3e",
			sNormSigData.tau[nRow], sNormSigData.num[nRow],
			sNormSigData.sigma[nRow]);
		ShortenExp(szRowData);
	}

	if(nSigmaPlotType==BOTH_RUN)
	{
		// Check that row # is valid
		if(nRow<0 || nRow>=sModSigData.points)
		{
			// Return error code
			return (int) DTE_ROWOUTOFRANGE;
		}

		// Load row data into string for display in table
		_snprintf(szRowData, nReadTableChars,
			"%9.3e%7d%9.3e%9.3e%9.3e",
			sNormSigData.tau[nRow], (int)sNormSigData.num[nRow],
			sNormSigData.std_dev[nRow], sNormSigData.sigma[nRow],
			sModSigData.sigma[nRow]);
		ShortenExp(szRowData);
	}

	if(nSigmaPlotType==FULL_RUN)
	{
		// Check that row # is valid
		if(nRow<0 || nRow>=sNormSigData.points)
		{
			// Return error code
			return (int) DTE_ROWOUTOFRANGE;
		}

		// Load row data into string for display in table
		_snprintf(szRowData, nReadTableChars,
			"%9.3e%7d         %9.3e%9.3e",
			sNormSigData.tau[nRow], (int)sNormSigData.num[nRow],
			sNormSigData.sigma[nRow], sModSigData.sigma[nRow]);
		ShortenExp(szRowData);
	}

   // Return success
   return DTE_OKAY;
}

/*****************************************************************************/
/*                                                                           */
/*                             GetCornData()                                 */
/*                                                                           */
/*      Function to put stability data points into row of 3-cornered hat     */
/*		data table                                                           */
/*                                                                           */
/*      There is a VMSTRUCT inside the DataTable control.  It contains the   */
/*      elements nStatus, dwKey and lpData.  A pointer to it is passed to    */
/*      us via the lParam of each DTM message.  We assign this to a          */
/*      LPVMSTRUCT pointer called lpVMData.  We then compose a single        */
/*      formatted string with the tau, sig_a, sig_b and sig_c data           */
/*      for 1 row of the stability data table:                               */
/*                                                                           */
/*      We use dwKey to access our sigmadata structure to get one row of     */
/*      stability data.  The relevant corndata items are:                    */
/*                                                                           */
/*          float tau[SIGMA_SIZE];            Averaging time data array      */
/*          float sig_a[SIGMA_SIZE];          Sigma data array               */
/*          float sig_b[SIGMA_SIZE];          Lower sigma error bar array    */
/*          float sig_c[SIGMA_SIZE];          Upper sigma error bar array    */
/*                                                                           */
/*      The Corn function uses the global sNormSigData sigmadata structure   */
/*		to read the stability data in, and the sCornData corndata structure  */
/*      for the separated variances being displayed by this function.        */
/*                                                                           */
/*      The local variables lpRowData and nRow are passed via the LPVMSTRUCT */
/*      parameter lpVMData.  They are then obtained as (SIGROWSTRUCT *)      */
/*      lpVMData->lpData and lpVMData->dwKey.                                */
/*                                                                           */
/*      Parameter:                                                           */
/*          LPVMSTRUCT  lpVMData        Pointer to row info structure:       */
/*                                          int nStatus      error code      */
/*                                          DWORD dwKey      data row #      */
/*                                          LPVOID lpData    row data string */
/*                                                                           */
/*      Revision record:                                                     */
/*          08/18/01    Created from GetSigmaData()                          */
/*			07/23/07	Added nCornTableChars for _snprintf() usage          */
/*                                                                           */
/*****************************************************************************/

int WINAPI GetCornData(LPVMSTRUCT lpVMData)
{
	// Local variables
	// The maximum allowable # of chars that can be put into the Corn table
	// is the sum of the # chars in each of its columns
	// Four extra chars are needed for full display of last column
	// because each e format field needs 1 more character
	// for its 3-digit exponent before it is shortened
	int nCornTableChars=CT_NUM_TAU_CHARS +
		CT_NUM_A_CHARS + CT_NUM_B_CHARS +
		CT_NUM_C_CHARS + CT_NUM_EXTRA_CHARS;
	// Alias for table data pointer (just to simplify code)
	LPSTR szRowData=lpVMData->lpData;
	// Alias for table row # (just to simplify code)
	int nRow=(int)lpVMData->dwKey;


	// Check that row # is valid
	if(nRow<0 || nRow>=sCornData.points)
	{
		// Return error code
		return (int)DTE_ROWOUTOFRANGE;
	}

	// Load row data into string for display in table
	_snprintf(szRowData, nCornTableChars,
		"%9.3e%9.3e%9.3e%9.3e",
		sCornData.tau[nRow], sCornData.sig_a[nRow], sCornData.sig_b[nRow],
		sCornData.sig_c[nRow]);
	ShortenExp(szRowData);

   // Return success
   return DTE_OKAY;
}

/*****************************************************************************/
/*                                                                           */
/*                             GetCornResults()                              */
/*                                                                           */
/*      Function to put stability results points into row of 3-cornered hat  */
/*		data table                                                           */
/*                                                                           */
/*      There is a VMSTRUCT inside the DataTable control.  It contains the   */
/*      elements nStatus, dwKey and lpData.  A pointer to it is passed to    */
/*      us via the lParam of each DTM message.  We assign this to a          */
/*      LPVMSTRUCT pointer called lpVMData.  We then compose a single        */
/*      formatted string with the tau, sig_a, sig_b and sig_c data           */
/*      for 1 row of the stability data table:                               */
/*                                                                           */
/*      We use dwKey to access our sigmadata structure to get one row of     */
/*      stability data.  The relevant corndata items are:                    */
/*                                                                           */
/*          float tau[SIGMA_SIZE];            Averaging time data array      */
/*          float sig_a[SIGMA_SIZE];          Sigma data array               */
/*          float sig_b[SIGMA_SIZE];          Lower sigma error bar array    */
/*          float sig_c[SIGMA_SIZE];          Upper sigma error bar array    */
/*                                                                           */
/*      The Corn function uses the global sNormSigData sigmadata structure   */
/*		to read the stability data in, and the sCornResults corndata struct  */
/*      for the separated variances being displayed by this function.        */
/*                                                                           */
/*      The local variables lpRowData and nRow are passed via the LPVMSTRUCT */
/*      parameter lpVMData.  They are then obtained as (SIGROWSTRUCT *)      */
/*      lpVMData->lpData and lpVMData->dwKey.                                */
/*                                                                           */
/*      Parameter:                                                           */
/*          LPVMSTRUCT  lpVMData        Pointer to row info structure:       */
/*                                          int nStatus      error code      */
/*                                          DWORD dwKey      data row #      */
/*                                          LPVOID lpData    row data string */
/*                                                                           */
/*      Revision record:                                                     */
/*          08/19/01    Created from GetCornData()                           */
/*			07/23/07	Added nCornTableChars for _snprintf() usage          */
/*                                                                           */
/*****************************************************************************/

int WINAPI GetCornResults(LPVMSTRUCT lpVMData)
{
	// Local variables
	// The maximum allowable # of chars that can be put into the Corn table
	// is the sum of the # chars in each of its columns
	// Four extra chars are needed for full display of last column
	// because each e format field needs 1 more character
	// for its 3-digit exponent before it is shortened
	int nCornTableChars=CT_NUM_TAU_CHARS +
		CT_NUM_A_CHARS + CT_NUM_B_CHARS +
		CT_NUM_C_CHARS + CT_NUM_EXTRA_CHARS;
	// Alias for table data pointer (just to simplify code)
	LPSTR szRowData=lpVMData->lpData;
	// Alias for table row # (just to simplify code)
	int nRow=(int)lpVMData->dwKey;

	// Check that row # is valid
	if(nRow<0 || nRow>=sCornResults.points)
	{
		// Return error code
		return (int)DTE_ROWOUTOFRANGE;
	}

	// Load row data into string for display in table
	_snprintf(szRowData, nCornTableChars,
		"%9.3e%9.3e%9.3e%9.3e",
		sCornResults.tau[nRow], sCornResults.sig_a[nRow],
		sCornResults.sig_b[nRow], sCornResults.sig_c[nRow]);
	ShortenExp(szRowData);

	// 0 is code for negative variance
	// Never have - sign so fields are always same width
	// Check for and label negative variances
	if(szRowData[9]=='0')
	{
		// Label cell
		szRowData[9]='N';
		szRowData[10]='e';
		szRowData[11]='g';
		szRowData[12]='a';
		szRowData[13]='t';
		szRowData[14]='i';
		szRowData[15]='v';
		szRowData[16]='e';
		szRowData[17]=' ';
	}

	if(szRowData[18]=='0')
	{
		// Label cell
		szRowData[18]='N';
		szRowData[19]='e';
		szRowData[20]='g';
		szRowData[21]='a';
		szRowData[22]='t';
		szRowData[23]='i';
		szRowData[24]='v';
		szRowData[25]='e';
		szRowData[26]=' ';
	}

	if(szRowData[27]=='0')
	{
		// Label cell
		szRowData[27]='N';
		szRowData[28]='e';
		szRowData[29]='g';
		szRowData[30]='a';
		szRowData[31]='t';
		szRowData[32]='i';
		szRowData[33]='v';
		szRowData[34]='e';
		szRowData[35]=' ';
	}
	
	// Return success
   return DTE_OKAY;
}

/*****************************************************************************/
/*                                                                           */
/*                   PrintData Dialog Procedure                              */
/*                                                                           */
/*      Function to print selected phase or frequency data on printer        */
/*                                                                           */
/*      Revision record:                                                     */
/*          11/28/96    Added bFont flag                                     */
/*          02/02/97    Added bLines flag & macro                            */
/*			02/21/98	Updated printing code for Win32 API                  */
/*			03/21/08	Added copy support                                   */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK PrintDataDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local macro
	#define LINES_PER_COLUMN 80     // # data lines/column - was 55
	#define PRINT_LINES 0           // Control printing of lines (0 or 1)

	// Local variables
	// Chars
	char szBuffer[BUFFER_SIZE+1];   // Text buffer
	char szFormat[BUFFER_SIZE+1];   // Format string
	// Ints
	int nEntry;                     // # entered by user
	int nPrev;                      // Previous value
	static int nStart;              // Analysis start index
	static int nEnd;                // Analysis end index
	static int nSize;               // # data points
	static int nLines;				// # lines of data to copy to clipboard
	// BOOLs
	static BOOL bErrorTrap=FALSE;   // Flag for entry error
	static BOOL bTags=FALSE;        // Timetag flag
	static BOOL bAll=FALSE;         // All data flag
	static BOOL bPrintData;         // FREQ_DATA or PHASE_DATA print data type
	static BOOL bLines;             // Lines flag

	// Printing variables
	// Chars
	static char szLabel[BUFFER_SIZE+1];     // "Phase" or "Frequency" label
	// Shorts
	static short yChar;             // Text character vertical size
	static short xChar;             // Text character horizontal size
	static short xPage, yPage;      // Graphic page dims in pixels
	// Ints
	static int i;                   // Index
	static int nLine;             	// Line #
	static int nCol;                // Column #
	static int nPage;               // Page #
	static int nPages;              // # Pages
	static int nFull;               // Max # data points per page
	// BOOLs
	static BOOL bNewPage;           // New page flag
	static BOOL bFont=FALSE;        // Flag for font created
	// Handles
	HDC hdcPrn;                     // Handle to printer device context
	// Function Pointers
	FARPROC lpfnAbortProc;          // Pointer to AbortProc()
	FARPROC lpfnPrintDlgProc;       // Pointer to PrintDlgProc()
	// Structs
	TEXTMETRIC tm;                  // Text metrics structure
	// Printer font variables
	LOGFONT logfont;                // Printer logical font structure
	static HFONT hPrnFont;          // Printer font handle
	// Win32 API printing structs
	PRINTDLG pd;
	DOCINFO di;
	// Clipboard variables
	static int nClip;				// Size of szClipboard (chars)
	HGLOBAL hClipboard;				// Handle to clipboard text buffer
	LPSTR	szClipboard;			// Ptr to clipboard text string

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Initilize lines flag
			bLines=PRINT_LINES;

			// Initialize the print data type
			bPrintData=bDataType;

			// Initialize the data type radio buttons
			Button_SetCheck(GETHCTL(IDC_PRINT_PHASE), !bPrintData);
			Button_SetCheck(GETHCTL(IDC_PRINT_FREQ), bPrintData);

			// Disable data type button for which there is no data
			if(!bFreqData)
			{
				EnableWindow(GETHCTL(IDC_PRINT_FREQ), FALSE);
			}

			if(!bPhaseData)
			{
				EnableWindow(GETHCTL(IDC_PRINT_PHASE), FALSE);
			}

			// Initialize the Timetags checkbox state
			Button_SetCheck(GETHCTL(IDC_PRINT_TAGS), bTags);

			// Disable the Timetags checkbox if there is no timetag data
			if(bPrintData==FREQ_DATA && !bFreqTimetags)
			{
				EnableWindow(GETHCTL(IDC_PRINT_TAGS), FALSE);
			}

			if(bPrintData==PHASE_DATA && !bPhaseTimetags)
			{
				EnableWindow(GETHCTL(IDC_PRINT_TAGS), FALSE);
			}

			// Initialize the All Data checkbox state
			Button_SetCheck(GETHCTL(IDC_PRINT_ALL), bAll);

			// Initialize the Start and End values
			SendMessage(hDlg, WM_COMMAND,
				GET_WM_COMMAND_MPS(IDC_PRINT_ALL, NULL, 0));

			return TRUE;
		}

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				// Respond to Help pushbutton
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::PRINT_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::PRINT_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "PRINT_FUNCTION");
					#endif
				}
				break;

				// Respond to Phase radio button message
				case IDC_PRINT_PHASE:
				{
					// Get the state of the Phase radio button
					bPrintData=!(BOOL)
						Button_GetCheck(GETHCTL(IDC_PRINT_PHASE));

					// Update the Start and End values
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_PRINT_ALL, NULL, 0));

					// Enable Timetags checkbox if there is timetag data
					if(bPhaseTimetags)
					{
						EnableWindow(GETHCTL(IDC_PRINT_TAGS), TRUE);
					}
					// Disable Timetags checkbox if there is no timetag data
					else
					{
						EnableWindow(GETHCTL(IDC_PRINT_TAGS), FALSE);
					}
				}
				break;

				// Respond to Freq radio button message
				case IDC_PRINT_FREQ:
				{
					// Get the state of the Freq radio button
					bPrintData=(BOOL)Button_GetCheck(GETHCTL(IDC_PRINT_FREQ));

					// Update the Start and End values
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_PRINT_ALL, NULL, 0));

					// Enable Timetags checkbox if there is timetag data
					if(bFreqTimetags)
					{
						EnableWindow(GETHCTL(IDC_PRINT_TAGS), TRUE);
					}
					// Disable Timetags checkbox if there is no timetag data
					else
					{
						EnableWindow(GETHCTL(IDC_PRINT_TAGS), FALSE);
					}
				}
				break;

				// Respond to Timetags checkbox message
				case IDC_PRINT_TAGS:
				{
					// Get the state of the Timetags checkbox
					bTags=(BOOL)Button_GetCheck(GETHCTL(IDC_PRINT_TAGS));
				}
				break;

				// Respond to All Data checkbox message
				case IDC_PRINT_ALL:
				{
					// Get the state of the All Data checkbox
					bAll=(BOOL)Button_GetCheck(GETHCTL(IDC_PRINT_ALL));

					// Get analysis limits
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_PRINT_LIMITS, NULL, 0));

					if(bAll)
					{
						// Set the start value to 1
						SetWindowText(GETHCTL(IDC_PRINT_START), "1");

						// Set the end value to # data points
						_snprintf(szBuffer, sizeof(szBuffer), "%d", nSize);
						SetWindowText(GETHCTL(IDC_PRINT_END), szBuffer);
					}
					else
					{
						// Set the start value to analysis start
						_snprintf(szBuffer, sizeof(szBuffer), "%d", nStart);
						SetWindowText(GETHCTL(IDC_PRINT_START), szBuffer);

						// Set the end value to analysis end
						_snprintf(szBuffer, sizeof(szBuffer), "%d", nEnd);
						SetWindowText(GETHCTL(IDC_PRINT_END), szBuffer);
					}
				}
				break;

				// Respond to Start edit control message
				case IDC_PRINT_START:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_PRINT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Save previous value
						nPrev=nStart;

						// Get (new) start point #
						GetWindowText(GETHCTL(IDC_PRINT_START),	szBuffer,
							BUFFER_SIZE);
						nEntry=abs(atoi(szBuffer));

						// Check entry - must be between 1 and nEnd
						// Numeric params are value, min & max
						if(ValidateInteger(hDlg, nEntry, 1, nEnd)==TRUE)
						{
							// New value OK
							nStart=nEntry;
							_snprintf(szBuffer, sizeof(szBuffer), "%d",
								nStart);
							SetWindowText(GETHCTL(IDC_PRINT_START),	szBuffer);

							// Clear bAll if nStart>1
							if(nStart>1)
							{
								bAll=FALSE;
								Button_SetCheck(GETHCTL(IDC_PRINT_ALL), bAll);
							}
						}
						else
						{
							// Invalid entry - restore previous value
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nPrev);
							SetWindowText(GETHCTL(IDC_PRINT_START), szBuffer);
							SetFocus(GETHCTL(IDC_PRINT_START));
						}
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Respond to End edit control message
				case IDC_PRINT_END:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_PRINT_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Save previous value
						nPrev=nEnd;

						// Get (new) end point #
						GetWindowText(GETHCTL(IDC_PRINT_END), szBuffer,
							BUFFER_SIZE);
						nEntry=abs(atoi(szBuffer));

						// Check entry - must be between nStart and nSize
						// Numeric params are value, min & max
						if(ValidateInteger(hDlg, nEntry, nStart, nSize)==TRUE)
						{
							// New value OK
							nEnd=nEntry;
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nEnd);
							SetWindowText(GETHCTL(IDC_PRINT_END), szBuffer);

							// Clear bAll if nEnd<nSize
							if(nStart<nSize)
							{
								bAll=FALSE;
								Button_SetCheck(GETHCTL(IDC_PRINT_ALL), bAll);
							}
						}
						else
						{
							// Invalid entry - restore previous value
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nPrev);
							SetWindowText(GETHCTL(IDC_PRINT_END), szBuffer);
							SetFocus(GETHCTL(IDC_PRINT_END));
						}
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Internal function to get data and analysis limits
				case IDC_PRINT_LIMITS:
				{
					// Get # data points
					if(bPrintData==FREQ_DATA)
					{
						GetWindowText(hwndFreqNum, szBuffer, BUFFER_SIZE);
					}
					else
					{
						GetWindowText(hwndPhaseNum, szBuffer, BUFFER_SIZE);
					}
					nSize=atoi(szBuffer);

					// Get analysis start value
					if(bPrintData==FREQ_DATA)
					{
						GetWindowText(hwndFreqStart, szBuffer, BUFFER_SIZE);
					}
					else
					{
						GetWindowText(hwndPhaseStart, szBuffer,	BUFFER_SIZE);
					}
					nStart=atoi(szBuffer);

					// Get analysis end value
					if(bPrintData==FREQ_DATA)
					{
						GetWindowText(hwndFreqEnd, szBuffer, BUFFER_SIZE);
					}
					else
					{
						GetWindowText(hwndPhaseEnd, szBuffer, BUFFER_SIZE);
					}
					nEnd=atoi(szBuffer);
				}
				break;

				// Respond to CR in an edit control
				// Note: No button is a DEFPUSHBUTTON
				case IDOK:
				{
					// Does start edit control have focus?
					if(GetFocus()==GETHCTL(IDC_PRINT_START))
					{
						// Send EN_KILLFOCUS message to start edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_PRINT_START, NULL,
							EN_KILLFOCUS));
					}

					// Does end edit control have focus?
					if(GetFocus()==GETHCTL(IDC_PRINT_END))
					{
						// Send EN_KILLFOCUS message to end edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_PRINT_END, NULL,
							EN_KILLFOCUS));
					}
				}
				break;

				#if(1) // New code 03/21/07
				// Respond to copy button
				case IDC_PRINT_COPY:
				{
					// Get size of clipboard memory allocation
					// Total # lines = # data points plus header lines
					// Allow lines to be a generous 80 characters wide
					nLines=nEnd-nStart+1;
					nClip=(5+nLines)*80;
					
					// Allocate global memory for nClip lines of info
					hClipboard=GlobalAlloc(GMEM_DDESHARE,
						(DWORD)nClip);
					szClipboard=GlobalLock(hClipboard);

					// Write title
					if(bPrintData==FREQ_DATA)
					{
						strlcpy(szClipboard, "Frequency Data File: ", nClip);
						strlcat(szClipboard, szFileTitle, nClip);
					}
					else // Phase data
					{
						strlcpy(szClipboard, "Phase Data File: ", nClip);
						strlcat(szClipboard, szFileTitle, nClip);
					}
					strlcat(szClipboard, "\r\n", nClip);

					// Write sub-title
					_snprintf(szBuffer, sizeof(szBuffer),
						"Points %d thru %d of %d", nStart, nEnd, nSize);
					strlcat(szClipboard, szBuffer, nClip);
					strlcat(szClipboard, "\r\n", nClip);

					// Write lines to clipboard
					if( (bPrintData==FREQ_DATA && bFreqTimetags && bTags) ||
						(bPrintData==PHASE_DATA && bPhaseTimetags && bTags) )
					{
						if(bPrintData==FREQ_DATA)
						{
							// Write heading
							strlcpy(szBuffer,
								"#\tTimetag\t\t\tFrequency",
								sizeof(szBuffer));
							strlcat(szClipboard, szBuffer, nClip);
							strlcat(szClipboard, "\r\n", nClip);

							// Write data
							for(i=nStart-1; i<nEnd; i++)
							{
								// Write #
								_snprintf(szBuffer, sizeof(szBuffer),
									"%d", i+1);
								strlcat(szClipboard, szBuffer, nClip);

								// Write timnetag
								_snprintf(szBuffer, sizeof(szBuffer), "\t%+20.13e",
									fFreqTimetags[i+ARRAY_OFFSET]);
								ShortenExp(szBuffer);
								strlcat(szClipboard, szBuffer, nClip);

								// Write freq
								_snprintf(szBuffer, sizeof(szBuffer), "\t%+20.13e",
									fFreqData[i+ARRAY_OFFSET]);
								ShortenExp(szBuffer);
								strlcat(szClipboard, szBuffer, nClip);
								strlcat(szClipboard, "\r\n", nClip);
							}
						}
						else // Phase data
						{
							// Write heading
							strlcpy(szBuffer,
								"#\tTimetag\t\t\tPhase",
								sizeof(szBuffer));
							strlcat(szClipboard, szBuffer, nClip);
							strlcat(szClipboard, "\r\n", nClip);

							// Write data
							for(i=nStart-1; i<nEnd; i++)
							{
								// Write #
								_snprintf(szBuffer, sizeof(szBuffer),
									"%d", i+1);
								strlcat(szClipboard, szBuffer, nClip);

								// Write timnetag
								_snprintf(szBuffer, sizeof(szBuffer), "\t%+20.13e",
									fPhaseTimetags[i+ARRAY_OFFSET]);
								ShortenExp(szBuffer);
								strlcat(szClipboard, szBuffer, nClip);

								// Write phase
								_snprintf(szBuffer, sizeof(szBuffer), "\t%+20.13e",
									fPhaseData[i+ARRAY_OFFSET]);
								ShortenExp(szBuffer);
								strlcat(szClipboard, szBuffer, nClip);
								strlcat(szClipboard, "\r\n", nClip);
							}
						}
					}
					else // No timetags
					{
						if(bPrintData==FREQ_DATA)
						{
							// Write heading
							strlcpy(szBuffer,
								"#\tFrequency",
								sizeof(szBuffer));
							strlcat(szClipboard, szBuffer, nClip);
							strlcat(szClipboard, "\r\n", nClip);

							// Write data
							for(i=nStart-1; i<nEnd; i++)
							{
								// Write #
								_snprintf(szBuffer, sizeof(szBuffer),
									"%d", i+1);
								strlcat(szClipboard, szBuffer, nClip);

								// Write freq
								_snprintf(szBuffer, sizeof(szBuffer), "\t%+20.13e",
									fFreqData[i+ARRAY_OFFSET]);
								ShortenExp(szBuffer);
								strlcat(szClipboard, szBuffer, nClip);
								strlcat(szClipboard, "\r\n", nClip);
							}
						}
						else // Phase data
						{
							// Write heading
							strlcpy(szBuffer,
								"# \tPhase",
								sizeof(szBuffer));
							strlcat(szClipboard, szBuffer, nClip);
							strlcat(szClipboard, "\r\n", nClip);

							// Write data
							for(i=nStart-1; i<nEnd; i++)
							{
								// Write #
								_snprintf(szBuffer, sizeof(szBuffer),
									"%d", i+1);
								strlcat(szClipboard, szBuffer, nClip);

								// Write phase
								_snprintf(szBuffer, sizeof(szBuffer), "\t%+20.13e",
									fPhaseData[i+ARRAY_OFFSET]);
								ShortenExp(szBuffer);
								strlcat(szClipboard, szBuffer, nClip);
								strlcat(szClipboard, "\r\n", nClip);
							}
						}
					}

					// Write info to clipboard
					GlobalUnlock(hClipboard);
					OpenClipboard(NULL);
					EmptyClipboard();
					SetClipboardData(CF_TEXT, hClipboard);
					CloseClipboard();
				}
				break;
				#endif

				// Respond to OK pushbutton
				// Print phase or freq data on printer
				// Note: No font selection, uses fixed-space font.
				case IDC_PRINT_ACCEPT:
				{

					// Let user choose printer with print dialog box
					// Initialize PRINTDLG structure
					memset(&pd, 0, sizeof(PRINTDLG));
					pd.lStructSize=sizeof(PRINTDLG);
					pd.Flags=PD_RETURNDEFAULT; // Don't show dialog box

					// 1st (hidden) call to PrintDlg()
					// To set up hDevNames & hDevMode
 					if(!PrintDlg(&pd))
					{
						// PrintDlg() called failed
						MessageBox(hwndMain, "Printer Not Found", "Run Print",
						MB_ICONEXCLAMATION);
						break;
					}

					// Reinitialize PRINTDLG structure
					pd.Flags=PD_RETURNDC | PD_NOSELECTION | PD_NOPAGENUMS;
					// Get DC & no selection of text & no page #s

					// 2nd (visible) call to PrintDlg()
					if(PrintDlg(&pd))
					{
						// Get printer device context
						hdcPrn=pd.hDC;
					}
					else
					{
						if(CommDlgExtendedError())
						{
							// Printer error
							MessageBox(hwndMain, "Printer Error", "Run Print",
							MB_ICONEXCLAMATION);
						}
						else // Error code 0
						{
							// User hit cancel button
							break;
						}
					}

					// Determine logfont.lfHeight from point size = nPointSize
					// where nPointSize is global variable that user can enter
					// in General page of Configure property sheet
					// Win32 documentation gives the formula:
					// lfHeight = -MulDiv(PointSize,
					// GetDeviceCaps(hDC, LOGPIXELSY), 72);
					// which becomes the following for our variables:
					// nFontHeight = -MulDiv(nPointSize,
					// GetDeviceCaps(hdcPrn, LOGPIXELSY), 72);
					// Both nPointSize and nFontHeight are global variables
					// A couple of typical values are nPointSize=9,
					// nFontHeight=-75
					// and nPointSize=10, nFontHeight=-83
					// (the abs value of nFontHeight is used)
					nFontHeight = -MulDiv(nPointSize, GetDeviceCaps(hdcPrn,
						LOGPIXELSY), 72);
					
					// Set font attributes
					// Size to fit 4 columns on std 8.5"x11" portrait page
					// Fixed pitch for easy alignment
					logfont.lfHeight=nFontHeight;
					logfont.lfWidth=0;
					logfont.lfEscapement=0;
					logfont.lfOrientation=0;
					logfont.lfWeight=0;
					logfont.lfItalic=0;
					logfont.lfUnderline=0;
					logfont.lfStrikeOut=0;
					logfont.lfCharSet=OEM_CHARSET;
					logfont.lfOutPrecision=OUT_DEFAULT_PRECIS;
					logfont.lfClipPrecision=CLIP_DEFAULT_PRECIS;
					logfont.lfQuality=PROOF_QUALITY;
					logfont.lfPitchAndFamily=FIXED_PITCH | FF_DONTCARE;
					strlcpy(logfont.lfFaceName,"", LF_FACESIZE);

					// Create printer font
					hPrnFont=CreateFontIndirect(&logfont);
					bFont=TRUE;

					// Select font into printer device
					SelectObject(hdcPrn, hPrnFont);

					// Get text metrics
					GetTextMetrics(hdcPrn, &tm);
					yChar=(short)(tm.tmHeight+tm.tmExternalLeading);
					xChar=(short)tm.tmAveCharWidth;

					// Get page dimensions
					xPage=(short)GetDeviceCaps(hdcPrn, HORZRES);
					yPage=(short)GetDeviceCaps(hdcPrn, VERTRES);

					// Compose Print Manager message
					LoadString(hInst, IDS_MESSAGE_DATA, szPrnMsg,
						BUFFER_SIZE);

					// Set up DOCINFO structure
					memset(&di, 0, sizeof(DOCINFO));
					di.cbSize=sizeof(DOCINFO);
					di.lpszDocName=szPrnMsg;

					// Start printing
					if(hdcPrn!=NULL)
					{
						// Disable program window
						EnableWindow(hDlg, FALSE);

						// Set up abort procedure
						bUserAbort=FALSE;
						lpfnPrintDlgProc=(FARPROC)PrintDlgProc;
						hDlgPrint=CreateDialog(hInst, "PrintAbortBox",
							hDlg, (DLGPROC)lpfnPrintDlgProc);
						lpfnAbortProc=(FARPROC)AbortProc;
						Escape(hdcPrn, SETABORTPROC, 0,
							(LPSTR)lpfnAbortProc, NULL);
					
					// Start printing
					if(hdcPrn != NULL)
					{
						if(StartDoc(hdcPrn, &di) != SP_ERROR)
						{
							// Actual printing code starts here
							// Initialize newpage flag
							bNewPage=TRUE;

							// Initialize page #, line # & data point index
							nPage=0;
							nLine=0;
							i=nStart-1;

							// Determine total # pages
							if(bTags)
							{
								// Determine page capacity
								nFull=2*LINES_PER_COLUMN;
							}
							else
							{
								// Determine page capacity
								nFull=4*LINES_PER_COLUMN;
							}
							// Note:  The 1.0 forces a float calc
							nPages=(int)ceil((nEnd-nStart+1.0)/nFull);

							// Print while loop
							while(i<nEnd)
							{
								if(bNewPage)
								{
									// Start new page
									StartPage(hdcPrn);

									// Clear new page flag
									bNewPage=FALSE;

									// Select font into printer device
									// Note: Have to do this for each page
									SelectObject(hdcPrn, hPrnFont);

									// Annotate printout
									nCol=0;
									SetTextAlign(hdcPrn, TA_LEFT || TA_TOP);

									if(bPrintData==FREQ_DATA)
									{
										// Write title
										nLine=0;
										LoadString(hInst, IDS_FORMAT_16,
											szFormat, BUFFER_SIZE);
										_snprintf(szBuffer, sizeof(szBuffer),
											szFormat, szFileTitle);
										TextOut(hdcPrn, (int)(xChar/2),
											(int)((nLine+0.5)*yChar), szBuffer,
											strlen(szBuffer));

										// Compose label
										strlcpy(szLabel, "        Frequency",
											sizeof(szLabel));
									}
									else // Phase data
									{
										// Write title
										nLine=0;
										LoadString(hInst, IDS_FORMAT_17,
											szFormat, BUFFER_SIZE);
										_snprintf(szBuffer, sizeof(szBuffer),
											szFormat, szFileTitle);
										TextOut(hdcPrn, (int)(xChar/2),
											(int)((nLine+0.5)*yChar), szBuffer,
											strlen(szBuffer));

										// Compose label
										strlcpy(szLabel, "            Phase",
											sizeof(szLabel));
									}

									// Write sub-title
									nLine=1;
									_snprintf(szBuffer, sizeof(szBuffer),
										" Points %d thru %d of %d", nStart,
										nEnd, nSize);
									TextOut(hdcPrn, (int)(xChar/2),
										(int)((nLine+0.5)*yChar), szBuffer,
										strlen(szBuffer));

									// Write page #
									nLine=0;
									_snprintf(szBuffer, sizeof(szBuffer),
										"Page %d of %d ", nPage+1, nPages);
									TextOut(hdcPrn, (int)(xPage/2),
										(int)((nLine+0.5)*yChar), szBuffer,
										strlen(szBuffer));

									// Write date
									nLine=1;
									TextOut(hdcPrn, (int)(xPage/2),
										(int)((nLine+0.5)*yChar),
										szDate, strlen(szDate));

									// Write headings
									nLine=3;

									if(bTags)
									{
										// 2 # labels
										strlcpy(szBuffer, " #",
											sizeof(szBuffer));
										TextOut(hdcPrn, (int)(xChar/2),
											(int)((nLine+0.5)*yChar), szBuffer,
											strlen(szBuffer));
										TextOut(hdcPrn, (int)(xPage/2+xChar/2),
											(int)((nLine+0.5)*yChar), szBuffer,
											strlen(szBuffer));

										// 2 timetag labels
										strlcpy(szBuffer, "           Timetag",
											sizeof(szBuffer));
										TextOut(hdcPrn, (int)((7*xChar)+
											xChar/2),
											(int)((nLine+0.5)*yChar), szBuffer,
											strlen(szBuffer));
										TextOut(hdcPrn, (int)((xPage/2)+
											(7*xChar)+
											xChar/2), (int)((nLine+0.5)*yChar),
											szBuffer, strlen(szBuffer));

										// 2 value labels
										TextOut(hdcPrn,
											(int)((((7*xChar)+(xPage/2))/2)+
											xChar/2),
											(int)((nLine+0.5)*yChar), szLabel,
											strlen(szLabel));
										TextOut(hdcPrn,
											(int)((xPage/2)+(((7*xChar)+
											(xPage/2))/2)+
											xChar/2), (int)((nLine+0.5)*yChar),
											szLabel, strlen(szLabel));
									}
									else // No timetags
									{
									// 4 # labels
										strlcpy(szBuffer, "   #",
											sizeof(szBuffer));
										TextOut(hdcPrn, (int)((0*xPage/4)+
											xChar/2),
											(int)((nLine+0.5)*yChar), szBuffer,
											strlen(szBuffer));
										TextOut(hdcPrn,
											(int)((1*xPage/4)+xChar/2),
											(int)((nLine+0.5)*yChar), szBuffer,
											strlen(szBuffer));
										TextOut(hdcPrn,
											(int)((2*xPage/4)+xChar/2),
											(int)((nLine+0.5)*yChar), szBuffer,
											strlen(szBuffer));
										TextOut(hdcPrn,
											(int)((3*xPage/4)+xChar/2),
											(int)((nLine+0.5)*yChar), szBuffer,
											strlen(szBuffer));

										// 4 value labels
										TextOut(hdcPrn, (int)((0*xPage/4)+
											(7*xChar)+
											xChar/2), (int)((nLine+0.5)*yChar),
											szLabel, strlen(szLabel));
										TextOut(hdcPrn, (int)((1*xPage/4)+
											(7*xChar)+
											xChar/2), (int)((nLine+0.5)*yChar),
											szLabel, strlen(szLabel));
										TextOut(hdcPrn, (int)((2*xPage/4)+
											(7*xChar)+
											xChar/2), (int)((nLine+0.5)*yChar),
											szLabel, strlen(szLabel));
										TextOut(hdcPrn, (int)((3*xPage/4)+
											(7*xChar)+
											xChar/2), (int)((nLine+0.5)*yChar),
											szLabel, strlen(szLabel));
									}
									// Initialize line # and data point index
									nLine=5;
								} // End of new page code

								// Compose 1 line of data
								// Note: %17.10e format would be OK for time-
								// tags, but printout looks better if they use
								// same %+20.13 format as phase or freq data.
								if(bTags)
								{
									// Determine column #
									nCol=(int)floor(i/LINES_PER_COLUMN)%2;

									// Determine line #
									nLine=((nLine-5)%LINES_PER_COLUMN)+5;

									// Write #
									_snprintf(szBuffer, sizeof(szBuffer),
										" %04d", i+1);
									TextOut(hdcPrn, (int)((xChar/2)+
										(nCol*xPage/2)),
										(int)((nLine+0.4)*yChar), szBuffer,
										strlen(szBuffer));

									if(bPrintData==FREQ_DATA)
									{
										_snprintf(szBuffer, sizeof(szBuffer),
											"  %+20.13e",
											fFreqTimetags[i+ARRAY_OFFSET]);
										ShortenExp(szBuffer);

										// Write timetag
										TextOut(hdcPrn,
											(int)((7*xChar)+(xChar/2)+
											(nCol*xPage/2)),
											(int)((nLine+0.4)*yChar), szBuffer,
											strlen(szBuffer));

										_snprintf(szBuffer, sizeof(szBuffer),
											"  %+20.13e",
											fFreqData[i+ARRAY_OFFSET]);
										ShortenExp(szBuffer);
									}
									else // Phase data
									{
										_snprintf(szBuffer, sizeof(szBuffer),
											"  %+20.13e",
											fPhaseTimetags[i+ARRAY_OFFSET]);
										ShortenExp(szBuffer);

										// Write timetag
										TextOut(hdcPrn,
										(int)(7*xChar)+(xChar/2)+(nCol*xPage/2),
										(int)((nLine+0.4)*yChar), szBuffer,
										strlen(szBuffer));

										_snprintf(szBuffer, sizeof(szBuffer),
											"  %+20.13e",
											fPhaseData[i+ARRAY_OFFSET]);
										ShortenExp(szBuffer);
									}

									// Write value
									TextOut(hdcPrn,
										(int)(((7*xChar)+(xPage/2))/2)+
										(xChar/2)+
										(int)(nCol*xPage/2),
										(int)((nLine+0.4)*yChar),
										szBuffer, strlen(szBuffer));
								}
								else // No timetags
								{
									// Determine column #
									nCol=(int)floor(i/LINES_PER_COLUMN)%4;

									// Determine line #
									nLine=((nLine-5)%LINES_PER_COLUMN)+5;

									// Write #
									_snprintf(szBuffer, sizeof(szBuffer),
										" %04d", i+1);
									TextOut(hdcPrn, (int)((xChar/2)+
										(nCol*xPage/4)),
										(int)((nLine+0.4)*yChar), szBuffer,
										strlen(szBuffer));

									if(bPrintData==FREQ_DATA)
									{
										_snprintf(szBuffer, sizeof(szBuffer),
											"  %+20.13e",
											fFreqData[i+ARRAY_OFFSET]);
										ShortenExp(szBuffer);
									}
									else // Phase data
									{
										_snprintf(szBuffer, sizeof(szBuffer),
											"%+20.13e",
											fPhaseData[i+ARRAY_OFFSET]);
										ShortenExp(szBuffer);
									}

									// Write value
									TextOut(hdcPrn,
										(int)((7*xChar)+(xChar/2)+
										(nCol*xPage/4)),
										(int)((nLine+0.4)*yChar), szBuffer,
										strlen(szBuffer));
								}
								// Increment data index and line #
								i++;
								nLine++;

								// Check if page full
								if(i%nFull==0)
								{
									// End page
									EndPage(hdcPrn);
									nPage++;
									bNewPage=TRUE;
								}
							} // End of printing while loop
						} // End of print if statement

						// End last page
						EndPage(hdcPrn);
						
						// End printing
						EndDoc(hdcPrn);

						if(bPrintData==FREQ_DATA)
						{
							// Put info into log file
							_snprintf(szBuffer, sizeof(szBuffer), "#=%d",
								nEnd-nStart+1);
							WriteLog(22, szBuffer);
						}
						else // Phase data
						{
							// Put info into log file
							_snprintf(szBuffer, sizeof(szBuffer), "#=%d",
								nEnd-nStart+1);
							WriteLog(21, szBuffer);
						}
								
						}
						else // Error or print to file cancelled
						{
							;
						}

						// Check for user abort
						if(!bUserAbort)
						{
							// Reenable program window
							EnableWindow(hDlg, TRUE);
							// Destroy print abort dialog box
							DestroyWindow(hDlgPrint);
						}

						// Release device context
						DeleteDC(hdcPrn);
					}

					// Delete printer logical font
					DeleteObject(hPrnFont);
				}
				break;

				// Respond to esc key or cancel button
				case IDCANCEL:
				case IDC_PRINT_CANCEL:
				{
					// Delete printer logical font
					if(bFont)
					{
						DeleteObject(hPrnFont);
					}

					// Close dialog box
					EndDialog(hDlg, 0);
				}
				return TRUE;
			}
		}
		break;
	 }
	 return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*                             AbortProc()                                   */
/*                                                                           */
/*      AbortProc() from PRINT3.C of Petzold Chap. 15                        */
/*      Address of this function is passed to Windows with the Escape()      */
/*      SETABORTPROC subfunction to yield control if the GDI runs out of     */
/*      disk space.  This allows other programs (including PRINTMAN) to      */
/*      to run while Stable/Win is printing.                                 */
/*                                                                           */
/*      Revision record:                                                     */
/*                                                                           */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK AbortProc (HDC hdcPrn, short nCode)
{
	MSG   msg;

	// Note: Could check for nCode==SP_OUTOFDISK and return FALSE here

	while(!bUserAbort && PeekMessage(&msg, NULL, 0, 0, PM_REMOVE))
	{
		if(!hDlgPrint || !IsDialogMessage(hDlgPrint, &msg))
		{
			TranslateMessage(&msg);
			DispatchMessage(&msg);
		}
	}
	return !bUserAbort;
}

/*****************************************************************************/
/*                                                                           */
/*                             PrintDlgProc()                                */
/*                                                                           */
/*      PrintDlgProc() from PRINT3.C of Petzold Chap. 15                     */
/*      Modeless dialog box to allow user to cancel printing.                */
/*                                                                           */
/*      Revision record:                                                     */
/*                                                                           */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK PrintDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	switch(message)
	{
		case WM_INITDIALOG:
		{
			EnableMenuItem(GetSystemMenu(hDlg, FALSE), SC_CLOSE, MF_GRAYED);
			return TRUE;
		}

		case WM_COMMAND:
		{
			bUserAbort=TRUE;
			EnableWindow(GetParent(hDlg), TRUE);
			DestroyWindow(hDlg);
			hDlgPrint=0;
			return TRUE;
		}
	}
	return FALSE;
}
#endif

/*****************************************************************************/
/*                                                                           */
/*                    Part Dialog Procedure                                  */
/*                                                                           */
/*      Function to remove all except a selected portion of phase or         */
/*      frequency data.                                                      */
/*                                                                           */
/*      Revision record:                                                     */
/*          08/11/96    Written and added to Stable/Win                      */
/*          10/29/96    Added edit CR response & error trap logic            */
/*                      Now seems 100% AOK as example of dlg box behavior    */
/*          11/03/96    Added increment filename extension logic             */
/*			08/15/98	Added timetag processing                             */
/*			12/09/00	Change OK so dialog box stays open to repeat action  */
/*						and change Cancel to Close                           */
/*			05/17/01	Added timetag display & up/down buttons              */
/*			11/18/06	Added CreateTab() call                               */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK PartDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	// Chars
	char szBuffer[BUFFER_SIZE+1];   // Text buffer
	// Ints
	int i;                          // Index
	int nEntry;                     // # entered by user
	int nPrev;                      // Previous value
	static int nStart;              // Data start index
	static int nEnd;                // Data end index
	static int nSize;               // # data points
	static int nTagType;			// Timetag type
	// BOOLs
	static BOOL bErrorTrap=FALSE;   // Flag for entry error
	static BOOL bTags=FALSE;		// Flag for timetags
	// Timetag variables
	// Ints
	int nYear;
	int nDOY;
	int nMonth;
	int nDay;
	int nHour;
	int nMin;
	int nSec;
	static int nSum[] = { 0, 31, 59, 90, 120, 151, 181, 212,
						  243, 273, 304, 334, 365 };
	// Longs
	long lnMJD;
	// F_TYPEs
	F_TYPE fMJD;
	F_TYPE fIntMJD;
	F_TYPE fFractMJD;

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Initialize
			SendMessage(hDlg, WM_COMMAND,
				GET_WM_COMMAND_MPS(IDC_PART_INITIALIZE, NULL, 0));
			return TRUE;
		}

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				// Respond to Help pushbutton
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::PART_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::PART_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "PART_FUNCTION");
					#endif
				}
				break;

				// Respond to Start edit control message
				case IDC_PART_START:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_PART_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Save previous value
						nPrev=nStart;

						// Get (new) start point #
						GetWindowText(GETHCTL(IDC_PART_START), szBuffer,
							BUFFER_SIZE);
						nEntry=abs(atoi(szBuffer));

						// Check entry - must be between 1 and nEnd
						// Numeric params are value, min & max
						if(ValidateInteger(hDlg, nEntry, 1, nEnd)==TRUE)
						{
							// New value OK
							nStart=nEntry;

							// Redisplay value
							_snprintf(szBuffer, sizeof(szBuffer), "%d",
								nStart);
							SetWindowText(GETHCTL(IDC_PART_START), szBuffer);

							// Do we have timetags?
							if(bTags)
							{
								// Show start timetag
								SendMessage(hDlg, WM_COMMAND,
									GET_WM_COMMAND_MPS(IDC_PART_SHOWSTARTTAG,
									NULL, 0));
							}
 						}
						else
						{
							// Invalid entry - restore previous value
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nPrev);
							SetWindowText(GETHCTL(IDC_PART_START), szBuffer);
							SetFocus(GETHCTL(IDC_PART_START));
						}
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

				// Respond to End edit control message
				case IDC_PART_END:
				{
					// Respond to edit control when it loses the input focus
					// unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) &&
						(GetFocus()!=GETHCTL(IDC_PART_CANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Save previous value
						nPrev=nEnd;

						// Get (new) end point #
						GetWindowText(GETHCTL(IDC_PART_END), szBuffer,
							BUFFER_SIZE);
						nEntry=abs(atoi(szBuffer));

						// Check entry - must be between nStart and nSize
						// Numeric params are value, min & max
						if(ValidateInteger(hDlg, nEntry, nStart, nSize)==TRUE)
						{
							// New value OK
							nEnd=nEntry;

							// Redisplay value
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nEnd);
							SetWindowText(GETHCTL(IDC_PART_END), szBuffer);

							// Do we have timetags?
							if(bTags)
							{
								// Show end timetag
								SendMessage(hDlg, WM_COMMAND,
									GET_WM_COMMAND_MPS(IDC_PART_SHOWENDTAG,
									NULL, 0));
							}
 						}
						else
						{
							// Invalid entry - restore previous value
							_snprintf(szBuffer, sizeof(szBuffer), "%d", nPrev);
							SetWindowText(GETHCTL(IDC_PART_END), szBuffer);
							SetFocus(GETHCTL(IDC_PART_END));
						}
					}
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
				}
				break;

                case IDC_PART_STARTUP:
                {
                    // Increment start #
                    nStart++;

					// Limit max start to nEnd
					if(nStart>nEnd)
					{
						nStart=nEnd;
					}

					// Redisplay start value
					_snprintf(szBuffer, sizeof(szBuffer), "%d", nStart);
					SetWindowText(GETHCTL(IDC_PART_START), szBuffer);

					// Do we have timetags?
					if(bTags)
					{
						// Show start timetag
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_PART_SHOWSTARTTAG, NULL,
							0));
					}
                }
                break;

                case IDC_PART_STARTDOWN:
                {
                    // Decrement start #
                    nStart--;

					// Limit min start to 1
					if(nStart<1)
					{
						nStart=1;
					}

					// Redisplay start value
					_snprintf(szBuffer, sizeof(szBuffer), "%d", nStart);
					SetWindowText(GETHCTL(IDC_PART_START), szBuffer);

					// Do we have timetags
					if(bTags)
					{
						// Show start timetag
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_PART_SHOWSTARTTAG, NULL,
							0));
					}
                }
                break;

                case IDC_PART_ENDUP:
                {
                    // Increment end #
                    nEnd++;

					// Limit max end to nSize
					if(nEnd>nSize)
					{
						nEnd=nSize;
					}

					// Redisplay end value
					_snprintf(szBuffer, sizeof(szBuffer), "%d", nEnd);
					SetWindowText(GETHCTL(IDC_PART_END), szBuffer);

					// Do we have timetags?
					if(bTags)
					{
						// Show end timetag
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_PART_SHOWENDTAG, NULL,
							0));
					}
                }
                break;

                case IDC_PART_ENDDOWN:
                {
                    // Decrement end #
                    nEnd--;

					// Limit min end to nStart
					if(nEnd<nStart)
					{
						nEnd=nStart;
					}

					// Redisplay end value
					_snprintf(szBuffer, sizeof(szBuffer), "%d", nEnd);
					SetWindowText(GETHCTL(IDC_PART_END), szBuffer);

					// Do we have timetags?
					if(bTags)
					{
						// Show end timetag
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_PART_SHOWENDTAG, NULL,
							0));
					}
                 }
                break;

                // Detect timetag type change
                case IDC_PART_TAGTYPE:
                {
                    if(GET_WM_COMMAND_CMD(wParam, lParam)==CBN_SELCHANGE) 
                    {
						// Get the combo box selection
						nTagType=
							ComboBox_GetCurSel(GETHCTL(IDC_PART_TAGTYPE));
					}

					// Do we have timetags?
					if(bTags)
					{
						// Show start timetag
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_PART_SHOWSTARTTAG, NULL,
							0));

 						// Show end timetag
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_PART_SHOWENDTAG, NULL,
							0));
                    }
                }
                break;

				// Respond to CR in an edit control
				// Note: No button is a DEFPUSHBUTTON
				case IDOK:
				{
					// Does start edit control have focus?
					if(GetFocus()==GETHCTL(IDC_PART_START))
					{
						// Send EN_KILLFOCUS message to start edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_PART_START, NULL,
							EN_KILLFOCUS));
					}

					// Does end edit control have focus?
					if(GetFocus()==GETHCTL(IDC_PART_END))
					{
						// Send EN_KILLFOCUS message to end edit control
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_PART_END, NULL,
							EN_KILLFOCUS));
					}
				}
				break;

				// Internal subroutine to initialize
				case IDC_PART_INITIALIZE:
				{
					// Fill up the timetag type combo box list
					nDummy=ComboBox_ResetContent(GETHCTL(IDC_PART_TAGTYPE));
					nDummy=ComboBox_InsertString(GETHCTL(IDC_PART_TAGTYPE), 0,
							"None");
					nDummy=ComboBox_InsertString(GETHCTL(IDC_PART_TAGTYPE), 1,
							"MJD");
					nDummy=ComboBox_InsertString(GETHCTL(IDC_PART_TAGTYPE), 2,
							"DOY");
					nDummy=ComboBox_InsertString(GETHCTL(IDC_PART_TAGTYPE), 3,
							"Date");
					nDummy=ComboBox_InsertString(GETHCTL(IDC_PART_TAGTYPE), 4,
							"Exp");

					// Show selected timetag format
					nDummy=ComboBox_SetCurSel(GETHCTL(IDC_PART_TAGTYPE),
						nTagType);

					// Set up timetags
					if(bDataType==FREQ_DATA)
					{
						// Set timetag flag
						bTags=bFreqTimetags;
						
						if(bTags)
						{
							// Set tags pointer
							fTags=fFreqTimetags;
						}
					}
					else
					{
						// Set timetag flag
						bTags=bPhaseTimetags;
						
						if(bTags)
						{
							// Set tags pointer
							fTags=fPhaseTimetags;
						}
					}

					// Get # data points
					nSize=(int)fData[0];
					
					// Initialize limits
					nEnd=nSize;
					nStart=1;

					// Disable timetag type combo box if no timetags
					EnableWindow(GETHCTL(IDC_PART_TAGTYPE), bTags);

					// Do we have timetags?
					if(bTags)
					{
						// Show start timetag
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_PART_SHOWSTARTTAG, NULL,
							0));

 						// Show end timetag
						SendMessage(hDlg, WM_COMMAND,
							GET_WM_COMMAND_MPS(IDC_PART_SHOWENDTAG, NULL, 0));
                    }
					else
					{
						// Clear timetag display
						SetWindowText(GETHCTL(IDC_PART_SHOWSTARTTAG), "");
						SetWindowText(GETHCTL(IDC_PART_SHOWENDTAG), "");
					}

					// Set the start value to 1
					SetWindowText(GETHCTL(IDC_PART_START), "1");

					// Set the end value to # data points
					_snprintf(szBuffer, sizeof(szBuffer), "%d", nSize);
					SetWindowText(GETHCTL(IDC_PART_END), szBuffer);
				}
				break;

				// Internal subroutine to show start timetag
				case IDC_PART_SHOWSTARTTAG:
				{
					switch(nTagType)
					{
						case TAGTYPE_NONE:
						{
							strlcpy(szBuffer, "", sizeof(szBuffer));
						}
						break;

						case TAGTYPE_MJD:
						{
							// Format: MJD=00000.00000000
							_snprintf(szBuffer, sizeof(szBuffer), "MJD=%14.8f",
								fTags[nStart+ARRAY_OFFSET-1]);
							ShortenExp(szBuffer);
						}
						break;

						case TAGTYPE_DOY:
						{
							// MJD to date conversion
							// Get full MJD
							fMJD=fTags[nStart+ARRAY_OFFSET-1];

							// Round the MJD up by 0.5 sec
							fMJD+=5.78704e-6;

							// Split MJD into integer and fractional parts
							fFractMJD=modf(fMJD, &fIntMJD);
							lnMJD=(long)fIntMJD;

							// Convert integer MJD into date
							MJDToDate(lnMJD, &nDay, &nMonth, &nYear);
							nDOY=nSum[nMonth-1]+nDay;
							if(nYear%4==0 && nYear%100!=0 || nYear%400==0)
							{
								if(nMonth>2)
								{
									nDOY++;
								}
							}

							// Convert fractional MJD into time
							fFractMJD*=24.0;
							nHour=(int)fFractMJD;
							fFractMJD-=nHour;
							fFractMJD*=60.0;
							nMin=(int)fFractMJD;
							fFractMJD-=nMin;
							fFractMJD*=60.0;
							nSec=(int)(fFractMJD);

							// Format: DOY=YYYY:DDD Time=HH:MM:SS
							_snprintf(szBuffer, sizeof(szBuffer),
								"DOY=%04d:%03d Time=%02d:%02d:%02d",
								nYear, nDOY, nHour, nMin, nSec);
							ShortenExp(szBuffer);
						}
						break;

						case TAGTYPE_DATE:
						{
							// MJD to date conversion
							// Get full MJD
							fMJD=fTags[nStart+ARRAY_OFFSET-1];

							// Round the MJD up by 0.5 sec
							fMJD+=5.78704e-6;

							// Split MJD into integer and fractional parts
							fFractMJD=modf(fMJD, &fIntMJD);
							lnMJD=(long)fIntMJD;

							// Convert integer MJD into date
							MJDToDate(lnMJD, &nDay, &nMonth, &nYear);

							// Convert fractional MJD into time
							fFractMJD*=24.0;
							nHour=(int)fFractMJD;
							fFractMJD-=nHour;
							fFractMJD*=60.0;
							nMin=(int)fFractMJD;
							fFractMJD-=nMin;
							fFractMJD*=60.0;
							nSec=(int)(fFractMJD);

							// Format: Date=YYYY:MM:DD Time=HH:MM:SS
							_snprintf(szBuffer, sizeof(szBuffer),
								"Date=%02d:%02d:%02d Time=%02d:%02d:%02d",
								nYear, nMonth, nDay, nHour, nMin, nSec);
							ShortenExp(szBuffer);
						}
						break;

						case TAGTYPE_MISC:
						{
							// Format: Timetag=-1.000000000000e+00
							_snprintf(szBuffer, sizeof(szBuffer),
								"Timetag=%17.12e",
								fTags[nStart+ARRAY_OFFSET-1]);
							ShortenExp(szBuffer);
						}
						break;
					}

					// Display start timetag
					SetWindowText(GETHCTL(IDC_PART_STARTTAG), szBuffer);
				}
				break;

				// Internal subroutine to show end timetag
				case IDC_PART_SHOWENDTAG:
				{
					switch(nTagType)
					{
						case TAGTYPE_NONE:
						{
							strlcpy(szBuffer, "", sizeof(szBuffer));
						}
						break;

						case TAGTYPE_MJD:
						{
							// Format: MJD=00000.00000000
							_snprintf(szBuffer, sizeof(szBuffer), "MJD=%14.8f",
								fTags[nEnd+ARRAY_OFFSET-1]);
							ShortenExp(szBuffer);
						}
						break;

						case TAGTYPE_DOY:
						{
							// MJD to date conversion
							// Get full MJD
							fMJD=fTags[nEnd+ARRAY_OFFSET-1];

							// Round the MJD up by 0.5 sec
							fMJD+=5.78704e-6;

							// Split MJD into integer and fractional parts
							fFractMJD=modf(fMJD, &fIntMJD);
							lnMJD=(long)fIntMJD;

							// Convert integer MJD into date
							MJDToDate(lnMJD, &nDay, &nMonth, &nYear);
							nDOY=nSum[nMonth-1]+nDay;
							if(nYear%4==0 && nYear%100!=0 || nYear%400==0)
							{
								if(nMonth>2)
								{
									nDOY++;
								}
							}

							// Convert fractional MJD into time
							fFractMJD*=24.0;
							nHour=(int)fFractMJD;
							fFractMJD-=nHour;
							fFractMJD*=60.0;
							nMin=(int)fFractMJD;
							fFractMJD-=nMin;
							fFractMJD*=60.0;
							nSec=(int)(fFractMJD);

							// Format: DOY=YYYY:DDD Time=HH:MM:SS
							_snprintf(szBuffer, sizeof(szBuffer),
								"DOY=%04d:%03d Time=%02d:%02d:%02d",
								nYear, nDOY, nHour, nMin, nSec);
							ShortenExp(szBuffer);
						}
						break;

						case TAGTYPE_DATE:
						{
							// MJD to date conversion
							// Get full MJD
							fMJD=fTags[nEnd+ARRAY_OFFSET-1];

							// Round the MJD up by 0.5 sec
							fMJD+=5.78704e-6;

							// Split MJD into integer and fractional parts
							fFractMJD=modf(fMJD, &fIntMJD);
							lnMJD=(long)fIntMJD;

							// Convert integer MJD into date
							MJDToDate(lnMJD, &nDay, &nMonth, &nYear);

							// Convert fractional MJD into time
							fFractMJD*=24.0;
							nHour=(int)fFractMJD;
							fFractMJD-=nHour;
							fFractMJD*=60.0;
							nMin=(int)fFractMJD;
							fFractMJD-=nMin;
							fFractMJD*=60.0;
							nSec=(int)(fFractMJD);

							// Format: Date=YYYY:MM:DD Time=HH:MM:SS
							_snprintf(szBuffer, sizeof(szBuffer),
								"Date=%02d:%02d:%02d Time=%02d:%02d:%02d",
								nYear, nMonth, nDay, nHour, nMin, nSec);
							ShortenExp(szBuffer);
						}
						break;

						case TAGTYPE_MISC:
						{
							// Format: Timetag=-1.000000000000e+00
							_snprintf(szBuffer, sizeof(szBuffer),
								"Timetag=%17.12e", fTags[nEnd+ARRAY_OFFSET-1]);
							ShortenExp(szBuffer);
						}
						break;
					}

					// Display start timetag
					SetWindowText(GETHCTL(IDC_PART_ENDTAG), szBuffer);
				}
				break;
				
				// Respond to OK button
				case IDC_PART_ACCEPT:
				{
					// Necessary to make ALT O keyboard command work
					SetFocus(GETHCTL(IDC_PART_ACCEPT));

					// Set busy flag
					bBusy=TRUE;
					
					// Manipulate data only if necessary
					if((nStart!=1) || (nEnd!=nSize))
					{
						// Create tab to save previous data if requested
						if(bTabs && bTabChange)
						{
							CreateTab();
						}
						
						// Eliminate unwanted data
						// Set new # data points
						nSize=nEnd-nStart+1;

						// Manipulate data
						if(bDataType==FREQ_DATA)
						{
							// Process freq data
							fFreqData[0]=(F_TYPE)nSize;

							// Shift data up as required
							for(i=ARRAY_OFFSET; i<nSize+ARRAY_OFFSET; i++)
							{
								fFreqData[i]=fFreqData[i+nStart-1];
							}

							// Set new full start and end limits
							fFreqData[1]=1;
							fFreqData[2]=fFreqData[0];

							// Realloc freq data to (smaller) size
							if((fFreqData=(F_TYPE*)realloc(fFreqData,
								(nSize+ARRAY_OFFSET+EXTRA_MEM)
								*sizeof(F_TYPE)))==NULL)
							{
								// Shouldn't fail & not fatal anyway
								// so no need to bail out - just
								// announce error
								AllocErrorMessage();
							}

							if(bFreqTimetags)
							{
								// Process freq timetags
								fFreqTimetags[0]=(F_TYPE)nSize;

								// Shift timetags up as required
								for(i=ARRAY_OFFSET; i<nSize+ARRAY_OFFSET; i++)
								{
									fFreqTimetags[i]=fFreqTimetags[i+nStart-1];
								}

								// Set new full start and end limits
								fFreqTimetags[1]=1;
								fFreqTimetags[2]=fFreqTimetags[0];

								// Realloc freq timetags to (smaller) size
								if((fFreqTimetags=
									(F_TYPE*)realloc(fFreqTimetags,
									(nSize+ARRAY_OFFSET+EXTRA_MEM)
									*sizeof(F_TYPE)))==NULL)
								{
									// Shouldn't fail & not fatal anyway
									// so no need to bail out - just
									// announce error
									AllocErrorMessage();
								}
							}

							// Put info into log file
							_snprintf(szBuffer, sizeof(szBuffer),
								"#=%d(%d-%d)", nEnd-nStart+1, nStart, nEnd);
							WriteLog(27, szBuffer);
								
							// Update status display
							_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
								nSize);
							SetWindowText(hwndFreqNum, szBuffer);
							SetWindowText(hwndFreqEnd, szBuffer);
							_snprintf(szBuffer, sizeof(szBuffer), "%5.0d", 1);
							SetWindowText(hwndFreqStart, szBuffer);
							bFreqDataChanged=TRUE;
							bFreqDataUnsaved=TRUE;
							bFreqScaleChanged=TRUE;
							bFreqRedraw=TRUE;

							// Force new PSD plot scale
							sPSPlot.y_tic=0;

							// Update general data and timetag pointers
							fData=fFreqData;
							fTags=fFreqTimetags;

							// Increment filename
							if(bIncExtension)
							{
								IncExtension(szFile, FREQ_DATA);
								IncExtension(szFileTitle, FREQ_DATA);
								IncExtension(szFreqFile, FREQ_DATA);
								IncExtension(szFreqFileTitle, FREQ_DATA);
								SetWindowText(hwndFreqFilename,
									szFileTitle);
							}

							// Set redraw flag
							bFreqRedraw=TRUE;

							// Clear data synch flag
							bSynch=FALSE;

							// Redraw freq status plot from data
							UpdateStatusBar(hwndMain, NEW_DATA);
						}
						else // Phase data
						{
							// Process phase data
							fPhaseData[0]=(F_TYPE)nSize;

							// Shift data up as required
							for(i=ARRAY_OFFSET; i<nSize+ARRAY_OFFSET; i++)
							{
								fPhaseData[i]=fPhaseData[i+nStart-1];
							}

							// Set new full start and end limits
							fPhaseData[1]=1;
							fPhaseData[2]=fPhaseData[0];

							// Realloc phase data to (smaller) size
							if((fPhaseData=(F_TYPE*)realloc(fPhaseData,
								(nSize+ARRAY_OFFSET+EXTRA_MEM)
								*sizeof(F_TYPE)))==NULL)
							{
								// Shouldn't fail & not fatal anyway
								// so no need to bail out - just
								// announce error
								AllocErrorMessage();
							}

							if(bPhaseTimetags)
							{
								// Process phase timetags
								fPhaseTimetags[0]=(F_TYPE)nSize;

								// Shift timetags up as required
								for(i=ARRAY_OFFSET; i<nSize+ARRAY_OFFSET; i++)
								{
									fPhaseTimetags[i]=
										fPhaseTimetags[i+nStart-1];
								}

								// Set new full start and end limits
								fPhaseTimetags[1]=1;
								fPhaseTimetags[2]=fPhaseTimetags[0];

								// Realloc phase timetags to (smaller) size
								if((fPhaseTimetags=
									(F_TYPE*)realloc(fPhaseTimetags,
									(nSize+ARRAY_OFFSET+EXTRA_MEM)
									*sizeof(F_TYPE)))==NULL)
								{
 									// Shouldn't fail & not fatal anyway
									// so no need to bail out - just
									// announce error
									AllocErrorMessage();
								}
							}

							// Put info into log file
							_snprintf(szBuffer, sizeof(szBuffer),
								"#=%d(%d-%d)", nEnd-nStart+1, nStart, nEnd);
							WriteLog(26, szBuffer);
								
							// Update status display
							_snprintf(szBuffer, sizeof(szBuffer), "%5.0d",
								nSize);
							SetWindowText(hwndPhaseNum, szBuffer);
							SetWindowText(hwndPhaseEnd, szBuffer);
							_snprintf(szBuffer, sizeof(szBuffer), "%5.0d", 1);
							SetWindowText(hwndPhaseStart, szBuffer);
							bPhaseDataChanged=TRUE;
							bPhaseDataUnsaved=TRUE;
							bPhaseScaleChanged=TRUE;
							bPhaseRedraw=TRUE;

							// Force new PSD plot scale
							sPSPlot.y_tic=0;

							// Update general data and timetag pointers
							fData=fPhaseData;
							fTags=fPhaseTimetags;

							// Increment filename
							if(bIncExtension)
							{
								IncExtension(szFile, PHASE_DATA);
								IncExtension(szFileTitle, PHASE_DATA);
								IncExtension(szPhaseFile, PHASE_DATA);
								IncExtension(szPhaseFileTitle, PHASE_DATA);
								SetWindowText(hwndPhaseFilename,
									szFileTitle);
							}

							// Set redraw flag
							bPhaseRedraw=TRUE;
	
							// Clear data synch flag
							bSynch=FALSE;

							// Redraw phase status plot from data
							UpdateStatusBar(hwndMain, NEW_DATA);
						}

						// Clear plot lines
						ClearLines();

						// Clear busy flag
						bBusy=FALSE;
					}

					// Reinitialize
					SendMessage(hDlg, WM_COMMAND,
						GET_WM_COMMAND_MPS(IDC_PART_INITIALIZE, NULL, 0));
				}
				break;

				// Respond to esc key or close button
				case IDCANCEL:
				case IDC_PART_CANCEL:
				{
					EndDialog (hDlg, 0);
				}
				return TRUE;
			}
		}
		break;
	 }
	 return FALSE;
}

#ifndef LITE_VER
/*****************************************************************************/
/*                                                                           */
/*                    Filter Dialog Procedure                                */
/*                                                                           */
/*  Procedure to filter time domain phase or frequency data                  */
/*                                                                           */
/*      Revision record:                                                     */
/*          07/17/08    Created                                              */
/*                                                                           */
/*****************************************************************************/

BOOL CALLBACK FilterDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local macros
	// Filter types
	#define LOWPASS		0
	#define HIGHPASS	1
	#define BANDPASS	2
	#define BANDSTOP	3

	// Local variables
	// Chars
	char szBuffer[BUFFER_SIZE+1];       // Text buffer
	// Ints
	static int n;						// Data size
	static int nFFT;					// Filtering FFT array size
	static int nFilterType=1;			// Filter type
	static int nHigh;					// Index of upper cutoff freq
	static int nLow;					// Index of lower cutoff freq
	static BOOL bErrorTrap=FALSE;		// Flag for entry error
	// F_TYPEs
	static F_TYPE fEntry;				// User entry to be validated
	static F_TYPE fPrev;				// Previous value before new entry
	static F_TYPE fTau;					// Tau value of data
	static F_TYPE fHigh;				// Value of upper cutoff freq
	static F_TYPE fLow;					// Value of lower cutoff freq
	static F_TYPE fMax;					// Max Fourier frequency (Nyquist freq)
	static F_TYPE fMin;					// Min Fourier frequency (bin size)

    switch(message)
    {
        case WM_INITDIALOG:
        {
            // Write prompt message
            // WritePromptMessage(TB_FILTER);

            // Initialize the controls
 
            // Initialize the filter type radio buttons
            Button_SetCheck(GETHCTL(IDC_FILTER_HIGH), TRUE);
            Button_SetCheck(GETHCTL(IDC_FILTER_LOW), FALSE);
            Button_SetCheck(GETHCTL(IDC_FILTER_BAND), FALSE);
            Button_SetCheck(GETHCTL(IDC_FILTER_STOP), FALSE);

			// Show the high pass frequency entry boxes
			ShowWindow(GETHCTL(IDC_FILTER_HI), SW_HIDE);
			ShowWindow(GETHCTL(IDC_FILTER_LO), SW_SHOWNORMAL);
			ShowWindow(GETHCTL(IDC_FILTER_UPPER), SW_HIDE);
			ShowWindow(GETHCTL(IDC_FILTER_LOWER), SW_SHOWNORMAL);
			SetWindowText(GETHCTL(IDC_FILTER_LOWER), "C&utoff:");

			// Get tau value
			if(bDataType==PHASE_DATA)
			{
				// Get phase tau entry
				GetWindowText(GetDlgItem(hwndMain, IDC_PHASETAU),
					szBuffer, BUFFER_SIZE);
			}
			else // Freq data
			{
				// Get freq tau entry
				GetWindowText(GetDlgItem(hwndMain, IDC_FREQTAU),
					szBuffer, BUFFER_SIZE);
			}
			
			// Set tau value
			fTau=fabs(atof(szBuffer));
			
			// Show the max and min Fourier freq
			// The filtering is done with an extended FFT array
			// having 2x next power-of-2 of data size
			// Get # analysis points - not necessarily a power-of-2
			n=(int)(fData[2]-fData[1]+1);

			// Size of next higher power-of-2
			nFFT=(int)pow(2.0, (double)ceil(log(n)/log(2)));

			// Size of extended even reflected "flipped" FFT array
			// is nFFT*2

			// Min Fourier freq = bin size = 1/nFFT*tau, Hz
			// Note: This applies to the original data set
			// not the extended one used in FFTFilter()
			fMin=1.0/(nFFT*fTau);
			_snprintf(szBuffer, sizeof(szBuffer), "%11.5e",fMin);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_FILTER_MINFREQ), szBuffer);

			// Max Fourier freq = Nyquist freq = 1/2*tau, Hz
			fMax=1.0/(2*fTau);
			_snprintf(szBuffer, sizeof(szBuffer), "%11.5e",fMax);
			ShortenExp(szBuffer);
			SetWindowText(GETHCTL(IDC_FILTER_MAXFREQ), szBuffer);

			// Set initial values of fLow and fHigh at fMin and fMax
			fLow=fMin;
			fHigh=fMax;
			_snprintf(szBuffer, sizeof(szBuffer), "%11.5e",fMax);
			SetWindowText(GETHCTL(IDC_FILTER_HI), szBuffer);
			_snprintf(szBuffer, sizeof(szBuffer), "%11.5e",fMin);
			SetWindowText(GETHCTL(IDC_FILTER_LO), szBuffer);

			// Set initial values of nLow and nHigh
			nLow=(int)((nFFT*fLow/fMax)-1.0);
			nHigh=(int)((nFFT*fHigh/fMax)-1.0);

			return TRUE;
		}

        case WM_COMMAND:
        {
            switch(GET_WM_COMMAND_ID(wParam, lParam))
            {
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::FILTER_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::FILTER_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "FILTER_FUNCTION");
					#endif
                }
                break;

                // Detect high pass button change
                case IDC_FILTER_HIGH:
                {
                    if(GET_WM_COMMAND_CMD(wParam, lParam)==BN_CLICKED)
                    {
						nFilterType=HIGHPASS;
						ShowWindow(GETHCTL(IDC_FILTER_HI), SW_HIDE);
						ShowWindow(GETHCTL(IDC_FILTER_LO), SW_SHOWNORMAL);
						ShowWindow(GETHCTL(IDC_FILTER_UPPER), SW_HIDE);
						ShowWindow(GETHCTL(IDC_FILTER_LOWER), SW_SHOWNORMAL);
						SetWindowText(GETHCTL(IDC_FILTER_LOWER), "C&utoff:");
						SetWindowText(GETHCTL(IDC_FILTER_TEXT),
							"Select filter type and enter cutoff frequency."
							" Then press OK to apply filtering.");
                    }
                }
                break;

                // Detect low pass button change
				case IDC_FILTER_LOW:
                {
                    if(GET_WM_COMMAND_CMD(wParam, lParam)==BN_CLICKED)
                    {
						nFilterType=LOWPASS;
						ShowWindow(GETHCTL(IDC_FILTER_HI), SW_SHOWNORMAL);
						ShowWindow(GETHCTL(IDC_FILTER_LO), SW_HIDE);
						ShowWindow(GETHCTL(IDC_FILTER_UPPER), SW_SHOWNORMAL);
						ShowWindow(GETHCTL(IDC_FILTER_LOWER), SW_HIDE);
						SetWindowText(GETHCTL(IDC_FILTER_UPPER), "C&utoff:");
						SetWindowText(GETHCTL(IDC_FILTER_TEXT),
							"Select filter type and enter cutoff frequency."
							" Then press OK to apply filtering.");
                    }
                }
                break;

                // Detect band pass button change
                case IDC_FILTER_BAND:
                {
                    if(GET_WM_COMMAND_CMD(wParam, lParam)==BN_CLICKED)
                    {
						nFilterType=BANDPASS;
						ShowWindow(GETHCTL(IDC_FILTER_HI), SW_SHOWNORMAL);
						ShowWindow(GETHCTL(IDC_FILTER_LO), SW_SHOWNORMAL);
						ShowWindow(GETHCTL(IDC_FILTER_UPPER), SW_SHOWNORMAL);
						ShowWindow(GETHCTL(IDC_FILTER_LOWER), SW_SHOWNORMAL);
						SetWindowText(GETHCTL(IDC_FILTER_UPPER), "H&igh:");
						SetWindowText(GETHCTL(IDC_FILTER_LOWER), "L&ow:");
						SetWindowText(GETHCTL(IDC_FILTER_TEXT),
							"Select filter type and enter cutoff frequencies."
							" Then press OK to apply filtering.");
                    }
                }
                break;

                // Detect band stop button change
				case IDC_FILTER_STOP:
                {
                    if(GET_WM_COMMAND_CMD(wParam, lParam)==BN_CLICKED)
                    {
						nFilterType=BANDSTOP;
						ShowWindow(GETHCTL(IDC_FILTER_HI), SW_SHOWNORMAL);
						ShowWindow(GETHCTL(IDC_FILTER_LO), SW_SHOWNORMAL);
						ShowWindow(GETHCTL(IDC_FILTER_UPPER), SW_SHOWNORMAL);
						ShowWindow(GETHCTL(IDC_FILTER_LOWER), SW_SHOWNORMAL);
						SetWindowText(GETHCTL(IDC_FILTER_UPPER), "H&igh:");
						SetWindowText(GETHCTL(IDC_FILTER_LOWER), "L&ow:");
						SetWindowText(GETHCTL(IDC_FILTER_TEXT),
							"Select filter type and enter cutoff frequencies."
							" Then press OK to apply filtering.");
                    }
                }
                break;


                // Respond to upper cutoff freq edit control message
                case IDC_FILTER_HI:
                {
					// Respond to edit control when it loses the input focus
                    // unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) && (GetFocus()!=GETHCTL(IDCANCEL)))
					{
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Save previous value
						fPrev=fHigh;

                        // Get upper cutoff freq
						GetWindowText(GETHCTL(IDC_FILTER_HI), szBuffer,
							BUFFER_SIZE);
                        fEntry=(F_TYPE)atof(szBuffer);

						// Validate entry
						// For HIGHPASS and LOWPASS there is only one setting
						// and the bounds can extend fron fMin to fMax
						// For BANDPASS and BANDSTOP there are two setings
						// and the one cannot contradict the other
						if(nFilterType==HIGHPASS || nFilterType==LOWPASS)
						{
							// Upper cutoff freq must be between fMin and fMax
							// Numeric params are value, min & max
							// Validate entry
							if(ValidateFloat(hDlg, fEntry, fMin, fMax)==TRUE)
							{
								// New value OK
								fHigh=fEntry;
								_snprintf(szBuffer, sizeof(szBuffer), "%11.5e",
									fHigh);
								ShortenExp(szBuffer);
								SetWindowText(GETHCTL(IDC_FILTER_HI), szBuffer);
							}
							else
							{
								// Invalid entry - restore previous value
								_snprintf(szBuffer, sizeof(szBuffer), "%11.5e",
									fPrev);
								ShortenExp(szBuffer);
								SetWindowText(GETHCTL(IDC_FILTER_HI), szBuffer);
								SetFocus(GETHCTL(IDC_FILTER_HI));
							}
						}
						else // BANDPASS and BANDSTOP
						{
							// Upper cutoff freq cannot be less than fLow
							// Numeric params are value, min & max
							// Validate entry
							if(ValidateFloat(hDlg, fEntry, fLow, fMax)==TRUE)
							{
								// New value OK
								fHigh=fEntry;
								_snprintf(szBuffer, sizeof(szBuffer), "%11.5e",
									fHigh);
								ShortenExp(szBuffer);
								SetWindowText(GETHCTL(IDC_FILTER_HI), szBuffer);
							}
							else
							{
								// Invalid entry - restore previous value
								_snprintf(szBuffer, sizeof(szBuffer), "%11.5e",
									fPrev);
								ShortenExp(szBuffer);
								SetWindowText(GETHCTL(IDC_FILTER_HI), szBuffer);
								SetFocus(GETHCTL(IDC_FILTER_HI));
							}
						}

						// Find closest Fourier freq and its index
						// Filtering index i is that of double length 2*n2 flipped data
						// Valid from 0 to 2*n2-1
						// Index zero is DC term
						// Index 1 is first Fourier frequency = bin size
						// So index goes from 1 to nFFT-1
						nHigh=(int)((nFFT*fHigh/fMax)-1.0);
                    }
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
                }
                break;

                // Respond to lower cutoff freq edit control message
                case IDC_FILTER_LO:
                {
                    // Respond to edit control when it loses the input focus
                    // unless it loses it to the cancel button
					if((GET_WM_COMMAND_CMD(wParam, lParam)==EN_KILLFOCUS) &&
						(!bErrorTrap) && (GetFocus()!=GETHCTL(IDCANCEL)))
                    {
						// Set error flag to avoid multiple error messages
						bErrorTrap=TRUE;

						// Save previous value
						fPrev=fLow;

                        // Get lower cutoff freq
						GetWindowText(GETHCTL(IDC_FILTER_LO),	szBuffer,
							BUFFER_SIZE);
                        fEntry=(F_TYPE)atof(szBuffer);

						// Validate entry
						// For HIGHPASS and LOWPASS there is only one setting
						// and the bounds can extend fron fMin to fMax
						// For BANDPASS and BANDSTOP there are two setings
						// and the one cannot contradict the other
						if(nFilterType==HIGHPASS || nFilterType==LOWPASS)
						{
							// Upper cutoff freq must be between fMin and fMax
							// Numeric params are value, min & max
							// Validate entry
							if(ValidateFloat(hDlg, fEntry, fMin, fMax)==TRUE)
							{
								// New value OK
								fLow=fEntry;
								_snprintf(szBuffer, sizeof(szBuffer), "%11.5e",
									fLow);
								ShortenExp(szBuffer);
								SetWindowText(GETHCTL(IDC_FILTER_LO), szBuffer);
							}
							else
							{
								// Invalid entry - restore previous value
								_snprintf(szBuffer, sizeof(szBuffer), "%11.5e",
									fPrev);
								ShortenExp(szBuffer);
								SetWindowText(GETHCTL(IDC_FILTER_LO), szBuffer);
								SetFocus(GETHCTL(IDC_FILTER_LO));
							}
						}
						else // BANDPASS and BANDSTOP
						{
							// Lower cutoff freq cannot be more than fHigh
							// Numeric params are value, min & max
							// Validate entry
							if(ValidateFloat(hDlg, fEntry, fMin, fHigh)==TRUE)
							{
								// New value OK
								fLow=fEntry;
								_snprintf(szBuffer, sizeof(szBuffer), "%11.5e",
									fLow);
								ShortenExp(szBuffer);
								SetWindowText(GETHCTL(IDC_FILTER_LO), szBuffer);
							}
							else
							{
								// Invalid entry - restore previous value
								_snprintf(szBuffer, sizeof(szBuffer), "%11.5e",
									fPrev);
								ShortenExp(szBuffer);
								SetWindowText(GETHCTL(IDC_FILTER_LO), szBuffer);
								SetFocus(GETHCTL(IDC_FILTER_LO));
							}
						}

						// Find Fourier freq and its index
						// Filtering index i is that of the original data set
						// not the double length 2*nFFT flipped data
						// Valid from 0 to nFFT-1
						// Index zero is DC term
						// Index 1 is first Fourier frequency = bin size
						// So index goes from 1 to nFFT-1
						nLow=(int)((nFFT*fLow/fMax)-1.0);

						// TRACE_INT(nFFT);
						// TRACE_EXP(fLow);
						// TRACE_EXP(fMax);
						// TRACE_EXP(nFFT*fLow/fMax);
						// TRACE_INT(nLow);
                    }
					else
					{
						// Reset error flag
						bErrorTrap=FALSE;
					}
                }
                break;

				// Respond to CR in an edit control
                // Note: No button is a DEFPUSHBUTTON
                case IDOK:
                {
                    // Does upper cutoff freq edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FILTER_HI))
                    {
                        // Send EN_KILLFOCUS message to upper cutoff freq edit control
                        SendMessage(hDlg, WM_COMMAND,
                            GET_WM_COMMAND_MPS(IDC_FILTER_HI, NULL,
                                EN_KILLFOCUS));
                    }

                    // Does lower cutoff freq edit control have focus?
                    if(GetFocus()==GETHCTL(IDC_FILTER_LO))
                    {
                        // Send EN_KILLFOCUS message to lower cutoff freq edit control
						SendMessage(hDlg, WM_COMMAND,
                            GET_WM_COMMAND_MPS(IDC_FILTER_LO, NULL,
                            EN_KILLFOCUS));
                    }
                }
                break;

                case IDC_FILTER_ACCEPT:
                {
					// Call filter function:
					// int FFTFilter(F_TYPE z[], int type, int filter, int low, int high)
					// FFTFilter(fData, bDataType, nFilterType, nLow, nHigh

					// Create tab to save previous data if requested
					if(bTabs && bTabChange)
					{
						CreateTab();
					}
						
					switch(nFilterType)
					{
						case LOWPASS:
						{
							// TRACE_INT(nFilterType);
							// TRACE_STR("Low Pass");
							// LOWPASS = 0
							// Zero FFT data from index high to n2-1
							// and its conjugate
							FFTFilter(fData, bDataType, 0, 0, nHigh);

							// Write Log
							_snprintf(szBuffer, sizeof(szBuffer),
								"Low Pass Cutoff (Hz) = %e", fHigh);
							WriteLog(78+bDataType, szBuffer); 
						}
						break;

						case HIGHPASS:
						{
							// TRACE_INT(nFilterType);
							// TRACE_STR("High Pass");
							// HIGHPASS = 1
							// Zero FFT data from index 1 to low
							// and its conjugate
							FFTFilter(fData, bDataType, 1, nLow, 0);

							// Write Log
							_snprintf(szBuffer, sizeof(szBuffer),
								"High Pass Cutoff (Hz) = %e", fLow);
							WriteLog(78+bDataType, szBuffer); 
						}
						break;

						case BANDPASS:
						{
							// TRACE_INT(nFilterType);
							// TRACE_STR("Band Pass");
							// BANDPASS = 2
							// Zero FFT data from index 1 to low
							// and from index high to n2-1
							// and their conjugates
							FFTFilter(fData, bDataType, 2, nLow, nHigh);

							// Write Log
							_snprintf(szBuffer, sizeof(szBuffer),
								"Band Pass (Hz) = %e to %e", fLow, fHigh);
							WriteLog(78+bDataType, szBuffer); 
						}
						break;

						case BANDSTOP:
						{
							// TRACE_INT(nFilterType);
							// TRACE_STR("Band Stop");
							// BANDSTOP = 3
							// Zero FFT data from low to high
							// and its conjugate
							FFTFilter(fData, bDataType, 3, nLow, nHigh);

							// Write Log
							_snprintf(szBuffer, sizeof(szBuffer),
								"Band Stop (Hz) = %e to %e", fLow, fHigh);
							WriteLog(78+bDataType, szBuffer); 
						}
						break;
					}

					// Update status flags and filename extensions
					if(bDataType==PHASE_DATA)
					{
						// Set change flags
                        bPhaseDataChanged=TRUE;
						bPhaseDataUnsaved=TRUE;
                        bPhaseScaleChanged=TRUE;
						bPhaseRedraw=TRUE;

						// Force new PSD plot scale
						sPSPlot.y_tic=0;

						// Clear plot lines
						ClearLines();

						// Increment filename
                        if(bIncExtension)
                        {
                            IncExtension(szFile, PHASE_DATA);
                            IncExtension(szFileTitle, PHASE_DATA);
                            IncExtension(szPhaseFile, PHASE_DATA);
                            IncExtension(szPhaseFileTitle, PHASE_DATA);
                            SetWindowText(hwndPhaseFilename, szFileTitle);
                        }
					}
					else // Freq data
					{
						// Set change flags
	                    bFreqDataChanged=TRUE;
						bFreqDataUnsaved=TRUE;
						sFPlot.new_file=TRUE;
                        bFreqScaleChanged=TRUE;
						bFreqRedraw=TRUE;

						// Force new PSD plot scale
						sPSPlot.y_tic=0;

						// Clear plot lines
						ClearLines();

						// Increment filename
                        if(bIncExtension)
                        {
                            IncExtension(szFile, FREQ_DATA);
                            IncExtension(szFileTitle, FREQ_DATA);
                            IncExtension(szFreqFile, FREQ_DATA);
                            IncExtension(szFreqFileTitle, FREQ_DATA);
                            SetWindowText(hwndFreqFilename, szFileTitle);
                        }
					}

					// Redraw status plots from new data
					UpdateStatusBar(hwndMain, NEW_DATA);

					// Reset redraw flag
					bPhaseRedraw=FALSE;
					bFreqRedraw=FALSE;

					// Clear plot lines
					ClearLines();

					// Clear synch flag
					bSynch=FALSE;
 				}

                // Fall right into cancel
                // Respond to esc key or cancel button
                case IDCANCEL:
				case IDC_FILTER_CANCEL:
                {
                    EndDialog (hDlg, 0);
                }
                return TRUE;
			}
        }
        break;
     }
     return FALSE;
}
#endif

/*****************************************************************************/


