/*****************************************************************************/
/*                                                                           */
/*                            STABLE_P.C                                     */
/*                                                                           */
/*		GraphiC Plotting Functions for Windows 95/NT version of Stable       */
/*                                                                           */
/*		Functions:		FreqPlot()                                           */
/*                      SigmaPlot()                                          */
/*                      PowerSpectrumPlot()                                  */
/*                      PhasePlot()                                          */
/*                      MsgBox()                                             */
/*                      TableBox()                                           */
/*                      AllTableBox()                                        */
/*                      HistoPlot()                                          */
/*						Dateline()                                           */
/*						PlotDlgProc()                                        */
/*						TVARLabel()                                          */
/*						ClipPlot()                                           */
/*						UnclipPlot()                                         */
/*						InsertPlot()                                         */
/*						AutocorrelationPlot()                                */
/*						CalcLinFit()                                         */
/*						LagScatterPlot()                                     */
/*						DynamicSigmaPlot()                                   */
/*						lmfunc()                                             */
/*						jumps()                                              */
/*						blkjumps()                                           */
/*						stars()                                              */
/*						seqjumps()                                           */
/*						FindSpurs()                                          */
/*                                                                           */
/*		Revision record:                                                     */
/*			06/30/97	Replaced FAR PASCAL _export with WINAPI              */
/*			07/12/97	Made more changes for Win 32 compatibility           */
/*			12/24/97	Made changes for error-free BC 32 bit compliation    */
/*			01/16/98	Added ShortenExp() usage for MSC VC++                */
/*			01/28/98	Added precautionary UnclipPlot() calls               */
/*			02/25/98	LABELSIZE macro in STABLE_W.H increased from 100 to  */
/*						128 to fix elusive memory overwrite error            */
/*			07/23/03	Added demo version watermarks to all plots           */
/*			08/05/03	Added autocorrelation plot                           */
/*			11/09/05	Added dynamic stability plot                         */
/*			07/25/07    Changed to safe string functions                     */
/*          01/13/08	Cleaned up nonlinear fit code                        */
/*                      Still have levmar code, but not used                 */
/*                      because of licensing issues                          */
/*						and it doesn't work as well as lmmin                 */
/*          01/15/08	Removed levmar code                                  */
/*			01/25/08	Added trial frequency jump functions                 */
/*			01/28/08	Added stars() trial freq jump function               */
/*			01/30/08	Added blkjumps() trial freq jump function            */
/*			02/03/08	Added seqjumps() trial freq jump function            */
/*			02/07/08	Added trial cumulative sum jump detection code       */
/*          02/09/08	Jump detection using blkjumps() and cusum            */
/*                      fully implemented and working well                   */
/*						Added avgjumps() to show actual freq averages        */
/*			05/15/08	Added FindSpurs()                                    */
/*			05/27/11	Added AllTableBox()                                  */
/*                                                                           */
/* (c) 1996-2011  W. Riley  Hamilton Technical Services All Rights Reserved  */
/*                                                                           */
/*****************************************************************************/

#define STRICT 		// For Win32 compatibility

// Include the stable_w header file
#include "stable_w.h"           // STABLE_W header file

// lmmin headers
#include "lmmin.h"
#include "lm_eval.h"

// Prototype for duplicated GraphiC function
void GCLASS initialq(void);

// Function evaluation function declaration
void lmfunc(double *p, double *x, int m, int n, void *data);

#if(1)
// Function prototypes for jump detection algorithms - some not used
// int jumps(float y[], int num, int avg_factor, double limit);
int blkjumps(float y[], int num, int length, int offset, float limit,
	float mean[]);
// int stars(float y[], int num, int lgth, double prob, float mean[],
//	double *thresh);
int seqjumps(float y[], int num, int length, int offset, float limit,
	float mean[]);
int cusum(float y[], int num, float c[], float *min, float *max, int *imax,
	int *imin);
int avgjumps(float y[], int num, float mean[]);
#endif


/*****************************************************************************/
/*                                                                           */
/*								FreqPlot()                                   */
/*                                                                           */
/*		Function to plot frequency data                                      */
/*      Parameters:                                                          */
/*			f_data[] = array of frequency data; f_data[0] = # data points    */
/*			f_data[1] = plot start; f_data[2] = plot end                     */
/*      	zero treated as gap in data                                      */
/*			aux_data[] = array of auxilary data; aux_data[0] = # points      */
/*			aux_data[1] = start; aux_data[2] = end                           */
/*			p plotdata structure elements:                                   */
/*				title = plot title                                           */
/*      		subtitle = plot subtitle                                     */
/*				x_label = x-axis label                                       */
/*				left_y_label = left-hand y-axis label                        */
/*				x_offset = x-axis scale offset                               */
/*				x_mult = x-axis scale multiplier                             */
/*				y_offset = y-axis scale offset                               */
/*				y_mult = y-axis scale multiplier                             */
/*          	y_min = y-axis scale minimun                                 */
/*          	y_max = y-axis scale maximum                                 */
/*          	y_div = # of y-axis major divisions                          */
/*          	y_tic = # of y-axis tics between major divisions             */
/*				do_box = draw box flag                                       */
/*      		do_line = draw regression line code                          */
/*			              0=None, 1=Line, 2=Log, 3=Menu, 4=Dual              */
/*						  The Menu code then leads to the following types:   */
/*						  0=None, 1=Endpoints, 2=Linear Fit, 3=Average,      */
/*						  4=Marker, 5=Null                                   */
/*				do_date = write date flag                                    */
/*     			do_mouse = activate mouse/cursor flag                        */
/*				new_file = new basic data file flag                          */
/*				new_name = new exact data file flag                          */
/*				position = position of message box                           */
/*          	plot_filename = .tkf filename for plot                       */
/*		Returns nothing (void)                                               */
/*                                                                           */
/*		Freq Plot do_line Codes:	 Freq Plot Line Menu line_type Types:    */
/*			FPLOT_NONE	0				FLINE_NONE	0                        */
/*			FPLOT_LINE	1				FLINE_END   1                        */
/*			FPLOT_LOG	2				FLINE_LIN   2                        */
/*			FPLOT_DIFF	3				FLINE_AVG   3                        */
/*										FLINE_MARK  4                        */
/*                                                                           */
/*		Revision record:                                                     */
/*			06/30/96	Adapted from plot_freq() of Stable/DOS               */
/*			07/12/96	Added code for drawing annotations                   */
/*			07/13/96	More adaptation of DOS version code                  */
/*			11/09/96	Ditto - Now all is basically functional              */
/*			11/12/96	Added clipping to line drawing code                  */
/*			11/18/96	Revised plot sizes, etc.                             */
/*			03/15/97	Changed clipping to use ClipPlot()                   */
/*			04/07/97	Fixed newly-broken log fit calc message logic        */
/*			06/08/97	Eliminated all dual plot code                        */
/*						Drafted code for diffusion fit plotting              */
/*			06/18/98	Added fixes for curve() 16k point limit              */
/*			12/12/98	Added ability to insert mini plot                    */
/*			03/02/00	Added display of average fit with lowest priority    */
/*			03/11/01	Added provisions for thicker lines                   */
/*			03/11/02	Made changes in plot scale code                      */
/*			03/23/02	Made changes in plot scale code                      */
/*			09/27/02	Added average fit                                    */
/*			04/10/03	Fixed slope at end error for log and diffusion fits  */
/*			08/01/03	Added opaque note panel                              */
/*			10/02/03	Changed plot insert code                             */
/*			12/14/07	Added polynomial fit code                            */
/*          12/16/07	Changed to S&E Tools PolyCurveFit()                  */
/*			12/17/07	Added writing fit parameters to clipboard            */
/*			12/20/07	Added function fitting                               */
/*			12/22/07	Added function initial values                        */
/*			12/23/07	Added function fitting r-squared calc                */
/*          01/01/08	Added polynomial and nonlinear fit macros            */
/*			01/12/08	Got lmmin nonlinear fit working                      */
/*          01/15/08	Removed levmar code                                  */
/*			01/21/08	Fixed plot func fit label w/ decimal pt in exponent  */
/*			01/25/08	Added jump detection code                            */
/*			02/07/08	Added cumulative sum jump detection code             */
/*                      Added cusum sub-plot option                          */
/*          02/10/08	Added calculating confidence factor message          */
/*			02/11/08	Added provisions for zoomed freq jump plotting       */
/*			02/21/08	Got seqjumps() jump detection working                */
/*			02/26/08	Added BLKAVG and SEQAVG labels                       */
/*			03/06/08	Added data_color usage                               */
/*			07/29/08	Added function fit removal log file entry            */
/*                                                                           */
/*****************************************************************************/

void WINAPI FreqPlot(F_TYPE f_data[], F_TYPE aux_data[], struct plotdata *p)
{
	// lmmin function declarations
	void lm_evaluate(double *par, int m_dat, double *fvec,
		void *data, int *info);
	double fit_function(double t, double *p);
	void printout(int n_par, double *par, int m_dat, double *fvec,
		void *data, int iflag, int iter, int nfev);
	
	// Local macros
	#define XFORMAT_SIZE	8
	#define YFORMAT_SIZE	8

	// Extra memory allocation for stars() jump detection method
	// Set to zero if not used
	#define MOREMEM	0

	// Codes returned from the expression evaluator
	#define E_OK           0        // Successful evaluation
	#define E_SYNTAX       1        // Syntax error
	#define E_UNBALAN      2        // Unbalanced parenthesis
	#define E_DIVZERO      3        // Attempted division by zero
	#define E_UNKNOWN      4        // Reference to unknown variable
	#define E_MAXVARS      5        // Maximum variables exceeded
	#define E_BADFUNC      6        // Unrecognised function
	#define E_NUMARGS      7        // Wrong number of arguments to funtion
	#define E_NOARG        8        // Missing an argument to a funtion
	#define E_EMPTY        9        // Empty expression

	// lmmin struts
    lm_control_type control;
    lm_data_type data;

	// Local variables
	// Floats
	float *x,*y;
	float *m; // mean array
	float *cs; // cumulative sum array array
	float *s; // shuffled y[] array
	float width;
	float x_max, x_min;                                    /* x scale limits */
	float y_max, y_min;                                    /* y scale limits */
	float xste;                                        /* x-axis tic spacing */
	float yste;                                        /* y-axis tic spacing */
	float save_start;
	float save_end;
	float largestjump;	                       /* largest freq jump detected */
	float csmin, csmax;                   /* cumulative sum min and max vals */
	float range;						                      /* cusum range */
	float conf;			                                 /* confidence facor */
	float temp;                                  /* temporary float variable */
	// Doybles
	double val;												 /* double value */
	// Terms for function fit coefficient of determination
	double mean;	// Mean of observations
	double ssr;		// Regression sum of squares
	double sst;		// Total sum of squares
	double sse;		// Error sum of squares
	double rsqrd;	// Coefficient of determination
	// Ints
	int i;
	int j;
	int k;
	int npts;
	int num;                             /* # points in log or diffusion fit */
	int len;				                    	        /* string length */
	int lgth;                                    /* message length in pixels */
	int line_flag=FALSE;
	int x_div;						           /* # x-scale div for roundq() */
	int nClip;						          /* size of szClipboard (chars) */
	int nparam;						            /* # function fit parameters */
	int flag;                                        /* function return code */
	int icsmin, icsmax;               // Cumulative sum min and max point #s */
	int count;			                        /* general counting variable */
	int big;                                        /* index of biggest jump */
	#ifdef DEMO_VERSION
	int x_pix, y_pix, x_pix_min, y_pix_min, x_pix_max, y_pix_max;
	#endif
	// Chars
	char szBuffer[BIG_BUFFER_SIZE+1];                         /* Text buffer */
	char szLog[BIG_BUFFER_SIZE+1];                        /* Log text buffer */
	char szJumpBuffer[BIG_BUFFER_SIZE+1];               /* Jump value buffer */
	char szFunction[BUFFER_SIZE+1];   /* User-entered algebraic fit function */
	char label_str[BIGLABELSIZE+1];
	char yformat[YFORMAT_SIZE];
	char xformat[XFORMAT_SIZE];
	char *szTemp;
	char *ptr;							     /* general pointer to character */
	char *ptr1;
	char *ptr2;
	// Expression evaluator error messages
	char* ErrMsgs[] =
	{
	   "Syntax error",
	   "Unbalanced parenthesis",
	   "Division by zero",
	   "Unknown variable",
	   "Maximum variables exceeded",
	   "Unrecognised funtion",
	   "Wrong number of arguments to funtion",
	   "Missing an argument",
	   "Empty expression"
	};
	// For panel filling of notes
	float xpan[5], ypan[5];
	char ch;
	char buf[NOTESIZE+1];
	int xpix, ypix;
	int wid, max_wid=0;
	int allow=15, ydel;
	int tsavfq=0;
	int bsavfq=0;
	int descend;
	// Colors
	int background_color=BRT_WHITE;
	int grid_color=BLACK;
	int box_color=BLACK;
	int label_color=BLUE;
	int data_color=RED;
	int annotation_color=BLACK;
	int line_color=GREEN;
	int mean_color=GREEN;
	int jump_color=GREEN;
	int alt_data_color=YELLOW;
	int af; // Averaging factor for curve fit lines
	// Fit parameters
	F_TYPE avg;
	F_TYPE slope;
	F_TYPE intercept;
	static F_TYPE a, b, c, v;
	static BOOL bHaveLogFit=FALSE;	// Flag that valid log fit already done
	static BOOL bHaveDiffFit=FALSE;	// Flag that valid diff fit already done
	// Cursor variables
	float *fx;                  // Pointer to x-axis point array
	float *fy;                  // Pointer to y-axis point array
	int find;					// Point array dimensions
	// S&E poly fit and function fit array variables
	polytype *px;				// Pointer to x (point) data array
	polytype *py;				// Pointer to y (phase) data array
	polytype *aa;				// Pointer to coefficient array
	polytype *yest;				// Pointer to y estimate array
	polytype *yres;				// Pointer to y residual array
	polytype *cerr;				// Pointer to coefficient std error array
	polytype stderror;			// Standard error of fit
	polytype rsqr;				// r-squared of fit
	polytype r;					// r of fit
	char cferr;					// Singular matrix error flag
	// Clipboard variables
	HGLOBAL hClipboard;			// Handle to clipboard text buffer
	LPSTR	szClipboard;		// Ptr to clipboard text string
	// File pointers
	FILE *file;				// General file pointer
	FILE *fJmp;				// Jump mean value file pointer
	FILE *fCusum;			// Cumulative sum file pointer
	// FILE *fTest;		    // Test file pointer

	// Start of code
	// To eliminate complier warning
	aux_data[0]=aux_data[0];

	// Reset have log fit flag if new file
	if(p->new_file)
	{
		bHaveLogFit=FALSE;
		bHaveDiffFit=FALSE;
		fLogSlope=0.0;
		fDiffusionSlope=0.0;
	}

	// Reset new file flag
	p->new_file=FALSE;

	// Allocate memory for plot arrays
	if((x=(float*)malloc(((int)f_data[2]+2)*sizeof(float)))==NULL)
	{
		AllocErrorMessage();
		return;
	}
	
	// Note: stars() jump detection algorithm (if used)
	// requires additional memory to be allocated for y[] and m[] arrrays
	// = +avg_factor via MOREMEM macro - normally set to zero
	if((y=(float*)malloc(((int)f_data[2]+2+MOREMEM)*sizeof(float)))==NULL)
	{
		AllocErrorMessage();
		free(x);
		return;
	}

	// Array for mean data
	if((m=(float*)malloc((int)(f_data[2]+2+MOREMEM)*sizeof(float)))==NULL)
	{
		AllocErrorMessage();
		free(x);
		free(y);
		return;
	}

	// Array for cumulative sum data
	if((cs=(float*)malloc((int)(f_data[2]+2+MOREMEM)*sizeof(float)))==NULL)
	{
		AllocErrorMessage();
		free(x);
		free(y);
		free(m);
		return;
	}

	// Array for shuffled y[] data
	if((s=(float*)malloc((int)(f_data[2]+2+MOREMEM)*sizeof(float)))==NULL)
	{
		AllocErrorMessage();
		free(x);
		free(y);
		free(m);
		free(cs);
		return;
	}

	#if(0) // No longer required
	// Zero out the m[] array
	// This is impoprtant to avoid spikes in the STARS plot
	// apparently caused by uninitialized array points
	// which, if set to zero, the plotting routine skips
	// The root problem, however, lies in the stars() function
	// which should be setting those points to a value
	for(i=0; i<(int)(f_data[2]+2); i++)
	{
		m[i]=0.0;
	}
	#endif

	// Find average of freq data
	CalcMean(f_data, &avg, FREQ_DATA);

	// This is the begining of the actual GraphiC plotting code
	// Sequence of basic calls is per page I-34 of manual:
	//	   bgnplot()            	Initializations
	//	   startplot()          	Starts graphics
	//	   font()               	Loads fonts
	//	   page()               	Sets overall picture size
	//	   heading()				Draws title
	//	   xname(), yname()		 	Draws axis labels
	//	   area2d()					Defines axis lengths
	//

	// Write log info
	WriteLog(38, p->plot_filename);

	bgnplot(1,'g',p->plot_filename);                      /* initialize plot */
	startplot(background_color);         /* start plot with background color */
	font(4,"news.fnt",'\310',"swiss.fnt",'\311',"newsgrm.fnt",'\312',
		 "simplex.fnt",'\313');                                /* load fonts */
	page(FULLPAGE);                  /* Sets the maximum allowable page size */
	// page(7.50, 5.50);                     /* Adjust for smaller page size */
	// pgshift(1.0, 0.0);
	// physor(1.0, 0.0);
	heading("");    /* Blank heading allows space for title & subtitle later */
	fillfont(1);                                         /* Use filled fonts */

	// Kill the beep
	GPCSetBeepDefaults(0, 0);

	// Avoid unwanted clipping 
	UnclipPlot();
	
	// Axis labeling code
	fntchg('\310');                                              /* news.fnt */
	if(nStyle==MODERN_STYLE)                           /* Use "modern" style */
	{
		fntchg('\311');                                          /*swiss.fnt */
		upright(1);                          /* upright y-axis label numbers */
		numht((float)0.18);                           /* larger axis numbers */
		xnamht((float)0.22);                         /* larger x-axis labels */
		ynamht((float)0.22);                         /* larger y-axis labels */
	}
	color(label_color);             /* left y-axis label for single plot */
 	yname(p->left_y_label);                                 /* labels y-axis */
	color(label_color);                                  /* all other labels */
	xname(p->x_label);                                      /* labels x-axis */

	// Set plot area
	area2d((float)7.8, (float)5.3);

	// Insert cusum plot
	if( (p->do_cusum) && (p->do_line==FPLOT_JUMP) )
	{
		// Define area for plot insert
		gwindow((float)6.65, (float)4.5, (float)8.65, (float)6.0);
	}
	
	// Draw box
	color(box_color);                                  /* set box line color */
	if(p->do_box)
	{
		box();                                    /* draw box around picture */
	}                                                              /* end if */

	// Draw grid
	// The grid() function draws the major grid lines (at tics)
	// The fgrid() function draws the fine grid lines (between tics)
	// The 1st fgrid() arg is: 0=no ticks, -1=tick marks
	// The 2nd fgrid() arg is # ticks=# intervals-1
	color(grid_color);                          /* set box & grid line color */
	grid(9);                         /* draws dotted grid through tick marks */
	{
		fgrid(-1,p->y_tic-1);    /* fine grid tick marks between major ticks */
	}

	frame(1,1);                          /* add frame with ticks around plot */
	upright(1);                        /* causes y-axis labels to be upright */
	fntchg('\310');                                              /* news.fnt */

	// X-scale
	// Set x-axis plot scale for roundq()
	x_max=p->x_max;
	x_min=p->x_min; // Was x_min-p->x_min; until 07/19/16

	// Set the # x divisions for roundq()
	x_div=p->x_div;
	
	// Use roundq() to set xformat
	roundq(x_div, &x_min, &xste, &x_max, xformat);

	// Reset the scale limits to those actually wanted
	x_min=p->x_min;
	x_max=p->x_max;

	// Set the x-scale div size
	xste=((x_max-x_min)/p->x_div);

	// Y-scale
	// Set the y-scale max & min
	y_max=p->y_mult*(p->y_max+p->y_offset);
	y_min=p->y_mult*(p->y_min+p->y_offset);

	// Set the y-scale tic separation
	yste=((y_max-y_min)/p->y_div);

	// Round tic separation to avoid the dreaded 0.000000
	_snprintf(yformat, YFORMAT_SIZE, "%-1.3f", yste);
	yste=(float)atof(yformat);

	// Make sure yste is >0
	if(yste==0)
	{
		while(yste==0) // Adjust frequency scale to avoid O/F
		{
			// Adjust frequency scale multiplier
			p->y_mult*=10.0;
			y_max=p->y_mult*(p->y_max+p->y_offset);
			y_min=p->y_mult*(p->y_min+p->y_offset);

			// Set the y-scale tic separation
			yste=((y_max-y_min)/p->y_div);

			// Round tic separation
			_snprintf(yformat, YFORMAT_SIZE, "%-1.3f", yste);
			yste=(float)atof(yformat);

			// Change the y-axis label
			yname("NG Frequency Scale");
		}
	}

	// Adjust the y-scale format to avoid equal adjacent tic labels
	if(yste>=10.)
	{
		strlcpy(yformat, "%-1.0f", YFORMAT_SIZE);
	}
	else if(yste>=1.0)
	{
		strlcpy(yformat, "%-1.1f", YFORMAT_SIZE);
	}
	else if(yste>=0.1)
	{
		strlcpy(yformat, "%-1.2f", YFORMAT_SIZE);
	}
	else
	{
		strlcpy(yformat, "%-1.3f", YFORMAT_SIZE);
	}

	// Adjust the x-scale format to avoid equal adjacent tic labels
	// and too long labels

	if(xste>=10000.0)
	{
		strlcpy(xformat, "%-1.1e", XFORMAT_SIZE);
	}
	else if(xste>=10.0)
	{
		strlcpy(xformat, "%-1.0f", XFORMAT_SIZE);
	}
	else if(xste>=1.0)
	{
		strlcpy(xformat, "%-1.1f", XFORMAT_SIZE);
	}
	else if(xste>=0.1)
	{
		strlcpy(xformat, "%-1.2f", XFORMAT_SIZE);
	}
	else if(xste>=0.01)
	{
		strlcpy(xformat, "%-1.3f", XFORMAT_SIZE);
	}
	else
	{
		strlcpy(xformat, "%-1.4f", XFORMAT_SIZE);

		// With this format, can't show more than 8 tics
		if(p->x_div>8)
		{
			xste*=2;
		}
	}

	// Don't use the Graphic scale setting routine
	// This can cause the scale to ignore the user inputs
	// roundq(p->y_div, &y_min, &yste, &y_max, yformat);

	// Set plot scales
	graf(xformat, x_min, xste, x_max, yformat, y_min, yste, y_max);
	

	// Draw title & subtitle
	fntchg('\311');                                             /* swiss.fnt */

	color(label_color);                                   /* set label color */

	width=strwidth(p->title,(float)0.3);          /* get half-width of title */

	prtfnt((float)(4.75-width),(float)6.40,p->title,(float)0.3,0);
	                                                           /* draw title */

	width=strwidth(p->subtitle,(float)0.15);   /* get half-width of subtitle */

	prtfnt((float)(4.75-width),(float)6.175,p->subtitle,(float)0.15,0);
															/* draw subtitle */
	// Draw annotations
	// The putlabel() function is used for user-defined annotations.
	// This must come before any plotting - including grid lines
	// Then it is supposed to stay clean.
	// But, for user units, it should come after plot scales are set
	// It provides user messages via the plot annotations dialog box
	// The 2nd & 3rd args of putlabel() are in plot user units.
	// The 4th arg of putlabel() is char hgth in inches (for full-page).
	// The sFNote[i].nSize value is point size.  There are 72 points/inch.
	// The 5th arg of putlabel is border code: 1=border, 2=no border (strange)
	// So we get it as 2-sFNote[i].bBorder, where bBorder is ordinary BOOL flag
	// Multiline labels are OK with \n (newline, ASCII LF, dec int 10)
	// But they are NG with CR & LF as produced by an edit control.
	// So we must elim CRs from the note text string
	fntchg('\313');                                           /* simplex.fnt */
	color(grid_color);                          /* set box & grid line color */
	for(i=0; i<FNOTE_NUMNOTES; i++)
	{
		// Check if this is an active note (non-zero length)
		len=strlen(sFNote[i].szText);
		if(len)
		{
			// Allocate a temporary working buffer
			if((szTemp=(LPSTR)malloc((len+1)*sizeof(char)))==NULL)
			{
				AllocErrorMessage();
				free(x);
				free(y);
				return;
			}
			// Remove CRs from annotation text string
			// Note that we are also copying the EOS
			k=0;
			for(j=0; j<=len; j++)
			{
				if(sFNote[i].szText[j]!=13) // 13 = CR
				{
					szTemp[k]=sFNote[i].szText[j];
					k++;
				}
			}

			if(sFNote[i].bOpaque)
			// Put note into white panel to hide grid, plot, etc.
			{
				// GraphiC code from putlabel() of FNTPLT.C
				// modified to use here to determine vertices of label area
				// that actual putlabel() call uses to put note on plot
				// Input args are:
				//   char *string changed to szTemp
				//   float xpos
				//   float ypos
				//   float height = (float)(sFNote[i].nSize/72.0)
				// Local variables renamed as req'd & move to top of function
		
				 // Get size of area to make white panel for note
				usertopix((float)(sFNote[i].fX), (float)(sFNote[i].fY), 0.0,
					&xpix, &ypix);
				
				// Set line height
				ydel=20*sFNote[i].nSize;	// Correct value?
				
				// Initialize indices
				j=0;
				k=0;
				
				// Find maximum width of (possibly) multiline note
				// and add vertical height for multiple lines
				for(;;)
				{
					ch=szTemp[j++];
					if(ch!='\n' && ch!='\0')
					{
						buf[k++]=szTemp[j-1];
						if(k>=NOTESIZE)			  	      /* Buffer overflow */
						{
							j--;
							szTemp[j]='\0';              /* Terminate string */
							continue;                 /* Process what we can */
						}
					}
					else
					{
						buf[k]='\0';
						wid=intopix(strwidth(buf,
							(float)(sFNote[i].nSize/72.0)));
						if(wid>max_wid)
						{
							max_wid=wid;
						}
						if(ch!='\0') // ch is newline
						{
							bsavfq-=ydel;
						}
						k=0;
					}

					if(ch=='\0')
					{
						// Check the last line for descenders
						// g, j, p, q, y, /, \, #, ( and )
						descend=0;
						if((strpbrk(buf, "gjpqy/\\#()"))!=NULL)
						{
							descend=4*sFNote[i].nSize; // 1/5 line height
						}
						break;
					}
				}

				// Note: No allowance made here for descenders
				tsavfq=(int)(pix_convertq*(float)(sFNote[i].nSize/72.0));
				
				// Note area panel vertices are: [3]    [2]
				//                               [0, 4] [1]
				// Lower left:
				//   x0=xpix - allow
				//   y0=ypix - allow + bsavfq - descend
				// Upper right:
				//   x1=xpix + 2*max_wid + allow
				//   y1=ypix_sav + tsavfq + allow
				// That is the region we want to apply panel to

				// Calc vertices 0 and 4
				// Note: 15 is allowance for border added by GraphiC
				pixtouser(xpix-15, ypix-15+bsavfq-descend, &xpan[0], &ypan[0]);
				xpan[4]=xpan[0];
				ypan[4]=ypan[0];
				
				// Calc vertex 3
				pixtouser(xpix-15, ypix+15+tsavfq, &xpan[3], &ypan[3]);
				
				// Calc vertex 2
				pixtouser(xpix+15+2*(max_wid), ypix+15+tsavfq, &xpan[2],
					&ypan[2]);
				
				// Calc vertex 1
				pixtouser(xpix+15+2*(max_wid), ypix-15+bsavfq-descend,
					&xpan[1], &ypan[1]);
				
				// Create panel with bright white background
				panel(xpan, ypan, 4, 447, FALSE); // Use 204 (red) for test
				
				// Process panel
				panproc();
			}

			// Draw annotation - use temp string w/o CRs
			putlabel(szTemp, (float)sFNote[i].fX, (float)sFNote[i].fY,
				(float)(sFNote[i].nSize/72.0), 2-sFNote[i].bBorder,
				USER_UNITS);

			// Free temporary working buffer
			free(szTemp);
		}
	}
	fntchg('\310');                                              /* news.fnt */

	npts=0;
	for(i=(int)(f_data[1]+2); i<=(int)(f_data[2]+2); i++)
													 /* load data into array */
	{
		if(f_data[i])                           /* don't add offset to a gap */
		{
			y[npts]=(float)(p->y_mult*(f_data[i]+p->y_offset));
			if(y[npts]<y_min)                        /* clip if below bottom */
			{
				y[npts]=y_min;
			}
			if(y[npts]>y_max)                           /* clip if above top */
			{
				y[npts]=y_max;
			}
		}                                                          /* end if */
		else
		{
			y[npts]=0;
		}                                                        /* end else */
		x[npts]=p->x_mult*((i-2)+p->x_offset);
		npts++;
	}                                                             /* end for */

	#if(0) // For early jump detection tests - now obsolete
	// 3rd arg is avg factor
	// 4th arg is jump detection threshold
	i=jumps(y, npts, 10, 1.0*1e-13*p->y_mult);
	TRACE_INT(i);
	#endif
	
	#if(1) // Perform frequency jump detection
	if(p->do_line==FPLOT_JUMP)                             /* jump detection */
	{
		// Jump detection method using block average algorithm
		// 1st arg is freq data array (float, no header, scaled)
		// 2nd arg is # freq data points
		// 3rd arg is window length
		// 4th arg is window offset
		// 5th arg is jump detection threshold
		// 6th arg is mean value array (float, same size as freq data array)
		if(p->method==BLKAVG) // Use BLKAVG jump detection method
		{
			// Find jumps
			p->num=blkjumps(y, npts, p->length, p->offset,
				p->limit*p->y_mult, m);

			// Compose jump detection message
			_snprintf(label_str, LABELSIZE,
				"BLKAVG Freq Jump Detection: "
				"Window Length=%d, Window Offset=%d, "
				"Jump Threshold=%e (%5.3f sigma), @# Jumps=%d",
				p->length, p->offset, p->limit, p->limit/p->sigma, p->num);
		}

		// Alternative jump detection method using sequential algorithm
		if(p->method==SEQAVG) // Use SEQAVG jump detection method
		{
			// Find jumps
			p->num=seqjumps(y, npts, p->length, p->offset, p->limit*p->y_mult, m);

			// Calc averages
			if(p->num>0) // If have any jumps
			{
				// Put freq averages in jump intervals into mean array[]
				avgjumps(y, npts, m);
			}

			// Compose jump detection message
			_snprintf(label_str, LABELSIZE,
				"SEQAVG Freq Jump Detection: "
				"Window Length=%d, Window Offset=%d, "
				"Jump Threshold=%e (%5.3f sigma), @# Jumps=%d",
				p->length, p->offset, p->limit, p->limit/p->sigma, p->num);
		}

		// Show annotation
		ShortenExp(label_str);
		UnclipPlot();
		fntchg('\313');                                       /* simplex.fnt */
		color(annotation_color);                     /* fit annotation color */
		tmargin((float)6.655);
		if(sFPlot.do_fit)
		{
			ctline(label_str,(float)0.075);
		}
		line_flag=TRUE;

		// Calc cumulative sums
		cusum(y, npts, cs, &csmin, &csmax, &icsmin, &icsmax);

		// Write the cumulative sum array to a file
		fCusum=fopen("Cusum.dat", "w");

		// Write cusum data file
		for(i=0; i<npts; i++)
		{
			// Compose line
			_snprintf(szBuffer, sizeof(szBuffer), "%d %e\n", i+1, cs[i]);

			// Write file
			fputs(szBuffer, fCusum);
		}
		
		// Close file
		fclose(fCusum);

		// Write the jump array to a file
		fJmp=fopen("Jump.dat", "w");

		// Write jump data file
		for(i=0; i<npts; i++)
		{
			// Compose line
			_snprintf(szBuffer, sizeof(szBuffer), "%d %e\n", i+1, m[i]);

			// Write file
			fputs(szBuffer, fJmp);
		}
		
		// Close file
		fclose(fJmp);

		// Determine confidence factor for detected jump
		// Know range of its cusum = csmax - csmin
		// Want to know how many times the cusum of randomly-shuffled data
		// exceeds that range for a large number (say 1000) trials

		// Generate shuffled data array s[] from y[]
		// for all s[i] from i=0 to npts-1
		// First copy original array to shuffled one
		// Then loop thru shuffled array
		// swapping each indexed point with random one
		// s[i] <=> y[j] where j=rand()*(npts-1)/RAND_MAX
		// after initial call to srand((unsigned)time(NULL))
		// Then calc cusum(), find csmax - csmin, and test it
		// If it is > actual cusum range, increment count
		// Do this 1000 times
		// Calc conf as 100*(1000-count)/1000 %
		if(p->do_conf && p->num)
		{
			// Show calculating message - it can take a while
			UnclipPlot();
			fntchg('\313');                                       /* simplex.fnt */
			color(annotation_color);                     /* fit annotation color */
			tmargin((float)2.000);
			ctline("Calculating Confidence Factor - Please Wait",(float)0.075);

			// Initializations
			range=csmax-csmin;
			count=0;
			srand((unsigned)time(NULL));

			// Open test ranges file
			// fTest=fopen("Test.dat", "w");
			
			// Generate test cases
			for(k=0; k<1000; k++)
			{
				// Copy original array
				for(i=0; i<npts; i++)
				{
					s[i]=y[i];
				}
				
				// Perform random swaps 
				for(i=0; i<npts; i++)
				{
					j=(int)((float)(rand())*(float)((npts-1))/(float)(RAND_MAX));
					temp=s[i];
					s[i]=s[j];
					s[j]=temp;
				}
				
				// Calc cusum
				cusum(s, npts, cs, &csmin, &csmax, &icsmin, &icsmax);

				// Write test range to file
				// Compose line
				// _snprintf(szBuffer, sizeof(szBuffer), "%d %e\n", k+1, csmax-csmin);

				// Write file
				// fputs(szBuffer, fTest);

				// Increment count if test range exceeded
				// Note: This happens only for a very small data set
				// Otherwise conf level always > 99.9 %
				if((csmax-csmin)>range)
				{
					count++;
				}
			}

			// Erase calculating message
			UnclipPlot();
			fntchg('\313');                                       /* simplex.fnt */
			color(background_color);                     /* background color */
			tmargin((float)2.000);
			ctline("Calculating Confidence Factor - Please Wait",(float)0.075);

			// Close test file
			// fclose(fTest);

			// Calc confidence level (%)
			conf=(float)(100.0*(1000-count)/1000.0);

			// Calc actual cumulative sums again
			cusum(y, npts, cs, &csmin, &csmax, &icsmin, &icsmax);
		}
	}
	#endif
	
	#if(0) // For tests of STARS jump detection algorithm - not used
	// 1st arg is freq data array
	// 2nd arg is data array size
	// 3rd arg is window length
	// 4th arg is jump detection probability
	// 5th arg is mean value array
	// 6th arg is jump threshold (sigmas)
	i=stars(y, npts, 10, 0.005, m, &val);

	// Compose a test message
	_snprintf(label_str, LABELSIZE,
		"STARS Jump Analysis: Length=%d, Prob=%7.5f, Threshold=%5.3f sigma, # Jumps=%d",
		10, 0.005, val, i);
	ShortenExp(label_str);
	UnclipPlot();
	fntchg('\313');                                       /* simplex.fnt */
	color(annotation_color);                     /* fit annotation color */
	tmargin((float)6.655);
	if(sFPlot.do_fit)
	{
		ctline(label_str,(float)0.075);
	}
	line_flag=TRUE;

	// Write the jump array to a file
	fJmp=fopen("Jump.dat", "w");

	// Write jump data file
	for(i=0; i<npts; i++)
	{
		// Compose line
		_snprintf(szBuffer, sizeof(szBuffer), "%d %e\n", i+1, m[i]);

		// Write file
		fputs(szBuffer, fJmp);
	}

	fclose(fJmp);
	#endif
	
	// Set color for data plot
	color(data_color);                                         /* data color */
	
	// Select alternative data color if data_color is >0
	// Note:  This is currently the only place this parameter is used
	// Here it is just used as a flag
	// But it could be used to convey the actual color value
	// It is allowed only when showing jumps
	if( (p->data_color)  && (p->do_line==FPLOT_JUMP) )
	{
		color(alt_data_color);                       /* alternate data color */
	}

	// Set plot line thickness
	// 0 is default, 20 is wider
	tline(p->thick);

	// Clip freq data plot
	ClipPlot();

	// Plot data
	for(i=0; !*(y+i); i++)
	{
		;                                   /* just increment i to skip gaps */
	}
	uline((*(x+i)-p->x_mult),*(y+i),*(x+i),*(y+i),1);         /* first point */
	if(*(y+i+1))                              /* check if 2nd point is a gap */
	{
		uline(*(x+i),*(y+i),*(x+i),*(y+i+1),0);
		uline(*(x+i),*(y+i+1),*(x+i+1),*(y+i+1),2);
	}                                                              /* end if */
	for(++i; i<npts-2; i++)                             /* continue plotting */
	{
		if(*(y+i) && *(y+i+1))                                  /* skip gaps */
		{
			uline((*(x+i)-p->x_mult),*(y+i),*(x+i),*(y+i),1);
			uline(*(x+i),*(y+i),*(x+i),*(y+i+1),0);        /* plot freq data */
			uline(*(x+i),*(y+i+1),*(x+i+1),*(y+i+1),2);
		}                                                          /* end if */
	}                                                             /* end for */
	if(*(y+i+1))                                               /* last point */
	{
		if(*(y+i))
		{
			uline((*(x+i)-p->x_mult),*(y+i),*(x+i),*(y+i),1);
			uline(*(x+i),*(y+i),*(x+i),*(y+i+1),0);
		}                                                          /* end if */
		else
		{
			uline(*(x+i),*(y+i+1),*(x+i+1),*(y+i+1),1);
		}                                                        /* end else */
		uline(*(x+i),*(y+i+1),*(x+i+1),*(y+i+1),2);
	}                                                              /* end if */

	#if(1) // Part of preferred blkjumps() method for jump detection
	if(p->do_line==FPLOT_JUMP)                             /* jump detection */
	{
		color(mean_color);                                         /* data color */

		// Plot mean
		for(i=0; !*(m+i); i++)
		{
			;                                   /* just increment i to skip gaps */
		}
		uline((*(x+i)-p->x_mult),*(m+i),*(x+i),*(m+i),1);         /* first point */
		if(*(m+i+1))                              /* check if 2nd point is a gap */
		{
			uline(*(x+i),*(m+i),*(x+i),*(m+i+1),0);
			uline(*(x+i),*(m+i+1),*(x+i+1),*(m+i+1),2);
		}                                                              /* end if */
		for(++i; i<npts-2; i++)                             /* continue plotting */
		{
			if(*(m+i) && *(m+i+1))                                  /* skip gaps */
			{
				uline((*(x+i)-p->x_mult),*(m+i),*(x+i),*(m+i),1);
				uline(*(x+i),*(m+i),*(x+i),*(m+i+1),0);        /* plot mean data */
				uline(*(x+i),*(m+i+1),*(x+i+1),*(m+i+1),2);
			}                                                          /* end if */
		}                                                             /* end for */
		if(*(m+i+1))                                               /* last point */
		{
			if(*(m+i))
			{
				uline((*(x+i)-p->x_mult),*(m+i),*(x+i),*(m+i),1);
				uline(*(x+i),*(m+i),*(x+i),*(m+i+1),0);
			}                                                          /* end if */
			else
			{
				uline(*(x+i),*(m+i+1),*(x+i+1),*(m+i+1),1);
			}                                                        /* end else */
			uline(*(x+i),*(m+i+1),*(x+i+1),*(m+i+1),2);
		}	                                                           /* end if */

		// Format the jump plotting
		color(jump_color);

		// Find jump points (zero values in m[] array)
		// For each one, draw a vertical line
		// from previous mean y value to next mean y value
		// at that x value
		largestjump=(float)0.0;

		// Save jump values in text buffer
		// Will hold about BIG_BUFFER_SIZE/12 = 1024/12 = 85 values
		strlcpy(szJumpBuffer, "", sizeof(szJumpBuffer));
		strlcpy(p->message_str, "", MESSAGESIZE);

		// Search for jumps
		big=-100;  // This puts marker offscale if no jumps
		for(i=p->offset; i<(npts/p->length)*p->length; i++)
		{
			if(m[i]==0)
			{
				// Draw heavy vertical line to denote jump
				tline(50);
				uline((float)((i+f_data[1]-1)*p->x_mult), m[i-1],
					(float)((i+f_data[1]-1)*p->x_mult), m[i+1], 1);

				// Fill in gap after jump
				tline(p->thick);
				uline(i*p->x_mult, m[i+1], (i+1)*p->x_mult, m[i+1], 1);

				// Write jump info to jump value text buffer
				_snprintf(szBuffer, sizeof(szBuffer), "%d\t\t%e\r\n",
					i+(int)(f_data[1])-1, fabs(m[i+1]-m[i-1])/p->y_mult);
				ShortenExp(szBuffer);
				strlcat(szJumpBuffer, szBuffer, sizeof(szJumpBuffer));

				// Write it to largest jump value and message if it is
				if((fabs(m[i+1]-m[i-1])/p->y_mult)>(fabs(largestjump)))
				{
					// largestjump=(float)(fabs(m[i+1]-m[i-1])/p->y_mult);
					largestjump=(float)((m[i+1]-m[i-1])/p->y_mult);
					_snprintf(p->message_str, MESSAGESIZE,
						"Largest Jump=%e at Point=%d", largestjump, i+(int)(f_data[1])-1);
					ShortenExp(p->message_str);

					// Save index of biggest jump
					big=i;
				}
			}
		}

		// Draw pointer to mark location of biggest jump
		fntchg('\312');                                       /* newsgrm fnt */
		color(jump_color);                         /* annotation color */
		tmargin((float)5.0);
		pltfnt((float)(((big -((x_max-x_min)/250))+f_data[1]-1)*p->x_mult), y_min,"",
			(float)0.075, 0);                         /* char 133=down arrow */
		                          /* x location adjustment centers character */

		// Write jump info to clipboard
		if(TRUE) // Could control this with a flag
		{
			 // # chars to write to clipboard
			nClip=(13+p->num)*80;
					
			// Get memory and handle for clipboard
			hClipboard=GlobalAlloc(GMEM_DDESHARE, (DWORD)nClip);
			szClipboard=GlobalLock(hClipboard);

			// Compose clipboard text
			strlcpy(szClipboard, "File: ", nClip);
			strlcat(szClipboard, szFreqFileTitle, nClip);
			strlcat(szClipboard, "\r\n", nClip);
			if(p->method==BLKAVG)
			{
				strlcat(szClipboard, "BLKAVG Jump Detection Results:\r\n", nClip);
			}
			else // SEQAVG method
			{
				strlcat(szClipboard, "SEQAVG Jump Detection Results:\r\n", nClip);
			}

			// Compose jump detection parameters
			_snprintf(szBuffer, sizeof(szBuffer),
				"Window Length = %d\r\n", p->length);
			ShortenExp(szBuffer);
			strlcat(szClipboard, szBuffer, nClip);
			if(p->method==BLKAVG)
			{
				_snprintf(szBuffer, sizeof(szBuffer),
					"Window Offset = %d\r\n", p->offset);
				ShortenExp(szBuffer);
				strlcat(szClipboard, szBuffer, nClip);
			}
			_snprintf(szBuffer, sizeof(szBuffer),
				"Jump Threshold = %e\r\n", p->limit);
			ShortenExp(szBuffer);
			strlcat(szClipboard, szBuffer, nClip);

			// Compose jump report
			_snprintf(szBuffer, sizeof(szBuffer),
				"# Jumps = %d\r\n", p->num);
			ShortenExp(szBuffer);
			strlcat(szClipboard, szBuffer, nClip);
			if(p->num)
			{
				_snprintf(szBuffer, sizeof(szBuffer),
					"Largest Jump = %e\r\n", largestjump);
				ShortenExp(szBuffer);
				strlcat(szClipboard, szBuffer, nClip);
				_snprintf(szBuffer, sizeof(szBuffer),
					"Point #\t\tJump Size\r\n");
				ShortenExp(szBuffer);
				strlcat(szClipboard, szBuffer, nClip);
			}
			strlcat(szClipboard, szJumpBuffer, nClip);

			// Show cumulative sum results
			// NOTE: Last point always near zero - actual value meaningless
			// may want to omit
			strlcat(szClipboard, "Scaled Cumulative Sum Results:\r\n", nClip);
			_snprintf(szBuffer, sizeof(szBuffer),
				"Min = %e at Point # %d\r\n", csmin, icsmin+1+(int)(f_data[1])-1);
			strlcat(szClipboard, szBuffer, nClip);
			_snprintf(szBuffer, sizeof(szBuffer),
				"Max = %e at Point # %d\r\n", csmax, icsmax+1+(int)(f_data[1])-1);
			strlcat(szClipboard, szBuffer, nClip);
			if(p->num==1)
			{
				// Show estimated single freq jump value
				if(fabs((csmax/(icsmax-1))+(csmax/(npts-icsmax)))>
					fabs((csmin/(icsmin-1))+(csmin/(npts-icsmin))))
				{
					// Using max - cusum plot looks like ^
					strlcat(szClipboard, "Single Jump Estimate:\r\n", nClip);
					_snprintf(szBuffer, sizeof(szBuffer),
						"Jump = %+e at Point # %d\r\n",
						-((csmax/(icsmax-1))+(csmax/(npts-icsmax)))/p->y_mult,
						icsmax+1+(int)(f_data[1])-1);
					strlcat(szClipboard, szBuffer, nClip);
				}
				else
				{
					// Using min - cusum plot looks like V
					strlcat(szClipboard, "Single Jump Estimate:\r\n", nClip);
					_snprintf(szBuffer, sizeof(szBuffer),
						"Jump = %+e at Point # %d\r\n",
						-((csmin/(icsmin-1))+(csmin/(npts-icsmin)))/p->y_mult,
						icsmin+1+(int)(f_data[1])-1);
					strlcat(szClipboard, szBuffer, nClip);
				}

				if(p->do_conf)
				{
					if(conf=100.0)
					{
						_snprintf(szBuffer, sizeof(szBuffer),
							"Confidence Factor > 99.9 %%\r\n");
						strlcat(szClipboard, szBuffer, nClip);
					}
					else
					{
						_snprintf(szBuffer, sizeof(szBuffer),
							"Confidence Factor = %4.1f %%\r\n", conf);
						strlcat(szClipboard, szBuffer, nClip);
					}
				}
			}

			// Open clipboard, write text to it, and close clipboard
			GlobalUnlock(hClipboard);
			OpenClipboard(NULL);
			EmptyClipboard();
			SetClipboardData(CF_TEXT, hClipboard);
			CloseClipboard();
		}
	}
	#endif

	// Unclip plot
	UnclipPlot();

	// Restore plot line thickness
	tline(0);

	// Draw lines
	// Note: Need error trapping for entry of NG line parameters
	if(p->do_line==FPLOT_LINE)                            /* linear fit line */
	{
		CalcLinFreqDrift(f_data, &intercept, &slope, &v);      /* calc drift */

		color(line_color);                                     /* line color */
		/* draw linear regression line */
		x[0]=(float)(p->x_mult*(f_data[1]+p->x_offset));
		y[0]=(float)(p->y_mult*((intercept+(f_data[1] * slope))+p->y_offset));
		x[1]=(float)(p->x_mult*(f_data[2]+p->x_offset));
		y[1]=(float)(p->y_mult*((intercept+(f_data[2] * slope))+p->y_offset));

		ClipPlot();
		curve(x, y, 2, 0);
		UnclipPlot();

		// Sums for mean of observations p_data[]
		mean=0.0;
		for(i=0; i<npts; i++)
		{
			mean+=f_data[i+ARRAY_OFFSET];
		}
		mean/=(double)npts;

		// Sums for sst
		sst=0.0;
		for(i=0; i<npts; i++)
		{
			sst+=(f_data[i+ARRAY_OFFSET]-mean)*(f_data[i+ARRAY_OFFSET]-mean);
		}
		
		// Sums for sse
		sse=0.0;
		for(i=0; i<npts; i++)
		{
			sse+=(f_data[i+ARRAY_OFFSET]-(intercept+slope*i))*
				(f_data[i+ARRAY_OFFSET]-(intercept+slope*i));
		}
		
		// Calc r-squared = coefficient of determination to judge goodness of fit
		// It is SSR / SST = regression sum of squares  / total sum of squares
		// Or (better for numerical reasons) 1 - SSE/SST
		// SSR = Sum (predicted value - mean)^2 = variability of modelled data
		// SST = Sum (observed value - mean)^2 = variability of observed data
		// SSE = Sum (observed - predicted value)^2
		// where mean = avgerage of observed values

		// Calc r-squared
		rsqrd=1.0-(sse/sst);

		_snprintf(label_str, LABELSIZE,
				"Linear Fit: y(t)=a+bt, Intercept=a=%-10.7e, "
				"Slope=b=%-10.7e", intercept,slope);
		ShortenExp(label_str);
		fntchg('\313');                                       /* simplex.fnt */
		color(annotation_color);                     /* fit annotation color */
		tmargin((float)6.655);
		if(sFPlot.do_fit)
		{
			ctline(label_str,(float)0.075);
		}
		line_flag=TRUE;

		// Write linear fit coefficients to clipboard
		if(TRUE) // Could control this with a flag
		{
			 // # chars to write to clipboard
			nClip=7*80;
				
			// Get memory and handle for clipboard
			hClipboard=GlobalAlloc(GMEM_DDESHARE, (DWORD)nClip);
			szClipboard=GlobalLock(hClipboard);

			// Compose clipboard text
			strlcpy(szClipboard, "File: ", nClip);
			strlcat(szClipboard, szFreqFileTitle, nClip);
			strlcat(szClipboard, "\r\n", nClip);
			strlcat(szClipboard, "Linear Fit Parameters:\r\n", nClip);
			strlcat(szClipboard, "y(t)=a+bt\r\n", nClip);
			strlcat(szClipboard, "where t = Data point #\r\n", nClip);

			// Compose fit coefficients
			_snprintf(szBuffer, sizeof(szBuffer), "a = %e\r\n", intercept);
			ShortenExp(szBuffer);
			strlcat(szClipboard, szBuffer, nClip);
			_snprintf(szBuffer, sizeof(szBuffer), "b = %e\r\n", slope);
			ShortenExp(szBuffer);
			strlcat(szClipboard, szBuffer, nClip);

			// Compose coefficient of determination
			_snprintf(szBuffer, sizeof(szBuffer), "r = %e\r\n", rsqrd);
			ShortenExp(szBuffer);
			strlcat(szClipboard, szBuffer, nClip);

			// Open clipboard, write text to it, and close clipboard
			GlobalUnlock(hClipboard);
			OpenClipboard(NULL);
			EmptyClipboard();
			SetClipboardData(CF_TEXT, hClipboard);
			CloseClipboard();
		}
	}                                                              /* end if */

	if(p->do_line==FPLOT_LOG)                                /* log fit line */
	{
		color(line_color);                             /* line message color */
		tmargin((float)6.4);
		if(!bHaveLogFit)
		{
			// Display calculating message
			LoadString(hInst, IDS_MESSAGE_CALCLOGFIT, label_str, LABELSIZE);
			WriteMessage(label_str);

			// Display wait cursor
			SetCursor(hWait);

			// Calc log fit
			CalcLogFreqDrift(f_data, &a, &b, &c, &v);      /* log calc drift */

			// Display normal cursor
			SetCursor(hArrow);

			// Erase calculating message
			WriteMessage("");

			// Set have log fit flag
			bHaveLogFit=TRUE;
		}
		fntchg('\310');                                          /* news.fnt */
		color(line_color);                                     /* line color */
												 /* draw log regression line */
		npts=0;

		// Note: Average because curve() has a problem with # pts > 16383
		// Determine averaging factor to use for plotting log fit
		af=(int)ceil((f_data[2]-f_data[1]+1)/16383.0);

		for(i=(int)(f_data[1]+2); i<=(int)(f_data[2]+2); i+=af)
												  /* put fit data into array */
		{
			y[npts]=(float)(p->y_mult*(c+(a*log(((i-2)*b)+1))+p->y_offset));
			x[npts]=(float)(p->x_mult*((i-2)+p->x_offset));
			npts++;
		}                                                         /* end for */
		
		ClipPlot();

		curve(x, y, npts, 0);
		UnclipPlot();
	
		// Sums for mean of observations p_data[]
		mean=0.0;
		for(i=0; i<npts; i++)
		{
			mean+=f_data[i+ARRAY_OFFSET];
		}
		mean/=(double)npts;

		// Sums for sst
		sst=0.0;
		for(i=0; i<npts; i++)
		{
			sst+=(f_data[i+ARRAY_OFFSET]-mean)*(f_data[i+ARRAY_OFFSET]-mean);
		}
		
		// Sums for sse
		sse=0.0;
		for(i=0; i<npts; i++)
		{
			sse+=(f_data[i+ARRAY_OFFSET]-(a*log(b*i+1)+c))*(f_data[i+ARRAY_OFFSET]-
				(a*log(b*i+1)+c));
		}
		
		// Calc r-squared = coefficient of determination to judge goodness of fit
		// It is SSR / SST = regression sum of squares  / total sum of squares
		// Or (better for numerical reasons) 1 - SSE/SST
		// SSR = Sum (predicted value - mean)^2 = variability of modelled data
		// SST = Sum (observed value - mean)^2 = variability of observed data
		// SSE = Sum (observed - predicted value)^2
		// where mean = avgerage of observed values

		// Calc r-squared
		rsqrd=1.0-(sse/sst);

		num=(int)(f_data[2]-f_data[1]+1);
		_snprintf(label_str, LABELSIZE,
				"Log Fit: y(t)=a*ln(bt+1)+c, "
				"a=%-10.7e, b=%-10.7e, c=%-10.7e, slope=%-10.7e at end",
				 a, b, c, (a*b)/((b*num)+1));
		ShortenExp(label_str);

		// New code 04/11/03
		// Save log fit parameters in global variables
		fLogA=a;
		fLogB=b;
		fLogSlope=(a*b)/((b*num)+1);

		fntchg('\313');                                       /* simplex.fnt */
		color(annotation_color);                     /* fit annotation color */
		tmargin((float)6.655);
		if(sFPlot.do_fit)
		{
			ctline(label_str,(float)0.075);
		}
		line_flag=TRUE;

		// Write log fit coefficients to clipboard
		if(TRUE) // Could control this with a flag
		{
			 // # chars to write to clipboard
			nClip=9*80;
				
			// Get memory and handle for clipboard
			hClipboard=GlobalAlloc(GMEM_DDESHARE, (DWORD)nClip);
			szClipboard=GlobalLock(hClipboard);

			// Compose clipboard text
			strlcpy(szClipboard, "File: ", nClip);
			strlcat(szClipboard, szFreqFileTitle, nClip);
			strlcat(szClipboard, "\r\n", nClip);
			strlcat(szClipboard, "Log Fit Parameters:\r\n", nClip);
			strlcat(szClipboard, "y(t)=a*ln(bt+1)+c\r\n", nClip);
			strlcat(szClipboard, "where t = Data point #\r\n", nClip);

			// Compose fit coefficients
			_snprintf(szBuffer, sizeof(szBuffer), "a = %e\r\n", a);
			ShortenExp(szBuffer);
			strlcat(szClipboard, szBuffer, nClip);
			_snprintf(szBuffer, sizeof(szBuffer), "b = %e\r\n", b);
			ShortenExp(szBuffer);
			strlcat(szClipboard, szBuffer, nClip);
			_snprintf(szBuffer, sizeof(szBuffer), "c = %e\r\n", c);
			ShortenExp(szBuffer);
			strlcat(szClipboard, szBuffer, nClip);
			_snprintf(szBuffer, sizeof(szBuffer), "Slope at end = %e\r\n",
				(a*b)/((b*num)+1));
			ShortenExp(szBuffer);
			strlcat(szClipboard, szBuffer, nClip);

			// Compose coefficient of determination
			_snprintf(szBuffer, sizeof(szBuffer), "r = %e\r\n", rsqrd);
			ShortenExp(szBuffer);
			strlcat(szClipboard, szBuffer, nClip);

			// Open clipboard, write text to it, and close clipboard
			GlobalUnlock(hClipboard);
			OpenClipboard(NULL);
			EmptyClipboard();
			SetClipboardData(CF_TEXT, hClipboard);
			CloseClipboard();
		}
	}                                                              /* end if */

	if(p->do_line==FPLOT_DIFF)                         /* diffusion fit line */
	{
		color(line_color);                             /* line message color */
		tmargin((float)6.4);

		if(!bHaveDiffFit)
		{
			// Display calculating message
			LoadString(hInst, IDS_MESSAGE_CALCDIFFIT, label_str, LABELSIZE);
			WriteMessage(label_str);

			// Display wait cursor
			SetCursor(hWait);

			CalcDiffusionFreqDrift(f_data, &a, &b, &c, &v);      /* calc fit */

			// Display normal cursor
			SetCursor(hArrow);

			// Erase calculating message
			LoadString(hInst, IDS_MESSAGE_CALCDIFFIT, label_str, LABELSIZE);
			WriteMessage("");

			// Set have log fit flag
			bHaveDiffFit=TRUE;
		}
		fntchg('\310');                                          /* news.fnt */
													  /* draw diffusion line */
		npts=0;

		// Note: Average because curve() has a problem with # pts > 16383
		// Determine averaging factor to use for plotting diffusion fit
		af=(int)ceil((f_data[2]-f_data[1]+1)/16383.0);

		for(i=(int)(f_data[1]+2); i<=(int)(f_data[2]+2); i+=af)
												  /* put fit data into array */
		{
			y[npts]=(float)(p->y_mult*(a+(b*sqrt((i-2)+c))+p->y_offset));
			x[npts]=(float)(p->x_mult*((i-2)+p->x_offset));
			npts++;
		}                                                         /* end for */

		ClipPlot();
		color(line_color);                             /* line message color */
		curve(x, y, npts, 0);
		UnclipPlot();

		// Sums for mean of observations p_data[]
		mean=0.0;
		for(i=0; i<npts; i++)
		{
			mean+=f_data[i+ARRAY_OFFSET];
		}
		mean/=(double)npts;

		// Sums for sst
		sst=0.0;
		for(i=0; i<npts; i++)
		{
			sst+=(f_data[i+ARRAY_OFFSET]-mean)*(f_data[i+ARRAY_OFFSET]-mean);
		}
		
		// Sums for sse
		sse=0.0;
		for(i=0; i<npts; i++)
		{
			sse+=(f_data[i+ARRAY_OFFSET]-(a+b*sqrt(i+c)))*(f_data[i+ARRAY_OFFSET]-
				(a+b*sqrt(i+c)));
		}
		
		// Calc r-squared = coefficient of determination to judge goodness of fit
		// It is SSR / SST = regression sum of squares  / total sum of squares
		// Or (better for numerical reasons) 1 - SSE/SST
		// SSR = Sum (predicted value - mean)^2 = variability of modelled data
		// SST = Sum (observed value - mean)^2 = variability of observed data
		// SSE = Sum (observed - predicted value)^2
		// where mean = avgerage of observed values

		// Calc r-squared
		rsqrd=1.0-(sse/sst);

		num=(int)(f_data[2]-f_data[1]+1);
		_snprintf(label_str, LABELSIZE,
				"Diffusion Fit: y(t)=a+b(t+c)[1/2], a=%-10.7e, "
				"b=%-10.7e, c=%-10.7e, slope=%-10.7e at end",
				a, b, c, 0.5*b/sqrt(num+c));
		ShortenExp(label_str);

		// New code 04/13/03
		// Save log fit parameters in global variables
		fDiffB=b;
		fDiffC=c;
		fDiffusionSlope=0.5*b/sqrt(num+c);

		fntchg('\313');                                       /* simplex.fnt */
		color(annotation_color);                     /* fit annotation color */
		tmargin((float)6.655);
		if(sFPlot.do_fit)
		{
			ctline(label_str,(float)0.075);
		}
		line_flag=TRUE;

		// Write diffusion fit coefficients to clipboard
		if(TRUE) // Could control this with a flag
		{
			 // # chars to write to clipboard
			nClip=9*80;
				
			// Get memory and handle for clipboard
			hClipboard=GlobalAlloc(GMEM_DDESHARE, (DWORD)nClip);
			szClipboard=GlobalLock(hClipboard);

			// Compose clipboard text
			strlcpy(szClipboard, "File: ", nClip);
			strlcat(szClipboard, szFreqFileTitle, nClip);
			strlcat(szClipboard, "\r\n", nClip);
			strlcat(szClipboard, "Diffusion Fit Parameters:\r\n", nClip);
			strlcat(szClipboard, "y(t)=a+b(t+c)^0.5\r\n", nClip);
			strlcat(szClipboard, "where t = Data point #\r\n", nClip);

			// Compose fit coefficients
			_snprintf(szBuffer, sizeof(szBuffer), "a = %e\r\n", a);
			ShortenExp(szBuffer);
			strlcat(szClipboard, szBuffer, nClip);
			_snprintf(szBuffer, sizeof(szBuffer), "b = %e\r\n", b);
			ShortenExp(szBuffer);
			strlcat(szClipboard, szBuffer, nClip);
			_snprintf(szBuffer, sizeof(szBuffer), "c = %e\r\n", c);
			ShortenExp(szBuffer);
			strlcat(szClipboard, szBuffer, nClip);
			_snprintf(szBuffer, sizeof(szBuffer), "Slope at end = %e\r\n",
				0.5*b/sqrt(num+c));
			ShortenExp(szBuffer);
			strlcat(szClipboard, szBuffer, nClip);

			// Compose coefficient of determination
			_snprintf(szBuffer, sizeof(szBuffer), "r = %e\r\n", rsqrd);
			ShortenExp(szBuffer);
			strlcat(szClipboard, szBuffer, nClip);

			// Open clipboard, write text to it, and close clipboard
			GlobalUnlock(hClipboard);
			OpenClipboard(NULL);
			EmptyClipboard();
			SetClipboardData(CF_TEXT, hClipboard);
			CloseClipboard();
		}
	}                                                              /* end if */

	if(p->do_line==FPLOT_AVG)                            /* average fit line */
	{
		CalcMean(f_data, &avg, FREQ_DATA);   /* calc average */

		color(line_color);                             /* line message color */
		// Draw line
		uline((float)(p->x_mult*(f_data[1]+p->x_offset)),
			(float)(p->y_mult*(avg+p->y_offset)),
			(float)(p->x_mult*(f_data[2]+p->x_offset)),
			(float)(p->y_mult*(avg+p->y_offset)), 3);

		_snprintf(label_str, LABELSIZE,
		"1st Average Fit: y(avg)=%-10.7e", avg);
		ShortenExp(label_str);
		fntchg('\313');					                      /* simplex.fnt */
		color(annotation_color);		                 /* note color=black */
		tmargin((float)6.655);
		if(sFPlot.do_fit)
		{
			ctline(label_str,(float)0.075);
		}
		line_flag=TRUE;
		color(line_color);                                     /* line color */
		ClipPlot();
		line_flag=TRUE;

		// Write average fit coefficients to clipboard
		if(TRUE) // Could control this with a flag
		{
			 // # chars to write to clipboard
			nClip=2*80;
				
			// Get memory and handle for clipboard
			hClipboard=GlobalAlloc(GMEM_DDESHARE, (DWORD)nClip);
			szClipboard=GlobalLock(hClipboard);

			// Compose clipboard text
			strlcpy(szClipboard, "File: ", nClip);
			strlcat(szClipboard, szFreqFileTitle, nClip);
			strlcat(szClipboard, "\r\n", nClip);

			// Compose average
			_snprintf(szBuffer, sizeof(szBuffer), "Average = %e\r\n", avg);
			ShortenExp(szBuffer);
			strlcat(szClipboard, szBuffer, nClip);

			// Open clipboard, write text to it, and close clipboard
			GlobalUnlock(hClipboard);
			OpenClipboard(NULL);
			EmptyClipboard();
			SetClipboardData(CF_TEXT, hClipboard);
			CloseClipboard();
		}
	}                                                              /* end if */

	// Polynomial fitting using Quinn-Curtis S&E function
	// S&E polynomial fit gives good results
	// but fails for orders greater than about 7
	// if set up to use floats - doubles are better
	// So the polytype is defined as double in polytype.h and Stable_w.h
	// That is necessary for better numerical dynamic range
	// Using doubles, poly fit seems OK up to order=12, so 9 S/B OK
	// Have to copy data to double array before calling PolyCurveFit()
	// and use float arrays for plotting the fit 
	if(p->do_line==FPLOT_POLY)                            /* polynominal fit */
	{
		color(line_color);                                     /* line color */

		// Allocate arrays a, yest, yres and cerr
		if((aa=(polytype*)malloc((p->order+1)*sizeof(polytype)))==NULL)
		{
			AllocErrorMessage();
			return;
		}
		if((yest=(polytype*)malloc(npts*sizeof(polytype)))==NULL)
		{
			AllocErrorMessage();
			free(aa);
			return;
		}
		if((yres=(polytype*)malloc(npts*sizeof(polytype)))==NULL)
		{
			AllocErrorMessage();
			free(aa);
			free(yest);
			return;
		}
		if((px=(polytype*)malloc(npts*sizeof(polytype)))==NULL)
		{
			AllocErrorMessage();
			free(aa);
			free(yest);
			free(yres);
			return;
		}
		if((py=(polytype*)malloc(npts*sizeof(polytype)))==NULL)
		{
			AllocErrorMessage();
			free(aa);
			free(yest);
			free(yres);
			free(px);
			return;
		}
		if((cerr=(polytype*)malloc((p->order+1)*sizeof(polytype)))==NULL)
		{
			AllocErrorMessage();
			free(aa);
			free(yest);
			free(yres);
			free(px);
			free(py);
			return;
		}

		// Convert x[] and y[] float arrays to px[] and py[] polytype=double arrays
		for(i=0; i<npts; i++)
		{
			px[i]=(polytype)x[i];
			py[i]=(polytype)y[i];
		}
		
		// Calc polynomial fit
		// void PolyCurveFit(polytype *indvar, polytype *depvar, int numobs, int order,
		// polytype *coef, polytype *yest, polytype *resid, polytype *see,
		// polytype *coefsig, polytype *rsq, polytype *r, char *cferror)
		// Arguments (in order) are as follows:
		// *indvar = pointer to 0-based float time data vector x[] of size numobs=npts
		// *depvar = pointer to 0-based float phase data vector y[] of size numobs=npts
		// int numobs = # data points=npts
		// int order = polynomial order=p->order (1=linear, etc)
		// polytype *coef = pointer to 0-based float fit coefficient vector aa[]
		//     of size p->order+1
		// polytype *yest = pointer to 0-based float fit y estimate vector yest[]
		//     of size numobs=npts
		// polytype *resid = pointer to 0-based float fit y residual vector yres[]
		//     of size numobs=npts
		// polytype *see = pointer to standard error of estimate = stderror
		// polytype *coefsig = pointer to 0-based float fit coefficient std error vector
		//     cerr[] of size p->order+1
		// polytype *rsq = pointer to r-squared error of estimate = rsqr
		// polytype *r = pointer to r value of estimate = r
		// char *cferror = pointer to singular matrix error flag = cferr

		PolyCurveFit(px, py, npts, p->order, aa, yest, yres, &stderror, cerr, &rsqr,
			&r, &cferr);

		// Free working arrays yest, and cerr
		free(yest);
		free(yres);
		free(cerr);
		
		if(!cferr)
			{
			// Put fit data into y[] array for plotting
			// y[] is float array
			// aa[] and px[] arrays are polytype=double
			for(i=0; i<npts; i++)
			{
				// Clear point
				y[i]=(float)0.0;

				// Add power of x terms up to poly order
				for(j=0; j<p->order+1; j++)
				{
					y[i]+=(float)(aa[j]*pow(px[i], j));
				}
			}
			
			// Plot poly fit data
			ClipPlot();
			for(i=0; i<npts-1; i++)                             /* plot fit data */
			{
				uline(*(x+i),*(y+i),*(x+i+1),*(y+i+1),1);
			}                                                         /* end for */
			UnclipPlot();

			// Compose fit parameters
			UnclipPlot();

			// Scale the poly fit coefficients by the y scale factor
			for(i=0; i<=p->order+1; i++)
			{
				aa[i]/=p->y_mult;
			}

			// Display fit coefficients
			switch(p->order)
			{
				case 1:
				{
					_snprintf(label_str, BIGLABELSIZE,
						"1st Order Polynomial Fit: a0=%e, a1=%e",
						aa[0], aa[1]);
					break;
				}

				case 2:
				{
					_snprintf(label_str, BIGLABELSIZE,
						"2nd Order Polynomial Fit: a0=%e, a1=%e, a2=%e",
						aa[0], aa[1], aa[2]);
					break;
				}

				case 3:
				{
					_snprintf(label_str, BIGLABELSIZE,
						"3rd Order Polynomial Fit: a0=%e, a1=%e, a2=%e, a3=%e",
						aa[0], aa[1], aa[2], aa[3]);
					break;
				}

				case 4:
				{
					_snprintf(label_str, BIGLABELSIZE,
						"4th Order Polynomial Fit: a0=%e, a1=%e, a2=%e, a3=%e, a4=%e",
						aa[0], aa[1], aa[2], aa[3], aa[4]);
					break;
				}

				case 5:
				{
					_snprintf(label_str, BIGLABELSIZE,
						"5th Order Poly Fit: a0=%7.5e, a1=%7.5e, a2=%7.5e, a3=%7.5e,"
						" a4=%7.5e, a5=%7.5e",
						aa[0], aa[1], aa[2], aa[3], aa[4], aa[5]);
					break;
				}

				case 6:
				{
					_snprintf(label_str, BIGLABELSIZE,
						"6th Order Poly Fit: a0=%6.4e, a1=%6.4e, a2=%6.4e, a3=%6.4e,"
						" a4=%6.4e, a5=%6.4e, a6=%6.4e",
						aa[0], aa[1], aa[2], aa[3], aa[4], aa[5], aa[6]);
					break;
				}

				case 7:
				{
					_snprintf(label_str, BIGLABELSIZE,
						"Poly Fit: a0=%6.4e, a1=%6.4e, a2=%6.4e, a3=%6.4e, a4=%6.4e,"
						" a5=%6.4e, a6=%6.4e, a7=%6.4e",
						aa[0], aa[1], aa[2], aa[3], aa[4], aa[5], aa[6], aa[7]);
					break;
				}

				case 8:
				{
					_snprintf(label_str, BIGLABELSIZE,
						"Poly Fit: a0=%5.3e, a1=%5.3e, a2=%5.3e, a3=%5.3e, a4=%5.3e,"
						" a5=%5.3e, a6=%5.3e, a7=%5.3e, a8=%5.3e",
						aa[0], aa[1], aa[2], aa[3], aa[4], aa[5], aa[6], aa[7], aa[8]);
					break;
				}

				case 9:
				{
					_snprintf(label_str, BIGLABELSIZE,
						"Poly Fit: a0=%5.3e, a1=%5.3e, a2=%5.3e, a3=%5.3e, a4=%5.3e,"
						" a5=%5.3e, a6=%5.3e, a7=%5.3e, a8=%5.3e, a9=%5.3e",
						aa[0], aa[1], aa[2], aa[3], aa[4], aa[5], aa[6], aa[7], aa[8], aa[9]);
					break;
				}
			}
			ShortenExp(label_str);
			fntchg('\313');					  /* simplex.fnt */
			color(annotation_color);	 /* note color=black */
			tmargin((float)6.655);
			
			// Write polynomial fit coefficients to clipboard
			if(TRUE) // Could control this with a flag
			{
				 // # chars to write to clipboard
				nClip=(7+p->order)*80;
					
				// Get memory and handle for clipboard
				hClipboard=GlobalAlloc(GMEM_DDESHARE, (DWORD)nClip);
				szClipboard=GlobalLock(hClipboard);

				// Compose clipboard text
				strlcpy(szClipboard, "File: ", nClip);
				strlcat(szClipboard, szFreqFileTitle, nClip);
				strlcat(szClipboard, "\r\n", nClip);
				strlcat(szClipboard, "Polynomial Fit Parameters:\r\n", nClip);
				_snprintf(szBuffer, sizeof(szBuffer), "Order = %d\r\n", p->order);
				strlcat(szClipboard, szBuffer, nClip);
				strlcat(szClipboard, "y(t)={Sum over i from 0 to order} a[i]t^i\r\n", nClip);
				strlcat(szClipboard, "where t = Data point #\r\n", nClip);

				// Compose fit coefficients
				for(i=0; i<p->order+1; i++)
				{
					_snprintf(szBuffer, sizeof(szBuffer), "a[%d] = %e\r\n", i, aa[i]);
					ShortenExp(szBuffer);
					strlcat(szClipboard, szBuffer, nClip);
				}

				// Compose coefficient of determination
				_snprintf(szBuffer, sizeof(szBuffer), "r = %e\r\n", rsqr);
				ShortenExp(szBuffer);
				strlcat(szClipboard, szBuffer, nClip);

				// Open clipboard, write text to it, and close clipboard
				GlobalUnlock(hClipboard);
				OpenClipboard(NULL);
				EmptyClipboard();
				SetClipboardData(CF_TEXT, hClipboard);
				CloseClipboard();
			}
			
			// Free coefficient array aa
			free(aa);

			// Free polytype data arrays
			free(px);
			free(py);

			// Show fit parameters
			if(sFPlot.do_fit)
			{
				if(p->order<4) // order 1-3
				{
					ctline(label_str,(float)0.075);
				}
				else if(p->order<6) // order 4-5
				{
					ctline(label_str,(float)0.070);
				}
				else if(p->order<8) // order 6-7
				{
					ctline(label_str,(float)0.065);
				}
				else // order 8-9
				{
					ctline(label_str,(float)0.060);
				}
			}
		}
		else // Fit failed
		{
			fntchg('\313');					  /* simplex.fnt */
			color(annotation_color);	 /* note color=black */
			tmargin((float)6.655);
			ctline("Polynomial fit failed - try lower order",(float)0.075);
		}

		line_flag=TRUE;
		color(line_color);                 /* line color */
		ClipPlot();
	}

	if(p->do_line==FPLOT_FUNC)            /* general non-linear function fit */
	{
		// Get function expression
		// Note: The additional copy of this string may not be necessary
		// But this allows it to be retained after GraphiC editing
		strlcpy(szFunction, p->function, sizeof(szFunction));
		
		// Function has nparam parameters
		// and each one has a corresponding p[j] value
		// where j=0 to nparam-1
		// Each t corresponds to a y[] index value i
		// where i=0 to npts-1
		// The operators +,-,*,/,^ and ()'s are retained as is
		// as are the math functions like exp() & sin()
		// To evaluate function, first set value of parameters and t
		// and then use same symbolic expression
		
		color(line_color);                                     /* line color */

		// Determine # function parameters (nparam)
		// Scan szFunction for chars between a to j
		// not followed by an alphabetic character
		// or a left parenthesis (indicating end of math function name)
		// Note: This is not already done in FreqPlotDlgProc()
		// unless FuncFitDlgProc() was called
		nparam=0;
		for(i=0; i<NUMPARAMS; i++)
		{
			// Look for a character between a and j
			if((ptr=strchr(szFunction, 'a'+i)))
			{
				// Check if the next character is non-alphabetic
				if((isalpha(*(ptr+1)))==0)
				{
					// Check if the next character is not a left parenthesis
					if((*(ptr+1)!='('))
					{
						nparam++;
					}
				}
			}
		}
	
		// Set # fit parameters in struct member
		sFPlot.num=nparam;
	
		// Allocate aa[], px[] and py[] arrays (polytype is double)
		if((aa=(polytype*)malloc((nparam)*sizeof(polytype)))==NULL)
		{
			AllocErrorMessage();
			return;
		}
		if((px=(polytype*)malloc(npts*sizeof(polytype)))==NULL)
		{
			AllocErrorMessage();
			free(aa);
			return;
		}
		if((py=(polytype*)malloc(npts*sizeof(polytype)))==NULL)
		{
			AllocErrorMessage();
			free(aa);
			free(px);
			return;
		}

		// Put measured data from y[] into py[]
		// This converts float y[] to polytype=double py[] array
		// Unscale the y[] data as it is being transferred
		// Note: An alternative would be to get it directly from the
		// main fFreqData array
		for(i=0; i<npts; i++)
		{
			py[i]=(polytype)((y[i]-p->y_offset)/p->y_mult);
		}
		
		// Put initial parameter values into aa[]
		// Note that these are in unscaled phase data units
		// with t as point #
		for(i=0; i<nparam; i++)
		{
			aa[i]=sFPlot.param[i];
		}

		// Do a trial evaluation to verify valid expression
		// Set the parameter values
		// They must be in alphabetical order without any gaps
		for(i=0; i<nparam; i++)
		{
			szBuffer[0]='a'+i;
			szBuffer[1]='\0';
			SetValue(szBuffer, &aa[i]);
		}
		
		// Evaluate expression
		val=0.0;
		SetValue("t", &val);
		i=Evaluate(szFunction, &val, &flag );

		// Check for error
		if(i!=E_OK)
		{
			//	E_OK           0        /* Successful evaluation
			//	E_SYNTAX       1        /* Syntax error
			//	E_UNBALAN      2        /* Unbalanced parenthesis
			//	E_DIVZERO      3        /* Attempted division by zero
			//	E_UNKNOWN      4        /* Reference to unknown variable
			//	E_MAXVARS      5        /* Maximum variables exceeded
			//	E_BADFUNC      6        /* Unrecognised function
			//	E_NUMARGS      7        /* Wrong number of arguments to funtion
			//	E_NOARG        8        /* Missing an argument to a funtion
			//	E_EMPTY        9        /* Empty expression

			switch(i)
			{
				case E_SYNTAX:
				{
					strlcpy(szBuffer, ErrMsgs[i-1], sizeof(szBuffer));
					strlcat(szBuffer, "\nCheck expression syntax\n", sizeof(szBuffer));
					MessageBox(hDialog, szBuffer, "Freq Data Plot Function Fit Error",
						MB_ICONEXCLAMATION);
				}
				break;

				case E_UNBALAN:
				{
					strlcpy(szBuffer, ErrMsgs[i-1], sizeof(szBuffer));
					strlcat(szBuffer, "\nCheck for parenthesis balance\n", sizeof(szBuffer));
					MessageBox(hDialog, szBuffer, "Freq Data Plot Function Fit Error",
						MB_ICONEXCLAMATION);
				}
				break;

				case E_DIVZERO:
				{
					strlcpy(szBuffer, ErrMsgs[i-1], sizeof(szBuffer));
					strlcat(szBuffer, "\nCheck for divide by zero\n", sizeof(szBuffer));
					MessageBox(hDialog, szBuffer, "Freq Data Plot Function Fit Error",
						MB_ICONEXCLAMATION);
				}
				break;

				case E_UNKNOWN:
				{
					strlcpy(szBuffer, ErrMsgs[i-1], sizeof(szBuffer));
					strlcat(szBuffer, "\nCheck for unallowed variable\n", sizeof(szBuffer));
					strlcat(szBuffer, "or variable without following operator\n", sizeof(szBuffer));
					MessageBox(hDialog, szBuffer, "Freq Data Plot Function Fit Error",
						MB_ICONEXCLAMATION);
				}
				break;

				case E_MAXVARS:
				{
					strlcpy(szBuffer, ErrMsgs[i-1], sizeof(szBuffer));
					strlcat(szBuffer, "\nExpression too complex\n", sizeof(szBuffer));
					MessageBox(hDialog, szBuffer, "Freq Data Plot Function Fit Error",
						MB_ICONEXCLAMATION);
				}
				break;

				case E_BADFUNC:
				{
					strlcpy(szBuffer, ErrMsgs[i-1], sizeof(szBuffer));
					strlcat(szBuffer, "\nCheck function name\n", sizeof(szBuffer));
					strlcat(szBuffer, "Allowable functions are:\n", sizeof(szBuffer));
					strlcat(szBuffer, "sin, cos, tan, asin, acos, atan, sinh, cosh, tanh, \n",
						sizeof(szBuffer));
					strlcat(szBuffer, "exp, log, log10, sqrt, floor, ceil, abs, and hypot",
						sizeof(szBuffer));
					MessageBox(hDialog, szBuffer, "Freq Data Plot Function Fit Error",
						MB_ICONEXCLAMATION);
				}
				break;

				case E_NUMARGS:
				{
					strlcpy(szBuffer, ErrMsgs[i-1], sizeof(szBuffer));
					strlcat(szBuffer, "\nCheck # of function arguments", sizeof(szBuffer));
					MessageBox(hDialog, szBuffer, "Freq Data Plot Function Fit Error",
						MB_ICONEXCLAMATION);
				}
				break;

				case E_NOARG:
				{
					strlcpy(szBuffer, ErrMsgs[i-1], sizeof(szBuffer));
					strlcat(szBuffer, "\nEnter missing function argument(s)", sizeof(szBuffer));
					MessageBox(hDialog, szBuffer, "Freq Data Plot Function Fit Error",
						MB_ICONEXCLAMATION);
				}
				break;

				case E_EMPTY:
				{
					strlcpy(szBuffer, ErrMsgs[i-1], sizeof(szBuffer));
					strlcat(szBuffer, "\nEnter function expression", sizeof(szBuffer));
					MessageBox(hDialog, szBuffer, "Freq Data Plot Function Fit Error",
						MB_ICONEXCLAMATION);
				}
				break;
			}

			// Free parameter array aa
			free(aa);

			// Free fit data arrays
			free(px);
			free(py);

			endplot();				/* finish plot and wait for instructions */
												/* to exit or draw next plot */
										/* resets file pointers and defaults */
			// Free plot arrays
			free(x);
			free(y);

			stopplot();    /* close files, return to text mode, exit program */
			return;
		}
		else // OK - Proceed with function fit
		{		
			// Sums for mean of observations y[]
			mean=0.0;
			for(i=0; i<npts; i++)
			{
				mean+=py[i];
			}
			mean/=(double)npts;

			// Sums for sst
			sst=0.0;
			for(i=0; i<npts; i++)
			{
				sst+=(py[i]-mean)*(py[i]-mean);
			}
	
			// Code for LM function fit using lmmin
			// lmmin works better than levmar and is in public domain
 			// Settings for lmmin fit
			lm_initialize_control(&control);
			data.user_func=fit_function;
			data.user_t=px;
			data.user_y=py;

			// Perform lmmin nonlinear function fit:
			//
			// Uses lm_mininize with expanded signature as top-level function
			// to pass function expression string:
			//     void lm_minimize(int m_dat, int n_par, double *par,
			//         lm_evaluate_ftype * lm_evaluate, lm_print_ftype * printout,
			//         void *data, lm_control_type * control, char *expression)
			// where:
			//     int m_dat is # observations (data points)
			//     int n_par is # fit parameters
			//     double *par is parameter array of size n_par
			//     lm_evaluate_ftype *evaluate is pointer to function evaluation function
			//     lm_print_ftype *printout is printout function
			//     void *data is pointer to data structure
			//     lm_control_type *control is pointer to control structure
			//     char *expression is function expression string to be fitted
			//
			// Calls lm_evaluate with expanded signature:
			// void lm_evaluate(int m_par, double *par, int m_dat, double *fvec,
			//     void *data, char *e, int *info)
			//
			// Calls print_function(), a customized version of lm_print_default():
			// void print_function(int n_par, double *par, int m_dat, double *fvec,
		    //     void *data, int iflag, int iter, int nfev)
			// where:
			//		m_dat=npts;
			//		n_par=nparam;
			//		par=aa
			// Must put nparam into global variable int nGlobalNumParam
			// and szFunction address into global pGlobalExpression
			nGlobalNumParam=nparam;
			pGlobalExpression=&szFunction[0];

			// Fill the px[] array with "time" values
			for(i=0; i<npts; i++)
			{
				px[i]=(polytype)i;
			}

			// Perform the fit
			lm_minimize(npts, nparam, aa, lm_evaluate, printout,
				&data, &control);

			// Print results:
			// printf("status: %s after %d evaluations\n",
			//		lm_shortmsg[control.info], control.nfev);

			// Put fit data into y[] array for plotting
			// y[] is float array
			// aa[] and px[] arrays are polytype=double
			
			// Evaluate general algebraic expression for plot
			lmfunc(aa, py, nparam, npts, szFunction);
			
			// Sums for ssr
			ssr=0.0;
			for(i=0; i<npts; i++)
			{
				ssr+=(py[i]-mean)*(py[i]-mean);
			}
			
			// Calc r-squared = coefficient of determination to judge goodness of fit
			// It is SS(R) / SS(T) = regression sum of squares  / total sum of squares
			// SS(R) = Sum (predicted value - mean)^2
			// SS(T) = Sum (observed value - mean)^2
			// where mean = avgerage of observed values
			rsqrd=ssr/sst;

			// Put scaled values into float plot array
			for(i=0; i<npts; i++)
			{
				y[i]=(float)((py[i]*p->y_mult)+p->y_offset);
			}
				
			// Plot function fit data
			ClipPlot();
			for(i=0; i<npts-1; i++)                             /* plot function */
			{
				uline(*(x+i),*(y+i),*(x+i+1),*(y+i+1),1);
			}                                                         /* end for */
			UnclipPlot();

			// New code 07/11/08 to remove fit from freq data
			// Have fit function evaluated at npts in double py[]
			// Data is npts in f_data[] array
			if(p->remove)
			{
                // Create tab to save previous data if requested
				if(bTabs && bTabChange)
				{
					CreateTab();
				}
						
				j=0;
				// Loop through freq data
				for(i=(int)(f_data[1]+2); i<=(int)(f_data[2]+2); i++)
				{
					if(f_data[i])                                           /* skip gaps */
					{
						f_data[i]-=py[j];                   /* remove fit from freq data */
					}                                                          /* end if */
					j++;                                    /* increment fit array index */
				}                                                             /* end for */
            
				// Set data changed flags
				bFreqDataChanged=TRUE;
				bFreqDataUnsaved=TRUE;
				sFPlot.new_file=TRUE;
				bFreqScaleChanged=TRUE;
				bFreqRedraw=TRUE;

				// Increment filename
				if(bIncExtension)
				{
					IncExtension(szFile, FREQ_DATA);
					IncExtension(szFileTitle, FREQ_DATA);
					IncExtension(szFreqFile, FREQ_DATA);
					IncExtension(szFreqFileTitle, FREQ_DATA);
					SetWindowText(hwndFreqFilename, szFileTitle);
				}
				
				// Force new PSD plot scale
				sPSPlot.y_tic=0;

				// Redraw status plots from new data
				UpdateStatusBar(hwndMain, NEW_DATA);

				// Reset redraw flag
				bFreqRedraw=FALSE;

				// Clear plot lines
				ClearLines();

				// Clear synch flag
				bSynch=FALSE;

				// Clear remove fit checkbox state
				sFPlot.remove=FALSE;

				// Write log file
				_snprintf(szLog, sizeof(szBuffer), "y(t)=%s, ", szFunction);
				for(i=0; i<nparam; i++)
				{
					_snprintf(szBuffer, sizeof(szBuffer), " =%e", aa[i]);
					szBuffer[0]='a'+i; // Put param letter into string
					strncat(szLog, szBuffer, sizeof(szBuffer));
					if(i<nparam-1) // Add comma and space if not last param
					{
						strncat(szLog, ", ", sizeof(szBuffer));
					}
				}
				WriteLog(80, szLog);
			}

			// Write function fit coefficients to clipboard
			if(TRUE) // Could control this with a flag
			{
				 // # chars to write to clipboard
				nClip=(7+p->order)*80;
					
				// Get memory and handle for clipboard
				hClipboard=GlobalAlloc(GMEM_DDESHARE, (DWORD)nClip);
				szClipboard=GlobalLock(hClipboard);

				// Compose clipboard text
				strlcpy(szClipboard, "File: ", nClip);
				strlcat(szClipboard, szFreqFileTitle, nClip);
				strlcat(szClipboard, "\r\n", nClip);
				strlcat(szClipboard, "Function: y(t)=", nClip);
				strlcat(szClipboard, szFunction, nClip);
				strlcat(szClipboard, "\r\n", nClip);
				strlcat(szClipboard, "Fit Parameters:\r\n", nClip);

				// Compose fit parameters
				for(i=0; i<nparam; i++)
				{
					_snprintf(szBuffer, sizeof(szBuffer), "%c = %e\r\n", 'a'+i, aa[i]);
					ShortenExp(szBuffer);
					strlcat(szClipboard, szBuffer, nClip);
				}

				// Add time note
				strlcat(szClipboard, "t = Data point #\r\n", nClip);

				// Show coefficient of determination
				_snprintf(szBuffer, sizeof(szBuffer), "r = %e\r\n", rsqrd);
				ShortenExp(szBuffer);
				strlcat(szClipboard, szBuffer, nClip);

				// Open clipboard, write text to it, and close clipboard
				GlobalUnlock(hClipboard);
				OpenClipboard(NULL);
				EmptyClipboard();
				SetClipboardData(CF_TEXT, hClipboard);
				CloseClipboard();
			}
				
			// Compose plot label for fit parameters
			// Note: ^ is not a valid character for GraphiC label
			// Need to put a @ in fromt of it
			// Or (better) surround exponent with [ and ]
			while(ptr=strchr(szFunction, '^'))
			{
				// Replace ^ with [
				*ptr='[';

				#if(0) // Original code
				// Find end of exponent
				// Note: This isn't quite right
				// For an exponent with a decimal point
				// only the characters before it are raised
				ptr1=ptr+1;
				while(isdigit(*ptr1))
				{
					ptr1++;
				}
				#endif

				#if(1) // New code 01/21/08
				// Find end of exponent
				ptr1=ptr+1;
				while( (isdigit(*ptr1)) || (*ptr1=='.') )
				{
					ptr1++;
				}
				#endif

				// ptr1 now points to next character after exponent
				// Move this and all following characters up one space
				// Get length of string (not including EOS)
				len=strlen(szFunction);
				// Set ptr2 to 1 space past EOS
				ptr2=&szFunction[len+1];
				// Move characters up 1 space
				while(ptr2>ptr1)
				{
					*ptr2=*(ptr2-1);
					ptr2--;
				}

				// Make character at ptr1 a ]
				*ptr1=']';
			}

			// Note: We might want to remove the *'s
			// But can we remove them all?
			
			strlcpy(label_str, "Function Fit: y(t)=", BIGLABELSIZE);
			strlcat(label_str, szFunction, BIGLABELSIZE);
			strlcat(label_str, ", ", BIGLABELSIZE);

			for(i=0; i<nparam; i++)
			{
				_snprintf(szBuffer, sizeof(szBuffer), " %c=%e.", 'a'+i, aa[i]);
				strlcat(label_str, szBuffer, BIGLABELSIZE);
			}

			// Display function expression and fit coefficients
			// Show fit parameters if do_fit flag set
			if(sFPlot.do_fit)
			{
				ShortenExp(label_str);
				fntchg('\313');					  /* simplex.fnt */
				color(annotation_color);	 /* note color=black */
				tmargin((float)6.655);
				if(nparam<4) // 1-3 params
				{
						ctline(label_str,(float)0.075);
				}
				else if(nparam<6) // 4-5 params
				{
						ctline(label_str,(float)0.070);
				}
				else if(nparam<8)// 6-7 params
				{
						ctline(label_str,(float)0.065);
				}
				else // 8-9 params
				{
						ctline(label_str,(float)0.060);
				}
			}

			// Free parameter array aa
			free(aa);

			// Free fit data arrays
			free(px);
			free(py);
		}
	}

	{
		color(line_color);                                     /* line color */
		save_start=(float)f_data[1];                  /* save starting point */
		save_end=(float)f_data[2];                      /* save ending point */

		// Clip lines
		ClipPlot();

		for(i=0; i<FLINE_NUMLINES; i++)
		{
			switch(sFLine[i].nLineType)
			{
				case FLINE_NONE:                                  /* no line */
				{
					break;
				}
				case FLINE_END:                    /* line between endpoints */
				{
					if( (sFLine[i].fXStart>0)                       &&
						(sFLine[i].fXEnd>=sFLine[i].fXStart)        &&
						((sFLine[i].fXEnd-sFLine[i].fXStart)<=npts) )
					{
						f_data[1]=sFLine[i].fXStart;
						f_data[2]=sFLine[i].fXEnd;

						// Draw line
						uline((float)(p->x_mult*(f_data[1]+p->x_offset)),
							(float)(p->y_mult*(sFLine[i].fYStart+p->y_offset)),
							(float)(p->x_mult*(f_data[2]+p->x_offset)),
							(float)(p->y_mult*(sFLine[i].fYEnd+p->y_offset)),
							3);
					}
					break;
				}
				case FLINE_LIN:                           /* regression line */
				{
					if( (sFLine[i].fXStart>0)                       &&
						(sFLine[i].fXEnd>=sFLine[i].fXStart)        &&
						((sFLine[i].fXEnd-sFLine[i].fXStart)<=npts) )
					{
						f_data[1]=sFLine[i].fXStart;
						f_data[2]=sFLine[i].fXEnd;

						CalcLinFreqDrift(f_data, &intercept, &slope, &v);
															   /* calc drift */
						// Draw line
						uline((float)(p->x_mult*(f_data[1]+p->x_offset)),
							(float)(p->y_mult*((intercept+(f_data[1] *
							slope))+p->y_offset)),
							(float)(p->x_mult*(f_data[2]+p->x_offset)),
							(float)(p->y_mult*((intercept+(f_data[2] *
							slope))+p->y_offset)), 3);

						if(!line_flag)			 /* can list only 1 line fit */
						{
							UnclipPlot();
							_snprintf(label_str, LABELSIZE,
							"1st Linear Fit: y(t)=a+bt, "
							"Intercept=a=%-10.7e, Slope=b=%-10.7e",
							intercept,slope);
							ShortenExp(label_str);
							fntchg('\313');					  /* simplex.fnt */
							color(annotation_color);     /* note color=black */
							tmargin((float)6.655);
							if(sFPlot.do_fit)
							{
								ctline(label_str,(float)0.075);
							}
							line_flag=TRUE;
							color(line_color);                 /* line color */
							ClipPlot();
						}
					}
					break;
				}
				case FLINE_AVG:                    /* horizontal line at avg */
				{
					if( (sFLine[i].fXStart>0)                       &&
						(sFLine[i].fXEnd>=sFLine[i].fXStart)        &&
						((sFLine[i].fXEnd-sFLine[i].fXStart)<=npts) )
					{
 						f_data[1]=sFLine[i].fXStart;
						f_data[2]=sFLine[i].fXEnd;

						CalcMean(f_data, &avg, FREQ_DATA);   /* calc average */

						// Draw line
						uline((float)(p->x_mult*(f_data[1]+p->x_offset)),
							(float)(p->y_mult*(avg+p->y_offset)),
							(float)(p->x_mult*(f_data[2]+p->x_offset)),
							(float)(p->y_mult*(avg+p->y_offset)), 3);

						// List average fit
						if(!line_flag)			 /* can list only 1 line fit */
						{
							UnclipPlot();
							_snprintf(label_str, LABELSIZE,
							"1st Average Fit: y(avg)=%-10.7e", avg);
							ShortenExp(label_str);
							fntchg('\313');					  /* simplex.fnt */
							color(annotation_color);   /* note color = black */
							tmargin((float)6.655);
							if(sFPlot.do_fit)
							{
								ctline(label_str,(float)0.075);
							}
							line_flag=TRUE;
							color(line_color);                 /* line color */
							ClipPlot();
						}
					}
					break;
				}
				case FLINE_MARK:                     /* vertical marker line */
				{
					if( (sFLine[i].fXStart>0)                       &&
						((sFLine[i].fXEnd-sFLine[i].fXStart)<=npts) )
					{
						f_data[1]=sFLine[i].fXStart;
						f_data[2]=sFLine[i].fXStart;

						// Draw line
						uline((float)(p->x_mult*(f_data[1]+p->x_offset)),
							(float)(p->y_mult*(p->y_min+p->y_offset)),
							(float)(p->x_mult*(f_data[2]+p->x_offset)),
							(float)(p->y_mult*(p->y_max+p->y_offset)), 3);
					}
					break;
				}
			}                                                  /* end switch */
		}                                                         /* end for */
		f_data[1]=save_start;                      /* restore starting point */
		f_data[2]=save_end;                          /* restore ending point */

		// Unclip lines
		UnclipPlot();

	}                                                              /* end if */

	fntchg('\313');                                           /* simplex.fnt */
	color(annotation_color);                       /* annotation color=black */

	// Write date
	if(p->do_date)
	{
		Dateline(1, 1, 1);                   /* put date & file info on plot */
	}                                                              /* end if */

	// Display message box
	// Locations are x, y in pixels, origin at bottom left, 8192 x 6266 space
	// Find half length of message box in pixels
	lgth=(H_MARGIN+strwidtq(p->message_str, CHAR_HGTH));

	// Write message
	if(p->message_str[0]!='\0')         /* don't display a blank message box */
	{
		switch(p->position)
		{
			case MSG_TOP_LEFT:            /* message box at top left of plot */
			{
				MsgBox(300,4400,p->message_str);
				break;
			}                                                    /* end case */
			case MSG_MID_LEFT:         /* message box at middle left of plot */
			{
				MsgBox(300,2270,p->message_str);
				break;
			}                                                    /* end case */
			case MSG_BOT_LEFT:         /* message box at bottom left of plot */
			{
				MsgBox(300,200,p->message_str);
				break;
			}                                                    /* end case */
			case MSG_TOP_CENTER:        /* message box at top center of plot */
			{
				MsgBox(3470-lgth,4400, p->message_str);
				break;
			}                                                    /* end case */
			case MSG_MID_CENTER:     /* message box at middle center of plot */
			{
				MsgBox(3470-lgth,2270,p->message_str);
				break;
			}                                                    /* end case */
			case MSG_BOT_CENTER:     /* message box at bottom center of plot */
			{
				MsgBox(3470-lgth,200,p->message_str);
				break;
			}                                                    /* end case */
			case MSG_TOP_RIGHT:          /* message box at top right of plot */
			{
				MsgBox(6770-2*lgth,4400,p->message_str);
				break;
			}                                                    /* end case */
			case MSG_MID_RIGHT:       /* message box at middle right of plot */
			{
				MsgBox(6770-2*lgth,2270,p->message_str);
				break;
			}                                                    /* end case */
			case MSG_BOT_RIGHT:       /* message box at bottom right of plot */
			{
				MsgBox(6770-2*lgth,200,p->message_str);
				break;
			}                                                    /* end case */
		}                                                      /* end switch */
	}

	// Insert plot if bDoFreqPlotInsert is set
	if(bDoFreqPlotInsert)
	{
		// Frequency plot insert filename is szFreqPlotInsertFile
		// Try to open it
		if((file=fopen(szFreqPlotInsertFile, "r"))!=NULL)
		{
			// Immediately release file pointer
			fclose(file);

			// Insert data plot at bottom left of sigma plot
			// Note:  This must be a tkf file or this will fail
			InsertPlot(300, 200, szFreqPlotInsertFile);

		}
	}

	// Write label
	if(bPlotLabel)
	{
		UnclipPlot();
		color(annotation_color);                         /* annotation color */
		width=(float)intopix(strwidth(szPlotLabel, (float)0.05));
		putlabel(szPlotLabel, (float)(8192-2*(width+20)), (float)20.0,
			(float)0.05, 0, PIXEL_UNITS);
	}

	// Activate mouse cursor
	if(p->do_mouse)
	{
		// Allocate memory for x and y point arrays
		fx=(float*)gpcalloc(64, sizeof(float));
		fy=(float*)gpcalloc(64, sizeof(float));

		curson(0, 0, &fx, &fy, &find);                /* turn on mouse cursor*/

		// Free memory - this assumes that point info isn't needed
		gpcfree((void**)&fx);
		gpcfree((void**)&fy);
	}                                                              /* end if */

	rightax(0);

	#if(0) // Experimental code 11/07/09
	// This GraphiC function displays the x and y values of the plotted data
	// in a box at the top of the plot at the right of the menu bar
	// The readout cursor starts off at the center of the plot
	// One can move the cursor crosshairs with the left and right arrow keys
	// or go to start or end with Home and End keys
	// When done, one must left click with the mouse on the readout to close it
	// Esc is supposed to close readout, but doesn't
	// It doesn't draw lines or do anything else
	curvefollow(0, 0, x, y, npts);
	#endif
	
	// Avoid unwanted clipping 
	UnclipPlot();

	#ifdef DEMO_VERSION
	// Add watermark for demo version
	// Get plot size in pixels
	usertopix(x_max, y_max, 0.0, &x_pix_max, &y_pix_max);
	usertopix(x_min, y_min, 0.0, &x_pix_min, &y_pix_min);
	x_pix=x_pix_max-x_pix_min;
	y_pix=y_pix_max-y_pix_min;
	// Select hatched swiss font
	fntchg('\311');                                              /* news.fnt */
	fontfill(2, 230, 0);
	// Display watermark
	pltfnt((float)x_min, (float)y_min, "Stable32 Demo Version", (float)0.6,
		(int)(180*atan2((double)y_pix, (double)x_pix)/PI));
	#endif

	#ifdef VITSAS_VER
	// Add watermark for V-ITSAS version
	color(227);
	tmargin((float)0.15);
	ltline(" Stable32 V-ITSAS", (float)0.12);
	tmargin((float)0.15);
	rtline("Evaluation Version ", (float)0.12);
	#endif

	#if(1) // New code 11/23/11
	// Note that print comes before metafile
	// The metafile is NG with both print and metafile
	// in the opposite order
	// Process bCmdT command to print plot
	if(bCmdT)
	{
		// Send print message to GraphiC
		PostMessage(hGPC, WM_COMMAND,
			GET_WM_COMMAND_MPS(IDM_PRINT, 0, 0));
	}

	// Process bCmdM command to copy plot metafile to clipboard
	if(bCmdM)
	{
		// Send copy metafile message to GraphiC
		PostMessage(hGPC, WM_COMMAND,
			GET_WM_COMMAND_MPS(IDM_COPYMETA, 0, 0));
	}

	// Process bCmdX command to close plot
	if(bCmdX)
	{
		// Show the plot briefly
		Sleep(1000);

		// Close plot and plot dialog box
		PostMessage(hPlot, WM_CLOSE, (WPARAM)0, (LPARAM)0);
		PostMessage(hPlotBox, WM_CLOSE, (WPARAM)0, (LPARAM)0);
	}
	#endif

	endplot();
									/* finish plot and wait for instructions */
												/* to exit or draw next plot */
										/* resets file pointers and defaults */
	// Insert cusum sub-plot
	if( (p->do_cusum) && (p->do_line==FPLOT_JUMP) && !bCmdX )
	{
		// Start insert plot
		startplot(background_color);
		
		// Select font
		fntchg('\313');                                       /* simplex.fnt */

		// Do font scaling
		setscale(1);

		// Draw box around plot area
		color(box_color);
		box();

		// Write title
		color(label_color);
		_snprintf(szBuffer, sizeof(szBuffer), "CUSUM Plot");
		heading(szBuffer);

		// Set up plot scales
		axesoff(AXESOFF);
		color(grid_color);
		scales(10, 10, x, cs, npts);

		// Draw scatter plot (points w/o lines)
		scatplot(1);
		color(data_color);
		if(npts>10000)
		{
			sympick(16); // Small dot
		}
		else
		{
			sympick(12); // Big dot
		}

		// Clip scatter plot
		ClipPlot();
		
		// Draw curve
		curve(x, cs, npts, 1);

		// Restore normal curves
		scatplot(0);

		// Stop clipping
		UnclipPlot();

		// End plot insert
		endplot();
	}

	// Free plot arrays
	free(x);
	free(y);
	free(m);
	free(cs);
	free(s);

	stopplot();            /* close files, return to text mode, exit program */
}                                                          /* end FreqPlot() */

/*****************************************************************************/
/*                                                                           */
/*								SigmaPlot()                                  */
/*                                                                           */
/*		Function to plot Allan variance data                                 */
/*      Parameters:                                                          */
/*			p plotdata structure elements:                                   */
/*      		title = plot title                                           */
/*      		subtitle = plot subtitle                                     */
/*				do_box = draw box flag                                       */
/*				do_errbar = draw error bars flag                             */
/*				do_date = write date flag                                    */
/*          	do_line = line menu flag                                     */
/*				do_table = write sigma-tau table on plot flag                */
/*				plotype = 0 normal sigma y                                   */
/*						  1 modified sigma y                                 */
/*						  2 sigma x                                          */
/*					  	  3 overlapping normal sigma y                       */
/*						  4 both overlapping & modified sigma y              */
/*						  5 all tau (not used)                               */
/*						  6 total sigma y                                    */
/*						  7 Hadamard deviation                               */
/*				new_file = new sigma data file flag                          */
/*				position = position of message box                           */
/*				plot_filename = .tkf filename for plot                       */
/*				x_min = tau scale minimum                                    */
/*				x_max = tau scale maximum                                    */
/*				y_min = sigma scale minimum                                  */
/*				y_max = sigma scale maximum                                  */
/*				message_str = message box text                               */
/*                                                                           */
/*				The following plotdata structure elements are not used:      */
/*					x_offset                                                 */
/*					x_mult                                                   */
/*					y_offset                                                 */
/*					y_mult                                                   */
/*					x_label                                                  */
/*					left_x_label                                             */
/*					right_y_label                                            */
/*					x_div                                                    */
/*					x_tic                                                    */
/*					y_div                                                    */
/*					y_tic                                                    */
/*              	config                                                   */
/*                                                                           */
/*          BOOL autoscale_s = flag for autoscaling of sigma axis            */
/*          BOOL autoscale_t = flag for autoscaling of tau axis              */
/*          BOOL read_flag   = flag indicating plot of stability data file   */
/*			int nSigmaSize   = size of sigma data array                      */
/*                                                                           */
/*																			 */
/* 			sigmadata structure elements for sigma data:                     */
/*				int		points                   number of sigma data points */
/*				float	*tau            pointer to averaging time data array */
/*				float	*num          pointer to number of data points array */
/*				float	*sigma                   pointer to sigma data array */
/*				float	*ci                   pointer to confidence interval */
/*				float	*sig_min      pointer to lower sigma error bar array */
/*				float	*sig_max      pointer to upper sigma error bar array */
/*				float	*std_dev         pointer to standard deviation array */
/*				int		*alpha          pointer to noise type exponent array */
/*                                                                           */
/*          The sigmadata structures are:                                    */
/*				sNormSigData;    // Normal & overlapping sigma data struct   */
/*				sModSigData;     // Modified & time sigma data struct        */
/*				sAllNormSigData; // All tau norm & overlap sigma data struct */
/*				sAllModSigData;  // All tau mod & time sigma data struct     */
/*                                                                           */
/*			 SigmaPlotTypes:                                                 */
/*				NORMAL_RUN                                                   */
/*				OVERLAPPING_RUN                                              */
/*				MODIFIED_RUN                                                 */
/*				TIME_RUN                                                     */
/*				HADAMARD_RUN                                                 */
/*				OVERLAPHAD_RUN                                               */
/*				TOTAL_RUN                                                    */
/*				MODTOTAL_RUN                                                 */
/*				TIMETOTAL_RUN                                                */
/*				BOTH_RUN                                                     */
/*				TIERMS_RUN                                                   */
/*				MTIE_RUN                                                     */
/*				THEO1_RUN                                                    */
/*				FULL_RUN                                                     */
/*                                                                           */
/*      Returns nothing (void)                                               */
/*                                                                           */
/*		Revision record:                                                     */
/*			08/17/96	Adapted from plot_sigma() of Stable/DOS              */
/*			10/26/96	Got noise lines, sigma table, notes & messages going */
/*			10/28/96	Added bias factors to plot scales                    */
/*			11/18/96	Revised plot sizes, etc.                             */
/*			12/17/96	Adjusted x-axis label & table box positions          */
/*			01/10/97	Added bias factors to mod & time sigma plot scales   */
/*			01/28/97	Added some code for all tau sigma type               */
/*			01/29/97	Completed code for all tau sigma type                */
/*			01/30/97	Increased # allowable points for Read case           */
/*						Added provisions for multiple sets of stability data */
/*						and plotting of curve w/o symbols                    */
/*			02/23/97	Added clipping of noise lines                        */
/*			03/15/97	Changed clipping of noise lines to ClipPlot()        */
/*			05/10/97	Now allow all tau with all sigma types, so need to   */
/*						pass info both about all tau and sigma type: use     */
/*						global bAllTau flag                                  */
/*			02/15/98	Added nSigmaSize usage                               */
/*			08/30/98	Added do_fit usage                                   */
/*			12/12/98	Added ability to insert mini plot                    */
/*			03/13/99	Added overlapping Hadamard deviation                 */
/*			12/25/99	Added Mod Totdev                                     */
/*			05/05/00	Added TTOT                                           */
/*			10/29/00	Added HTOT                                           */
/*          02/18/01	Added use of smaller symbol for large # points       */
/*			03/11/01	Added provisions for thicker lines                   */
/*			02/09/03	Added Theo1                                          */
/*			02/15/03	Added Overlap & Theo1                                */
/*			08/01/03	Added opaque note panel                              */
/*			10/02/03	Changed plot insert code                             */
/*			11/01/05	Added mask plotting code                             */
/*			11/22/06	Use multiple plot symbols for different data sets    */
/*			                                                                 */
/*****************************************************************************/

#ifndef _MSC_VER
	#pragma argsused
#endif

void WINAPI SigmaPlot(struct plotdata *p, BOOL autoscale_s,
	BOOL autoscale_t, BOOL read_flag)
{
	// Local variables
	// Chars
	// char szBuffer[BUFFER_SIZE];		// For testing
	char label_str[LABELSIZE+1];
	char *szTemp;
	// Ints
	int i;							// Index
	int j;                          // Ditto
	int k;                          // Ditto
	int noise_flag=FALSE;           //
	int xdec;                       // # x decades in plot
	int ydec;                       // # y decades in plot
	int len;
	int lgth;
	int symbol;						// plot symbol #

	#ifdef DEMO_VERSION
	int x_pix, y_pix, x_pix_min, y_pix_min, x_pix_max, y_pix_max;
	#endif

	// For panel filling of notes
	float xpan[5], ypan[5];
	char ch;
	char buf[NOTESIZE+1];
	int xpix, ypix;
	int wid, max_wid=0;
	int allow=15, ydel;
	int tsavfq=0;
	int bsavfq=0;
	int descend;

	// Colors
	int background_color=BRT_WHITE;
	int grid_color=BLACK;
	int box_color=BLACK;
	int label_color=BLUE;
	int data_color=RED;
	int annotation_color=BLACK;
	int line_color=GREEN;
	int aux_color=GREEN;
	// BOOLS
	BOOL bAllocError=FALSE;         // Memory allocation error flag
	BOOL tdev_flag=FALSE;           // Flag for TDEV line annotation
	// Floats
	float *x, *y;     				// Pointers to plot data
	float x1, y1, x2, y2;           // Endpoints of TDEV line
	float width;                    // Half-width of title string
	float temp1, temp2;
	float line_value;               // Value of TDEV line
	static float sigma_1[8];
	FILE *file;									             /* file pointer */

	
	// Start of code
	// Allocate memory for plot data arrays
	// Note: 2 extra points are allocated for scale limits
	if((x=(float*)malloc((nSigmaSize+2)*sizeof(float)))==NULL)
	{
		bAllocError=TRUE;
	}

	if((y=(float*)malloc((nSigmaSize+2)*sizeof(float)))==NULL)
	{
		free(x);
		bAllocError=TRUE;
	}
	
	// Announce memory allocation error
	if(bAllocError)
	{
		AllocErrorMessage();
		return;
	}

	// Sequence of basic GraphiC plotting calls is per page I-34 of manual:
	//	   bgnplot()           	Initializations
	//	   startplot()         	Starts graphics
	//	   font()              	Loads fonts
	//	   page()              	Sets overall picture size
	//	   heading()			Draws title
	//	   xname(), yname()	 	Draws axis labels
	//	   area2d()				Defines axis lengths

	// Write log info
	WriteLog(39, p->plot_filename);

	bgnplot(1,'g',p->plot_filename);                      /* initialize plot */
	startplot(background_color);         /* start plot with background color */

	// Load fonts
	font(4,"news.fnt",'\310',"swiss.fnt",'\311',"newsgrm.fnt",'\312',
		 "simplex.fnt",'\313');

	page(FULLPAGE);                  /* Sets the maximum allowable page size */

	heading("");    /* Blank heading allows space for title & subtitle later */
	fillfont(1);                                         /* Use filled fonts */

	// Kill the beep
	GPCSetBeepDefaults(0, 0);

	// Avoid unwanted clipping 
	UnclipPlot();
	
	// Axis labeling code
	if(nStyle==ORIGINAL_STYLE)
	{
		SetLabelSpace(X_AXIS, 2);
	}
	else
	{
		SetLabelSpace(X_AXIS, 1);
	}

	fntchg('\310');                                              /* news.fnt */
	if(nStyle==MODERN_STYLE)                           /* Use "modern" style */
	{
		fntchg('\311');                                          /*swiss.fnt */
		upright(1);                          /* upright y-axis label numbers */
		numht((float)0.18);                           /* larger axis numbers */
		xnamht((float)0.22);                         /* larger x-axis labels */
		ynamht((float)0.22);                         /* larger y-axis labels */
	}
	color(label_color);                 /* left y-axis label for single plot */
	strlcpy(label_str, sSPlot.x_label, sizeof(label_str));
	xname(label_str);                                        /* x-axis label */

	strlcpy(label_str, sSPlot.left_y_label, sizeof(label_str));
	yname(label_str);

	area2d((float)7.8, (float)5.3);             /* Sets the area of the plot */

	// Position plot on page
	// Can do this in absolute terms for the sigma plot
	// because the y-axis scale labels are always the same size
	physor((float)0.75, (float)0.80);

	color(grid_color);                                         /* grid color */
	grid(4);                         /* draws dotted grid through tick marks */
	fgrid(9,0);                            /* dotted lines on subdivisions */
			/* log scales ignore requested # of subdiv and use 10 per decade */

	frame(1,1);                          /* add frame with ticks around plot */

	// Draw box
	color(box_color);                                  /* set box line color */
	if(p->do_box)
	{
		box();                                    /* draw box around picture */
	}                                                              /* end if */

	// Load data points
	// Note: FULL_RUN has overlapping sigma in NormSigData array
	// and Tho1 deviation in ModSigData array
	// Autoscaling is set using NormSigData array in code below
	// No issues with # points or x-axis
	// Normal sigma array has full tau range
	// But y-axis sigma data may have zeros at end
	// And Tho1 data in the mod sig array can have zeros at beginning
	// As it now stands, this sigma plotting never autoscales
	// It always uses scales determined externally prior to plotting
	// CalcSigmaPlotScale() takes care of the zeros, so none of this matters
	// But it would if SigmaPlot() was asked to autoscale
	// So watch out in future
	if( nSigmaPlotType==NORMAL_RUN   || nSigmaPlotType==OVERLAPPING_RUN ||
		nSigmaPlotType==TOTAL_RUN    || nSigmaPlotType==BOTH_RUN        ||
		nSigmaPlotType==HADAMARD_RUN || nSigmaPlotType==TIERMS_RUN      ||
		nSigmaPlotType==MTIE_RUN     ||	nSigmaPlotType==OVERLAPHAD_RUN  ||
		nSigmaPlotType==HADTOTAL_RUN ||	nSigmaPlotType==THEO1_RUN       ||
		nSigmaPlotType==FULL_RUN	 || nSigmaPlotType==CROSS_RUN)
	{
		for(i=0; i<sNormSigData.points; i++)
		{        		                                 /* load data points */
			x[i+2]=sNormSigData.tau[i];
			y[i+2]=sNormSigData.sigma[i];
		}                                                         /* end for */

		if(autoscale_t)
		{
			// Put x scale limits into 1st 2 points
			x[0]=x[2];
			x[1]=x[2];
		}
		else
		{
			// Apply bias factors to assure correct scales
			x[0]=(float)(p->x_min*1.001);
			x[1]=(float)(p->x_max*0.999);
		}

		if(autoscale_s)
		{
			// Put y scale limits into 1st 2 points
			y[0]=y[2];
			y[1]=y[2];
		}
		else
		{
			// Apply bias factors to assure correct scales
			y[0]=(float)(p->y_min*1.001);
			y[1]=(float)(p->y_max*0.999);
		}

		// Set plot scales
		if( (autoscale_t) || (autoscale_s) )
		{
			lglgscle(x,y,sNormSigData.points+2); /* set scale using all data */
		}
		else
		{
			lglgscle(x,y,2);                  /* set scale using limits only */
		}
	}
	else // Modified & Time Sigma & Mod Totdev
	{
		for(i=0; i<sModSigData.points; i++)
		{        		                                 /* load data points */
			x[i+2]=sModSigData.tau[i];
			y[i+2]=sModSigData.sigma[i];
		}                                                         /* end for */

		if(autoscale_t)
		{
			x[0]=x[2];
			x[1]=x[2];
		}
		else
		{
			// Apply bias factors to assure correct scales
			x[0]=(float)(p->x_min*1.001);
			x[1]=(float)(p->x_max*0.999);
		}

		if(autoscale_s)
		{
			y[0]=y[1];
			y[1]=y[2];
		}
		else
		{
			// Apply bias factors to assure correct scales
			y[0]=(float)(p->y_min*1.001);
			y[1]=(float)(p->y_max*0.999);
		}

		// Set plot scales
		if( (autoscale_t) || (autoscale_s) )
		{
			lglgscle(x,y,sModSigData.points+2); /* set scale using all data */
		}
		else
		{
			lglgscle(x,y,2);                  /* set scale using limits only */
		}
	}

	// Draw title & subtitle
	fntchg('\311');                                             /* swiss.fnt */

	color(label_color);                                   /* set label color */

	width=strwidth(p->title,(float)0.3);          /* get half-width of title */
	prtfnt((float)(4.75-width),(float)6.40,p->title,(float)0.3,0);
															   /* draw title */
	width=strwidth(p->subtitle,(float)0.15);   /* get half-width of subtitle */
	prtfnt((float)(4.75-width),(float)6.175,p->subtitle,(float)0.15,0);
															/* draw subtitle */

	// Draw annotations
	// The putlabel() function is used for user-defined annotations.
	// This must come before any plotting - including grid lines
	// Then it is supposed to stay clean.
	// But, for user units, it should come after plot scales are set
	// It provides user messages via the plot annotations dialog box
	// The 2nd & 3rd args of putlabel() are in plot user units.
	// The 4th arg of putlabel() is char hgth in inches (for full-page).
	// The sFNote[i].nSize value is point size.  There are 72 points/inch.
	// The 5th arg of putlabel is border code: 1=border, 2=no border (strange)
	// So we get it as 2-sFNote[i].bBorder, where bBorder is ordinary BOOL flag
	// Multiline labels are OK with \n (newline, ASCII LF, dec int 10)
	// But they are NG with CR & LF as produced by an edit control.
	// So we must elim CRs from the note text string

	fntchg('\313');                                           /* simplex.fnt */
	color(grid_color);                          /* set box & grid line color */
	for(i=0; i<SNOTE_NUMNOTES; i++)
	{
		// Check if this is an active note (non-zero length)
		len=strlen(sSNote[i].szText);
		if(len)
		{
			// Allocate a temporary working buffer
			if((szTemp=(LPSTR)malloc((len+1)*sizeof(char)))==NULL)
			{
				AllocErrorMessage();
				free(x);
				free(y);
				return;
			}
			// Remove CRs from annotation text string
			// Note that we are also copying the EOS
			k=0;
			for(j=0; j<=len; j++)
			{
				if(sSNote[i].szText[j]!=13) // 13 = CR
				{
					szTemp[k]=sSNote[i].szText[j];
					k++;
				}
			}

			if(sSNote[i].bOpaque)
			// Put note into white panel to hide grid, plot, etc.
			{
				// GraphiC code from putlabel() of FNTPLT.C
				// modified to use here to determine vertices of label area
				// that actual putlabel() call uses to put note on plot
				// Input args are:
				//   char *string changed to szTemp
				//   float xpos
				//   float ypos
				//   float height = (float)(sSNote[i].nSize/72.0)
				// Local variables renamed as req'd & move to top of function
		
				 // Get size of area to make white panel for note
				usertopix((float)(sSNote[i].fX), (float)(sSNote[i].fY), 0.0,
					&xpix, &ypix);
				
				// Set line height
				ydel=20*sSNote[i].nSize;	// Correct value?
				
				// Initialize indices
				j=0;
				k=0;
				
				// Find maximum width of (possibly) multiline note
				// and add vertical height for multiple lines
				for(;;)
				{
					ch=szTemp[j++];
					if(ch!='\n' && ch!='\0')
					{
						buf[k++]=szTemp[j-1];
						if(k>=NOTESIZE)				      /* Buffer overflow */
						{
							j--;
							szTemp[j]='\0';              /* Terminate string */
							continue;                 /* Process what we can */
						}
					}
					else
					{
						buf[k]='\0';
						wid=intopix(strwidth(buf,
							(float)(sSNote[i].nSize/72.0)));
						if(wid>max_wid)
						{
							max_wid=wid;
						}
						if(ch!='\0') // ch is newline
						{
							bsavfq-=ydel;
						}
						k=0;
					}

					if(ch=='\0')
					{
						// Check the last line for descenders
						// g, j, p, q, y, /, \, #, ( and )
						descend=0;
						if((strpbrk(buf, "gjpqy/\\#()"))!=NULL)
						{
							descend=4*sSNote[i].nSize; // 1/5 line height
						}
						break;
					}
				}

				// Note: No allowance made here for decenders
				tsavfq=(int)(pix_convertq*(float)(sSNote[i].nSize/72.0));
				
				// Note area panel vertices are: [3]    [2]
				//                               [0, 4] [1]
				// Lower left:
				//   x0=xpix - allow
				//   y0=ypix - allow + bsavfq - descend
				// Upper right:
				//   x1=xpix + 2*max_wid + allow
				//   y1=ypix_sav + tsavfq + allow
				// That is the region we want to apply panel to

				// Calc vertices 0 and 4
				// Note: 15 is allowance for border added by GraphiC
				pixtouser(xpix-15, ypix-15+bsavfq-descend, &xpan[0], &ypan[0]);
				xpan[4]=xpan[0];
				ypan[4]=ypan[0];
				
				// Calc vertex 3
				pixtouser(xpix-15, ypix+15+tsavfq, &xpan[3], &ypan[3]);
				
				// Calc vertex 2
				pixtouser(xpix+15+2*(max_wid), ypix+15+tsavfq, &xpan[2],
					&ypan[2]);
				
				// Calc vertex 1
				pixtouser(xpix+15+2*(max_wid), ypix-15+bsavfq-descend,
					&xpan[1], &ypan[1]);
				
				// Create panel with bright white background
				panel(xpan, ypan, 4, 447, FALSE); // Use 204 (red) for test
				
				// Process panel
				panproc();
			}

			// Draw annotation - use temp string w/o CRs
			putlabel(szTemp, (float)sSNote[i].fX, (float)sSNote[i].fY,
				(float)(sSNote[i].nSize/72.0), 2-sSNote[i].bBorder,
				USER_UNITS);

			// Free temporary working buffer
			free(szTemp);
		}
	}

	// Plotting code starts here
	color(data_color);                                         /* data color */
	
	// Set plot line thickness
	// 0 is default, 20 is wider
	tcurve(p->thick);

	// Change made 02/18/01
	// Use smaller symbol if many points (e.g. all tau)
	if(sNormSigData.points>100)
	{
		symht((float)0.035);                              /* set symbol size */
	}
	else
	{
		symht((float)0.075);                              /* set symbol size */
	}

	if( nSigmaPlotType==NORMAL_RUN   || nSigmaPlotType==OVERLAPPING_RUN ||
		nSigmaPlotType==TOTAL_RUN    || nSigmaPlotType==BOTH_RUN        ||
		nSigmaPlotType==HADAMARD_RUN || nSigmaPlotType==TIERMS_RUN      ||
		nSigmaPlotType==MTIE_RUN     ||	nSigmaPlotType==OVERLAPHAD_RUN  ||
		nSigmaPlotType==HADTOTAL_RUN ||	nSigmaPlotType==THEO1_RUN       ||
		nSigmaPlotType==FULL_RUN	 || nSigmaPlotType==CROSS_RUN)
	{
		symbol=12;                                                /* solid o */
		sympick(symbol);                                              
		i=0;
		// Loop thru data points, ploting them in sets
		while(i<sNormSigData.points)
		{        	                                     /* load data points */
			// Store 1st point of a set
			x[0]=sNormSigData.tau[i];
			y[0]=sNormSigData.sigma[i];

			// Store remaining points of a set
			j=1;
			// End set when all points stored, or if next tau is smaller
			while( (i+j<sNormSigData.points) &&
				(sNormSigData.tau[i+j]>sNormSigData.tau[i+j-1]))
			{
				x[j]=sNormSigData.tau[i+j];
				y[j]=sNormSigData.sigma[i+j];

				// Test for zero point - added 02/15/03
				// The only time that is expected is during FULL_RUN plotting
				// where the overlapping sigma data stops
				// In that case, this code nicely stops plotting it
				if(y[j]==0.0)
				{
					// Bail out
					break;
				}
				else
				{
					j++;
				}
			}
			
			// Draw curve
			if(sNormSigData.num[i])
			{
				#if(0) // New code 04/09/10
				// This may be the place to change the color
				// of a negative cross sigma point
				// indicated by sNormSigData.sign (+1 or -1)
				// But can't use curve() since that plots all points
				// Must plot them point-by-point
				// Instead of color(data_color);
				// Define and use color(neg_data_color);
				#endif
				
				// Normal way
				// Draw curve with symbols
				// Use one of five filled symbols
				// 11=square, 12=circle, 13=down triangle, 14=diamond,
				// 15=up triangle
				// Default is 12=circle
				curve(x,y,j,1);

				// Change symbol for each data set
				if(symbol<15)
				{
					// Increment symbol
					symbol++;
				}
				else
				{
					// Start symbol cycle over
					symbol=11;
				}
				sympick(symbol);
			}
			else
			{
				// Make line wider
				if(p->thick)
				{
					tline(20);
				}

				// Draw curve without symbols
				// This is nice for a spec curve
				// It is also used for the domain function sigma-tau plot
				// Select by setting # analysis pts of 1st row of set = 0
				for(k=0; k<j-1; k++)
				{
					uline(sNormSigData.tau[i+k], sNormSigData.sigma[i+k],
						sNormSigData.tau[i+k+1], sNormSigData.sigma[i+k+1], 1);
				}
				
				// Restore normal line width
				tline(0);
			}

			// Increment outer index
			i+=j;
		}                                                         /* end for */

		// Draw error bars - none drawn if no max & min sigma data
		// More specifically, error bars are drawn only
		// if(ymax-ymin>0) or if(xmax-xmin>0)
		// We don't use x-axis errorbars
		if(p->do_errbar)
		{
			for(i=0; i<sNormSigData.points; i++)
			{
				{
					errorbar(sNormSigData.tau[i], sNormSigData.tau[i],
						sNormSigData.tau[i], sNormSigData.sigma[i],
						sNormSigData.sig_min[i], sNormSigData.sig_max[i]);
				}
			}                                                     /* end for */
		}										   	               /* end if */
	}                                                              /* end if */

	if(nSigmaPlotType==MODIFIED_RUN   || nSigmaPlotType==TIME_RUN     ||
		nSigmaPlotType==BOTH_RUN      || nSigmaPlotType==MODTOTAL_RUN ||
		nSigmaPlotType==TIMETOTAL_RUN || nSigmaPlotType==FULL_RUN )
	{
		symbol=1;                                                 /* open o */
		sympick(symbol);                                              
		if(nSigmaPlotType==4)
		{
			color(aux_color);                              /* aux data color */
		}

		i=0;

		// Loop thru data points, ploting them in sets
		while(i<sModSigData.points)                      /* load data points */
		{        	                                     
			// Skip leading points that are zero - added 02/15/03
			// The only time that is expected in for a FULL_RUN
			// where the beginning Tho1 points may be missing
			while(sModSigData.sigma[i]==0.0)
			{
				i++;
			}

			// Store 1st point of a set
			x[0]=sModSigData.tau[i];
			y[0]=sModSigData.sigma[i];

			// Store remaining points of a set
			j=1;
			// End set when all points stored, or if next tau is smaller
			while( (i+j<sModSigData.points) &&
				(sModSigData.tau[i+j]>sModSigData.tau[i+j-1]))
			{
				x[j]=sModSigData.tau[i+j];
				y[j]=sModSigData.sigma[i+j];
				j++;
			}
			
			// Draw curve
			if(sModSigData.num[i])
			{
				// Normal way
				// Draw curve with symbols
				// Use one of five unfilled symbols
				// 0=square, 1=circle, 2=down triangle, 5=diamond,
				// 6=up triangle
				// Default is 1=circle
				curve(x,y,j,1);

				// Change symbol for each data set
				if((symbol<2) || (symbol>4))
				{
					// Increment symbol
					symbol++;
				}
				else if(symbol==2)
				{
					symbol=5;
				}
				if(symbol>6)
				{
					// Start symbol cycle over
					symbol=0;
				}
				sympick(symbol);
			}
			else
			{
				// Make line wider
				if(p->thick)
				{
					tline(20);
				}

				// Draw curve without symbols
				// This is nice for a spec curve
				// Select by setting # analysis pts of 1st row of set = 0
				for(k=0; k<j-1; k++)
				{
					uline(sModSigData.tau[i+k], sModSigData.sigma[i+k],
						sModSigData.tau[i+k+1], sModSigData.sigma[i+k+1], 1);
				}
				
				// Restore normal line width
				tline(0);
			}

			// Increment outer index
			i+=j;
		}                                                         /* end for */

		// Draw error bars - none drawn if no max & min sigma data
		if(p->do_errbar)
		{
			for(i=0; i<sModSigData.points; i++)
			{
				{
					errorbar(sModSigData.tau[i], sModSigData.tau[i],
						sModSigData.tau[i], sModSigData.sigma[i],
						sModSigData.sig_min[i], sModSigData.sig_max[i]);
				}
			}                                                     /* end for */
		}											               /* end if */
	}                                                              /* end if */

	// Start of line ploting code
	color(line_color);                                         /* line color */

	// Clip lines
	ClipPlot();

	// for(i=0; i<8; i++) Until 11/01/05 - Error
	for(i=0; i<SLINE_NUMLINES; i++)
	{
		switch(sSLine[i].nLineType)
		{
			case SLINE_NONE:
			{
				break;                                            /* no line */
			}
			case SLINE_END:
			{	                                   /* line between endpoints */
				uline((float)sSLine[i].fXStart, (float)sSLine[i].fYStart,
					(float)sSLine[i].fXEnd,(float)sSLine[i].fYEnd, 3);
				break;
			}
			case SLINE_NOISE:
			{                                                  /* noise line */
				sigma_1[i]=sSLine[i].fSigma1;

				if( (nSigmaPlotType==MODIFIED_RUN) ||
					(nSigmaPlotType==TIME_RUN) ||
					(nSigmaPlotType==MODTOTAL_RUN) ||
					(nSigmaPlotType==TIMETOTAL_RUN) )
				{
					if(sSLine[i].fSlope==-1.5)
					{
						temp1=sModSigData.tau[sSLine[i].nXStart];
						temp2=sModSigData.tau[sSLine[i].nXEnd];

						uline((float)temp1,
							(float)(sigma_1[i]/(temp1*sqrt(temp1))),
							(float)temp2,
							(float)(sigma_1[i]/(temp2*sqrt(temp2))),3);
					}
					else if(sSLine[i].fSlope==-1.0)
					{
						uline((float)sModSigData.tau[sSLine[i].nXStart],
							(float)
							(sigma_1[i]/sModSigData.tau[sSLine[i].nXStart]),
							(float)sModSigData.tau[sSLine[i].nXEnd],
							(float)
							(sigma_1[i]/sModSigData.tau[sSLine[i].nXEnd]),
							3);
					}
					else if(sSLine[i].fSlope==-0.5)
					{
						uline((float)sModSigData.tau[sSLine[i].nXStart],
							(float)(sigma_1[i]/
							sqrt(sModSigData.tau[sSLine[i].nXStart])),
							(float)sModSigData.tau[sSLine[i].nXEnd],
							(float)(sigma_1[i]/
							sqrt(sModSigData.tau[sSLine[i].nXEnd])),3);
					}
					else if(sSLine[i].fSlope==0.0)
					{
						uline((float)sModSigData.tau[sSLine[i].nXStart],
							(float)sigma_1[i],
							(float)sModSigData.tau[sSLine[i].nXEnd],
							(float)sigma_1[i],3);
					}
					else if(sSLine[i].fSlope==0.5)
					{
						uline((float)sModSigData.tau[sSLine[i].nXStart],
							(float)(sigma_1[i]*
							sqrt(sModSigData.tau[sSLine[i].nXStart])),
							(float)sModSigData.tau[sSLine[i].nXEnd],
							(float)(sigma_1[i]*
							sqrt(sModSigData.tau[sSLine[i].nXEnd])),3);
					}
					else if(sSLine[i].fSlope==1.0)
					{
						uline((float)sModSigData.tau[sSLine[i].nXStart],
						(float)
						(sigma_1[i]*sModSigData.tau[sSLine[i].nXStart]),
						(float)sModSigData.tau[sSLine[i].nXEnd],
						(float)
						(sigma_1[i]*sModSigData.tau[sSLine[i].nXEnd]),
						3);
					}
					else if(sSLine[i].fSlope==1.5)
					{
						uline((float)sModSigData.tau[sSLine[i].nXStart],
							(float)
							(sigma_1[i]*sModSigData.tau[sSLine[i].nXStart]
							*sqrt(sModSigData.tau[sSLine[i].nXStart])),
							(float)sModSigData.tau[sSLine[i].nXEnd],
							(float)
							(sigma_1[i]*sModSigData.tau[sSLine[i].nXEnd]
							*sqrt(sModSigData.tau[sSLine[i].nXEnd])),3);
					}
					else if(sSLine[i].fSlope==2.0)
					{
						uline((float)sModSigData.tau[sSLine[i].nXStart],
							(float)
							(sigma_1[i]*sModSigData.tau[sSLine[i].nXStart]
							*sModSigData.tau[sSLine[i].nXStart]),
							(float)sModSigData.tau[sSLine[i].nXEnd],
							(float)
							(sigma_1[i]*sModSigData.tau[sSLine[i].nXEnd]
							*sModSigData.tau[sSLine[i].nXEnd]),3);
					}
				}
				else // ADEV
				{
					if(sSLine[i].fSlope==-1.5)
					{
						temp1=sNormSigData.tau[sSLine[i].nXStart];
						temp2=sNormSigData.tau[sSLine[i].nXEnd];

						uline((float)temp1,
							(float)(sigma_1[i]/(temp1*sqrt(temp1))),
							(float)
							temp2, (float)(sigma_1[i]/(temp2*sqrt(temp2))),
							3);
					}
					else if(sSLine[i].fSlope==-1.0)
					{
						uline((float)sNormSigData.tau[sSLine[i].nXStart],
							(float)
							(sigma_1[i]/sNormSigData.tau[sSLine[i].nXStart]),
							(float)
							sNormSigData.tau[sSLine[i].nXEnd],
							(float)
							(sigma_1[i]/sNormSigData.tau[sSLine[i].nXEnd]),
							3);
					}
					else if(sSLine[i].fSlope==-0.5)
					{
						uline((float)sNormSigData.tau[sSLine[i].nXStart],
							(float)(sigma_1[i]/
							sqrt(sNormSigData.tau[sSLine[i].nXStart])),
							(float)sNormSigData.tau[sSLine[i].nXEnd],
							(float)(sigma_1[i]/
							sqrt(sNormSigData.tau[sSLine[i].nXEnd])),3);
					}
					else if(sSLine[i].fSlope==0.0)
					{
						uline((float)sNormSigData.tau[sSLine[i].nXStart],
						(float)sigma_1[i],
						(float)sNormSigData.tau[sSLine[i].nXEnd],
						(float)sigma_1[i],3);
					}
					else if(sSLine[i].fSlope==0.5)
					{
						uline((float)sNormSigData.tau[sSLine[i].nXStart],
							(float)(sigma_1[i]*
							sqrt(sNormSigData.tau[sSLine[i].nXStart])),
							(float)sNormSigData.tau[sSLine[i].nXEnd],
							(float)(sigma_1[i]*
							sqrt(sNormSigData.tau[sSLine[i].nXEnd])),3);
					}
					else if(sSLine[i].fSlope==1.0)
					{
						uline((float)sNormSigData.tau[sSLine[i].nXStart],
							(float)
							(sigma_1[i]*sNormSigData.tau[sSLine[i].nXStart]),
							(float)sNormSigData.tau[sSLine[i].nXEnd],
							(float)
							(sigma_1[i]*sNormSigData.tau[sSLine[i].nXEnd]),
							3);
					}
					else if(sSLine[i].fSlope==1.5)
					{
						uline((float)sNormSigData.tau[sSLine[i].nXStart],
							(float)
							(sigma_1[i]*sNormSigData.tau[sSLine[i].nXStart]
							*sqrt(sNormSigData.tau[sSLine[i].nXStart])),
							(float)sNormSigData.tau[sSLine[i].nXEnd],
							(float)
							(sigma_1[i]*sNormSigData.tau[sSLine[i].nXEnd]
							*sqrt(sNormSigData.tau[sSLine[i].nXEnd])),3);
					}
					else if(sSLine[i].fSlope==2.0)
					{
						uline((float)sNormSigData.tau[sSLine[i].nXStart],
							(float)
							(sigma_1[i]*sNormSigData.tau[sSLine[i].nXStart]
							*sNormSigData.tau[sSLine[i].nXStart]),
							(float)sNormSigData.tau[sSLine[i].nXEnd],
							(float)
							(sigma_1[i]*sNormSigData.tau[sSLine[i].nXEnd]
							*sNormSigData.tau[sSLine[i].nXEnd]),3);
					}
				}

				if( (!noise_flag) && (!tdev_flag) && (p->do_fit) )
				 /* can show only 1 noise fit, and only if no TDEV shown */
				{
					UnclipPlot();
					_snprintf(label_str, LABELSIZE,
					"1st Noise Fit: Sigma(1)=%-10.7e, Slope=%+4.1f",
					sigma_1[i], sSLine[i].fSlope);
					ShortenExp(label_str);
					fntchg('\313');                           /* simplex.fnt */
					color(annotation_color);   /* fit annotation color=black */
					tmargin((float)6.7);
					ctline(label_str,(float)0.075);
					noise_flag=TRUE;
					color(line_color);                         /* line color */
					ClipPlot();
				}
				break;
			}
			case SLINE_HORIZ:
				{	                                      /* horizontal line */
					uline((float)sSLine[i].fXStart, (float)sSLine[i].fYStart,
						(float)sSLine[i].fXEnd, (float)sSLine[i].fYStart, 3);
					break;
			}
			case SLINE_VERT:
				{                                           /* vertical line */
					uline((float)sSLine[i].fXStart, (float)sSLine[i].fYStart,
						(float)sSLine[i].fXStart, (float)sSLine[i].fYEnd, 3);
					break;
			}
			case SLINE_TDEV:
				{                                              /* TDEV lines */
				// TDEV lines allowed for mod sigma types only
				if( (nSigmaPlotType==MODIFIED_RUN) ||
					(nSigmaPlotType==MODTOTAL_RUN) )
				{
					// calc & round # decades in x and y plot scales

					// Use plotdata struct limits for lines so they can
					// cover full size of manually emtered plot scales.
					xdec=(int)floor((log10(p->x_max/p->x_min)+0.5));
					ydec=(int)floor((log10(p->y_max/p->y_min)+0.5));

					// line endpoints are clipped to within plot limits
					for(j=0; j<xdec+ydec; j++)
					{
						x1=(float)max(p->x_min,1.73*p->x_min*pow(10.0,j-ydec));
						y1=(float)min(1.73*p->y_min*pow(10.0,j),p->y_max);
						x2=(float)min(p->x_max,1.73*p->x_min*pow(10.0,j));
						y2=(float)max(1.73*p->y_min*pow(10.0,j-xdec),p->y_min);
						uline(x1,y1,x2,y2,3);
						fntchg('\313');                       /* simplex.fnt */

						// round TDEV line value
						line_value=(float)floor((log10(p->x_min*
								   p->y_min*pow(10.0,j))+0.5));

						// get label in engineering notation
						TVARLabel((int)line_value,label_str);

						// write label by TDEV line
						pltfnt((float)(0.85*sqrt(x1*x2)),
							(float)(1.25*sqrt(y1*y2)),
							label_str,(float)0.1, (int)
							(-(180/3.14)*atan2(5.25/ydec,7.65/xdec)));
					}

					if( (!noise_flag) && (p->do_fit) )
					/* don't annotate TDEV lines if annotated noise line */
					/* with both noise and TDEV lines, will get note for */
					/* whichever one comes first */
					{
						UnclipPlot();
						_snprintf(label_str,
							LABELSIZE, "Lines = Loci of Constant TDEV");
						fntchg('\313');                       /* simplex.fnt */
						color(annotation_color);     /* fit annotation color */
						tmargin((float)6.7);
						ctline(label_str,(float)0.075);
						color(line_color);                     /* line color */
						tdev_flag=TRUE;
						ClipPlot();
					}                                              /* end if */
				}
				break;
			}
			case SLINE_MASK:
			{	 									 		   /* Mask plots */
				// Read and plot mask data for mask # = i
				// # mask points is nMask[i]
				// Mask data was read from disk when it was selected
				// in Run Lines dialog
				// Mask data is array of sigma-tau values
				// Mask sigma array is fMaskSigma[i][j]
				// where i=mask #, j=point #
				// Mask tau array is fMaskTau[i][j]
				// where i=mask #, j=point #
				// Lines w/o symbols drawn in line color between these points 

				// Plot mask
				color(line_color);							   /* line color */
				curve(fMaskTau[i], fMaskSigma[i], nMaskRows[i], 0);
				ClipPlot();
			}
		}                                                      /* end switch */
	}

	// Unclip lines - probably unnecessary
	UnclipPlot();

	// End of line plotting code

	if(nPlotType==DOMAIN_SIGMA_PLOT)
	{
		fntchg('\313');                                       /* simplex.fnt */
		color(annotation_color);                         /* annotation color */
		//tmargin((float)6.655);
		tmargin((float)6.7);
		_snprintf(label_str, LABELSIZE,
			"Carrier Freq=%e MHz, BW=%e Hz", p->carrier, p->bw);
		ShortenExp(label_str);
		ctline(label_str, (float)0.075);
	}

	// Note:  Problem when all tau data is Read and plotted
	// Must set p->do_table to FALSE for that case
	// Select annotation font and color
	fntchg('\313');                                           /* simplex.fnt */
	color(annotation_color);                       /* annotation color=black */

	// Draw sigma-tau table
	// Note: y position was 2673 for Stable/DOS GraphiC 5.01
	// Last arg was 2642 - changed everywhere to 2715 on 12/17/96
	// # pixels doubled in GraphiC 7.1
	// x position values are changed in TableBox(), y values are used x2
	if(p->do_table && !bAllTau)                     /* do non all tau table? */
	{
		if(nSigmaPlotType==BOTH_RUN)         /* overlapping & mod sigma plot */
		{
			TableBox(2, sNormSigData.points, p->table_position);
		}                                                          /* end if */
		else if(nSigmaPlotType==FULL_RUN)        /* overlapping & Tho1 plot */
		{
			TableBox(3, sNormSigData.points+3, p->table_position);
		}                                                          /* end if */
		else if( (nSigmaPlotType==TIME_RUN) ||
			     (nSigmaPlotType==TIMETOTAL_RUN) )
		/* time sigma table at left side */
		{
					 /* adjust x location depending on int or exp tau format */
								/* to undo adjustment that table_box() makes */
											/* for right side table location */
			TableBox(1, sModSigData.points, p->table_position); 
		}                                                          /* end if */

		else if(nSigmaPlotType==MODIFIED_RUN ||
			    nSigmaPlotType==MODTOTAL_RUN )
		{
			TableBox(1, sModSigData.points, p->table_position);  
		}                                                          /* end if */
		else											 /* other plot types */
		{
			TableBox(1, sNormSigData.points, p->table_position);
		}                                                          /* end if */
	}                                                              /* end if */

	#if(1) // New code 05/27/11
	// Draw fast MTIE sigma-tau table
	if(p->do_table && bAllTau && nSigmaPlotType==MTIE_RUN)
	{
		TableBox(1, sNormSigData.points, p->table_position);
	}                                                              /* end if */

	// Draw all tau sigma-tau table
	if(p->do_table && bAllTau && nSigmaPlotType!=MTIE_RUN)
	{
		if(nSigmaPlotType==BOTH_RUN)         /* overlapping & mod sigma plot */
		{
			AllTableBox(2, sAllNormSigData.points, p->table_position);
		}                                                          /* end if */
		else if(nSigmaPlotType==FULL_RUN)        /* overlapping & Tho1 plot */
		{
			AllTableBox(3, sAllNormSigData.points+3, p->table_position);
		}                                                          /* end if */
		else if( (nSigmaPlotType==TIME_RUN) ||
			     (nSigmaPlotType==TIMETOTAL_RUN) )
		/* time sigma table at left side */
		{
					 /* adjust x location depending on int or exp tau format */
								/* to undo adjustment that table_box() makes */
											/* for right side table location */
			AllTableBox(1, sAllModSigData.points, p->table_position); 
		}                                                          /* end if */

		else if(nSigmaPlotType==MODIFIED_RUN ||
			    nSigmaPlotType==MODTOTAL_RUN )
		{
			AllTableBox(1, sAllModSigData.points, p->table_position);  
		}                                                          /* end if */
		else											 /* other plot types */
		{
			AllTableBox(1, sAllNormSigData.points, p->table_position);
		}                                                          /* end if */
	}                                                              /* end if */
	#endif

	// Uuclip again
	UnclipPlot();

	// Write date
	if(p->do_date)
	{

		if(nPlotType==READ_PLOT)
		{
			Dateline(0, 1, 1);  /* date & file info on plot w/o points & tau */
		}
		if(nPlotType==DOMAIN_SIGMA_PLOT)
		{
			Dateline(0, 0, 1);   /* date only on plot w/o points, tau & file */
		}
		else
		{
			Dateline(1, 1, 1);          /* put full date & file info on plot */
		}
	}                                                              /* end if */

	// Display message box
	// Locations are x, y in pixels, origin at bottom left, 8192 x 6266 space
	// Find half length of message box in pixels
	lgth=(H_MARGIN+strwidtq(p->message_str, CHAR_HGTH));

	// Write message
	if(p->message_str[0]!='\0')         /* don't display a blank message box */
	{
		switch(p->position)
		{
			case MSG_TOP_LEFT:            /* message box at top left of plot */
			{
				MsgBox(300,4440,p->message_str);
				break;
			}                                                    /* end case */
			case MSG_MID_LEFT:         /* message box at middle left of plot */
			{
				MsgBox(300,2270,p->message_str);
				break;
			}                                                    /* end case */
			case MSG_BOT_LEFT:         /* message box at bottom left of plot */
			{
				MsgBox(300,200,p->message_str);
				break;
			}                                                    /* end case */
			case MSG_TOP_CENTER:        /* message box at top center of plot */
			{
				MsgBox(3470-lgth, 4440, p->message_str);
				break;
			}                                                    /* end case */
			case MSG_MID_CENTER:     /* message box at middle center of plot */
			{
				MsgBox(3470-lgth,2270,p->message_str);
				break;
			}                                                    /* end case */
			case MSG_BOT_CENTER:     /* message box at bottom center of plot */
			{
				MsgBox(3470-lgth,200,p->message_str);
				break;
			}                                                    /* end case */
			case MSG_TOP_RIGHT:          /* message box at top right of plot */
			{
				MsgBox(6770-2*lgth,4440,p->message_str);
				break;
			}                                                    /* end case */
			case MSG_MID_RIGHT:       /* message box at middle right of plot */
			{
				MsgBox(6770-2*lgth,2270,p->message_str);
				break;
			}                                                    /* end case */
			case MSG_BOT_RIGHT:       /* message box at bottom right of plot */
			{
				MsgBox(6770-2*lgth,200,p->message_str);
				break;
			}                                                    /* end case */
		}                                                      /* end switch */
	}

	// Insert plot if bDoStabPlotInsert is set
	if(bDoStabPlotInsert)
	{
		// Stability plot insert filename is szStabPlotInsertFile
		// Try to open it
		if((file=fopen(szStabPlotInsertFile, "r"))!=NULL)
		{
			// Immediately release file pointer
			fclose(file);

			// Insert data plot at bottom left of sigma plot
			// Note:  This must be a tkf file or this will fail
			InsertPlot(300, 200, szStabPlotInsertFile);

		}
	}

	// Write label
	if(bPlotLabel)
	{
		UnclipPlot();
		color(annotation_color);                         /* annotation color */
		width=(float)intopix(strwidth(szPlotLabel, (float)0.05));
		putlabel(szPlotLabel, (float)(8192-2*(width+20)), (float)20.0,
			(float)0.05, 0, PIXEL_UNITS);
	}

	// Free plot data arrays
	free(x);
	free(y);

	// Avoid unwanted clipping 
	UnclipPlot();

	#ifdef DEMO_VERSION
	// Add watermark for demo version
	// Get plot size in pixels
	usertopix(p->x_max, p->y_max, 0.0, &x_pix_max, &y_pix_max);
	usertopix(p->x_min, p->y_min, 0.0, &x_pix_min, &y_pix_min);
	x_pix=x_pix_max-x_pix_min;
	y_pix=y_pix_max-y_pix_min;
	// Select hatched swiss font
	fntchg('\311');                                              /* news.fnt */
	fontfill(2, 230, 0);
	// Display watermark
	pltfnt((float)p->x_min, (float)p->y_min, "Stable32 Demo Version",
		(float)0.6, (int)(180*atan2((double)y_pix, (double)x_pix)/PI));
	#endif

	#ifdef VITSAS_VER
	// Add watermark for V-ITSAS version
	color(227);
	tmargin((float)0.15);
	ltline(" Stable32 V-ITSAS", (float)0.12);
	tmargin((float)0.15);
	rtline("Evaluation Version ", (float)0.12);
	#endif

	#if(1) // New code 11/23/11
	// Process bCmdM command to copy plot metafile to clipboard
	if(bCmdM)
	{
		// Send copy metafile message to GraphiC
		PostMessage(hGPC, WM_COMMAND,
			GET_WM_COMMAND_MPS(IDM_COPYMETA, 0, 0));
	}

	// Process bCmdT command to print plot
	if(bCmdT)
	{
		// Send print message to GraphiC
		PostMessage(hGPC, WM_COMMAND,
			GET_WM_COMMAND_MPS(IDM_PRINT, 0, 0));
	}

	// Process bCmdX command to close plot
	if(bCmdX)
	{
		// Show the plot briefly
		Sleep(1000);

		// Close plot and plot dialog box
		PostMessage(hPlot, WM_CLOSE, (WPARAM)0, (LPARAM)0);
		PostMessage(hPlotBox, WM_CLOSE, (WPARAM)0, (LPARAM)0);
		// Doing this a second time seems necessary - don't know why
		// PostMessage(hPlotBox, WM_CLOSE, (WPARAM)0, (LPARAM)0);
		// But its still not closing now
		// This seems to do the trick
		EndDialog(hPlotBox, 0);
	}
	#endif

	endplot();
									/* finish plot and wait for instructions */
												/* to exit or draw next plot */
										/* resets file pointers and defaults */

	stopplot();            /* close files, return to text mode, exit program */
}                                                         /* end SigmaPlot() */

/*****************************************************************************/
/*                                                                           */
/*			   		       PowerSpectrumPlot()                               */
/*                                                                           */
/*		Function to plot power spectrum data                                 */
/*      Parameters:                                                          */
/*      	f_data[] = array of Fourier freq data                            */
/*          s_data[] = array of power spectral data                          */
/*			int points = # power spectrum points                             */
/*			int type = phase noise type: 0=Sx(f), 1=S(f), 2=(f), 3=Sy(f)   */
/*		p plotdata structure elements:                                       */
/*      	spectrum_title = plot title                                      */
/*      	spectrum_subtitle = plot subtitle                                */
/*			do_box  = draw box flag                                          */
/*			do_date = write date flag                                        */
/*			do_line = add noise line to plot                                 */
/*			spectrum_plot_filename = .tkf filename for plot                  */
/*      Returns nothing (void)                                               */
/*                                                                           */
/*      Note: Must use float arrays because that is what many GraphiC        */
/*            plotting functions require                                     */
/*                                                                           */
/*      Revision record:                                                     */
/*      	06/30/96	Adapted from plot_spectrum() of Stable/DOS           */
/*			11/18/96	Revised plot sizes, etc.                             */
/*			12/27/96	Up & running                                         */
/*			12/07/97	Added flag for displaying points                     */
/*						Changed to manually-set plot scales                  */
/*			06/18/98	Changed from curve() to uline() so big data sets OK  */
/*			03/11/01	Added provisions for thicker lines                   */
/*			02/02/02	Added provisions for user control of plot y-scale    */
/*			03/18/02	Used RoundAxes() for plot y-scale determination      */
/*			01/26/07	Added weighted PSD line fit                          */
/*			08/20/07	Fixed extra unsmoothed octave band average point     */
/*			05/15/08	Added provisions for finding and showing spurs       */
/*			06/02/08	Added provisions for removing spurs                  */
/*                                                                           */
/*****************************************************************************/

void WINAPI PowerSpectrumPlot(float f_data[], float s_data[],
	int points, int type, struct plotdata *p)
{
	int i;                                               /* outer loop index */
	int j;                                               /* inner loop index */
	int start;
	int af;                                              /* averaging factor */
	int line_num;                                       /* # line fit points */
	int background_color;
	int grid_color;
	int label_color;
	int data_color;
	int line_color;
	int annotation_color;
	int removed_color;
	int lgth;
	static int havespurs=0; /* flag that have spur(s) that are to be removed */
	//int nPSDMax;	// Index of maximum PSD value

	#ifdef DEMO_VERSION
	int x_pix, y_pix, x_pix_min, y_pix_min, x_pix_max, y_pix_max;
	#endif

	float width;
	double sum;                                 /* sum variables for average */
	// Note: Original line array size was 12 - changed to 32 04/24/98
	// This fixes problem with line fit with large data file sizes
	// Size should really be related to max # octave bands in max data size
	// Can calc as log(MAX_DATA_FILE_SIZE)/log(2)
	// For MAX_DATA_FILE_SIZE=999998, it is 20
	// Thus 32 is very generous - handles 4G file size
	float line_s[32];                            /* line fit spectral points */
	float line_f[32];                           /* line fit frequency points */
	float line_a[32];						/* line average averaging factor */
	// float num;                                * float version of line_num */
	double sum_f=0;                          /* line fit summation variables */
	double sum_s=0;
	double sum_ff=0;
	double sum_fs=0;
	double slope;                        /* power-law slope of S(f) line fit */
	double intercept;                      /* intercept of log S(f) line fit */
	float k;                                 /* numerical value of intercept */
	float spurlimit;	         /* Log margin above PSD fit to declare spur */

	// double temp;                  /* temp variable to hold log(line_f[i]) */
	char label_str[LABELSIZE+1];
	char msg_str[MESSAGESIZE+1];
	char buffer[BUFFER_SIZE+1];
	float s_min, s_max, f_min, f_max;
	F_TYPE y_scale_min, y_scale_max, x_scale_min, x_scale_max;
	int y_scale_tics;
	int n_min, n_max;

	// Cursor variables
	float *fx;                  // Pointer to x-axis point array
	float *fy;                  // Pointer to y-axis point array
	int find;					// Point array dimensions

	// Plot scale parameters
	F_TYPE smin;				// Scale min
	F_TYPE smax;				// Scale max
	F_TYPE sdiv;				// Scale div

	// NR weighted linear fit parameters
	int ndata;
	int mwt;
	float x[33];
	float y[33];
	float sig[33];
	float a;
	float b;
	float siga;
	float sigb;
	float chi2;
	float q;

	// assign colors
	background_color=BRT_WHITE;
	grid_color=BLACK;
	label_color=BLUE;
	data_color=RED;
	line_color=GREEN;
	annotation_color=BLACK;
	removed_color=YELLOW;

	// Sequence of basic GraphiC plotting calls S/B per page I-34 of manual:
	//	   bgnplot()           	Initializations
	//	   startplot()         	Starts graphics
	//	   font()              	Loads fonts
	//	   page()              	Sets overall picture size
	//	   heading()			Draws title
	//	   xname(), yname()	 	Draws axis labels
	//	   area2d()				Defines axis lengths

	// Write log info
	WriteLog(41, p->plot_filename);

	bgnplot(1, 'g', p->plot_filename);                    /* initialize plot */

	startplot(background_color);         /* start plot with background color */

	// Load fonts
	font(4,"news.fnt", '\310', "swiss.fnt", '\311', "newsgrm.fnt", '\312',
		 "simplex.fnt", '\313');

	page(FULLPAGE);                  /* Sets the maximum allowable page size */

	heading("");    /* Blank heading allows space for title & subtitle later */
	fillfont(1);                                         /* Use filled fonts */

	// Kill the beep
	GPCSetBeepDefaults(0, 0);

	#if(0) // We don't want this because it removes the ENBW message
	// Clear plot message box
	ComboBox_ResetContent(GetDlgItem(hDialog, IDC_PSPLOT_MESSAGE));
	#endif
	
	// Avoid unwanted clipping 
	UnclipPlot();

	// Label x and y axes
	// Note that different strings are used for different styles
	// because the original strings don't work for modern style
	if(nStyle==MODERN_STYLE)                           /* Use "modern" style */
	{
		fntchg('\311');                                          /*swiss.fnt */
		upright(1);                          /* upright y-axis label numbers */
		numht((float)0.18);                           /* larger axis numbers */
		xnamht((float)0.22);                         /* larger x-axis labels */
		ynamht((float)0.22);                         /* larger y-axis labels */
		color(label_color);                                   /* label color */
		strcpy(label_str, "Fourier Frequency, f, Hz");
		xname(label_str);                                    /* x-axis label */

		// Special x-axis label for domain PSD plot
		if(nPlotType==DOMAIN_PSD_PLOT)
		{
			xname("Sideband Frequency, f, Hz");              /* x-axis label */
		}

		if(bDataType) // Sy(f)
		{
			LoadString(hInst, IDS_PSPLOT_YLABEL_3, label_str, LABELSIZE);
			yname(label_str);                         /* label for freq data */
		}
		else                                                   /* phase data */
		{
			if(type==0) // Sx(f)
			{
				LoadString(hInst, IDS_PSPLOT_YLABEL_10, label_str, LABELSIZE);
				yname(label_str);
			}
			if(type==1) // So(f)
			{
				LoadString(hInst, IDS_PSPLOT_YLABEL_11, label_str, LABELSIZE);
				yname(label_str);
			}
			if(type==2) // L(f)
			{
				LoadString(hInst, IDS_PSPLOT_YLABEL_2, label_str, LABELSIZE);
				yname(label_str);
			}
		}
	}
	else // Original style
	{
		fntchg('\310');
		color(label_color);                                   /* label color */
		LoadString(hInst, IDS_PSPLOT_XLABEL_0, label_str, LABELSIZE);
		xname(label_str);                                    /* x-axis label */

		// Special x-axis label for domain PSD plot
		if(nPlotType==DOMAIN_PSD_PLOT)
		{
			xname("Sideband Frequency, f, Hz");              /* x-axis label */
		}

		if(bDataType) // Sy(f)
		{
			LoadString(hInst, IDS_PSPLOT_YLABEL_6, label_str, LABELSIZE);
			yname(label_str);                         /* label for freq data */
		}
		else                                                   /* phase data */
		{
			if(type==0) // Sx(f)
			{
				LoadString(hInst, IDS_PSPLOT_YLABEL_7, label_str, LABELSIZE);
				yname(label_str);
			}
			if(type==1) // So(f)
			{
				LoadString(hInst, IDS_PSPLOT_YLABEL_8, label_str, LABELSIZE);
				yname(label_str);
			}
			if(type==2) // L(f)
			{
				LoadString(hInst, IDS_PSPLOT_YLABEL_9, label_str, LABELSIZE);
				yname(label_str);
			}
		}
	}

	fntchg('\310');                                              /* news.fnt */
	area2d((float)7.8, (float)5.3);                      /* plot dimenisions */
	upright(1);                                  /* horizontal y-axis labels */
	color(grid_color);                                         /* grid color */
	grid(2);                                          /* fine dot grid lines */
	fgrid(9, 0);                             /* dotted lines on subdivisions */
			/* log scales ignore requested # of subdiv and use 10 per decade */
	frame(1, 1);                         /* add frame with ticks around plot */

	if(p->do_box)
	{
		box();                              /* draw a box around the picture */
	}

	 // Set plot scales manually
	// Make sure there are at least 2 points
	if(points<2)
	{
		MessageBox(hDialog, "Too few points to plot", "Spectrum Plot",
			MB_ICONEXCLAMATION);
		endplot();                                         /* terminate plot */
		stopplot();                                  /* close files and quit */
		return;
	}

	// y=linear PSD scale in log units, x=log Fourier freq scale
	// Set y scale
	// Note: y_tic=0 is code that scale needs to be set
	// It also must be set if the y_min and y_max are the same (zero range)
	if((p->y_min==p->y_max) || (p->y_tic==0)) // Scale is not set
	{	
		// Find y-data min & max
		minmax(&s_min, &s_max, s_data, points);
	}
	else // Use manually entered or previous values
	{
		s_min=p->y_min;
		s_max=p->y_max;
	}

	// Determine plot scale using RoundAxes() function
	// Note: This seems to give the best results yet
	// Produces nice scale in all trials without exception
	smin=s_min;
	smax=s_max;
	RoundAxes(&smin, &smax, &sdiv);
	sdiv*=5; // Note: This mult by 5 assures that 5 minor ticks are OK
	y_scale_tics=(int)ceil((smax-smin)/sdiv);
	y_scale_min=(float)smin;
	y_scale_max=(float)(smin+y_scale_tics*sdiv);

	// Tighten scale as much as possible
	while(s_min>=(y_scale_min+sdiv))
	{
		y_scale_min+=(float)sdiv;
		y_scale_tics-=1;
	}
	while(s_max<=(y_scale_max-sdiv))
	{
		y_scale_max-=(float)sdiv;
		y_scale_tics-=1;
	}

	// Put scale limits into plot structure
	p->y_min=(float)y_scale_min;
	p->y_max=(float)y_scale_max;
	p->y_tic=y_scale_tics;

	// Find x-data min & max
	// Note: The first 3 args are floats
	minmax(&f_min, &f_max, f_data, points);

	// Find x-scale decades
	// Note: freq cannot be zero, so log() S/B safe, but test to make sure
	if(f_min && f_max)
	{
		n_min=(int)floor(log10(f_min)+0.000001);
		n_max=(int)ceil(log10(f_max)-0.000001);
	}
	else
	{
		MessageBox(hDialog, "Plot error", "Spectrum Plot",
			MB_ICONEXCLAMATION);
		endplot();                                         /* terminate plot */
		stopplot();                                  /* close files and quit */
		return;
	}

	// Calc the numerical x-scale
	x_scale_min=(float)pow(10.0, (float)n_min);
	x_scale_max=(float)pow(10.0, (float)n_max);

	#if(1) // Added 08/26/07
	// Avoid ugly case where no tics
	// Keep an eye on this to make sure there are no gotchas
	if(y_scale_tics==1)
	{
		y_scale_tics=5;
	}
	#endif

	// Set manual semi-log scale
	// Label is integer format
	if((bDataType==PHASE_DATA) && (type==2)) // L(f)
	{
		xlog((float)x_scale_min, (float)x_scale_max, "%-1.0f",
			(float)y_scale_min,
			(float)((y_scale_max-y_scale_min)/y_scale_tics),
			(float)y_scale_max);
	}
	else
	{
		xlog((float)x_scale_min, (float)x_scale_max, "%-1.1f",
			(float)y_scale_min,
			(float)((y_scale_max-y_scale_min)/y_scale_tics),
			(float)y_scale_max);
	}

	// Note: to calc S(f), rad/Hz, must enter nominal frequency, v, and
	// multiply Sx(f) by (2v).  Sy(f), Sx(f) and S(f) are expressed as
	// log10 of their values.  (f) is S(f); it is expressed as 10log10 of
	// its numerical value. Those terms are conveyed by correction_factor to
	// SpectrumCalc()

	fntchg('\311');                                             /* swiss.fnt */

	color(label_color);                                   /* set label color */

	width=strwidth(p->title, (float)0.3);         /* get half-width of title */
	prtfnt((float)(4.75-width),(float)6.40,p->title,(float)0.3,0);  /* title */

	if(nStyle!=MODERN_STYLE)
	{
		// Update subtitle in case it changed because of spur removal
		strcpy(p->subtitle, szFileTitle);
	}

	width=strwidth(p->subtitle, (float)0.15);  /* get half-width of subtitle */
	prtfnt((float)(4.75-width), (float)6.175, p->subtitle, (float)0.15, 0);
	                                                        /* draw subtitle */

	color(data_color);                                         /* data color */
	sympick(1);

	// Set plot line thickness
	// 0 is default, 20 is wider
	tline(p->thick);

	// Change color if spurs are removed
	if(sPSPlot.nospur_plot)
	{
		color(removed_color);
	}

	// Use do_errbar flag to control plotting of points
	if(p->do_errbar)
	{
		ClipPlot();
		for(i=0; i<points-1; i++)                           /* plot fit data */
		{
			uline(*(f_data+i),*(s_data+i),*(f_data+i+1),*(s_data+i+1),1);
		}                                                         /* end for */
		UnclipPlot();
	}
	
	// Restore plot line thickness
	tline(0);

	// Draw octave band averages
	if( (p->do_line || p->do_spur) && (points>8) )
	{
		af=1;
		start=0;
		color(line_color);                                     /* line color */
		
		// Find octave band averages and draw them as circles if unsmoothed PSD
		if(!p->smooth)
		{
			// Note: (int) cast added to index limit to fix extra point bug 08/20/07
			for(i=0; i<(int)((log(points)/log(2))-1); i++) /* calc log-weighted avg */
			{
				af*=2;
				sum=0;
				for(j=0; j<af; j++)
				{
					sum+=s_data[start+j];
				}
				line_s[i]=(float)(sum/af);
				line_f[i]=(f_data[start]+f_data[start+af-1])/2;
				line_a[i]=(float)(fAF[(start+af)/2]); // Average avg factor
				start+=af;
				line_num=i+1;
			}

			// Draw octave band fit points	
			// Doesn't work for smoothed data because freq scale not linear
			if(p->do_line)                           /* draw points as symbols only */
			{
				curve(line_f, line_s, line_num, -1);
			}
		}

		// Draw weighted linear fit thru octave band averages
		// if unsmoothed PSD data
		if(!p->smooth)
		{
			// Call LinFit()
			// Note: This is an NR function that uses 1-based arrays
			// We want to find slope and intercept of linear fit
			// y=a+bx for num points
			// with x-axis values (Fourier freq) on log scale line_f[i]
			// and y-axis values (log PSD) on linear scale line_s[i]
			// So x values to fit are log10(line_f[i]
			// and y values to fit are simply line_s[i]
			// where i=1 to num (starting at 1 elminiates 1st point)
			// LinFit() prototype is:
			// void WINAPI LinFit(float x[], float y[], int ndata,
			// float sig[], int mwt, float *a, float *b, float *siga,
			// float *sigb, float *chi2, float *q)
			// Fit is: y=a+bx
			// We don't care about siga, sigb, chi2 & q
			// We want a and b from 1-based x[] and y[] arrays of size ndata
			// For weighted fit, also need sig[] std dev data for points
			// and must set mwt=1

			// Assign NR weighted linear fit input parameters
			ndata=line_num-1;
			mwt=1; // 1=apply weighting - always done, don't want choice w/o it

			// The weighting sigma values are based on number of PSD points
			// used above to determine each octave band average
			// This # is product of that number of pts (af in the code above)
			// and the averaging factor that was applied in the PSD calc.
			// The former is a simple power-of-two sequence (as in code above)
			// The latter applies only to the first few (LF) points  that have
			// averaging factors lower than most
			// These AFs are in global fAF array as a function of point index
			// and Fourier freq
			
			// Assigm 1-based array values
			for(i=0; i<32; i++)
			{
				x[i+1]=(float)log10(line_f[i]);
				y[i+1]=line_s[i];
				sig[i+1]=(float)(pow(2, (double)-i)); // # effect on variance
				if(sPSPlot.win!=MULTITAPER_WIN)
				{
					// AF effect on variance
					sig[i+1]/=line_a[i]; 
				}
				sig[i+1]=(float)sqrt(sig[i+1]); // Combined effect on std dev
			}

			// Perform weighted linear regression
			LinFit(x, y, ndata,
				sig, mwt, &a, &b, &siga,
				&sigb, &chi2, &q);
			
			// Assign NR weighted linear fit output parameters
			intercept=a;
			slope=b;
		}

		// Find and draw unweighted semilog fit thru all smoothed PSD data
		if((p->smooth)&&(!p->weight))
		{
			// Call SemiLogFit()
			// Important: This function uses all PSD data, not just
			// octave-band averages as done with LinFit() above
			// Note: This is an NR-type function that uses 1-based arrays
			// We want to find slope and intercept of semilog fit
			// y=a+b*log(x) for num points = points
			// with x-axis values (Fourier freq) on log scale = f_data[i]
			// and y-axis values (log PSD) on linear scale = s_data[i]
			// where i=0 to points-1 
			// SemiLogFit() prototype is:
			// void WINAPI LinFit(float x[], float y[], int ndata,
			// float sig[], int mwt, float *a, float *b, float *siga,
			// float *sigb, float *chi2, float *q)
			// Fit is: y=a+b*log(x)
			// We don't care about siga, sigb, chi2 & q
			// We want a and b from 1-based x[] and y[] arrays of size points
			// For weighted fit, also need sig[] std dev data for points
			// and must set mwt=1

			// Assign NR weighted linear fit input parameters
			ndata=points;
			mwt=0; // 0=no weighting, 1=apply weighting - Try first w/o weighting

			// The weighting sigma values will be based on the averaging factor
			// associated with each data set
			// These AFs are in global fAF array as a function of same point index
			// AF effect on variance is as:	sig[i]/=fAF[i];
			
			for(i=0; i<points; i++)
			{
				fAF[i]=(float)(1.0/fAF[i]);
			}
			
			// 1-based array values will be obtained by incrementing array pointers
			// Perform (possibly) weighted semilog least squares regression
			SemiLogFit(f_data-1, s_data-1, ndata, sig, mwt, &a, &b, &siga,
				&sigb, &chi2, &q);
			
			// Assign NR weighted semilog fit output parameters
			intercept=a;
			slope=b;
		}

		// Find and draw weighted semilog fit thru all smoothed PSD data
		if((p->smooth)&&(p->weight))
		{
			// Call SemiLogFit()
			// Important: This function uses all PSD data, not just
			// octave-band averages as done with LinFit() above
			// Note: This is an NR-type function that uses 1-based arrays
			// We want to find slope and intercept of semilog fit
			// y=a+b*log(x) for num points = points
			// with x-axis values (Fourier freq) on log scale = f_data[i]
			// and y-axis values (log PSD) on linear scale = s_data[i]
			// where i=0 to points-1 
			// SemiLogFit() prototype is:
			// void WINAPI LinFit(float x[], float y[], int ndata,
			// float sig[], int mwt, float *a, float *b, float *siga,
			// float *sigb, float *chi2, float *q)
			// Fit is: y=a+b*log(x)
			// We don't care about siga, sigb, chi2 & q
			// We want a and b from 1-based x[] and y[] arrays of size points
			// For weighted fit, also need sig[] std dev data for points
			// and must set mwt=1

			// Assign NR weighted linear fit input parameters
			ndata=points;
			mwt=1; // 0=no weighting, 1=apply weighting - Try first w/o weighting

			// The weighting sigma values will be based on the averaging factor
			// associated with each data set
			// These AFs are in global fAF array as a function of same point index
			// AF effect on variance is as:	sig[i]/=fAF[i]; 
			
			// Set std dev for weighting equal to reciprocal of sqrt of AF
			for(i=0; i<points; i++)
			{
				fAF[i]=(float)(1.0/sqrt(fAF[i]));
			}

			// 1-based array values will be obtained by incrementing array pointers
			// Perform (possibly) weighted semilog least squares regression
			SemiLogFit(f_data-1, s_data-1, ndata, fAF-1, mwt, &a, &b, &siga,
				&sigb, &chi2, &q);
			
			// Restore fAF array - this doesn't seem to be necessary
			for(i=0; i<points; i++)
			{
				fAF[i]=(float)1.0/(fAF[i]*fAF[i]);
			}

			// Assign NR weighted semilog fit output parameters
			intercept=a;
			slope=b;
		}
		
		// Is spur detection active?
		if(sPSPlot.do_spur)
		{
		// Set spur limit (detection threshold) from ini file
			// Read it again here to make sure it is updated
			// Note spur limit is in sPSPlot.limit in dB - must convert it to log limit
			// e.g., 20 dB = x100 = 2.0 log limit
			// Get sPSPlot.limit
			GetPrivateProfileString("Preferences", "PSDSpurLim", "20", buffer,
				BUFFER_SIZE, szIniFile);
			sPSPlot.limit=(float)atof(buffer);
			spurlimit=(float)(sPSPlot.limit/10);

			// Find, and optionally remove spurs (if any)
			// Last arg controls removal
			FindSpurs(points, type, s_data, f_data, spurlimit, (float)intercept, (float)slope,
				&sSpur, sPSPlot.nospur_plot);

			// Replot PSD points if spur removal flag is set
			if(sPSPlot.nospur_plot)
			{
				// Select data color
				color(data_color);                                         /* data color */

				// Use do_errbar flag to control plotting of points
				if(p->do_errbar)
				{
					ClipPlot();
					for(i=0; i<points-1; i++)                           /* plot fit data */
					{
						uline(*(f_data+i),*(s_data+i),*(f_data+i+1),*(s_data+i+1),1);
					}                                                         /* end for */
					UnclipPlot();
				}

				// Select line color
				color(line_color);                                         /* line color */
			}
		
			if(sSpur.num>0)
			{
				// If sPSPlot.nospur_data is set and sSpur.num is >0, then set havespurs
				if(sPSPlot.nospur_data)
				{
					if(sSpur.num>havespurs)
					{
						havespurs=sSpur.num;
					}
				}
				
				// Compose a message with the # of spurs
				_snprintf(msg_str, MESSAGESIZE, "# Spurs = %d", sSpur.num);

				// Load message string into combo box of power spectrum plot dialog 
				// Don't store it if it is already there
				if(ComboBox_FindString(GetDlgItem(hDialog, IDC_PSPLOT_MESSAGE), -1, msg_str)==CB_ERR)
				{
					// Insert string
					ComboBox_InsertString(GetDlgItem(hDialog, IDC_PSPLOT_MESSAGE), -1, msg_str);
				}

				// Set i to index of largest spur
				i=sSpur.max;

				// Compose spur message
				// Log PSD types
				if(type==0 || type==1 || type==3) // Sx(f) or So(f) or Sy(f)
				{
					if(sSpur.num>1)
					{
						// Show results as plot message
						_snprintf(msg_str, MESSAGESIZE, "Largest of %d Spurs: Freq=%5.3e, Log Amplitude=%4.2e",
							sSpur.num, sSpur.freq[i], sSpur.amp[i]+sSpur.corr);
					}
					else // 1 spur
					{
						// Show results as plot message
						_snprintf(msg_str, MESSAGESIZE, "Spur Freq=%5.3e, Log Amplitude=%4.2e",
							sSpur.freq[i], sSpur.amp[i]+sSpur.corr);
					}
					ShortenExp(msg_str);
				}
					
				// dB PSD type
				if(type==2) // L(f)
				{
					if(sSpur.num>1)
					{
						// Show results as plot message
						_snprintf(msg_str, MESSAGESIZE, "Largest of %d Spurs: Freq=%5.3e, Amplitude=%4.2f dBc",
							sSpur.num, sSpur.freq[i], sSpur.amp[i]+(float)10*sSpur.corr);
					}
					else // 1 spur
					{
						// Show results as plot message
						_snprintf(msg_str, MESSAGESIZE, "Spur Freq=%5.3e, Amplitude=%4.2f dBc",
							sSpur.freq[i], sSpur.amp[i]+(float)10*sSpur.corr);
					}
					ShortenExp(msg_str);
				}

				// Load message string into combo box of power spectrum plot dialog 
				// Don't store it if it is already there
				if(ComboBox_FindString(GetDlgItem(hDialog, IDC_PSPLOT_MESSAGE), -1, msg_str)==CB_ERR)
				{
					// Insert string
					ComboBox_InsertString(GetDlgItem(hDialog, IDC_PSPLOT_MESSAGE), -1, msg_str);
				}

				// Show message if flag set
				if(p->do_spur)
				{
					// Copy message to display string
					strlcpy(p->message_str, msg_str, MESSAGESIZE);
				}
			}
			else // No spurs
			{
				// Did # spurs just go to zero during removal from data?
				if(sPSPlot.nospur_data && havespurs)
				{
					if(havespurs>1)
					{
						_snprintf(msg_str, MESSAGESIZE, "%d Spurs Removed", havespurs);
					}
					else // Just 1 spur
					{
						_snprintf(msg_str, MESSAGESIZE, "%d Spur Removed", havespurs);
					}
					
					// Load message string into combo box of power spectrum plot dialog 
					// Don't store it if it is already there
					if(ComboBox_FindString(GetDlgItem(hDialog, IDC_PSPLOT_MESSAGE), -1, msg_str)==CB_ERR)
					{
						// Insert string
						ComboBox_InsertString(GetDlgItem(hDialog, IDC_PSPLOT_MESSAGE), -1, msg_str);
					}

					// Show message if flag set
					if(p->do_spur && havespurs)
					{
						// Copy message to display string
						strlcpy(p->message_str, msg_str, MESSAGESIZE);
					}
					
					// Reset have spurs 
					havespurs=0;
				}
			}

			// Clip plot for spur lines
			ClipPlot();

			// Draw spurs
			if((sSpur.num>0) &&(p->do_spur))
			{
				// Loop thru all spurs
				for(i=0; i<sSpur.num; i++)
				{
					// Drau line for L(f)
					if(type==2) // L(f)
					{
						// User thicker line
						tline(20);

						// Draw spur line
						// Is it above fit line?
						if(sSpur.amp[i]+10*sSpur.corr>(float)log10(pow(10.0, intercept)*pow(sSpur.freq[i], slope)))
						{
							// Spur line from fit line
							uline(sSpur.freq[i], (float)log10(pow(10.0, intercept)*pow(sSpur.freq[i], slope)),
								sSpur.freq[i], sSpur.amp[i]+10*sSpur.corr, 3);
						}
						else // Or below fit line
						{
							// Spur line from bottom of plot
							uline(sSpur.freq[i], (float)y_scale_min, sSpur.freq[i], sSpur.amp[i]+10*sSpur.corr, 3);
						}

						// Restore normal line width
						tline(0);
					}
					// Drau line for other PSD types
					if(type==0 || type==1 || type==3) // Sx(f) or So(f) or Sy(f)
					{
						// User thicker line
						tline(20);

						// Draw spur line
						// Is it above fit line?
						if(sSpur.amp[i]+sSpur.corr>(float)log10(pow(10.0, intercept)*pow(sSpur.freq[i], slope)))
						{
							// Spur line from fit line
							uline(sSpur.freq[i], (float)log10(pow(10.0, intercept)*pow(sSpur.freq[i], slope)),
								sSpur.freq[i], sSpur.amp[i]+sSpur.corr, 3);
						}
						else // Or below fit line
						{
							// Spur line from bottom of plot
							uline(sSpur.freq[i], (float)y_scale_min, sSpur.freq[i], sSpur.amp[i]+sSpur.corr, 3);
						}

						// Restore normal line width
						tline(0);
					}
				}
			}

			// Unclip plot after spur lines
			UnclipPlot();
		}

		if(p->do_line)
		{
			// Draw the power law fit line
			// Clipping added 2/2/02
			ClipPlot();
			
			if(type==0 || type==1 || type==3) // Sx(f) or So(f) or Sy(f)
			{
				k=(float)pow(10.0,intercept);
				uline((float)f_data[0],
					  (float)(log10(k*pow(f_data[0], slope))),
					  (float)f_data[points-1],
					  (float)(log10(k*pow(f_data[points-1], slope))), 3);
			}
			if(type==2) // L(f)
			{
				uline((float)f_data[0],
					  (float)(intercept+slope*log10(f_data[0])),
					  (float)f_data[points-1],
					  (float)(intercept+slope*log10(f_data[points-1])), 3);
			}

			UnclipPlot();

			// Label the power law fit
			if(type==0) // Sx(f)
			{
				// Make exponent  (B used)
				// The newsgrm font  is too dark
				_snprintf(label_str, LABELSIZE,
					"Power Law Fit: Sx(f)=kf[B], k=%10.7e,"
					" B=%10.7e", k, slope);
				ShortenExp(label_str);
			}
			if(type==1) // So(f)
			{
				// Make exponent  (B used)
				_snprintf(label_str, LABELSIZE,
					"Power Law Fit: So(f)=kf[B], k=%10.7e,"
					" B=%10.7e", k, slope);
				ShortenExp(label_str);
			}
			if(type==2) // L(f)
			{
				_snprintf(label_str, LABELSIZE,
					"Power Law Fit: L(1)=%5.2f dBc/Hz, Slope=%5.2f dB/decade",
					intercept, slope);
				ShortenExp(label_str);
			}
			if(type==3) // Sy(f)
			{
				_snprintf(label_str, LABELSIZE,
					"Power Law Fit: Sy(f)=kf[a], k=%10.7e, a=%10.7e",
					k, slope);
				ShortenExp(label_str);
			}

			fntchg('\313');                                       /* simplex.fnt */
			color(annotation_color);                         /* annotation color */
			tmargin((float)6.655);
			ctline(label_str, (float)0.075);
		}
	}

	if(nPlotType==DOMAIN_PSD_PLOT)
	{
		fntchg('\313');                                       /* simplex.fnt */
		color(annotation_color);                         /* annotation color */
		tmargin((float)6.655);
		_snprintf(label_str, LABELSIZE,
			"Carrier Freq=%e MHz, BW=%e Hz", p->carrier, p->bw);
		ShortenExp(label_str);
		ctline(label_str, (float)0.075);
	}

	if(sPSPlot.do_table)
	{
		fntchg('\313');                                       /* simplex.fnt */
		color(annotation_color);                         /* annotation color */
			  /* right_y_label string used for annotation of FFT window type */
		if(p->position==MSG_BOT_LEFT)  /* win annotation at top left of plot */
		{
			MsgBox(300, 4440, p->right_y_label);
		}
		else                        /* win annotation at bottom left of plot */
		{
			MsgBox(300, 200, p->right_y_label);
		}
	}

	// Unclip again 
	UnclipPlot();

	if(p->do_date)
	{
		if(nPlotType==DOMAIN_PSD_PLOT)
		{
			color(annotation_color);                     /* annotation color */
			Dateline(0, 0, 1);               /* put date & file info on plot */
		}
		else
		{
			color(annotation_color);                     /* annotation color */
			Dateline(1, 1, 1);               /* put date & file info on plot */
		}
	}

	// Increment filename
    if(sPSPlot.nospur_data && sSpur.num>0 && bDataType==FREQ_DATA && bIncExtension)
    {
        IncExtension(szFile, FREQ_DATA);
        IncExtension(szFileTitle, FREQ_DATA);
        IncExtension(szFreqFile, FREQ_DATA);
        IncExtension(szFreqFileTitle, FREQ_DATA);
        SetWindowText(hwndFreqFilename, szFileTitle);
    }

	// Increment filename
    if(sPSPlot.nospur_data && sSpur.num>0 && bDataType==PHASE_DATA && bIncExtension)
    {
        IncExtension(szFile, PHASE_DATA);
        IncExtension(szFileTitle, PHASE_DATA);
        IncExtension(szPhaseFile, PHASE_DATA);
        IncExtension(szPhaseFileTitle, PHASE_DATA);
        SetWindowText(hwndPhaseFilename, szFileTitle);
    }

	// Display message box
	// Locations are x, y in pixels, origin at bottom left, 8192 x 6266 space
	// Find half length of message box in pixels
	lgth=(H_MARGIN+strwidtq(p->message_str, CHAR_HGTH));

	// Write message
	if(p->message_str[0]!='\0')         /* don't display a blank message box */
	{
		switch(p->position)
		{
			case MSG_TOP_LEFT:            /* message box at top left of plot */
			{
				MsgBox(300, 4440, p->message_str);
				break;
			}
			case MSG_MID_LEFT:         /* message box at middle left of plot */
			{
				MsgBox(300, 2270, p->message_str);
				break;
			}
			case MSG_BOT_LEFT:         /* message box at bottom left of plot */
			{
				MsgBox(300, 200, p->message_str);
				break;
			}
			case MSG_TOP_CENTER:        /* message box at top center of plot */
			{
				MsgBox(3470-lgth, 4440, p->message_str);
				break;
			}
			case MSG_MID_CENTER:     /* message box at middle center of plot */
			{
				MsgBox(3470-lgth, 2270, p->message_str);
				break;
			}
			case MSG_BOT_CENTER:     /* message box at bottom center of plot */
			{
				MsgBox(3470-lgth, 200, p->message_str);
				break;
			}
			case MSG_TOP_RIGHT:          /* message box at top right of plot */
			{
				MsgBox(6770-2*lgth, 4440, p->message_str);
				break;
			}
			case MSG_MID_RIGHT:       /* message box at middle right of plot */
			{
				MsgBox(6770-2*lgth, 2270, p->message_str);
				break;
			}
			case MSG_BOT_RIGHT:       /* message box at bottom right of plot */
			{
				MsgBox(6770-2*lgth, 200, p->message_str);
				break;
			}
		}
	}

	// Write label
	if(bPlotLabel)
	{
		UnclipPlot();
		color(annotation_color);                         /* annotation color */
		width=(float)intopix(strwidth(szPlotLabel, (float)0.05));
		putlabel(szPlotLabel, (float)(8192-2*(width+20)), (float)20.0,
			(float)0.05, 0, PIXEL_UNITS);
	}

	// Activate mouse cursor
	if(p->do_mouse)
	{
		// Allocate memory for x and y point arrays
		fx=(float*)gpcalloc(64, sizeof(float));
		fy=(float*)gpcalloc(64, sizeof(float));

		curson(0, 0, &fx, &fy, &find);                /* turn on mouse cursor*/
	}

	// Avoid unwanted clipping 
	UnclipPlot();

	#ifdef DEMO_VERSION
	// Add watermark for demo version
	// Get plot size in pixels
	usertopix((float)x_scale_max, (float)y_scale_max, 0.0,
		&x_pix_max, &y_pix_max);
	usertopix((float)x_scale_min, (float)y_scale_min, 0.0,
		&x_pix_min, &y_pix_min);
	x_pix=x_pix_max-x_pix_min;
	y_pix=y_pix_max-y_pix_min;
	// Select hatched swiss font
	fntchg('\311');                                              /* news.fnt */
	fontfill(2, 230, 0);
	// Display watermark
	pltfnt((float)x_scale_min, (float)y_scale_min, "Stable32 Demo Version",
		(float)0.6, (int)(180*atan2((double)y_pix, (double)x_pix)/PI));
	#endif

	#ifdef VITSAS_VER
	// Add watermark for V-ITSAS version
	color(227);
	tmargin((float)0.15);
	ltline(" Stable32 V-ITSAS", (float)0.12);
	tmargin((float)0.15);
	rtline("Evaluation Version ", (float)0.12);
	#endif

	#if(1) // New code 11/23/11
	// Process bCmdM command to copy plot metafile to clipboard
	if(bCmdM)
	{
		// Send copy metafile message to GraphiC
		PostMessage(hGPC, WM_COMMAND,
			GET_WM_COMMAND_MPS(IDM_COPYMETA, 0, 0));
	}

	// Process bCmdT command to print plot
	if(bCmdT)
	{
		// Send print message to GraphiC
		PostMessage(hGPC, WM_COMMAND,
			GET_WM_COMMAND_MPS(IDM_PRINT, 0, 0));
	}

	// Process bCmdX command to close plot
	if(bCmdX)
	{
		// Show the plot briefly
		Sleep(1000);

		// Close plot and plot dialog box
		PostMessage(hPlot, WM_CLOSE, (WPARAM)0, (LPARAM)0);
		PostMessage(hPlotBox, WM_CLOSE, (WPARAM)0, (LPARAM)0);
	}
	#endif

	endplot();                                             /* terminate plot */
	stopplot();                                      /* close files and quit */
}

#if(1) // New code 05/15/08
/*****************************************************************************/
/*                                                                           */
/*								FindSpurs()                                  */
/*                                                                           */
/*		Function to find spurs in PSD data                                   */
/*                                                                           */
/*      Parameters:                                                          */
/*			int		points				# PSD points                         */
/*			int		type				PSD type code                        */
/*          float	s_data[]			PSD data array                       */
/*          float	f_data[]			Freq data array                      */
/*          float	limit				Spur threshold                       */
/*			float	intercept			Noise fit intercept                  */
/*			float	slope				Noise fit slope                      */
/*          struct	sspur				Spur data struct                     */
/*			BOOL	remove				Spur removal flag                    */
/*                                                                           */
/*		Returns nothing (void)                                               */
/*                                                                           */
/*		Revision record:                                                     */
/*			05/15/08	Created                                              */
/*			06/02/08	Added spur removal option                            */
/*                                                                           */
/*****************************************************************************/

void WINAPI FindSpurs(int points, int type, float s_data[], float f_data[],
	float limit, float intercept, float slope, struct spur *sspur,
	BOOL remove)
{
	// Local variables
	// Chars
	char *p;	// General pointer to char
	char szBuffer[BUFFER_SIZE+1];	// Text buffer
	// PSD names vs type #
	// 0=Sx(f), 1=So(f), 2=L(f), 3=Sy(f)
	char* PSDname[] =
	{
	   "Sx(f)\0",
	   "So(f)\0",
	   "L(f)\0",
	   "Sy(f)\0",
	};
	// PSD units vs type #
	// 0=Sx(f), 1=So(f), 2=dBc/Hz, 3=Sy(f)
	char* PSDunits[] =
	{
	   "sec/Hz\0",
	   "rad/Hz\0",
	   "dBc/Hz\0",
	   "1/Hz\0",
	};
	// Spur units vs type #
	// 0=Sx(f), 1=So(f), 2=dBc/Hz, 3=Sy(f)
	char* Spurunits[] =
	{
	   "Log sec\0",
	   "Log rad\0",
	   "dBc\0",
	   "Log df/f\0",
	};

	// Ints
	int i;				// General index
	int j;				// Spur removal index
	int k;				// Spur array index
	int nClip;			// Size of szClipboard (chars)
	int istart;			// First spur point
	int iend;			// Last spur point
	int ext=2;			// # FFT points to extend AF=1 spur removal range
	// Floats
	float offset;		// Relative PSD peak location (bins)
	float big;			// Largest spur amplitude
	// Clipboard variables
	HGLOBAL hClipboard;			// Handle to clipboard text buffer
	LPSTR	szClipboard;		// Ptr to clipboard text string

	// Candidate way to search for spurs:
	// Loop thru all PSD data from beginning to end one time
	// Look for point that exceeds threshold after "prewhitening"
	// by removing noise fit
	// Find local maximum
	// Calc exact PSD and freq by parabolic fit
	// Add spur to table - increase table sizes as required
	// Move off this spur - next PSD value below threshold
	// Iterate - search for next spur
	// End up with all spurs in table in order of increasing freq
	// Can find largest spur if wanted
	// Can then create spur table on clipboard and/or save to file
					
	// Initialize # spurs
	sspur->num=0;

	// Initialize spur index
	k=0;
	
	// Search is divided into two parts depending on PSD type
	if(type==2) // L(f)
	{
		// Loop through PSD data
		// Start at i=1 because parabolic fit goes back one point
		// It's reasonable to skip first (LF) point
		// Must end at i<points to cover all Fourier freqs
		// So deal with its fit index as special case below
		for(i=1; i<points; i++)
		{
			// Look for prewhitened PSD value that exceeds limit
			// Note that L(f) limit is 10*log limit
			if(s_data[i]-(float)(intercept+slope*log10(f_data[i]))>10*limit)
			{
				// Save index of first point that exceeded limit
				istart=i;
				sspur->first[k]=i;
				
				// Find local maximum
				while(s_data[i+1]>s_data[i])
				{
					// Increment the main loop index
					i++;

					// Check loop index
					if(i==points)
					{
						i--;
						break;
					}
				}

				// Now at local maxima (assuming single peak)
				// Save current spur zero-based index
				sspur->index[k]=i;

				// Increment spur count
				sspur->num++;

				// Note: If spur count exceeds allocated array size
				// must realloc to larger array size - that is not done yet
				// At least, we should bail out - break teminiates for loop
				if(sspur->num>NUMSPURS)
				{
					sspur->num--;
					break;
				}
				
				// Check that this is not last point
				if(i<points-1)
				{
					// Use a parabolic fit to the adjacent three
					// PSD and freq points to calc a better estimate of the max
					// PSD value and its frequency
					// Calc relative peak location in bins
					offset=(s_data[i-1]-s_data[i+1])/(2*(s_data[i-1]-2*s_data[i]+s_data[i+1]));
						
					// Calc estimated peak frequency is fFreq[nPSDMax]+fPSDOffset*fBin
					// where fBin is f_data[1]-f_data[0]
					sspur->freq[k]=(float)(f_data[i]+offset*(f_data[i+1]-f_data[i]));

					// Calc peak magnitude
					sspur->amp[k]=s_data[i]-((s_data[i-1]-s_data[i+1])*offset/4);

					// Move away from this spur - again assuming a single peak
					while(s_data[i]-(float)(intercept+slope*log10(f_data[i]))>10*limit)
					{
						// Increment the main loop index
						i++;

						// Check if index too large
						if(i==points)
						{
							i--;
							break;
						}
					}

					// Save index of last point that esceeded limit
					iend=i;
					sspur->last[k]=i;
				}
				else // Last point
				{
					// Just use it as this peak
					sspur->last[k]=i;
					sspur->freq[k]=(float)f_data[i];
					sspur->amp[k]=(float)s_data[i];
				}

				#if(1) // New code 06/08/08
				// Get AF=1 extended spur range preference
				// Note: This is an optional read-only value (default=2)
				ext=GetPrivateProfileInt("Preferences", "ExtendSpurRange", 2,
					szIniFile);
				
				// It applies only to AF=1 and points>=512
				if((sPSPlot.af!=1) || (points<512))
				{
					ext=0;
				}
				#endif

				// Remove spur from PSD data
				if(remove)
				{
					// Remove spur by setting its value to fit model
					// equal to (float)(intercept+slope*log10(f_data[j]))
					for(j=istart-ext; j<=iend+ext; j++)
					{
						// Make sure index is in-bounds
						if((j<0)||(j>=points))
						{
							continue;
						}

						s_data[j]=(float)(intercept+slope*log10(f_data[j]));
					}
				}

				// Iterate - look for next spur (if any)
				k++;
			}
		}
	}

	if(type==0 || type==1 || type==3) // Sx(f) or So(f) or Sy(f)
	{
		// Loop through PSD data
		// Start at 1 because parobolic fit can go back one point
		// End at i<points-1 because fit goes forward one point
		for(i=1; i<points-1; i++)
		{
			// Look for prewhitened PSD value that exceeds limit
			if(s_data[i]-(float)log10(pow(10.0, intercept)*pow(f_data[i], slope))>limit)
			{
				// Save index of first point that exceeded limit
				istart=i;
				sspur->first[k]=i;
				
				// Find local maximum
				while(s_data[i+1]>s_data[i])
				{
					// Increment the main loop index
					i++;

					// Check loop index
					if(i==points)
					{
						i--;
						break;
					}
				}

				// Now at local maxima (assuming single peak)
				// Save current spur zero-based index
				sspur->index[k]=i;

				// Increment spur count
				sspur->num++;
				
				// Note: If it exceeds allocated array size, must realloc
				// to larger array size - that is not done yet - we just limit # spurs
				// At least, we should bail out - break teminiates for loop
				if(sspur->num>=NUMSPURS)
				{
					sspur->num--;
					break;
				}

				// Check that this is not last point
				if(i<points-1)
				{
					// Use a parabolic fit to the adjacent three
					// PSD and freq points to calc a better estimate of the max
					// PSD value and its frequency
					// Calc relative peak location in bins
					offset=(s_data[i-1]-s_data[i+1])/(2*(s_data[i-1]-2*s_data[i]+s_data[i+1]));
						
					// Calc estimated peak frequency is fFreq[nPSDMax]+fPSDOffset*fBin
					// where fBin is f_data[1]-f_data[0]
					sspur->freq[k]=(float)(f_data[i]+offset*(f_data[i+1]-f_data[i]));

					// Calc peak magnitude
					sspur->amp[k]=s_data[i]-((s_data[i-1]-s_data[i+1])*offset/4);

					// Move away from this spur - again assuming a single peak
					while(s_data[i]-(float)(intercept+slope*log10(f_data[i]))>limit)
					{
						// Increment the main loop index
						i++;

						// Check if index too large
						if(i==points)
						{
							i--;
							break;
						}
					}

					// Save index of last point that esceeded limit
					iend=i;
					sspur->last[k]=i;
				}
				else // Last point
				{
					// Just use it as this peak
					sspur->last[k]=i;
					sspur->freq[k]=(float)f_data[i];
					sspur->amp[k]=(float)s_data[i];
				}

				#if(1) // New code 06/08/08
				// Get AF=1 extended spur range preference
				// Note: This is an optional read-only value (default=2)
				ext=GetPrivateProfileInt("Preferences", "ExtendSpurRange", 2,
					szIniFile);
				
				// It applies only to AF=1 and points>=512
				if((sPSPlot.af!=1) || (points<512))
				{
					ext=0;
				}
				#endif

				// Remove spur from PSD data
				if(remove)
				{
					// Remove spur by setting its value to fit model
					// equal to (float)(intercept+slope*log10(f_data[j]))
					for(j=istart-ext; j<=iend+ext; j++)
					{
						// Make sure index is in-bounds
						if((j<0)||(j>=points))
						{
							continue;
						}

						s_data[j]=(float)(intercept+slope*log10(f_data[j]));
					}
				}

				// Iterate - look for next spur (if any)
				k++;
			}
		}
	}

	#if(1) // New code 06/03/08
	if(sPSPlot.nospur_data)
	{
		// Remove spurs from time domain data
		if(bDataType) // Freq data
		{
			// Remove spurs from freq data
			nDummy=FFTSpurRemoval(fFreqData, bDataType, sspur, intercept, slope, f_data[1],
				type, sPSPlot.af);

			// Set redraw flag
			bFreqRedraw=TRUE;
		}
		else // Phase data
		{
			// Remove spurs from phase data
			nDummy=FFTSpurRemoval(fPhaseData, bDataType, sspur, intercept, slope, f_data[1],
				type, sPSPlot.af);
				
			// Set redraw flag
			bPhaseRedraw=TRUE;
		}
			
			// Redraw status plots from new data
			UpdateStatusBar(hwndMain, NEW_DATA);

			// Reset redraw flags
			bPhaseRedraw=FALSE;
			bFreqRedraw=FALSE;
	}
	#endif

	// Find largest spur and save its index
	// Set index to -1 to denote no spurs
	sspur->max=-1;

	// Are there any spurs?
	if(sspur->num>0)
	{
		// Initialize search
		big=sspur->amp[0];
		sspur->max=0;

		// Search for biggest spur
		for(i=0; i<sspur->num; i++)
		{
			if(sspur->amp[i]>big)
			{
				big=sspur->amp[i];
				sspur->max=i;
			}
		}
	}

	// At this point, the spur information is in the sspur struct
	// The calling routine may be the best place to format, display and/or store it
	// But it's reasonable to store it to the Windows clipboard here

	// Write spur information to clipboard
	if(TRUE) // Could control this with a flag
	{
		 // # chars to write to clipboard
		nClip=(6*80)+(sspur->num*80);
				
		// Get memory and handle for clipboard
		hClipboard=GlobalAlloc(GMEM_DDESHARE, (DWORD)nClip);
		szClipboard=GlobalLock(hClipboard);

		// Compose clipboard text
		strlcpy(szClipboard, "File: ", nClip);
		strlcat(szClipboard, szFileTitle, nClip);
		strlcat(szClipboard, "\r\n", nClip);
		strlcat(szClipboard, "PSD Type: ", nClip);
		strlcat(szClipboard, PSDname[type], nClip);
		strlcat(szClipboard, "\r\n", nClip);
		strlcpy(szBuffer, sPSPlot.right_y_label, nClip);
		// Remove @ character (if any)
		if((p=strchr(szBuffer, '@'))!=NULL)
		{
			*p=' ';
		}
		strlcat(szClipboard, szBuffer, nClip); 
		strlcat(szClipboard, "\r\n", nClip);
		
		// Excessive # spurs?
		if(sspur->num>=NUMSPURS-1)
		{
			MessageBox(hwndMain,
				"Too many spurs found.\nPress Options to\n"
				"Increase Spur Threshold.",
				"PSD Plot", MB_ICONEXCLAMATION);
		}
		
		// Are there any spurs?
		if(sspur->num>0)
		{
			if(type==2) // L(f)
			{
				_snprintf(szBuffer, sizeof(szBuffer),
					"Spur Threshold = %5.2e dB (x%3.2f)\r\n",
					10*limit, pow(10.0, limit));
				ShortenExp(szBuffer);
				strlcat(szClipboard, szBuffer, nClip);
				_snprintf(szBuffer, sizeof(szBuffer),
					"ENBW = %5.3e Hz, NB Corr = %4.2f dB\r\n",
					pow(10.0, sSpur.corr), 10*sSpur.corr);
				ShortenExp(szBuffer);
				strlcat(szClipboard, szBuffer, nClip);
			}
			if(type==0 || type==1 || type==3) // Sx(f) or So(f) or Sy(f)
			{
				_snprintf(szBuffer, sizeof(szBuffer),
					"Log Spur Threshold = %5.3e (x%3.2f)\r\n",
					limit, pow(10.0, limit));
				ShortenExp(szBuffer);
				strlcat(szClipboard, szBuffer, nClip);
				_snprintf(szBuffer, sizeof(szBuffer),
					"ENBW = %5.3e Hz, Log NB Corr = %4.2f\r\n",
					pow(10.0, sSpur.corr), sSpur.corr);
				ShortenExp(szBuffer);
				strlcat(szClipboard, szBuffer, nClip);
			}

			strlcat(szClipboard, "PSD Discrete Spurs:\r\n", nClip);

			// Write heading
			_snprintf(szBuffer, sizeof(szBuffer),
				"Spur\tFFT\tSpur\t\tDiscrete\r\n");
			strlcat(szClipboard, szBuffer, nClip);
			_snprintf(szBuffer, sizeof(szBuffer),
				"\tBin\tFrequency\tAmplitude\r\n", i+1);
			strlcat(szClipboard, szBuffer, nClip);
		    _snprintf(szBuffer, sizeof(szBuffer),
				"#\t#\tHz\t\t%s\r\n", Spurunits[type]);
			strlcat(szClipboard, szBuffer, nClip);

			// Loop thru all spurs
			for(i=0; i<sspur->num; i++)
			{
				// Compose spur information
				if(type==2) // L(f)
				{
					_snprintf(szBuffer, sizeof(szBuffer),
						"%d\t%d\t%5.3e\t%5.3e\t\r\n",
						i+1, sspur->index[i], sspur->freq[i],
						sspur->amp[i]+10*sspur->corr);
					ShortenExp(szBuffer);
					strlcat(szClipboard, szBuffer, nClip);
				}
				if(type==0 || type==1 || type==3) // Sx(f) or So(f) or Sy(f)
				{
					if(sspur->freq[i]<1e-10)
					{
						// TRACE_INT(i); // Why?
					}

					_snprintf(szBuffer, sizeof(szBuffer),
						"%d\t%d\t%5.3e\t%4.2e\t\r\n",
						i+1, sspur->index[i], sspur->freq[i],
						sspur->amp[i]+sspur->corr);
					ShortenExp(szBuffer);
					strlcat(szClipboard, szBuffer, nClip);
				}
			}
		}
		else // No spurs
		{
			// Show spur threshold
			if(type==2) // L(f)
			{
				_snprintf(szBuffer, sizeof(szBuffer),
					"Spur Threshold = %5.2e dB (x%3.2f)\r\n",
					10*limit, pow(10.0, limit));
				ShortenExp(szBuffer);
				strlcat(szClipboard, szBuffer, nClip);
			}
			if(type==0 || type==1 || type==3) // Sx(f) or So(f) or Sy(f)
			{
				_snprintf(szBuffer, sizeof(szBuffer),
					"Log Spur Threshold = %5.3e (x%3.2f)\r\n",
					limit, pow(10.0, limit));
				ShortenExp(szBuffer);
				strlcat(szClipboard, szBuffer, nClip);
			}

			// Write no spur message
			_snprintf(szBuffer, sizeof(szBuffer), "No discrete spurs\r\n");
			strlcat(szClipboard, szBuffer, nClip);
		}

		// Open clipboard, write text to it, and close clipboard
		GlobalUnlock(hClipboard);
		OpenClipboard(NULL);
		EmptyClipboard();
		SetClipboardData(CF_TEXT, hClipboard);
		CloseClipboard();
	}
}
#endif

#if(1)
/*****************************************************************************/
/*                                                                           */
/*								PhasePlot()                                  */
/*                                                                           */
/*		Function to plot phase data                                          */
/*      Parameters:                                                          */
/*			p_data[] = array of phase data; p_data[0] = # data points        */
/*			p_data[1] = plot start; p_data[2] = plot end                     */
/*      	zero treated as gap in data                                      */
/*		p plotdata struct elements:                                          */
/*          data_title = plot title                                          */
/*          data_subtitle = plot subtitle                                    */
/*			x_label = x-axis label                                           */
/*			y_label = y-axis label                                           */
/*			x_offset = x-axis scale offset                                   */
/*			x_mult = x-axis scale multiplier                                 */
/*			y_offset = y-axis scale offset                                   */
/*			y_mult = y-axis scale multiplier                                 */
/*          scale_min = y-axis scale minimun                                 */
/*          scale_max = y-axis scale maximum                                 */
/*          y_div = # of y-axis major divisions                              */
/*          y_tic = # of y-axis tics between major divisions                 */
/*			do_box = draw box flag                                           */
/*      	do_phase_line = draw regression line flag                        */
/*			do_date = write date flag                                        */
/*     		do_mouse = activate mouse/cursor flag                            */
/*			new_file = new basic phase data file flag                        */
/*			new_name = new exact phase data flag flag                        */
/*			position = position of message box                               */
/*          phase_plot_filename = .tkf filename for plot                     */
/*		Returns nothing (void)                                               */
/*                                                                           */
/*		Revision record:                                                     */
/*			06/30/96	Adapted from phase_plot() of Stable/DOS              */
/*			07/17/96	Adapted from FreqPlot() of Stable/Win                */
/*			11/12/96	Added clipping to line drawing code                  */
/*			11/18/96	Revised plot sizes, etc.                             */
/*			01/10/97	Quadratic drift made slope per data point interval   */
/*			03/15/97	Changed clipping to use ClipPlot()                   */
/*			12/12/98	Added ability to insert mini plot                    */
/*			03/02/00	Added display of average fit with lowest priority    */
/*			03/11/01	Added provisions for thicker lines                   */
/*			03/10/02	Made changes in plot scale code                      */
/*			03/23/02	Made changes in plot scale code                      */
/*			09/27/02	Added average fit                                    */
/*			08/01/03	Added opaque note panel                              */
/*			10/02/03	Changed plot insert code                             */
/*			12/14/07	Added polynomial fit code                            */
/*          12/16/07	Changed to S&E Tools PolyCurveFit()                  */
/*			12/17/07	Added writing fit parameters to clipboard            */
/*			12/18/07	Added core functionality for function fitting        */
/*						Verified levmar Levenberg-Marquart nonlinear curve   */
/*                      fitting code and Morley algebraic expression         */
/*                      evaluator.  Still need plot annotation, clipboard    */
/*                      writing and user interface for function entry.       */
/*          12/19/07	Function fit running                                 */
/*			12/22/07	Added function initial values                        */
/*			12/23/07	Added function fitting r-squared calc                */
/*			12/24/07	Added quadratic fit r-squared calc                   */
/*          01/01/08	Added polynomial and nonlinear fit macros            */
/*			01/13/08	Got lmmin nonlinear fit working                      */
/*			07/29/08	Added function fit removal log file entry            */
/*                                                                           */
/*****************************************************************************/

void WINAPI PhasePlot(F_TYPE p_data[], struct plotdata *p)
{
	// lmmin function declarations
	void lm_evaluate(double *par, int m_dat, double *fvec,
		void *data, int *info);
	double fit_function(double t, double *p);
	void printout(int n_par, double *par, int m_dat, double *fvec,
		void *data, int iflag, int iter, int nfev);

	// Local macros
	#define XFORMAT_SIZE	8
	#define YFORMAT_SIZE	8
	
	// Codes returned from the expression evaluator
	#define E_OK           0        // Successful evaluation
	#define E_SYNTAX       1        // Syntax error
	#define E_UNBALAN      2        // Unbalanced parenthesis
	#define E_DIVZERO      3        // Attempted division by zero
	#define E_UNKNOWN      4        // Reference to unknown variable
	#define E_MAXVARS      5        // Maximum variables exceeded
	#define E_BADFUNC      6        // Unrecognised function
	#define E_NUMARGS      7        // Wrong number of arguments to funtion
	#define E_NOARG        8        // Missing an argument to a funtion
	#define E_EMPTY        9        // Empty expression

	// lmmin struts
    lm_control_type control;
    lm_data_type data;

	// Local variables
	// Floats
	float *x,*y;
	float width;
	float x_max, x_min;                                    /* x scale limits */
	float y_max, y_min;                                    /* y scale limits */
	float xste;                                        /* x-axis tic spacing */
	float yste;                                        /* y-axis tic spacing */
	float save_start;
	float save_end;
	// Doubles
	double val;												 /* double value */
	// Terms for function fit coefficient of determination
	double mean;	// Mean of observations
	double ssr;		// Regression sum of squares
	double sst;		// Total sum of squares
	double sse;		// Error sum of squares
	double rsqrd;	// Coefficient of determination
	// Ints
	int i;
	int j;
	int k;
	int len;				                    	        /* string length */
	int npts;
	int nparam;						            /* # function fit parameters */
	int lgth;                                    /* message length in pixels */
	int line_flag=FALSE;
	int x_div;						           /* # x-scale div for roundq() */
	int nClip;						          /* size of szClipboard (chars) */
	int flag;                                        /* function return code */
	#ifdef DEMO_VERSION
	int x_pix, y_pix, x_pix_min, y_pix_min, x_pix_max, y_pix_max;
	#endif
	// Chars
	char szBuffer[BUFFER_SIZE+1];                             /* Text buffer */
	char szLog[BIG_BUFFER_SIZE+1];                        /* Log text buffer */
	char szFunction[BUFFER_SIZE+1];   /* User-entered algebraic fit function */
	char label_str[BIGLABELSIZE+1];         /* Increased for poly fit params */
	//char title_str[BUFFER_SIZE+1];       /* error message box title string */
	char yformat[YFORMAT_SIZE];
	char xformat[XFORMAT_SIZE];
	char *szTemp;
	char *ptr;							     /* general pointer to character */
	char *ptr1;
	char *ptr2;

	// Expression evaluator error messages
	char* ErrMsgs[] =
	{
	   "Syntax error",
	   "Unbalanced parenthesis",
	   "Division by zero",
	   "Unknown variable",
	   "Maximum variables exceeded",
	   "Unrecognised funtion",
	   "Wrong number of arguments to funtion",
	   "Missing an argument",
	   "Empty expression"
	};

	// For panel filling of notes
	float xpan[5], ypan[5];
	char ch;
	char buf[NOTESIZE+1];
	int xpix, ypix;
	int wid, max_wid=0;
	int allow=15, ydel;
	int tsavfq=0;
	int bsavfq=0;
	int descend;

	// Colors
	int background_color=BRT_WHITE;
	int grid_color=BLACK;
	int box_color=BLACK;
	int label_color=BLUE;
	int data_color=RED;
	int annotation_color=BLACK;
	int line_color=GREEN;

	// Fit parameters
	F_TYPE avg;
	F_TYPE slope;
	F_TYPE intercept;
	F_TYPE a, b, c, v;
	F_TYPE tau;

	// Cursor variables
	float *fx;                  // Pointer to x-axis point array
	float *fy;                  // Pointer to y-axis point array
	int find;					// Point array dimensions
	FILE *file;									             /* file pointer */

	// S&E poly fit variables
	polytype *px;				// Pointer to x (point) data array
	polytype *py;				// Pointer to y (phase) data array
	polytype *aa;				// Pointer to coefficient array
	polytype *yest;				// Pointer to y estimate array
	polytype *yres;				// Pointer to y residual array
	polytype *cerr;				// Pointer to coefficient std error array
	polytype stderror;			// Standard error of fit
	polytype rsqr;				// r-squared of fit
	polytype r;					// r of fit
	char cferr;					// Singular matrix error flag
	
	// Clipboard variables
	HGLOBAL hClipboard;			// Handle to clipboard text buffer
	LPSTR	szClipboard;		// Ptr to clipboard text string

	// Test for no data
	// Note: NULL plot filename test eliminated
	if((p_data[2]-p_data[1])<=0)
	{
		LoadString(hInst, IDS_MESSAGE_NOPHASEDATA, label_str, LABELSIZE);
		MessageBox(hwndMain, label_str,	"Stable32", MB_ICONEXCLAMATION);
		return;
	}                                                              /* end if */

	// Allocate memory for plot arrays
	if((x=(float*)malloc(((int)p_data[2]+2)*sizeof(float)))==NULL)
	{
		AllocErrorMessage();
		return;
	}
	if((y=(float*)malloc(((int)p_data[2]+2)*sizeof(float)))==NULL)
	{
		AllocErrorMessage();
		free(x);
		return;
	}

	CalcMean(p_data, &avg, FREQ_DATA);

	// This is the begining of the actual GraphiC plotting code
	// Sequence of basic calls is per page I-34 of manual:
	//	   bgnplot()            	Initializations
	//	   startplot()          	Starts graphics
	//	   font()               	Loads fonts
	//	   page()               	Sets overall picture size
	//	   heading()				Draws title
	//	   xname(), yname()		 	Draws axis labels
	//	   area2d()					Defines axis lengths
	//

	// Write log info
	WriteLog(37, p->plot_filename);

	bgnplot(1,'g',p->plot_filename);                      /* initialize plot */
	startplot(background_color);         /* start plot with background color */
	font(4,"news.fnt",'\310',"swiss.fnt",'\311',"newsgrm.fnt",'\312',
		 "simplex.fnt",'\313');                                /* load fonts */

	page(FULLPAGE);                  /* Sets the maximum allowable page size */
	heading("");    /* Blank heading allows space for title & subtitle later */
	fillfont(1);                                         /* Use filled fonts */

	// Kill the beep
	GPCSetBeepDefaults(0, 0);

	// Avoid unwanted clipping 
	UnclipPlot();
	
	// Axis labeling code
	fntchg('\310');                                              /* news.fnt */
	if(nStyle==MODERN_STYLE)                           /* Use "modern" style */
	{
		fntchg('\311');                                          /*swiss.fnt */
		upright(1);                          /* upright y-axis label numbers */
		numht((float)0.18);                           /* larger axis numbers */
		xnamht((float)0.22);                         /* larger x-axis labels */
		ynamht((float)0.22);                         /* larger y-axis labels */
	}
	color(label_color);                                        /* all labels */
	yname(p->left_y_label);                                 /* labels y-axis */
	xname(p->x_label);                                      /* labels x-axis */

	area2d((float)7.8, (float)5.3);             /* Sets the area of the plot */

	// Draw box
	color(box_color);                                  /* set box line color */
	if(p->do_box)
	{
		box();                                    /* draw box around picture */
	}                                                              /* end if */

	// Draw grid
	// The grid() function draws the major grid lines (at tics)
	// The fgrid() function draws the fine grid lines (between tics)
	// The 1st fgrid() arg is: 0=no ticks, -1=tick marks
	// The 2nd fgrid() arg is # ticks=# intervals-1
	color(grid_color);                          /* set box & grid line color */
	grid(9);                         /* draws dotted grid through tick marks */
	fgrid(-1,p->y_tic-1);        /* fine grid tick marks between major ticks */

	frame(1,1);                          /* add frame with ticks around plot */
	upright(1);                        /* causes y-axis labels to be upright */
	fntchg('\310');                                              /* news.fnt */

	// X-scale
	// Set x-axis plot scale for roundq()
	x_max=p->x_max;
	x_min=p->x_min; // Was x_min-p->x_min; until 07/19/16

	// Set the # x divisions for roundq()
	x_div=p->x_div;
	
	// Use roundq() to set xformat
	roundq(x_div, &x_min, &xste, &x_max, xformat);

	// Reset the scale limits to those actually wanted
	x_min=p->x_min;
	x_max=p->x_max;

	// Set the x-scale div size
	xste=((x_max-x_min)/p->x_div);

	// Y-scale
	// Set the y-scale max & min
	y_max=p->y_mult*(p->y_max+p->y_offset);
	y_min=p->y_mult*(p->y_min+p->y_offset);

	// Set the y-scale tic separation
	yste=((y_max-y_min)/p->y_div);
	
	// Round tic separation to avoid the dreaded 0.000000
	_snprintf(yformat, YFORMAT_SIZE, "%-1.3f", yste);
	yste=(float)atof(yformat);

	// Make sure yste is >0
	if(yste==0)
	{
		while(yste==0) // Adjust phase scale to avoid O/F
		{
			// Adjust phase scale multiplier
			p->y_mult*=10.0;
			y_max=p->y_mult*(p->y_max+p->y_offset);
			y_min=p->y_mult*(p->y_min+p->y_offset);

			// Set the y-scale tic separation
			yste=((y_max-y_min)/p->y_div);

			// Round tic separation
			_snprintf(yformat, YFORMAT_SIZE, "%-1.3f", yste);
			yste=(float)atof(yformat);

			// Change the y-axis label
			yname("NG Phase Scale");
		}
	}

	// Adjust the y-scale format to avoid equal adjacent tic labels
	if(yste>=10.0)
	{
		strlcpy(yformat, "%-1.0f", YFORMAT_SIZE);
	}
	else if(yste>=1.0)
	{
		strlcpy(yformat, "%-1.1f", YFORMAT_SIZE);
	}
	else if(yste>=0.1)
	{
		strlcpy(yformat, "%-1.2f", YFORMAT_SIZE);
	}
	else
	{
		strlcpy(yformat, "%-1.3f", YFORMAT_SIZE);
	}

	// Adjust the x-scale format to avoid equal adjacent tic labels
	// and too long labels

	if(xste>=10000.0)
	{
		strlcpy(xformat, "%-1.1e", XFORMAT_SIZE);
	}
	else if(xste>=10.0)
	{
		strlcpy(xformat, "%-1.0f", XFORMAT_SIZE);
	}
	else if(xste>=1.0)
	{
		strlcpy(xformat, "%-1.1f", XFORMAT_SIZE);
	}
	else if(xste>=0.1)
	{
		strlcpy(xformat, "%-1.2f", XFORMAT_SIZE);
	}
	else if(xste>=0.01)
	{
		strlcpy(xformat, "%-1.3f", XFORMAT_SIZE);
	}
	else
	{
		strlcpy(xformat, "%-1.4f", XFORMAT_SIZE);
		
		// With this format, can't show more than 8 tics
		if(p->x_div>8)
		{
			xste*=2;
		}
	}

	// Don't use the Graphic scale setting routine
	// This can cause the scale to ignore the user inputs
	// roundq(p->y_div, &y_min, &yste, &y_max, yformat);

	// Set plot scales
	graf(xformat, x_min, xste, x_max, yformat, y_min, yste, y_max);

	// Draw title & subtitle
	fntchg('\311');                                             /* swiss.fnt */

	color(label_color);                                   /* set label color */

	width=strwidth(p->title,(float)0.3);          /* get half-width of title */
	prtfnt((float)(4.75-width),(float)6.40,p->title,(float)0.3,0);  /* title */
	width=strwidth(p->subtitle,(float)0.15);   /* get half-width of subtitle */
	prtfnt((float)(4.75-width),(float)6.175,p->subtitle,(float)0.15,0);

	// Draw annotations
	// The putlabel() function is used for user-defined annotations.
	// This must come before any plotting - including grid lines
	// Then it is supposed to stay clean.
	// But, for user units, it should come after plot scales are set
	// It provides user messages via the plot annotations dialog box
	// The 2nd & 3rd args of putlabel() are in plot user units.
	// The 4th arg of putlabel() is char hgth in inches (for full-page).
	// The sPNote[i].nSize value is point size.  There are 72 points/inch.
	// The 5th arg of putlabel is border code: 1=border, 2=no border (strange)
	// So we get it as 2-sPNote[i].bBorder, where bBorder is ordinary BOOL flag
	// Multiline labels are OK with \n (newline, ASCII LF, dec int 10)
	// But they are NG with CR & LF as produced by an edit control.
	// So we must elim CRs from the note text string
	fntchg('\313');                                           /* simplex.fnt */
	color(grid_color);                          /* set box & grid line color */
	for(i=0; i<PNOTE_NUMNOTES; i++)
	{
		// Check if this is an active note (non-zero length)
		len=strlen(sPNote[i].szText);
		if(len)
		{
			// Allocate a temporary working buffer
			if((szTemp=(LPSTR)malloc((len+1)*sizeof(char)))==NULL)
			{
				AllocErrorMessage();
				free(x);
				free(y);
				return;
			}
			// Remove CRs from annotation text string
			// Note that we are also copying the EOS
			k=0;
			for(j=0; j<=len; j++)
			{
				if(sPNote[i].szText[j]!=13) // 13 = CR
				{
					szTemp[k]=sPNote[i].szText[j];
					k++;
				}
			}

			if(sPNote[i].bOpaque)
			// Put note into white panel to hide grid, plot, etc.
			{
				// GraphiC code from putlabel() of FNTPLT.C
				// modified to use here to determine vertices of label area
				// that actual putlabel() call uses to put note on plot
				// Input args are:
				//   char *string changed to szTemp
				//   float xpos
				//   float ypos
				//   float height = (float)(sPNote[i].nSize/72.0)
				// Local variables renamed as req'd & move to top of function
		
				 // Get size of area to make white panel for note
				usertopix((float)(sPNote[i].fX), (float)(sPNote[i].fY), 0.0,
					&xpix, &ypix);
				
				// Calc panel vertices [3] [2]
				//                  [0, 4] [1]

				// Set line height
				ydel=20*sPNote[i].nSize;	// Correct value?
				
				// Initialize indices
				j=0;
				k=0;
				
				// Find maximum width of (possibly) multiline note
				// and add vertical height for multiple lines
				for(;;)
				{
					ch=szTemp[j++];
					if(ch!='\n' && ch!='\0')
					{
						buf[k++]=szTemp[j-1];
						if(k>=NOTESIZE)				      /* Buffer overflow */
						{
							j--;
							szTemp[j]='\0';              /* Terminate string */
							continue;                 /* Process what we can */
						}
					}
					else
					{
						buf[k]='\0';
						wid=intopix(strwidth(buf,
							(float)(sPNote[i].nSize/72.0)));
						if(wid>max_wid)
						{
							max_wid=wid;
						}
						if(ch!='\0') // ch is newline
						{
							bsavfq-=ydel;
						}
						k=0;
					}

					if(ch=='\0')
					{
						// Check the last line for descenders
						// g, j, p, q, y, /, \, #, ( and )
						descend=0;
						if((strpbrk(buf, "gjpqy/\\#()"))!=NULL)
						{
							descend=4*sPNote[i].nSize; // 1/5 line height
						}
						break;
					}
				}

				// Note: No allowance made here for decenders
				tsavfq=(int)(pix_convertq*(float)(sPNote[i].nSize/72.0));
				
				// Note area panel vertices are: [3]    [2]
				//                               [0, 4] [1]
				// Lower left:
				//   x0=xpix - allow
				//   y0=ypix - allow + bsavfq - descend
				// Upper right:
				//   x1=xpix + 2*max_wid + allow
				//   y1=ypix_sav + tsavfq + allow
				// That is the region we want to apply panel to

				// Calc vertices 0 and 4
				// Note: 15 is allowance for border added by GraphiC
				pixtouser(xpix-15, ypix-15+bsavfq-descend, &xpan[0], &ypan[0]);
				xpan[4]=xpan[0];
				ypan[4]=ypan[0];
				
				// Calc vertex 3
				pixtouser(xpix-15, ypix+15+tsavfq, &xpan[3], &ypan[3]);
				
				// Calc vertex 2
				pixtouser(xpix+15+2*(max_wid), ypix+15+tsavfq, &xpan[2],
					&ypan[2]);
				
				// Calc vertex 1
				pixtouser(xpix+15+2*(max_wid),
					ypix-15+bsavfq-descend, &xpan[1],
					&ypan[1]);
				
				// Create panel with bright white background
				panel(xpan, ypan, 4, 447, FALSE); // Use 204 (red) for test
				
				// Process panel
				panproc();
			}

			// Draw annotation - use temp string w/o CRs
			putlabel(szTemp, (float)sPNote[i].fX, (float)sPNote[i].fY,
				(float)(sPNote[i].nSize/72.0), (int)(2-sPNote[i].bBorder),
				USER_UNITS);

			// Free temporary working buffer
			free(szTemp);
		}
	}

	fntchg('\310');                                              /* news.fnt */

	npts=0;
	for(i=(int)(p_data[1]+2); i<=(int)(p_data[2]+2); i++)       /* load data */
	{
		if(i==p_data[1]+2 || p_data[i] || i==p_data[2]+2)            /* gap? */
		{
			y[npts]=(float)(p->y_mult*(p_data[i]+p->y_offset));
			if(y[npts]<y_min)                        /* clip if below bottom */
			{
				y[npts]=y_min;
			}
			if(y[npts]>y_max)                           /* clip if above top */
			{
				y[npts]=y_max;
			}
		}                                                          /* end if */
		else
		{
			y[npts]=0;                                      /* keep gap zero */
		}                                                        /* end else */
		x[npts]=p->x_mult*((i-2)+p->x_offset);
		npts++;
	}                                                             /* end for */


	color(data_color);                                         /* data color */

	// Set plot line thickness
	// 0 is default, 20 is wider
	tline(p->thick);

	// Clip phase data plot
	ClipPlot();

	for(i=0; i<npts-1; i++)                               /* plot phase data */
	{
		if((i==0) || (*(y+i) && *(y+i+1)) || (i==npts-2))            /* gap? */
		{
			uline(*(x+i),*(y+i),*(x+i+1),*(y+i+1),1);
		}                                                          /* end if */
	}                                                             /* end for */

	// Unclip - probably unnecessary
	UnclipPlot();

	// Restore plot line thickness
	tline(0);

	// Draw lines
	// Note: Need error trapping for entry of NG line parameters

	if(p->do_line==PPLOT_QUAD)                              /* quadratic fit */
	{
		color(line_color);                                     /* line color */
								/* calc and plot quadratic fit to phase data */
		tau=1.0;     /* set tau=1 since basic x-axis spacing is 1 data point */

		CalcQuadraticDrift(p_data, tau, &a, &b, &c, &v);    /* quadratic fit */
		npts=0;
		for(i=(int)(p_data[1]+2); i<=(int)(p_data[2]+2); i++)
			                                      /* put fit data into array */
		{
			y[npts]=(float)(p->y_mult*((a+b*(i-1-p_data[1])
					+c*(i-1-p_data[1])*(i-1-p_data[1]))+p->y_offset));
			x[npts]=p->x_mult*((i-2)+p->x_offset);
			npts++;
		}                                                         /* end for */

		ClipPlot();
		for(i=0; i<npts-1; i++)                             /* plot fit data */
		{
			uline(*(x+i),*(y+i),*(x+i+1),*(y+i+1),1);
		}                                                         /* end for */
		UnclipPlot();

		// Sums for mean of observations p_data[]
		mean=0.0;
		for(i=0; i<npts; i++)
		{
			mean+=p_data[i+ARRAY_OFFSET];
		}
		mean/=(double)npts;

		// Sums for sst
		sst=0.0;
		for(i=0; i<npts; i++)
		{
			sst+=(p_data[i+ARRAY_OFFSET]-mean)*(p_data[i+ARRAY_OFFSET]-mean);
		}
		
		// Sums for sse
		sse=0.0;
		for(i=0; i<npts; i++)
		{
			sse+=(p_data[i+ARRAY_OFFSET]-
				(a+b*i+c*i*i))*(p_data[i+ARRAY_OFFSET]-(a+b*i+c*i*i));
		}
		
		// Calc r-squared = coefficient of determination
		// to judge goodness of fit
		// It is SSR / SST = regression sum of squares  / total sum of squares
		// Or (better for numerical reasons) 1 - SSE/SST
		// SSR = Sum (predicted value - mean)^2 = variability of modelled data
		// SST = Sum (observed value - mean)^2 = variability of observed data
		// SSE = Sum (observed - predicted value)^2
		// where mean = avgerage of observed values

		// Calc r-squared
		rsqrd=1.0-(sse/sst);

		_snprintf(label_str, LABELSIZE,
			"Quadratic Fit: x(t)=a+bt+ct[2], "
			"a=%-10.7e, b=%-10.7e, c=%-10.7e", a, b, c);
		ShortenExp(label_str);
		fntchg('\313');                                       /* simplex.fnt */
		color(annotation_color);                     /* fit annotation color */
		tmargin((float)6.655);
		if(sPPlot.do_fit)
		{
			ctline(label_str,(float)0.075);
		}
		line_flag=TRUE;

		// Write quadratic fit coefficients to clipboard
		if(TRUE) // Could control this with a flag
		{
			 // # chars to write to clipboard
			nClip=7*80;
				
			// Get memory and handle for clipboard
			hClipboard=GlobalAlloc(GMEM_DDESHARE, (DWORD)nClip);
			szClipboard=GlobalLock(hClipboard);

			// Compose clipboard text
			strlcpy(szClipboard, "File: ", nClip);
			strlcat(szClipboard, szPhaseFileTitle, nClip);
			strlcat(szClipboard, "\r\n", nClip);
			strlcat(szClipboard, "Quadratic Fit Parameters:\r\n", nClip);
			strlcat(szClipboard, "x(t)=a+bt+ct\r\n", nClip);

			// Compose fit coefficients
			_snprintf(szBuffer, sizeof(szBuffer), "a = %e\r\n", a);
			ShortenExp(szBuffer);
			strlcat(szClipboard, szBuffer, nClip);
			_snprintf(szBuffer, sizeof(szBuffer), "b = %e\r\n", b);
			ShortenExp(szBuffer);
			strlcat(szClipboard, szBuffer, nClip);
			_snprintf(szBuffer, sizeof(szBuffer), "c = %e\r\n", c);
			ShortenExp(szBuffer);
			strlcat(szClipboard, szBuffer, nClip);

			// Compose coefficient of determination
			_snprintf(szBuffer, sizeof(szBuffer), "r = %e\r\n", rsqrd);
			ShortenExp(szBuffer);
			strlcat(szClipboard, szBuffer, nClip);

			// Open clipboard, write text to it, and close clipboard
			GlobalUnlock(hClipboard);
			OpenClipboard(NULL);
			EmptyClipboard();
			SetClipboardData(CF_TEXT, hClipboard);
			CloseClipboard();
		}
	}                                                              /* end if */

	if(p->do_line==PPLOT_AVG)                                 /* average fit */
	{
		color(line_color);                                     /* line color */

		CalcMean(p_data, &avg, PHASE_DATA);                  /* calc average */

		// Draw line
		uline((float)(p->x_mult*(p_data[1]+p->x_offset)),
			(float)(p->y_mult*(avg+p->y_offset)),
			(float)(p->x_mult*(p_data[2]+p->x_offset)),
			(float)(p->y_mult*(avg+p->y_offset)), 3);

		// List average fit
		UnclipPlot();
		_snprintf(label_str, LABELSIZE,
			"1st Average Fit: x(avg)=%-10.7e", avg);
		ShortenExp(label_str);
		fntchg('\313');					  /* simplex.fnt */
		color(annotation_color);	 /* note color=black */
		tmargin((float)6.655);
		if(sPPlot.do_fit)
		{
			ctline(label_str,(float)0.075);
		}
		line_flag=TRUE;
		color(line_color);                 /* line color */
		ClipPlot();

		// Write average fit coefficients to clipboard
		if(TRUE) // Could control this with a flag
		{
			 // # chars to write to clipboard
			nClip=2*80;
				
			// Get memory and handle for clipboard
			hClipboard=GlobalAlloc(GMEM_DDESHARE, (DWORD)nClip);
			szClipboard=GlobalLock(hClipboard);

			// Compose clipboard text
			strlcpy(szClipboard, "File: ", nClip);
			strlcat(szClipboard, szPhaseFileTitle, nClip);
			strlcat(szClipboard, "\r\n", nClip);

			// Compose average
			_snprintf(szBuffer, sizeof(szBuffer), "Average = %e\r\n", avg);
			ShortenExp(szBuffer);
			strlcat(szClipboard, szBuffer, nClip);

			// Open clipboard, write text to it, and close clipboard
			GlobalUnlock(hClipboard);
			OpenClipboard(NULL);
			EmptyClipboard();
			SetClipboardData(CF_TEXT, hClipboard);
			CloseClipboard();
		}
	}

	// Polynomial fitting using Quinn-Curtis S&E function
	// S&E polynomial fit gives good results
	// but fails for orders greater than about 7
	// if set up to use floats - doubles are better
	// So the polytype is defined as double in polytype.h and Stable_w.h
	// That is necessary for better numerical dynamic range
	// Using doubles, poly fit seems OK up to order=12, so 9 S/B OK
	// Have to copy data to double array before calling PolyCurveFit()
	// and use float arrays for plotting the fit 
	if(p->do_line==PPLOT_POLY)                            /* polynominal fit */
	{
		color(line_color);                                     /* line color */

		// Calculate polynomial fit using NR svdfit() function
		// void PolyCurveFit(polytype *indvar, polytype *depvar, int numobs,
		//     int order,
		// polytype *coef, polytype *yest, polytype *resid, polytype *see,
		// polytype *coefsig, polytype *rsq, polytype *r, char *cferror)
		// Arguments (in order) are as follows:
		// *indvar = pointer to 0-based float time data vector x[]
		// of size numobs=npts
		// *depvar = pointer to 0-based float phase data vector y[]
		// of size numobs=npts
		// int numobs = # data points=npts
		// int order = polynomial order=p->order (1=linear, etc)
		// polytype *coef = pointer to 0-based float fit coefficient vector
		//     aa[] of size p->order+1
		// polytype *yest = pointer to 0-based float fit y estimate vector
		//     yest[] of size numobs=npts
		// polytype *resid = pointer to 0-based float fit y residual vector
		//     yres[] of size numobs=npts
		// polytype *see = pointer to standard error of estimate = stderror
		// polytype *coefsig = pointer to 0-based float fit coefficient
		//     std error vector cerr[] of size p->order+1
		// polytype *rsq = pointer to r-squared error of estimate = rsqr
		// polytype *r = pointer to r value of estimate = r
		// char *cferror = pointer to singular matrix error flag = cferr

		// Allocate arrays aa, yest, yres, px, py and cerr
		if((aa=(polytype*)malloc((p->order+1)*sizeof(polytype)))==NULL)
		{
			AllocErrorMessage();
			return;
		}
		if((yest=(polytype*)malloc(npts*sizeof(polytype)))==NULL)
		{
			AllocErrorMessage();
			free(aa);
			return;
		}
		if((yres=(polytype*)malloc(npts*sizeof(polytype)))==NULL)
		{
			AllocErrorMessage();
			free(aa);
			free(yest);
			return;
		}
		if((px=(polytype*)malloc(npts*sizeof(polytype)))==NULL)
		{
			AllocErrorMessage();
			free(aa);
			free(yest);
			free(yres);
			return;
		}
		if((py=(polytype*)malloc(npts*sizeof(polytype)))==NULL)
		{
			AllocErrorMessage();
			free(aa);
			free(yest);
			free(yres);
			free(px);
			return;
		}
		if((cerr=(polytype*)malloc((p->order+1)*sizeof(polytype)))==NULL)
		{
			AllocErrorMessage();
			free(aa);
			free(yest);
			free(yres);
			free(px);
			free(py);
			return;
		}

		// Convert x[] and y[] float arrays to px[] and py[] polytype=double arrays
		for(i=0; i<npts; i++)
		{
			px[i]=(polytype)x[i];
			py[i]=(polytype)y[i];
		}
		
		// Calc poly fit
		PolyCurveFit(px, py, npts, p->order, aa, yest, yres, &stderror, cerr,
			&rsqr, &r, &cferr); 

		// Free working arrays yest, and cerr
		free(yest);
		free(yres);
		free(cerr);
		
		if(!cferr)
			{
			// Put fit data into y[] array for plotting
			// y[] is float array
			// aa[] and px[] arrays are polytype=double
			for(i=0; i<npts; i++)
			{
				// Clear point
				y[i]=(float)0.0;

				// Add power of x terms up to poly order
				for(j=0; j<p->order+1; j++)
				{
					y[i]+=(float)(aa[j]*pow(px[i], j));
					// Note: Don't need px[]
					// Can just use this:
					// y[i]+=(float)(aa[j]*pow(i, j));
				}
			}
			
			// Plot poly fit data
			ClipPlot();
			for(i=0; i<npts-1; i++)                             /* plot fit data */
			{
				uline(*(x+i),*(y+i),*(x+i+1),*(y+i+1),1);
			}                                                         /* end for */
			UnclipPlot();

			// Compose fit parameters
			UnclipPlot();

			// Scale the poly fit coefficients by the y scale factor
			for(i=0; i<=p->order+1; i++)
			{
				aa[i]/=p->y_mult;
			}

			// Display fit coefficients
			switch(p->order)
			{
				case 1:
				{
					_snprintf(label_str, BIGLABELSIZE,
						"1st Order Polynomial Fit: a0=%e, a1=%e",
						aa[0], aa[1]);
					break;
				}

				case 2:
				{
					_snprintf(label_str, BIGLABELSIZE,
						"2nd Order Polynomial Fit: a0=%e, a1=%e, a2=%e",
						aa[0], aa[1], aa[2]);
					break;
				}

				case 3:
				{
					_snprintf(label_str, BIGLABELSIZE,
						"3rd Order Polynomial Fit: a0=%e, a1=%e, a2=%e, a3=%e",
						aa[0], aa[1], aa[2], aa[3]);
					break;
				}

				case 4:
				{
					_snprintf(label_str, BIGLABELSIZE,
						"4th Order Polynomial Fit: a0=%e, a1=%e, a2=%e, a3=%e, a4=%e",
						aa[0], aa[1], aa[2], aa[3], aa[4]);
					break;
				}

				case 5:
				{
					_snprintf(label_str, BIGLABELSIZE,
						"5th Order Poly Fit: a0=%7.5e, a1=%7.5e, a2=%7.5e, a3=%7.5e,"
						" a4=%7.5e, a5=%7.5e",
						aa[0], aa[1], aa[2], aa[3], aa[4], aa[5]);
					break;
				}

				case 6:
				{
					_snprintf(label_str, BIGLABELSIZE,
						"6th Order Poly Fit: a0=%6.4e, a1=%6.4e, a2=%6.4e, a3=%6.4e,"
						" a4=%6.4e, a5=%6.4e, a6=%6.4e",
						aa[0], aa[1], aa[2], aa[3], aa[4], aa[5], aa[6]);
					break;
				}

				case 7:
				{
					_snprintf(label_str, BIGLABELSIZE,
						"Poly Fit: a0=%6.4e, a1=%6.4e, a2=%6.4e, a3=%6.4e, a4=%6.4e,"
						" a5=%6.4e, a6=%6.4e, a7=%6.4e",
						aa[0], aa[1], aa[2], aa[3], aa[4], aa[5], aa[6], aa[7]);
					break;
				}

				case 8:
				{
					_snprintf(label_str, BIGLABELSIZE,
						"Poly Fit: a0=%5.3e, a1=%5.3e, a2=%5.3e, a3=%5.3e, a4=%5.3e,"
						" a5=%5.3e, a6=%5.3e, a7=%5.3e, a8=%5.3e",
						aa[0], aa[1], aa[2], aa[3], aa[4], aa[5], aa[6], aa[7], aa[8]);
					break;
				}

				case 9:
				{
					_snprintf(label_str, BIGLABELSIZE,
						"Poly Fit: a0=%5.3e, a1=%5.3e, a2=%5.3e, a3=%5.3e, a4=%5.3e,"
						" a5=%5.3e, a6=%5.3e, a7=%5.3e, a8=%5.3e, a9=%5.3e",
						aa[0], aa[1], aa[2], aa[3], aa[4], aa[5], aa[6], aa[7], aa[8], aa[9]);
					break;
				}
			}
			ShortenExp(label_str);
			fntchg('\313');					  /* simplex.fnt */
			color(annotation_color);	 /* note color=black */
			tmargin((float)6.655);
			
			// Write polynomial fit coefficients to clipboard
			if(TRUE) // Could control this with a flag
			{
				 // # chars to write to clipboard
				nClip=(7+p->order)*80;
				
				// Get memory and handle for clipboard
				hClipboard=GlobalAlloc(GMEM_DDESHARE, (DWORD)nClip);
				szClipboard=GlobalLock(hClipboard);

				// Compose clipboard text
				strlcpy(szClipboard, "File: ", nClip);
				strlcat(szClipboard, szPhaseFileTitle, nClip);
				strlcat(szClipboard, "\r\n", nClip);
				strlcat(szClipboard, "Polynomial Fit Parameters:\r\n", nClip);
				_snprintf(szBuffer, sizeof(szBuffer), "Order = %d\r\n", p->order);
				strlcat(szClipboard, szBuffer, nClip);
				strlcat(szClipboard, "x(t)={Sum over i from 0 to order} a[i]t^i\r\n",
					nClip);
				strlcat(szClipboard, "where t = Data point #\r\n", nClip);

				// Compose fit coefficients
				for(i=0; i<p->order+1; i++)
				{
					_snprintf(szBuffer, sizeof(szBuffer), "a[%d] = %e\r\n", i, aa[i]);
					ShortenExp(szBuffer);
					strlcat(szClipboard, szBuffer, nClip);
				}

				// Compose coefficient of determination
				_snprintf(szBuffer, sizeof(szBuffer), "r = %e\r\n", rsqr);
				ShortenExp(szBuffer);
				strlcat(szClipboard, szBuffer, nClip);

				// Open clipboard, write text to it, and close clipboard
				GlobalUnlock(hClipboard);
				OpenClipboard(NULL);
				EmptyClipboard();
				SetClipboardData(CF_TEXT, hClipboard);
				CloseClipboard();
			}
			
			// Free coefficient array aa
			free(aa);

			// Free polytype data arrays
			free(px);
			free(py);

			// Show fit parameters
			if(sPPlot.do_fit)
			{
				if(p->order<4) // order 1-3
				{
					ctline(label_str,(float)0.075);
				}
				else if(p->order<6) // order 4-5
				{
					ctline(label_str,(float)0.070);
				}
				else if(p->order<8) // order 6-7
				{
					ctline(label_str,(float)0.065);
				}
				else // order 8-9
				{
					ctline(label_str,(float)0.060);
				}
			}
		}
		else // Fit failed
		{
			fntchg('\313');					  /* simplex.fnt */
			color(annotation_color);	 /* note color=black */
			tmargin((float)6.655);
			ctline("Polynomial fit failed - try lower order",(float)0.075);
		}

		line_flag=TRUE;
		color(line_color);                 /* line color */
		ClipPlot();
	}

	if(p->do_line==PPLOT_FUNC)            /* general non-linear function fit */
	{
		// Get function expression
		// Note: The additional copy of this string may not be necessary
		// But this allows it to be retained after GraphiC editing
		strlcpy(szFunction, p->function, sizeof(szFunction));
		
		// Function has nparam parameters
		// and each one has a corresponding p[j] value
		// where j=0 to nparam-1
		// Each t corresponds to a y[] index value i
		// where i=0 to npts-1
		// The operators +,-,*,/,^ and ()'s are retained as is
		// as are the math functions like exp() & sin()
		// To evaluate function, first set value of parameters and t
		// and then use same symbolic expression
		
		color(line_color);                                     /* line color */

		// Determine # function parameters (max=NUMPARAMS=10)
		// Scan szFunction for chars between a to j
		// not followed by an alphabetic character
		// or a left parenthesis (indicating end of math function name)
		// Note: This not already done in PhasePlotDlgProc()
		// unless FuncFitDlgProc() was called
		nparam=0;
		for(i=0; i<NUMPARAMS; i++)
		{
			// Look for a character between a and j
			if((ptr=strchr(szFunction, 'a'+i)))
			{
				// Check if the next character is non-alphabetic
				if((isalpha(*(ptr+1)))==0)
				{
					// Check if the next character is not a left parenthesis
					if((*(ptr+1)!='('))
					{
						nparam++;
					}
				}
			}
		}

		// Set # fit parameters in struct member
		sPPlot.num=nparam;
	
		// Allocate aa[], px[] and py[] arrays (polytype is double)
		if((aa=(polytype*)malloc((nparam)*sizeof(polytype)))==NULL)
		{
			AllocErrorMessage();
			return;
		}
		if((px=(polytype*)malloc(npts*sizeof(polytype)))==NULL)
		{
			AllocErrorMessage();
			free(aa);
			return;
		}
		if((py=(polytype*)malloc(npts*sizeof(polytype)))==NULL)
		{
			AllocErrorMessage();
			free(aa);
			free(px);
			return;
		}

		// Put measured data from y[] into py[]
		// This converts float y[] to polytype=double py[] array
		// Unscale the y[] data as it is being transferred
		// Note: An alternative would be to get it directly from the
		// main fPhaseData array
		for(i=0; i<npts; i++)
		{
			py[i]=(polytype)((y[i]-p->y_offset)/p->y_mult);
		}
		
		// Put initial parameter values into aa[]
		// Note that these are in unscaled phase data units
		// with t as point #
		for(i=0; i<nparam; i++)
		{
			aa[i]=sPPlot.param[i];
		}

		// Do a trial evaluation to verify valid expression
		// Set the parameter values
		// They must be in alphabetical order without any gaps
		for(i=0; i<nparam; i++)
		{
			szBuffer[0]='a'+i;
			szBuffer[1]='\0';
			SetValue(szBuffer, &aa[i]);
		}
		
		// Evaluate expression
		val=0.0;
		SetValue("t", &val);
		i=Evaluate(szFunction, &val, &flag );

		// Check for error
		if(i!=E_OK)
		{
			//	E_OK           0        /* Successful evaluation
			//	E_SYNTAX       1        /* Syntax error
			//	E_UNBALAN      2        /* Unbalanced parenthesis
			//	E_DIVZERO      3        /* Attempted division by zero
			//	E_UNKNOWN      4        /* Reference to unknown variable
			//	E_MAXVARS      5        /* Maximum variables exceeded
			//	E_BADFUNC      6        /* Unrecognised function
			//	E_NUMARGS      7        /* Wrong number of arguments to funtion
			//	E_NOARG        8        /* Missing an argument to a funtion
			//	E_EMPTY        9        /* Empty expression

			switch(i)
			{
				case E_SYNTAX:
				{
					strlcpy(szBuffer, ErrMsgs[i-1], sizeof(szBuffer));
					strlcat(szBuffer, "\nCheck expression syntax\n", sizeof(szBuffer));
					MessageBox(hDialog, szBuffer, "Phase Data Plot Function Fit Error",
						MB_ICONEXCLAMATION);
				}
				break;

				case E_UNBALAN:
				{
					strlcpy(szBuffer, ErrMsgs[i-1], sizeof(szBuffer));
					strlcat(szBuffer, "\nCheck for parenthesis balance\n", sizeof(szBuffer));
					MessageBox(hDialog, szBuffer, "Phase Data Plot Function Fit Error",
						MB_ICONEXCLAMATION);
				}
				break;

				case E_DIVZERO:
				{
					strlcpy(szBuffer, ErrMsgs[i-1], sizeof(szBuffer));
					strlcat(szBuffer, "\nCheck for divide by zero\n", sizeof(szBuffer));
					MessageBox(hDialog, szBuffer, "Phase Data Plot Function Fit Error",
						MB_ICONEXCLAMATION);
				}
				break;

				case E_UNKNOWN:
				{
					strlcpy(szBuffer, ErrMsgs[i-1], sizeof(szBuffer));
					strlcat(szBuffer, "\nCheck for unallowed variable\n", sizeof(szBuffer));
					strlcat(szBuffer, "or variable without following operator\n", sizeof(szBuffer));
					MessageBox(hDialog, szBuffer, "Phase Data Plot Function Fit Error",
						MB_ICONEXCLAMATION);
				}
				break;

				case E_MAXVARS:
				{
					strlcpy(szBuffer, ErrMsgs[i-1], sizeof(szBuffer));
					strlcat(szBuffer, "\nExpression too complex\n", sizeof(szBuffer));
					MessageBox(hDialog, szBuffer, "Phase Data Plot Function Fit Error",
						MB_ICONEXCLAMATION);
				}
				break;

				case E_BADFUNC:
				{
					strlcpy(szBuffer, ErrMsgs[i-1], sizeof(szBuffer));
					strlcat(szBuffer, "\nCheck function name\n", sizeof(szBuffer));
					strlcat(szBuffer, "Allowable functions are:\n", sizeof(szBuffer));
					strlcat(szBuffer, "sin, cos, tan, asin, acos, atan, sinh, cosh, tanh, \n",
						sizeof(szBuffer));
					strlcat(szBuffer, "exp, log, log10, sqrt, floor, ceil, abs, and hypot",
						sizeof(szBuffer));
					MessageBox(hDialog, szBuffer, "Phase Data Plot Function Fit Error",
						MB_ICONEXCLAMATION);
				}
				break;

				case E_NUMARGS:
				{
					strlcpy(szBuffer, ErrMsgs[i-1], sizeof(szBuffer));
					strlcat(szBuffer, "\nCheck # of function arguments", sizeof(szBuffer));
					MessageBox(hDialog, szBuffer, "Phase Data Plot Function Fit Error",
						MB_ICONEXCLAMATION);
				}
				break;

				case E_NOARG:
				{
					strlcpy(szBuffer, ErrMsgs[i-1], sizeof(szBuffer));
					strlcat(szBuffer, "\nEnter missing function argument(s)", sizeof(szBuffer));
					MessageBox(hDialog, szBuffer, "Phase Data Plot Function Fit Error",
						MB_ICONEXCLAMATION);
				}
				break;

				case E_EMPTY:
				{
					strlcpy(szBuffer, ErrMsgs[i-1], sizeof(szBuffer));
					strlcat(szBuffer, "\nEnter function expression", sizeof(szBuffer));
					MessageBox(hDialog, szBuffer, "Phase Data Plot Function Fit Error",
						MB_ICONEXCLAMATION);
				}
				break;
			}

			// Free parameter array aa
			free(aa);

			// Free fit data array
			free(px);
			free(py);

			#if(1) // New code 11/23/11
			// Process bCmdM command to copy plot metafile to clipboard
			if(bCmdM)
			{
				// Send copy metafile message to GraphiC
				PostMessage(hGPC, WM_COMMAND,
					GET_WM_COMMAND_MPS(IDM_COPYMETA, 0, 0));
			}

			// Process bCmdT command to print plot
			if(bCmdT)
			{
				// Send print message to GraphiC
				PostMessage(hGPC, WM_COMMAND,
					GET_WM_COMMAND_MPS(IDM_PRINT, 0, 0));
			}

			// Process bCmdX command to close plot
			if(bCmdX)
			{
				// Show the plot briefly
				Sleep(1000);

				// Close plot and plot dialog box
				PostMessage(hPlot, WM_CLOSE, (WPARAM)0, (LPARAM)0);
				PostMessage(hPlotBox, WM_CLOSE, (WPARAM)0, (LPARAM)0);
			}
			#endif

			endplot();				/* finish plot and wait for instructions */
												/* to exit or draw next plot */
										/* resets file pointers and defaults */
			// Free plot arrays
			free(x);
			free(y);

			stopplot();    /* close files, return to text mode, exit program */
			return;
		}
		else // OK - Proceed with function fit
		{		
			// Sums for mean of observations y[]
			mean=0.0;
			for(i=0; i<npts; i++)
			{
				mean+=py[i];
			}
			mean/=(double)npts;

			// Sums for sst
			sst=0.0;
			for(i=0; i<npts; i++)
			{
				sst+=(py[i]-mean)*(py[i]-mean);
			}

			
			// Code for LM function fit using lmmin
 			// Settings for lmmin fit
			lm_initialize_control(&control);
			data.user_func=fit_function;
			data.user_t=px;
			data.user_y=py;

			// Perform lmmin nonlinear function fit:
			//
			// Uses lm_mininize with expanded signature as top-level function
			// to pass function expression string:
			//     void lm_minimize(int m_dat, int n_par, double *par,
			//         lm_evaluate_ftype * lm_evaluate, lm_print_ftype * printout,
			//         void *data, lm_control_type * control, char *expression)
			// where:
			//     int m_dat is # observations (data points)
			//     int n_par is # fit parameters
			//     double *par is parameter array of size n_par
			//     lm_evaluate_ftype *evaluate is pointer to function eval function
			//     lm_print_ftype *printout is printout function
			//     void *data is pointer to data structure
			//     lm_control_type *control is pointer to control structure
			//      char *expression is function expression string to be fitted
			//
			// Calls lm_evaluate with expanded signature:
			// void lm_evaluate(int m_par, double *par, int m_dat, double *fvec,
			//     void *data, char *e, int *info)
			//
			// Calls print_function(), a customized version of lm_print_default():
			// void print_function(int n_par, double *par, int m_dat, double *fvec,
		    //     void *data, int iflag, int iter, int nfev)
			// where:
			//		m_dat=npts;
			//		n_par=nparam;
			//		par=aa
			// Must put nparam into global variable int nGlobalNumParam
			// and szFunction address into global pGlobalExpression
			nGlobalNumParam=nparam;
			pGlobalExpression=&szFunction[0];

			// Fill the px[] array with "time" values
			for(i=0; i<npts; i++)
			{
				px[i]=(polytype)i;
			}

			// Perform the fit
			lm_minimize(npts, nparam, aa, lm_evaluate, printout,
				&data, &control);

			// Print results:
			// printf("status: %s after %d evaluations\n",
			//		lm_shortmsg[control.info], control.nfev);

			// Put fit data into y[] array for plotting
			// y[] is float array
			// aa[] and px[] arrays are polytype=double
			
			// Evaluate general algebraic expression for plot
			lmfunc(aa, py, nparam, npts, szFunction);
			
			// Sums for ssr
			ssr=0.0;
			for(i=0; i<npts; i++)
			{
				ssr+=(py[i]-mean)*(py[i]-mean);
			}
			
			// Calc r-squared = coefficient of determination to judge goodness of fit
			// It is SS(R) / SS(T) = regression sum of squares  / total sum of squares
			// SS(R) = Sum (predicted value - mean)^2
			// SS(T) = Sum (observed value - mean)^2
			// where mean = avgerage of observed values
			rsqrd=ssr/sst;

			// Put scaled values into float plot array
			for(i=0; i<npts; i++)
			{
				y[i]=(float)((py[i]*p->y_mult)+p->y_offset);
			}
				
			// Plot function fit data
			ClipPlot();
			for(i=0; i<npts-1; i++)                             /* plot function */
			{
				uline(*(x+i),*(y+i),*(x+i+1),*(y+i+1),1);
			}                                                         /* end for */
			UnclipPlot();

			// New code 07/11/08 to remove fit from phase data
			// Have fit function evaluated at npts in double py[]
			// Data is npts in f_data[] array
			if(p->remove)
			{
                // Create tab to save previous data if requested
				if(bTabs && bTabChange)
				{
					CreateTab();
				}
						
				j=0;
				// Loop through phase data
				for(i=(int)(p_data[1]+2); i<=(int)(p_data[2]+2); i++)
																 /* load data into array */
				{
					if(p_data[i])                                           /* skip gaps */
					{
						p_data[i]-=py[j];                  /* remove fit from phase data */
					}                                                          /* end if */
					j++;                                    /* increment fit array index */
				}                                                             /* end for */
            
				// Set data changed flags
				bPhaseDataChanged=TRUE;
				bPhaseDataUnsaved=TRUE;
				sPPlot.new_file=TRUE;
				bPhaseScaleChanged=TRUE;
				bPhaseRedraw=TRUE;

				// Increment filename
				if(bIncExtension)
				{
					IncExtension(szFile, PHASE_DATA);
					IncExtension(szFileTitle, PHASE_DATA);
					IncExtension(szPhaseFile, PHASE_DATA);
					IncExtension(szPhaseFileTitle, PHASE_DATA);
					SetWindowText(hwndPhaseFilename, szFileTitle);
				}
				
				// Force new PSD plot scale
				sPSPlot.y_tic=0;

				// Redraw status plots from new data
				UpdateStatusBar(hwndMain, NEW_DATA);

				// Reset redraw flag
				bPhaseRedraw=FALSE;

				// Clear plot lines
				ClearLines();

				// Clear synch flag
				bSynch=FALSE;

				// Clear remove fit checkbox state
				sPPlot.remove=FALSE;

				// Write log file
				_snprintf(szLog, sizeof(szBuffer), "x(t)=%s, ", szFunction);
				for(i=0; i<nparam; i++)
				{
					_snprintf(szBuffer, sizeof(szBuffer), " =%e", aa[i]);
					szBuffer[0]='a'+i; // Put param letter into string
					strncat(szLog, szBuffer, sizeof(szBuffer));
					if(i<nparam-1) // Add comma and space if not last param
					{
						strncat(szLog, ", ", sizeof(szBuffer));
					}
				}
				WriteLog(80, szLog);
			}

			// Write function fit coefficients to clipboard
			if(TRUE) // Could control this with a flag
			{
				 // # chars to write to clipboard
				nClip=(7+p->order)*80;
					
				// Get memory and handle for clipboard
				hClipboard=GlobalAlloc(GMEM_DDESHARE, (DWORD)nClip);
				szClipboard=GlobalLock(hClipboard);

				// Compose clipboard text
				strlcpy(szClipboard, "File: ", nClip);
				strlcat(szClipboard, szPhaseFileTitle, nClip);
				strlcat(szClipboard, "\r\n", nClip);
				strlcat(szClipboard, "Function: x(t)=", nClip);
				strlcat(szClipboard, szFunction, nClip);
				strlcat(szClipboard, "\r\n", nClip);
				strlcat(szClipboard, "Fit Parameters:\r\n", nClip);

				// Compose fit parameters
				for(i=0; i<nparam; i++)
				{
					_snprintf(szBuffer, sizeof(szBuffer), "%c = %e\r\n", 'a'+i, aa[i]);
					ShortenExp(szBuffer);
					strlcat(szClipboard, szBuffer, nClip);
				}

				// Add time note
				strlcat(szClipboard, "t = Data point #\r\n", nClip);

				// Show coefficient of determination
				_snprintf(szBuffer, sizeof(szBuffer), "r = %e\r\n", rsqrd);
				ShortenExp(szBuffer);
				strlcat(szClipboard, szBuffer, nClip);

				// Open clipboard, write text to it, and close clipboard
				GlobalUnlock(hClipboard);
				OpenClipboard(NULL);
				EmptyClipboard();
				SetClipboardData(CF_TEXT, hClipboard);
				CloseClipboard();
			}
				
			// Compose plot label for fit parameters
			// Note: ^ is not a valid character for GraphiC label
			// Need to put a @ in fromt of it
			// Or (better) surround exponent with [ and ]

			while(ptr=strchr(szFunction, '^'))
			{
				// Replace ^ with [
				*ptr='[';

				// Find end of exponent
				ptr1=ptr+1;
				while(isdigit(*ptr1))
				{
					ptr1++;
				}

				// ptr1 now points to next character after exponent
				// Move this and all following characters up one space
				// Get length of string (not including EOS)
				len=strlen(szFunction);
				// Set ptr2 to 1 space past EOS
				ptr2=&szFunction[len+1];
				// Move characters up 1 space
				while(ptr2>ptr1)
				{
					*ptr2=*(ptr2-1);
					ptr2--;
				}

				// Make character at ptr1 a ]
				*ptr1=']';
			}

			// Note: We might want to remove the *'s
			// But can we remove them all?
			
			strlcpy(label_str, "Function Fit: x(t)=", BIGLABELSIZE);
			strlcat(label_str, szFunction, BIGLABELSIZE);
			strlcat(label_str, ", ", BIGLABELSIZE);

			for(i=0; i<nparam; i++)
			{
				_snprintf(szBuffer, BUFFER_SIZE, " %c=%e.", 'a'+i, aa[i]);
				strlcat(label_str, szBuffer, BIGLABELSIZE);
			}

			// Display function expression and fit coefficients
			// Show fit parameters if do_fit flag set
			if(sPPlot.do_fit)
			{
				ShortenExp(label_str);
				fntchg('\313');					  /* simplex.fnt */
				color(annotation_color);	 /* note color=black */
				tmargin((float)6.655);
				if(nparam<4) // 1-3 params
				{
						ctline(label_str,(float)0.075);
				}
				else if(nparam<6) // 4-5 params
				{
						ctline(label_str,(float)0.070);
				}
				else if(nparam<8)// 6-7 params
				{
						ctline(label_str,(float)0.065);
				}
				else // 8-9 params
				{
						ctline(label_str,(float)0.060);
				}
			}

			// Free parameter array aa
			free(aa);

			// Free fit data array
			free(px);
			free(py);
		}
	}

	{
		color(line_color);                                     /* line color */
		save_start=(float)p_data[1];                  /* save starting point */
		save_end=(float)p_data[2];                      /* save ending point */

		// Clip lines
		ClipPlot();

		for(i=0; i<PLINE_NUMLINES; i++)
		{
			switch(sPLine[i].nLineType)
			{
				case PLINE_NONE:                                  /* no line */
				{
					break;
				}

				case PLINE_END:                    /* line between endpoints */
				{
					if( (sPLine[i].fXStart>0)                       &&
						(sPLine[i].fXEnd>=sPLine[i].fXStart)        &&
						((sPLine[i].fXEnd-sPLine[i].fXStart)<=npts) )
					{

					p_data[1]=sPLine[i].fXStart;
					p_data[2]=sPLine[i].fXEnd;

					// Draw line
					uline((float)(p->x_mult*(p_data[1]+p->x_offset)),
						(float)(p->y_mult*(sPLine[i].fYStart+p->y_offset)),
						(float)(p->x_mult*(p_data[2]+p->x_offset)),
						(float)(p->y_mult*(sPLine[i].fYEnd+p->y_offset)), 3);
					}
					break;
				}

				// PLINE_LIN not activated until 07/24/10
				case PLINE_LIN:                           /* regression line */
				{
					if( (sPLine[i].fXStart>0)                       &&
						(sPLine[i].fXEnd>=sPLine[i].fXStart)        &&
						((sPLine[i].fXEnd-sPLine[i].fXStart)<=npts) )
					{
						p_data[1]=sPLine[i].fXStart;
						p_data[2]=sPLine[i].fXEnd;

						CalcLinFreqDrift(p_data, &intercept, &slope, &v);
															   /* calc drift */
						// Draw line
						uline((float)(p->x_mult*(p_data[1]+p->x_offset)),
							(float)(p->y_mult*((intercept+(p_data[1] *
							slope))+p->y_offset)),
							(float)(p->x_mult*(p_data[2]+p->x_offset)),
							(float)(p->y_mult*((intercept+(p_data[2] *
							slope))+p->y_offset)), 3);

						if(!line_flag)           /* can list only 1 line fit */
						{
							UnclipPlot();
							_snprintf(label_str, LABELSIZE,
							"1st Linear Fit: y(t)=a+bt, "
							"Intercept=a=%-10.7e, Slope=b=%-10.7e",
							intercept,slope);
							ShortenExp(label_str);
							fntchg('\313');                   /* simplex.fnt */
							color(annotation_color);     /* annotation color */
							tmargin((float)6.655);
							if(sPPlot.do_fit)
							{
								ctline(label_str,(float)0.075);
							}
							line_flag=TRUE;
							color(line_color);                 /* line color */
							ClipPlot();
						}
					}
					break;
				}

				case PLINE_QUAD:                            /* quadratic fit */
				{
					if( (sPLine[i].fXStart>0)                       &&
						(sPLine[i].fXEnd>=sPLine[i].fXStart)        &&
						((sPLine[i].fXEnd-sPLine[i].fXStart)<=npts) )
					{
						p_data[1]=sPLine[i].fXStart;
						p_data[2]=sPLine[i].fXEnd;

						/* set tau=1 since x-axis spacing is 1 data point */
						tau=1;

						CalcQuadraticDrift(p_data, tau, &a, &b, &c, &v);

						npts=(int)(p_data[2]-p_data[1]+1);
						for(j=0; j<=npts; j++)
						{
							y[j]=
								(float)((a+b*(j+1)+c*(j+1)*(j+1))+p->y_offset);
							y[j]*=p->y_mult;
							x[j]=
								(float)(p->x_mult*((p_data[1]+j)+p->x_offset));
						}                                         /* end for */

						for(j=0; j<npts-1; j++)             /* plot fit data */
						{
							// Draw line
							uline(*(x+j), *(y+j), *(x+j+1), *(y+j+1), 1);
						}                                         /* end for */

						if(!line_flag)           /* can list only 1 line fit */
						{
							UnclipPlot();
							_snprintf(label_str, LABELSIZE,
							"1st Curve Fit: x(t)=a+bt+ct[2], "
							"a=%-10.7e, b=%-10.7e, c=%-10.7e", a, b, c);
							ShortenExp(label_str);
							fntchg('\313');                   /* simplex.fnt */
							color(annotation_color);     /* annotation color */
							tmargin((float)6.655);
							if(sPPlot.do_fit)
							{
								ctline(label_str,(float)0.075);
							}
							line_flag=TRUE;
							color(line_color);                 /* line color */
							ClipPlot();
						}
					}
					break;
				}
				case PLINE_AVG:                    /* horizontal line at avg */
				{
					if( (sPLine[i].fXStart>0)                       &&
						(sPLine[i].fXEnd>=sPLine[i].fXStart)        &&
						((sPLine[i].fXEnd-sPLine[i].fXStart)<=npts) )
					{
						p_data[1]=sPLine[i].fXStart;
						p_data[2]=sPLine[i].fXEnd;

						CalcMean(p_data, &avg, PHASE_DATA);  /* calc average */

						// Draw line
						uline((float)(p->x_mult*(p_data[1]+p->x_offset)),
							(float)(p->y_mult*(avg+p->y_offset)),
							(float)(p->x_mult*(p_data[2]+p->x_offset)),
							(float)(p->y_mult*(avg+p->y_offset)), 3);

						// List average fit
						if(!line_flag)			 /* can list only 1 line fit */
						{
							UnclipPlot();
							_snprintf(label_str, LABELSIZE,
							"1st Average Fit: x(avg)=%-10.7e", avg);
							ShortenExp(label_str);
							fntchg('\313');					  /* simplex.fnt */
							color(annotation_color);     /* note color=black */
							tmargin((float)6.655);
							if(sPPlot.do_fit)
							{
								ctline(label_str,(float)0.075);
							}
							line_flag=TRUE;
							color(line_color);                 /* line color */
							ClipPlot();
						}
					}
					break;
				}
				case PLINE_MARK:                     /* vertical marker line */
				{
					if( (sPLine[i].fXStart>0) &&
						((sPLine[i].fXEnd-sPLine[i].fXStart)<=npts) )
					{
						p_data[1]=sPLine[i].fXStart;
						p_data[2]=sPLine[i].fXStart;

						// Draw line
						uline((float)(p->x_mult*(p_data[1]+p->x_offset)),
							(float)(p->y_mult*(p->y_min+p->y_offset)),
							(float)(p->x_mult*(p_data[2]+p->x_offset)),
							(float)(p->y_mult*(p->y_max+p->y_offset)), 3);
					}
					break;
				}
			}                                                  /* end switch */
			// Unclip lines - probably unnecessary
			UnclipPlot();
		}                                                         /* end for */
		p_data[1]=save_start;                      /* restore starting point */
		p_data[2]=save_end;                          /* restore ending point */
	}                                                              /* end if */

	fntchg('\313');                                           /* simplex.fnt */
	color(annotation_color);                       /* annotation color=black */

	// Write date
	if(p->do_date)
	{
		Dateline(1, 1, 1);                   /* put date & file info on plot */
	}                                                              /* end if */

	// Display message box
	// Locations are x, y in pixels, origin at bottom left, 8192 x 6266 space
	// Find half length of message box in pixels
	lgth=(H_MARGIN+strwidtq(p->message_str, CHAR_HGTH));

	// Write message
	if(p->message_str[0]!='\0')         /* don't display a blank message box */
	{
		switch(p->position)
		{
			case MSG_TOP_LEFT:            /* message box at top left of plot */
			{
				MsgBox(300,4400,p->message_str);
				break;
			}                                                    /* end case */
			case MSG_MID_LEFT:         /* message box at middle left of plot */
			{
				MsgBox(300,2270,p->message_str);
				break;
			}                                                    /* end case */
			case MSG_BOT_LEFT:         /* message box at bottom left of plot */
			{
				MsgBox(300,200,p->message_str);
				break;
			}                                                    /* end case */
			case MSG_TOP_CENTER:        /* message box at top center of plot */
			{
				MsgBox(3470-lgth,4400, p->message_str);
				break;
			}                                                    /* end case */
			case MSG_MID_CENTER:     /* message box at middle center of plot */
			{
				MsgBox(3470-lgth,2270,p->message_str);
				break;
			}                                                    /* end case */
			case MSG_BOT_CENTER:     /* message box at bottom center of plot */
			{
				MsgBox(3470-lgth,200,p->message_str);
				break;
			}                                                    /* end case */
			case MSG_TOP_RIGHT:          /* message box at top right of plot */
			{
				MsgBox(6400-2*lgth,4400,p->message_str);
				break;
			}                                                    /* end case */
			case MSG_MID_RIGHT:       /* message box at middle right of plot */
			{
				MsgBox(6400-2*lgth,2270,p->message_str);
				break;
			}                                                    /* end case */
			case MSG_BOT_RIGHT:       /* message box at bottom right of plot */
			{
				MsgBox(6400-2*lgth,200,p->message_str);
				break;
			}                                                    /* end case */
		}                                                      /* end switch */
	}

	// Insert plot if bDoPhasePlotInsert is set
	if(bDoPhasePlotInsert)
	{
		// Phase plot insert filename is szPhasePlotInsertFile
		// Try to open it
		if((file=fopen(szPhasePlotInsertFile, "r"))!=NULL)
		{
			// Immediately release file pointer
			fclose(file);

			// Insert data plot at bottom left of sigma plot
			// Note:  This must be a tkf file or this will fail
			InsertPlot(300, 200, szPhasePlotInsertFile);

		}
	}

	// Write label
	if(bPlotLabel)
	{
		UnclipPlot();
		color(annotation_color);                         /* annotation color */
		width=(float)intopix(strwidth(szPlotLabel, (float)0.05));
		putlabel(szPlotLabel, 8192-2*(width+20), 20, (float)0.05, 0,
			PIXEL_UNITS);
	}

	// Activate mouse cursor
	if(p->do_mouse)
	{
		// Allocate memory for x and y point arrays
		fx=(float*)gpcalloc(64, sizeof(float));
		fy=(float*)gpcalloc(64, sizeof(float));

		curson(0, 0, &fx, &fy, &find);                /* turn on mouse cursor*/

		// Free memory - this assumes that point info isn't needed
		gpcfree((void**)&fx);
		gpcfree((void**)&fy);
	}                                                              /* end if */

	rightax(0);

	// Avoid unwanted clipping 
	UnclipPlot();

	#ifdef DEMO_VERSION
	// Add watermark for demo version
	// Get plot size in pixels
	usertopix(x_max, y_max, 0.0, &x_pix_max, &y_pix_max);
	usertopix(x_min, y_min, 0.0, &x_pix_min, &y_pix_min);
	x_pix=x_pix_max-x_pix_min;
	y_pix=y_pix_max-y_pix_min;
	// Select hatched swiss font
	fntchg('\311');                                              /* news.fnt */
	fontfill(2, 230, 0);
	// Display watermark
	pltfnt((float)x_min, (float)y_min, "Stable32 Demo Version", (float)0.6,
		(int)(180*atan2((double)y_pix, (double)x_pix)/PI));
	#endif

	#ifdef VITSAS_VER
	// Add watermark for V-ITSAS version
	color(227);
	tmargin((float)0.15);
	ltline(" Stable32 V-ITSAS", (float)0.12);
	tmargin((float)0.15);
	rtline("Evaluation Version ", (float)0.12);
	#endif

	#if(1) // New code 11/23/11
	// Process bCmdM command to copy plot metafile to clipboard
	if(bCmdM)
	{
		// Send copy metafile message to GraphiC
		PostMessage(hGPC, WM_COMMAND,
			GET_WM_COMMAND_MPS(IDM_COPYMETA, 0, 0));
	}

	// Process bCmdT command to print plot
	if(bCmdT)
	{
		// Send print message to GraphiC
		PostMessage(hGPC, WM_COMMAND,
			GET_WM_COMMAND_MPS(IDM_PRINT, 0, 0));
	}

	// Process bCmdX command to close plot
	if(bCmdX)
	{
		// Show the plot briefly
		Sleep(1000);

		// Close plot and plot dialog box
		PostMessage(hPlot, WM_CLOSE, (WPARAM)0, (LPARAM)0);
		PostMessage(hPlotBox, WM_CLOSE, (WPARAM)0, (LPARAM)0);
	}
	#endif

	endplot();
									/* finish plot and wait for instructions */
												/* to exit or draw next plot */
										/* resets file pointers and defaults */

	// Free plot arrays
	free(x);
	free(y);

	stopplot();            /* close files, return to text mode, exit program */
}
#endif

/*****************************************************************************/
/*                                                                           */
/*								MsgBox()                                     */
/*                                                                           */
/*		Function to write message box on plot                                */
/*      Parameters:                                                          */
/*			x = lower left box x location in pixels                          */
/*			y = lower left box y location in pixels                          */
/*      	message_str = message string to be written on plot               */
/*		Screen has 4096 x 3120 pixels                                        */
/*      Bottom left corner is at (x,y) = (0,0)                               */
/*      Top right corner is at (x,y) = (4095,3119)                           */
/*		Character height is 64 pixels                                        */
/*		Vertical margin is 30 pixels                                         */
/*		Horizontal margin is 40 pixels                                       */
/*		Panel color 447 (white) prints OK                                    */
/*		Returns nothing (void)                                               */
/*                                                                           */
/*		Revision record:                                                     */
/*			06/30/96	Adapted from message_box() of Stable/DOS             */
/*			07/08/96	Rewritten for new panel filling functions            */
/*			10/26/96	Debugged - added pixtouser() usage - now seems AOK   */
/*                                                                           */
/*****************************************************************************/

void WINAPI MsgBox( int x, int y, char *message_str)
{
	// Local variables
	int lgth;                                     /* length of box in pixels */
	int hgth=CHAR_HGTH+2*V_MARGIN;        /* height of message box in pixels */
	int i;                                                          /* index */
	float *xpan;                                /* pointer to x vertex array */
	float *ypan;                                /* pointer to y vertex array */

	// Start of code
	// Allocate memory for x and y vertex arrays which are in user plot units
	if((xpan=(float*)malloc((NUM_SIDES+1)*sizeof(float)))==NULL)
	{
		AllocErrorMessage();
		return;
	}

	if((ypan=(float*)malloc((NUM_SIDES+1)*sizeof(float)))==NULL)
	{
		AllocErrorMessage();
		free(xpan);
		return;
	}

	// Shift pixel location wrt physical origin
	x+=xphysorq;
	y+=yphysorq;

	// Find length of message box in pixels
	lgth=2*(H_MARGIN+strwidtq(message_str, CHAR_HGTH));
	// Note: Last arg now pixels, not mult factor

	// Load box vertices into array with user units
	// pixtouser() converts pixel units to user units
	// Vertices are as follows: [3  ]    [2  ]
	//                          [0,4]    [1  ]
	pixtouser(x, y, xpan, ypan);
	pixtouser(x+lgth, y, xpan+1, ypan+1);
	pixtouser(x+lgth, y+hgth, xpan+2, ypan+2);
	xpan[3]=xpan[0];
	ypan[3]=ypan[2];
	xpan[4]=xpan[0];             /* include these points to complete the box */
	ypan[4]=ypan[0];

	// Define panel area as bright white panel fill w/o border
	// Panel uses user units
	panel(xpan, ypan, NUM_SIDES, PAN_COLOR, FALSE);

	// Process panel
	panproc();

	// Draw border - do it this way so it will print OK
	// uline() uses user units
	for(i=0; i<4; i++)
	{
		uline(xpan[i], ypan[i], xpan[i+1], ypan[i+1], 3);
	}

	// Write message (xphysorq & yphysorq already added to x & y)
	// Notes: 3rd fntpltq() arg now pixels, not mult factor
	// 		  fntpltq() coord are wrt paper origin not plot scale origin
	//        xphysorq & yphysorq shift x & y coords from plot to paper origin
	fntpltq(x+H_MARGIN, y+V_MARGIN,message_str, CHAR_HGTH, 0);

	// Free x & y vertex arrays
	// dummy is to avoid compiler warning
	free(xpan);
	free(ypan);
}

/*****************************************************************************/
/*                                                                           */
/*								TableBox()                                   */
/*                                                                           */
/*		Function to write sigma-tau table box on plot                        */
/*                                                                           */
/*      Parameters:                                                          */
/*			type= type of sigma:                                             */
/*				  0 = normal or overlapping sigma                            */
/*				  1 = modified or time sigma                                 */
/*				  2 = dual, overlapping and modified sigma                   */
/*				  3 = dual, overlapping and Tho1                            */
/*			points = number of data points                                   */
/*			position = table position:                                       */
/*				  0 = TAB_TOP_LEFT                                           */
/*				  1 = TAB_TOP_RIGHT                                          */
/*				  2 = TAB_BOT_LEFT                                           */
/*				  3 = TAB_BOT_RIGHT                                          */
/*                                                                           */
/*		Returns nothing (void)                                               */
/*                                                                           */
/*		The sigma and tau values are in the global arrays                    */
/*      sNormSigData.sigma[i] and sNormSigData.tau[i] or                     */
/*      sModSigData.sigma[i] and sModSigData.tau[i],                         */
/*                                                                           */
/*		Screen has 8192 x 6266 pixels                                        */
/*      Bottom left corner is at (x,y) = (0,0)                               */
/*      Top right corner is at (x,y) = (8191,6265)                           */
/*		Nominal character height multiplier (chm) is 1.5                     */
/*                                                                           */
/*		Revision record:                                                     */
/*			06/30/96	Adapted from table_box() of Stable/DOS               */
/*			10/26/96	Rewritten for new panel filling functions            */
/*						Pixel #s scaled x2 for 8192 vs 4096 FS GraphiC 7.1   */
/*			03/15/97	Revised for variable positioning                     */
/*			04/07/97	Fixed bug with left-hand exp format table position   */
/*			01/16/98	Added calls to ShortenExp() for MSC VC++ 5.0 with NT */
/*			06/05/98	Added labels for TIE rms and MTIE                    */
/*			12/26/99	Added Mod Totvar                                     */
/*			02/15/03	Added type 3 for overlapping & Tho1                 */
/*			02/12/12	Adjusted table position for plot style               */
/*                                                                           */
/*****************************************************************************/

void WINAPI TableBox(int type, int points, int position)
{
	// Local macros
	#define CHR_HGT	2*42    // Base character height

	// Local variables
	// Chars
	char table_t_str[10];                                      /* tau string */
	char table_s1_str[20];                               /* 1st sigma string */
	char table_s2_str[20];                               /* 2nd sigma string */
	// Ints
	int i;                                                          /* index */
	int height;                                       /* height of table box */
	int dx;													     /* x offset */
	int x;                                           /* table horiz position */
	int y;                                            /* table vert position */

	// BOOLs
	BOOL dual=FALSE;                                       /* dual plot flag */
	BOOL bIntFormat;    	      /* flag to use integer tau format in table */
	// Floats
	float chm;                                /* character height multiplier */
	float *xpan;                                /* pointer to x vertex array */
	float *ypan;                                /* pointer to y vertex array */

	// Start of code
	// Allocate memory for x and y vertex arrays which are in user plot units
	if((xpan=(float*)malloc((NUM_SIDES+1)*sizeof(float)))==NULL)
	{
		AllocErrorMessage();
	}

	if((ypan=(float*)malloc((NUM_SIDES+1)*sizeof(float)))==NULL)
	{
		AllocErrorMessage();
		free(xpan);
		return;
	}

	// Set dual flag if dual plot & change type to 0
	if(type==2 || type==3)                                          /* dual */
	{
		dual=TRUE;
	}

	// Determine # points with non-zero # analysis points
	// Points with 0 analysis points are considered from an annotation set
	// and are not listed in table for a Read operation
	// For this to work right, the annotation set(s) must be at the end
	nDummy=0;
	for(i=0; i<points; i++)
	{
		if( (nSigmaPlotType==MODIFIED_RUN) ||
			(nSigmaPlotType==TIME_RUN)     ||
			(nSigmaPlotType==MODTOTAL_RUN) ||
			(nSigmaPlotType==TIMETOTAL_RUN) )
		{
			if(sModSigData.num[i])
			{
				nDummy++;
			}
		}
		else
		{
			if(sNormSigData.num[i])
			{
				nDummy++;
			}
		}
	}
	points=nDummy;

	// The type==3 # points needs to include all the tau points
	// for which there are either overlapping or Tho1 values
	// This is equal to the number of rows in the Run table
	// which is available in the rows member of the sigmadata struct
	// This information is used only for the type==3 FULL_RUN case
	if(type==3)
	{
		points=sNormSigData.rows;
	}

	// Set table position
	// The y increment of 5 was added 11/29/11 to make the modern plot style look better
	switch(position)
	{
		case TAB_TOP_LEFT:                      /* table at top left of plot */
		{
			if(nStyle==MODERN_STYLE)
			{
				x=280;
			}
			else // Original style
			{
				x=170;
			}
			y=2715-5;
			break;
		}
		case TAB_BOT_LEFT:                   /* table at bottom left of plot */
		{
			if(nStyle==MODERN_STYLE)
			{
				x=280;
			}
			else // Original style
			{
				x=170;
			}
			y=430-5;
			break;
		}
		case TAB_TOP_RIGHT:                    /* table at top right of plot */
		{
			x=3830;
			y=2715-5;
			break;
		}
		case TAB_BOT_RIGHT:                 /* table at bottom right of plot */
		{
			x=3830;
			y=430-5;
			break;
		}
	}

	// Scale for GraphiC Ver 7.1 # pixels change
	y*=2;
	x*=2;

	/* Calculate chm for # data points */
	chm=(float)(min((float)1.5, 1.5-(points-10)*0.045));

	/* Adjust x for table width using chm scaling */
	if( (position==TAB_TOP_RIGHT) || (position==TAB_BOT_RIGHT) )
	{
		if(dual)
		{
			x-=(int)(3400*(chm/1.5));
		}
		else
		{
			x-=(int)(2200*(chm/1.5));
		}

	}

	height=(int)(CHR_HGT*chm*1.6*(points+1.5));  /* calc height of table box */

	// Adjust vertical position if table is at bottom of plot
	if( (position==TAB_BOT_LEFT) || (position==TAB_BOT_RIGHT) )
	{
		y+=height;
	}

	// Determine table format
	if( (nSigmaPlotType==MODIFIED_RUN) ||
		(nSigmaPlotType==TIME_RUN)     ||
		(nSigmaPlotType==MODTOTAL_RUN) ||
		(nSigmaPlotType==TIMETOTAL_RUN) )
	{
		if(sModSigData.tau[0]>=1.0 && sModSigData.tau[points-1]<=9999)
		{
			bIntFormat=TRUE;
		}
		else
		{
			bIntFormat=FALSE;
		}
	}
	else // ADEV
	{
		if(sNormSigData.tau[0]>=1.0 && sNormSigData.tau[points-1]<=9999)
		{
			bIntFormat=TRUE;
		}
		else
		{
			bIntFormat=FALSE;
		}
	}

	if( (position==TAB_BOT_RIGHT) || (position==TAB_TOP_RIGHT) )
	{
		if(bIntFormat)
		{
			// 1 <= tau <= 9999, so use integer format in table
			dx=2*230;                                        /* add x offset */
		}
		else
		{
			// Use floating format for tau
			dx=0;                                             /* no x offset */
		}

		// Load box vertices into array with user units
		// Vertices are as follows: [3  ]    [2  ]
		//                          [0,4]    [1  ]
		pixtouser(x+dx, y, xpan, ypan);
		pixtouser((int)(x+2*40+(2*1060+dual*2*600)*chm/1.5),
			y, xpan+1, ypan+1);
		pixtouser((int)(x+2*40+(2*1060+dual*2*600)*chm/1.5),
			y-height, xpan+2, ypan+2);
		xpan[3]=xpan[0];
		ypan[3]=ypan[2];
		xpan[4]=xpan[0];       /* include these points to complete the curve */
		ypan[4]=ypan[0];
	}
	else // left-hand position
	{
		if(bIntFormat)
		{
			// 1 <= tau <= 9999, so use integer format in table
			dx=2*230;                                        /* add x offset */
			pixtouser((int)(x+2*40+(2*1060+dual*2*600)*chm/1.5),
				y, xpan+1, ypan+1);
			pixtouser((int)(x+2*40+(2*1060+dual*2*600)*chm/1.5),
				y-height, xpan+2, ypan+2);
		}
		else
		{
			// Use floating format for tau
			dx=2*230;                                        /* add x offset */
			pixtouser((int)(x+dx+2*40+(2*1060+dual*2*600)*chm/1.5),
				y, xpan+1, ypan+1);
			pixtouser((int)(x+dx+2*40+(2*1060+dual*2*600)*chm/1.5),
				y-height, xpan+2, ypan+2);
		}

		// Load box vertices into array with user units
		// Vertices are as follows: [3  ]    [2  ]
		//                          [0,4]    [1  ]
		// pixtouser(x_in, y_in, x_out, y_out)
		pixtouser(x+dx, y, xpan, ypan);
		xpan[3]=xpan[0];
		ypan[3]=ypan[2];
		xpan[4]=xpan[0];       /* include these points to complete the curve */
		ypan[4]=ypan[0];
	}

	// Define panel area as bright white panel fill w/o border
	panel(xpan, ypan, NUM_SIDES, PAN_COLOR, FALSE);

	panproc();                                    /* do the panel processing */

	for(i=0; i<4; i++)           /* draw border this way so it will print ok */
	{
		uline(xpan[i], ypan[i], xpan[i+1], ypan[i+1], 3);
	}

	// Reload vertices with pixel units
	xpan[0]=(float)(x+dx);
	ypan[0]=(float)y;
	xpan[1]=(float)(x+2*40+(2*1060+dual*2*600)*chm/1.5);
	ypan[1]=ypan[0];
	xpan[2]=xpan[1];
	ypan[2]=(float)(ypan[1]-height);
	xpan[3]=xpan[0];
	ypan[3]=ypan[2];
	xpan[4]=xpan[0];
	ypan[4]=ypan[0];

	// Write the sigma-tau values in a table on the plot.  The sigma & tau
	// values are written separately to line up the proportional font.
	
	for(i=0; i<points; i++)
	{
		if( (nSigmaPlotType==MODIFIED_RUN) ||
			(nSigmaPlotType==TIME_RUN)     ||
			(nSigmaPlotType==MODTOTAL_RUN) ||
			(nSigmaPlotType==TIMETOTAL_RUN) )
		{
			_snprintf(table_s1_str, sizeof(table_s1_str),
				"%4.2e",sModSigData.sigma[i]);
			ShortenExp(table_s1_str);
		}
		else // ADEV etc
		{
			// Display non-zero values only
			if(sNormSigData.sigma[i]==0.0)
			{
				_snprintf(table_s1_str, sizeof(table_s1_str), "");
			}
			else // Non-zero value
			{
				_snprintf(table_s1_str, sizeof(table_s1_str),
					"%4.2e",sNormSigData.sigma[i]);
				ShortenExp(table_s1_str);
			}

			if(nSigmaPlotType==BOTH_RUN || nSigmaPlotType==FULL_RUN)
			{
				// Display non-zero values only
				if(sModSigData.sigma[i]==0.0)
				{
					_snprintf(table_s2_str, sizeof(table_s2_str), "");
				}
				else // Non-zero value
				{
					_snprintf(table_s2_str, sizeof(table_s2_str), "%4.2e",
						sModSigData.sigma[i]);
					ShortenExp(table_s2_str);
				}
			}
		}

		if(bIntFormat)                                     /* int tau format */
		{
			if(type==2)
			{
				fntpltq((int)(xpan[0]+2*30), (int)(ypan[0]-2*90*chm/1.5),
					" Tau   Sigma   Mod Sigma", chm*CHR_HGT, 0);
			}
			else if(type==3)
			{
				fntpltq((int)(xpan[0]+2*30), (int)(ypan[0]-2*90*chm/1.5),
					"  AF     Sigma    Tho1", chm*CHR_HGT,0);
			}
			else if(nSigmaPlotType==TIERMS_RUN)
			{
				fntpltq((int)(xpan[0]+2*30), (int)(ypan[0]-2*90*chm/1.5),
					"   Tau TIE rms", chm*CHR_HGT,0);
			}
			else if(nSigmaPlotType==MTIE_RUN)
			{
				fntpltq((int)(xpan[0]+2*30), (int)(ypan[0]-2*90*chm/1.5),
					"   Tau  MTIE", chm*CHR_HGT,0);
			}
			else
			{
				fntpltq((int)(xpan[0]+2*30), (int)(ypan[0]-2*90*chm/1.5),
					" Tau   Sigma", chm*CHR_HGT, 0);
			}

			if( (nSigmaPlotType==MODIFIED_RUN) ||
				(nSigmaPlotType==TIME_RUN)     ||
				(nSigmaPlotType==MODTOTAL_RUN) ||
				(nSigmaPlotType==TIMETOTAL_RUN) )
			{
				_snprintf(table_t_str, sizeof(table_t_str), "%4.0f",
					sModSigData.tau[i]);
			}
			else if(nSigmaPlotType==FULL_RUN)
			{
				_snprintf(table_t_str, sizeof(table_t_str), "%4d",
					sNormSigData.af[i]);
			}
			else // ADEV etc
			{
				_snprintf(table_t_str, sizeof(table_t_str), "%4.0f",
					sNormSigData.tau[i]);
			}

			fntpltq((int)(xpan[0]+2*40),
				(int)(ypan[0]-2*50*chm/1.5-CHR_HGT*chm-CHR_HGT*chm*1.6*(i+1)),
				table_t_str, chm*CHR_HGT, 0);
			fntpltq((int)(xpan[0]+2*40+2*300*chm/1.5),
				(int)(ypan[0]-2*50*chm/1.5-CHR_HGT*chm-CHR_HGT*chm*1.6*(i+1)),
				table_s1_str, chm*CHR_HGT, 0);

			if(dual)
			{
				fntpltq((int)(xpan[0]+2*40+2*840*chm/1.5), (int)
					(ypan[0]-2*50*chm/1.5-CHR_HGT*chm-CHR_HGT*chm*1.6*(i+1)),
					table_s2_str, chm*CHR_HGT, 0);
			}
		}                                                          /* end if */
		else                                             /* float tau format */
		{
			if(type==2)
			{
				fntpltq((int)(xpan[0]+2*30), (int)(ypan[0]-2*90*chm/1.5),
					"   Tau      Sigma   Mod Sigma", chm*CHR_HGT,0);
			}
			else if(type==3)
			{
				fntpltq((int)(xpan[0]+2*30), (int)(ypan[0]-2*90*chm/1.5),
					"  AF      Sigma    Tho1", chm*CHR_HGT,0);
			}
			else if(nSigmaPlotType==TIERMS_RUN)
			{
				fntpltq((int)(xpan[0]+2*30), (int)(ypan[0]-2*90*chm/1.5),
					"   Tau      TIE rms", chm*CHR_HGT,0);
			}
			else if(nSigmaPlotType==MTIE_RUN)
			{
				fntpltq((int)(xpan[0]+2*30), (int)(ypan[0]-2*90*chm/1.5),
					"   Tau       MTIE", chm*CHR_HGT,0);
			}
			else
			{
				fntpltq((int)(xpan[0]+2*30), (int)(ypan[0]-2*90*chm/1.5),
					"   Tau      Sigma", chm*CHR_HGT,0);
			}

			if( (nSigmaPlotType==MODIFIED_RUN) ||
				(nSigmaPlotType==TIME_RUN)     ||
				(nSigmaPlotType==MODTOTAL_RUN) ||
				(nSigmaPlotType==TIMETOTAL_RUN) )
			{
				_snprintf(table_t_str, sizeof(table_t_str), "%4.2e",
					sModSigData.tau[i]);
				ShortenExp(table_t_str);
			}
			else if(nSigmaPlotType==FULL_RUN)
			{
				_snprintf(table_t_str, sizeof(table_t_str), "%4d",
					sNormSigData.af[i]);
			}
			else // ADEV etc
			{
				_snprintf(table_t_str, sizeof(table_t_str), "%4.2e",
					sNormSigData.tau[i]);
				ShortenExp(table_t_str);
			}

			fntpltq((int)(xpan[0]+2*40),
				(int)(ypan[0]-2*50*chm/1.5-CHR_HGT*chm-CHR_HGT*chm*1.6*(i+1)),
				table_t_str, chm*CHR_HGT, 0);
			fntpltq((int)(xpan[0]+2*40+2*540*chm/1.5),
				(int)(ypan[0]-2*50*chm/1.5-CHR_HGT*chm-CHR_HGT*chm*1.6*(i+1)),
				table_s1_str, chm*CHR_HGT, 0);

			if(dual)
			{
				fntpltq((int)(xpan[0]+2*40+2*1080*chm/1.5),	(int)
					(ypan[0]-2*50*chm/1.5-CHR_HGT*chm-CHR_HGT*chm*1.6*(i+1)),
					table_s2_str, chm*CHR_HGT, 0);
			}
		}                                                        /* end else */
	}                                                             /* end for */

	// Free x & y vertex arrays
	// dummy is to avoid compiler warning
	free(xpan);
	free(ypan);
}

/*****************************************************************************/
/*                                                                           */
/*							AllTableBox()                                    */
/*                                                                           */
/*		Function to write all tau sigma-tau table box on plot                */
/*                                                                           */
/*      Parameters:                                                          */
/*			type= type of sigma:                                             */
/*				  0 = normal or overlapping sigma                            */
/*				  1 = modified or time sigma                                 */
/*				  2 = dual, overlapping and modified sigma                   */
/*				  3 = dual, overlapping and Tho1                            */
/*			points = number of data points                                   */
/*			position = table position:                                       */
/*				  0 = TAB_TOP_LEFT                                           */
/*				  1 = TAB_TOP_RIGHT                                          */
/*				  2 = TAB_BOT_LEFT                                           */
/*				  3 = TAB_BOT_RIGHT                                          */
/*                                                                           */
/*		Returns nothing (void)                                               */
/*                                                                           */
/*		The sigma and tau values are in the global arrays                    */
/*      sAllNormSigData.sigma[i] and sAllNormSigData.tau[i] or               */
/*      sAllModSigData.sigma[i] and sAllModSigData.tau[i],                   */
/*                                                                           */
/*		Screen has 8192 x 6266 pixels                                        */
/*      Bottom left corner is at (x,y) = (0,0)                               */
/*      Top right corner is at (x,y) = (8191,6265)                           */
/*		Nominal character height multiplier (chm) is 1.5                     */
/*                                                                           */
/*      This separate function for all tau stability tables is similar to    */
/*      the one for octave or decade tables                                  */
/*                                                                           */
/*		Revision record:                                                     */
/*			05/27/11	Created from TableBox()                              */
/*                                                                           */
/*****************************************************************************/

void WINAPI AllTableBox(int type, int points, int position)
{
	// Local macros
	#define CHR_HGT	2*42    // Base character height

	// Local variables
	// Chars
	char table_t_str[10];                                      /* tau string */
	char table_s1_str[20];                               /* 1st sigma string */
	char table_s2_str[20];                               /* 2nd sigma string */
	// Ints
	int i;                                                          /* index */
	int height;                                       /* height of table box */
	int dx;													     /* x offset */
	int x;                                           /* table horiz position */
	int y;                                            /* table vert position */

	// BOOLs
	BOOL dual=FALSE;                                       /* dual plot flag */
	BOOL bIntFormat;    	      /* flag to use integer tau format in table */
	// Floats
	float chm;                                /* character height multiplier */
	float *xpan;                                /* pointer to x vertex array */
	float *ypan;                                /* pointer to y vertex array */

	// Start of code
	// Allocate memory for x and y vertex arrays which are in user plot units
	if((xpan=(float*)malloc((NUM_SIDES+1)*sizeof(float)))==NULL)
	{
		AllocErrorMessage();
	}

	if((ypan=(float*)malloc((NUM_SIDES+1)*sizeof(float)))==NULL)
	{
		AllocErrorMessage();
		free(xpan);
		return;
	}

	// Set dual flag if dual plot & change type to 0
	if(type==2 || type==3)                                          /* dual */
	{
		dual=TRUE;
	}

	// Determine # points with non-zero # analysis points
	// Points with 0 analysis points are considered from an annotation set
	// and are not listed in table for a Read operation
	// For this to work right, the annotation set(s) must be at the end
	nDummy=0;
	for(i=0; i<points; i++)
	{
		if( (nSigmaPlotType==MODIFIED_RUN) ||
			(nSigmaPlotType==TIME_RUN)     ||
			(nSigmaPlotType==MODTOTAL_RUN) ||
			(nSigmaPlotType==TIMETOTAL_RUN) )
		{
			if(sAllModSigData.num[i])
			{
				nDummy++;
			}
		}
		else
		{
			if(sAllNormSigData.num[i])
			{
				nDummy++;
			}
		}
	}
	points=nDummy+1; // Note the +1 that seems to be required here

	// The type==3 # points needs to include all the tau points
	// for which there are either overlapping or Tho1 values
	// This is equal to the number of rows in the Run table
	// which is available in the rows member of the sigmadata struct
	// This information is used only for the type==3 FULL_RUN case
	if(type==3)
	{
		points=sAllNormSigData.rows;
	}

	// Set table position
	switch(position)
	{
		case TAB_TOP_LEFT:                      /* table at top left of plot */
		{
			x=170;
			y=2715;
			break;
		}
		case TAB_BOT_LEFT:                   /* table at bottom left of plot */
		{
			x=170;
			y=430;
			break;
		}
		case TAB_TOP_RIGHT:                    /* table at top right of plot */
		{
			x=3830;
			y=2715;
			break;
		}
		case TAB_BOT_RIGHT:                 /* table at bottom right of plot */
		{
			x=3830;
			y=430;
			break;
		}
	}

	// Scale for GraphiC Ver 7.1 # pixels change
	y*=2;
	x*=2;

	/* Calculate chm for # data points */
	chm=(float)(min((float)1.5, 1.5-(points-10)*0.045));

	/* Adjust x for table width using chm scaling */
	if( (position==TAB_TOP_RIGHT) || (position==TAB_BOT_RIGHT) )
	{
		if(dual)
		{
			x-=(int)(3400*(chm/1.5));
		}
		else
		{
			x-=(int)(2200*(chm/1.5));
		}

	}

	height=(int)(CHR_HGT*chm*1.6*(points+1.5));  /* calc height of table box */

	// Adjust vertical position if table is at bottom of plot
	if( (position==TAB_BOT_LEFT) || (position==TAB_BOT_RIGHT) )
	{
		y+=height;
	}

	// Determine table format
	if( (nSigmaPlotType==MODIFIED_RUN) ||
		(nSigmaPlotType==TIME_RUN)     ||
		(nSigmaPlotType==MODTOTAL_RUN) ||
		(nSigmaPlotType==TIMETOTAL_RUN) )
	{
		if(sAllModSigData.tau[0]>=1.0 && sAllModSigData.tau[points-1]<=9999)
		{
			bIntFormat=TRUE;
		}
		else
		{
			bIntFormat=FALSE;
		}
	}
	else // ADEV
	{
		if(sAllNormSigData.tau[0]>=1.0 && sAllNormSigData.tau[points-1]<=9999)
		{
			bIntFormat=TRUE;
		}
		else
		{
			bIntFormat=FALSE;
		}
	}

	if( (position==TAB_BOT_RIGHT) || (position==TAB_TOP_RIGHT) )
	{
		if(bIntFormat)
		{
			// 1 <= tau <= 9999, so use integer format in table
			dx=2*230;                                        /* add x offset */
		}
		else
		{
			// Use floating format for tau
			dx=0;                                             /* no x offset */
		}

		// Load box vertices into array with user units
		// Vertices are as follows: [3  ]    [2  ]
		//                          [0,4]    [1  ]
		pixtouser(x+dx, y, xpan, ypan);
		pixtouser((int)(x+2*40+(2*1060+dual*2*600)*chm/1.5),
			y, xpan+1, ypan+1);
		pixtouser((int)(x+2*40+(2*1060+dual*2*600)*chm/1.5),
			y-height, xpan+2, ypan+2);
		xpan[3]=xpan[0];
		ypan[3]=ypan[2];
		xpan[4]=xpan[0];       /* include these points to complete the curve */
		ypan[4]=ypan[0];
	}
	else // left-hand position
	{
		if(bIntFormat)
		{
			// 1 <= tau <= 9999, so use integer format in table
			dx=2*230;                                        /* add x offset */
			pixtouser((int)(x+2*40+(2*1060+dual*2*600)*chm/1.5),
				y, xpan+1, ypan+1);
			pixtouser((int)(x+2*40+(2*1060+dual*2*600)*chm/1.5),
				y-height, xpan+2, ypan+2);
		}
		else
		{
			// Use floating format for tau
			dx=2*230;                                        /* add x offset */
			pixtouser((int)(x+dx+2*40+(2*1060+dual*2*600)*chm/1.5),
				y, xpan+1, ypan+1);
			pixtouser((int)(x+dx+2*40+(2*1060+dual*2*600)*chm/1.5),
				y-height, xpan+2, ypan+2);
		}

		// Load box vertices into array with user units
		// Vertices are as follows: [3  ]    [2  ]
		//                          [0,4]    [1  ]
		// pixtouser(x_in, y_in, x_out, y_out)
		pixtouser(x+dx, y, xpan, ypan);
		xpan[3]=xpan[0];
		ypan[3]=ypan[2];
		xpan[4]=xpan[0];       /* include these points to complete the curve */
		ypan[4]=ypan[0];
	}

	// Define panel area as bright white panel fill w/o border
	panel(xpan, ypan, NUM_SIDES, PAN_COLOR, FALSE);

	panproc();                                    /* do the panel processing */

	for(i=0; i<4; i++)           /* draw border this way so it will print ok */
	{
		uline(xpan[i], ypan[i], xpan[i+1], ypan[i+1], 3);
	}

	// Reload vertices with pixel units
	xpan[0]=(float)(x+dx);
	ypan[0]=(float)y;
	xpan[1]=(float)(x+2*40+(2*1060+dual*2*600)*chm/1.5);
	ypan[1]=ypan[0];
	xpan[2]=xpan[1];
	ypan[2]=(float)(ypan[1]-height);
	xpan[3]=xpan[0];
	ypan[3]=ypan[2];
	xpan[4]=xpan[0];
	ypan[4]=ypan[0];

	// Write the sigma-tau values in a table on the plot.  The sigma & tau
	// values are written separately to line up the proportional font.
	
	for(i=0; i<points; i++)
	{
		if( (nSigmaPlotType==MODIFIED_RUN) ||
			(nSigmaPlotType==TIME_RUN)     ||
			(nSigmaPlotType==MODTOTAL_RUN) ||
			(nSigmaPlotType==TIMETOTAL_RUN) )
		{
			_snprintf(table_s1_str, sizeof(table_s1_str),
				"%4.2e",sAllModSigData.sigma[i]);
			ShortenExp(table_s1_str);
		}
		else // ADEV etc
		{
			// Display non-zero values only
			if(sAllNormSigData.sigma[i]==0.0)
			{
				_snprintf(table_s1_str, sizeof(table_s1_str), "");
			}
			else // Non-zero value
			{
				_snprintf(table_s1_str, sizeof(table_s1_str),
					"%4.2e",sAllNormSigData.sigma[i]);
				ShortenExp(table_s1_str);
			}

			if(nSigmaPlotType==BOTH_RUN || nSigmaPlotType==FULL_RUN)
			{
				// Display non-zero values only
				if(sAllModSigData.sigma[i]==0.0)
				{
					_snprintf(table_s2_str, sizeof(table_s2_str), "");
				}
				else // Non-zero value
				{
					_snprintf(table_s2_str, sizeof(table_s2_str), "%4.2e",
						sAllModSigData.sigma[i]);
					ShortenExp(table_s2_str);
				}
			}
		}

		if(bIntFormat)                                     /* int tau format */
		{
			if(type==2)
			{
				fntpltq((int)(xpan[0]+2*30), (int)(ypan[0]-2*90*chm/1.5),
					" Tau   Sigma   Mod Sigma", chm*CHR_HGT, 0);
			}
			else if(type==3)
			{
				fntpltq((int)(xpan[0]+2*30), (int)(ypan[0]-2*90*chm/1.5),
					"  AF     Sigma    Tho1", chm*CHR_HGT,0);
			}
			else if(nSigmaPlotType==TIERMS_RUN)
			{
				fntpltq((int)(xpan[0]+2*30), (int)(ypan[0]-2*90*chm/1.5),
					"   Tau TIE rms", chm*CHR_HGT,0);
			}
			else if(nSigmaPlotType==MTIE_RUN)
			{
				fntpltq((int)(xpan[0]+2*30), (int)(ypan[0]-2*90*chm/1.5),
					"   Tau  MTIE", chm*CHR_HGT,0);
			}
			else
			{
				fntpltq((int)(xpan[0]+2*30), (int)(ypan[0]-2*90*chm/1.5),
					" Tau   Sigma", chm*CHR_HGT, 0);
			}

			if( (nSigmaPlotType==MODIFIED_RUN) ||
				(nSigmaPlotType==TIME_RUN)     ||
				(nSigmaPlotType==MODTOTAL_RUN) ||
				(nSigmaPlotType==TIMETOTAL_RUN) )
			{
				_snprintf(table_t_str, sizeof(table_t_str), "%4.0f",
					sAllModSigData.tau[i]);
			}
			else if(nSigmaPlotType==FULL_RUN)
			{
				_snprintf(table_t_str, sizeof(table_t_str), "%4d",
					sAllNormSigData.af[i]);
			}
			else // ADEV etc
			{
				_snprintf(table_t_str, sizeof(table_t_str), "%4.0f",
					sAllNormSigData.tau[i]);
			}

			fntpltq((int)(xpan[0]+2*40),
				(int)(ypan[0]-2*50*chm/1.5-CHR_HGT*chm-CHR_HGT*chm*1.6*(i+1)),
				table_t_str, chm*CHR_HGT, 0);
			fntpltq((int)(xpan[0]+2*40+2*300*chm/1.5),
				(int)(ypan[0]-2*50*chm/1.5-CHR_HGT*chm-CHR_HGT*chm*1.6*(i+1)),
				table_s1_str, chm*CHR_HGT, 0);

			if(dual)
			{
				fntpltq((int)(xpan[0]+2*40+2*840*chm/1.5), (int)
					(ypan[0]-2*50*chm/1.5-CHR_HGT*chm-CHR_HGT*chm*1.6*(i+1)),
					table_s2_str, chm*CHR_HGT, 0);
			}
		}                                                          /* end if */
		else                                             /* float tau format */
		{
			if(type==2)
			{
				fntpltq((int)(xpan[0]+2*30), (int)(ypan[0]-2*90*chm/1.5),
					"   Tau      Sigma   Mod Sigma", chm*CHR_HGT,0);
			}
			else if(type==3)
			{
				fntpltq((int)(xpan[0]+2*30), (int)(ypan[0]-2*90*chm/1.5),
					"  AF      Sigma    Tho1", chm*CHR_HGT,0);
			}
			else if(nSigmaPlotType==TIERMS_RUN)
			{
				fntpltq((int)(xpan[0]+2*30), (int)(ypan[0]-2*90*chm/1.5),
					"   Tau      TIE rms", chm*CHR_HGT,0);
			}
			else if(nSigmaPlotType==MTIE_RUN)
			{
				fntpltq((int)(xpan[0]+2*30), (int)(ypan[0]-2*90*chm/1.5),
					"   Tau       MTIE", chm*CHR_HGT,0);
			}
			else
			{
				fntpltq((int)(xpan[0]+2*30), (int)(ypan[0]-2*90*chm/1.5),
					"   Tau      Sigma", chm*CHR_HGT,0);
			}

			if( (nSigmaPlotType==MODIFIED_RUN) ||
				(nSigmaPlotType==TIME_RUN)     ||
				(nSigmaPlotType==MODTOTAL_RUN) ||
				(nSigmaPlotType==TIMETOTAL_RUN) )
			{
				_snprintf(table_t_str, sizeof(table_t_str), "%4.2e",
					sAllModSigData.tau[i]);
				ShortenExp(table_t_str);
			}
			else if(nSigmaPlotType==FULL_RUN)
			{
				_snprintf(table_t_str, sizeof(table_t_str), "%4d",
					sAllNormSigData.af[i]);
			}
			else // ADEV etc
			{
				_snprintf(table_t_str, sizeof(table_t_str), "%4.2e",
					sAllNormSigData.tau[i]);
				ShortenExp(table_t_str);
			}

			fntpltq((int)(xpan[0]+2*40),
				(int)(ypan[0]-2*50*chm/1.5-CHR_HGT*chm-CHR_HGT*chm*1.6*(i+1)),
				table_t_str, chm*CHR_HGT, 0);
			fntpltq((int)(xpan[0]+2*40+2*540*chm/1.5),
				(int)(ypan[0]-2*50*chm/1.5-CHR_HGT*chm-CHR_HGT*chm*1.6*(i+1)),
				table_s1_str, chm*CHR_HGT, 0);

			if(dual)
			{
				fntpltq((int)(xpan[0]+2*40+2*1080*chm/1.5),	(int)
					(ypan[0]-2*50*chm/1.5-CHR_HGT*chm-CHR_HGT*chm*1.6*(i+1)),
					table_s2_str, chm*CHR_HGT, 0);
			}
		}                                                        /* end else */
	}                                                             /* end for */

	// Free x & y vertex arrays
	// dummy is to avoid compiler warning
	free(xpan);
	free(ypan);
}

/*****************************************************************************/
/*                                                                           */
/*								HistoPlot()                                  */
/*                                                                           */
/*		Function to plot histogram data                                      */
/*      Parameters:                                                          */
/*      	f_data[]  = array of freq bin data                               */
/*          h_data[]  = array of histogram count data                        */
/*			int bins  = # bins                                               */
/*		p plotdata structure elements:                                       */
/*      	p.title = plot title                                             */
/*      	p.subtitle = plot subtitle                                       */
/*			p.do_box  = draw box flag                                        */
/*			p.do_date = write date flag                                      */
/*			p.plot_filename = .tkf filename for plot                         */
/*			p.message_str = text of message to be put in box on plot         */
/*      Returns nothing (void)                                               */
/*                                                                           */
/*      Revision record:                                                     */
/*      	06/30/96	Adapted from plot_histo() of Stable/DOS              */
/*			11/18/96	Revised plot sizes, etc.                             */
/*			12/29/96	Up and running                                       */
/*			05/17/00	Added fill flag usage = sHPlot.do_errbar             */
/*			03/11/01	Added provisions for thicker lines                   */
/*			07/22/10	Unwrapped scales() call to expose scale factors      */
/*                                                                           */
/*****************************************************************************/

void WINAPI HistoPlot(float f_data[], float h_data[],
   int bins,  struct plotdata *p)
{
	int i;                                                  /* general index */
	int background_color;
	int grid_color;
	int label_color;
	int bar_color;
	int separator_color;
	int line_color;
	int annotation_color;
	int lgth;                                    /* message length in pixels */

	#ifdef DEMO_VERSION
	int x_pix, y_pix, x_pix_min, y_pix_min, x_pix_max, y_pix_max;
	#endif

	float x[5];                                         /* x vertices of bar */
	float y[5];                                         /* y vertices of bar */
	float temp;                     /* temporary storage for 1st bin's value */
	float strwidth(char *string, float height);    /* GraphiC float function */
	float width;                             /* title or subtitle half width */
	float range;                                            /* x-scale range */
	float sd;                                          /* standard deviation */
	float m;                                                         /* mean */
	float x_start;
	float x_end;
	float p_start;                    /* normal probability for (x-m) and sd */
	float p_end;
	char label_str[LABELSIZE+1];

	// Cursor variables
	float *fx;                  // Pointer to x-axis point array
	float *fy;                  // Pointer to y-axis point array
	int find;					// Point array dimensions

	// Dummy variables for unwrapped scales() call
	int nxdiv, nydiv;
	float xmax, xmin, ymax, ymin, xste, yste;
	char xformat[8], yformat[8];

	// assign colors
	background_color=BRT_WHITE;
	grid_color=BLACK;
	label_color=BLUE;
	
	// Fill histogram bars if sHPlot.do_errbar=TRUE
	if(p->do_errbar)
	{
		bar_color=RED;
	}
	else
	{
		bar_color=BRT_WHITE;
	}

	separator_color=BLUE;
	line_color=GREEN;
	annotation_color=BLACK;

/*****************************************************************************/
/* This is the begining of the actual GraphiC plotting code                  */
/* Sequence of basic calls is per page I-34 of manual:                       */
/*	   bgnplot()            	Initializations                              */
/*	   startplot()          	Starts graphics                              */
/*	   font()               	Loads fonts                                  */
/*	   page()               	Sets overall picture size                    */
/*	   heading()				Draws title                                  */
/*	   xname(), yname()		 	Draws axis labels                            */
/*	   area2d()					Defines axis lengths                         */
/*	                                                                         */
/*****************************************************************************/

	// Write log info
	WriteLog(40, p->plot_filename);

	bgnplot(1,'g',p->plot_filename);                      /* initialize plot */
	startplot(background_color);        /* start plot & set background color */
	font(4,"news.fnt",'\310',"swiss.fnt",'\311',"newsgrm.fnt",'\312',
		 "simplex.fnt",'\313');                                /* load fonts */
	page(FULLPAGE);                  /* Sets the maximum allowable page size */
	heading("");    /* Blank heading allows space for title & subtitle later */
	fillfont(1);                                         /* Use filled fonts */

	// Kill the beep
	GPCSetBeepDefaults(0, 0);

	// Avoid unwanted clipping 
	UnclipPlot();
	
	color(label_color);                                       /* label color */
	fntchg('\310');                                              /* news.fnt */
	if(nStyle==MODERN_STYLE)                           /* Use "modern" style */
	{
		fntchg('\311');                                          /*swiss.fnt */
		upright(1);                          /* upright y-axis label numbers */
		numht((float)0.18);                           /* larger axis numbers */
		xnamht((float)0.22);                         /* larger x-axis labels */
		ynamht((float)0.22);                         /* larger y-axis labels */
	}
	xname(p->x_label);                                       /* x-axis label */
	yname(p->left_y_label);                                  /* y-axis label */
	area2d((float)7.8, (float)5.3);                      /* plot dimenisions */

	upright(1);                                  /* horizontal y-axis labels */
	color(grid_color);                                         /* grid color */
	grid(2);                                          /* fine dot grid lines */
	fgrid(9, 0);                             /* dotted lines on subdivisions */
	frame(1,1);                          /* add frame with ticks around plot */

	if(p->do_box)
	{
		box();                              /* draw a box around the picture */
	}                                                              /* end if */

	temp=h_data[0];                                  /* save 1st bin's value */
	h_data[0]=0;             /* set it = 0 to force y-scale to start at zero */

	#if(0) // Original code
	scales(5,5,f_data,h_data,bins);              /* self scaling linear axes */
	#endif

	/*************************************************************************

	scales() id simply a wrapper for these calls:

	/*************************************************************************
	void TYPE GCLASS scales(int nxdiv, int nydiv, float *x, float *y, int npts)
	{
		float xmax, xmin, ymax, ymin, xste, yste;
		char xformat[8], yformat[8];

		minmax(&xmin, &xmax, x, npts);
		minmax(&ymin, &ymax, y, npts);
		roundq(nxdiv, &xmin, &xste, &xmax, xformat);
		roundq(nydiv, &ymin, &yste, &ymax, yformat);
		graf(xformat, xmin, xste, xmax, yformat, ymin, yste, ymax);
	}
	**************************************************************************/

	#if(1) // Draft of subsitute for scales() call to expose scale factors
	nxdiv=5; // In case we want to change this
	nydiv=5; // In case we want to change this
	// x=f_data
	// y=h_data
	// npts=bins
	// Skip the following calls to use user-defined scales
	if((p->y_min==0.0)&&(p->y_max==0))
	{
		minmax(&xmin, &xmax, f_data, bins);
		minmax(&ymin, &ymax, h_data, bins);
		roundq(nxdiv, &xmin, &xste, &xmax, xformat);
		roundq(nydiv, &ymin, &yste, &ymax, yformat);
	}
	else // Set scales manually
	{
		minmax(&xmin, &xmax, f_data, bins);
		minmax(&ymin, &ymax, h_data, bins);
		roundq(nxdiv, &xmin, &xste, &xmax, xformat);
		roundq(nydiv, &ymin, &yste, &ymax, yformat);
		xmin=p->x_min;
		xmax=p->x_max;
		xste=p->x_step;
		ymin=p->y_min;
		ymax=p->y_max;
		yste=p->y_step;
	}
	// Enter here with user-defined scales:
	// X format min, step, max, and Y format min, step, max
	// max will be adjusted for a whole # of steps from min to max
	// y_min = y_max = 0 is flag for automatic scaling
	graf(xformat, xmin, xste, xmax, yformat, ymin, yste, ymax);

	// xmin is x-axis scale minimun
	// xmax is x-axis scale maximum
	// xste is x-axis scale step size between ticks
	// ymin is y-axis scale minimun
	// ymax is y-axis scale maximum
	// yste is y-axis scale step size between ticks
	// Those values are returned as plotdata struct items
	p->x_min=xmin;
	p->x_max=xmax;
	p->x_step=xste;
	p->y_min=ymin;
	p->y_max=ymax;
	p->y_step=yste;
	#endif

	h_data[0]=temp;                                         /* restore value */

	fntchg('\311');                                             /* swiss.fnt */

	color(label_color);                                   /* set label color */

	width=strwidth(p->title,(float)0.3);          /* get half-width of title */
	prtfnt((float)(4.75-width),(float)6.40,p->title,(float)0.3,0);  /* title */
	width=strwidth(p->subtitle,(float)0.15);   /* get half-width of subtitle */
	prtfnt((float)(4.75-width),(float)6.175,p->subtitle,(float)0.15,0);
	                                                       /* draw subtitle */

	for(i=0; i<bins; i++)                                      /* draw bars */
	{                                                           /*   1   2   */
		if(h_data[i])                                           /*           */
		{                                                       /*  0,4  3   */
			x[0]=f_data[i];
			x[1]=x[0];
			x[2]=f_data[i+1];
			x[3]=x[2];
			x[4]=x[0];
			y[0]=0;
			y[1]=h_data[i];
			y[2]=y[1];
			y[3]=0;
			y[4]=y[0];
			color(separator_color);                   /* bar separator color */
			panel(x,y,4,-bar_color,1);                      /* histogram bar */
			panproc();
		}                                                          /* end if */
	}                                                             /* end for */

	if(p->do_line)                         /* plot normal distribution curve */
	{
		color(line_color);                                     /* line color */
		x_start=p->x_min;
		range=p->x_max - p->x_min;
		m=p->y_offset;                                               /* mean */
		sd=p->y_mult;                                             /* std dev */
		p_start=(float)(p->y_max*exp(((m-x_start)*(x_start-m))/(2*sd*sd)));
		for(i=1; i<=100; i++)
		{
			x_end=p->x_min+i*(range/100);
			p_end=(float)(p->y_max*exp(((m-x_end)*(x_end-m))/(2*sd*sd)));
			uline(x_start, p_start, x_end, p_end, 3);
			x_start=x_end;
			p_start=p_end;
		}                                                         /* end for */
		_snprintf(label_str, sizeof(label_str),
			"Normal Curve Fit: "
			"Mean=%-10.7e, Std Dev=%-10.7e, Peak=%-3.0f",
			m, sd, p->y_max);
		ShortenExp(label_str);

		UnclipPlot();
		fntchg('\313');                                       /* simplex.fnt */
		color(annotation_color);                     /* fit annotation color */
		tmargin((float)6.655);
		ctline(label_str, (float)0.075);
}                                                      /* end if(p->do_line) */
	color(annotation_color);           /* black date & file annotation color */ 
	
	// Unclip again
	UnclipPlot();

	if(p->do_date)
	{
		Dateline(1, 1, 1);                   /* put date & file info on plot */
	}                                                              /* end if */

	// Display message box
	// Locations are x, y in pixels, origin at bottom left, 8192 x 6266 space
	// Find half length of message box in pixels
	lgth=(H_MARGIN+strwidtq(p->message_str, CHAR_HGTH));

	// Write message
	if(p->message_str[0]!='\0')         /* don't display a blank message box */
	{
		switch(p->position)
		{
			case MSG_TOP_LEFT:            /* message box at top left of plot */
			{
				MsgBox(300, 4400, p->message_str);
				break;
			}                                                    /* end case */
			case MSG_MID_LEFT:         /* message box at middle left of plot */
			{
				MsgBox(300, 2270, p->message_str);
				break;
			}                                                    /* end case */
			case MSG_BOT_LEFT:         /* message box at bottom left of plot */
			{
				MsgBox(300, 200, p->message_str);
				break;
			}                                                    /* end case */
			case MSG_TOP_CENTER:        /* message box at top center of plot */
			{
				MsgBox(3470-lgth, 4400, p->message_str);
				break;
			}                                                    /* end case */
			case MSG_MID_CENTER:     /* message box at middle center of plot */
			{
				MsgBox(3470-lgth, 2270, p->message_str);
				break;
			}                                                    /* end case */
			case MSG_BOT_CENTER:     /* message box at bottom center of plot */
			{
				MsgBox(3470-lgth, 200, p->message_str);
				break;
			}                                                    /* end case */
			case MSG_TOP_RIGHT:          /* message box at top right of plot */
			{
				MsgBox(6400-2*lgth, 4400, p->message_str);
				break;
			}                                                    /* end case */
			case MSG_MID_RIGHT:       /* message box at middle right of plot */
			{
				MsgBox(6400-2*lgth, 2270, p->message_str);
				break;
			}                                                    /* end case */
			case MSG_BOT_RIGHT:       /* message box at bottom right of plot */
			{
				MsgBox(6400-2*lgth, 200, p->message_str);
				break;
			}                                                    /* end case */
		}                                                      /* end switch */
	}

	// Write label
	if(bPlotLabel)
	{
		UnclipPlot();
		color(annotation_color);                         /* annotation color */
		width=(float)intopix(strwidth(szPlotLabel, (float)0.05));
		putlabel(szPlotLabel, 8192-2*(width+20), 20, (float)0.05, 0,
			PIXEL_UNITS);
	}

	// Activate mouse cursor
	if(p->do_mouse)
	{
		// Allocate memory for x and y point arrays
		fx=(float*)gpcalloc(64, sizeof(float));
		fy=(float*)gpcalloc(64, sizeof(float));

		curson(0, 0, &fx, &fy, &find);                /* turn on mouse cursor*/

		// Free memory - this assumes that point info isn't needed
		gpcfree((void**)&fx);
		gpcfree((void**)&fy);
	}                                                              /* end if */

	// Avoid unwanted clipping 
	UnclipPlot();

	#ifdef DEMO_VERSION
	// Add watermark for demo version
	// Get plot size in pixels
	usertopix(p->x_max, p->y_max, 0.0, &x_pix_max, &y_pix_max);
	usertopix(p->x_min, p->y_min, 0.0, &x_pix_min, &y_pix_min);
	x_pix=x_pix_max-x_pix_min;
	y_pix=y_pix_max-y_pix_min;
	// Select hatched swiss font
	fntchg('\311');                                              /* news.fnt */
	fontfill(2, 230, 0);
	// Display watermark
	pltfnt((float)p->x_min, (float)p->y_min, "Stable32 Demo Version",
		(float)0.6, (int)(180*atan2((double)y_pix, (double)x_pix)/PI));
	#endif

	#ifdef VITSAS_VER
	// Add watermark for V-ITSAS version
	color(227);
	tmargin((float)0.15);
	ltline(" Stable32 V-ITSAS", (float)0.12);
	tmargin((float)0.15);
	rtline("Evaluation Version ", (float)0.12);
	#endif

	#if(1) // New code 11/23/11
	// Process bCmdM command to copy plot metafile to clipboard
	if(bCmdM)
	{
		// Send copy metafile message to GraphiC
		PostMessage(hGPC, WM_COMMAND,
			GET_WM_COMMAND_MPS(IDM_COPYMETA, 0, 0));
	}

	// Process bCmdT command to print plot
	if(bCmdT)
	{
		// Send print message to GraphiC
		PostMessage(hGPC, WM_COMMAND,
			GET_WM_COMMAND_MPS(IDM_PRINT, 0, 0));
	}

	// Process bCmdX command to close plot
	if(bCmdX)
	{
		// Show the plot briefly
		Sleep(1000);

		// Close plot and plot dialog box
		PostMessage(hPlot, WM_CLOSE, (WPARAM)0, (LPARAM)0);
		PostMessage(hPlotBox, WM_CLOSE, (WPARAM)0, (LPARAM)0);
	}
	#endif

	endplot();                                             /* terminate plot */
	stopplot();                                      /* close files and quit */
}                                                          /* end plot_histo */

/*****************************************************************************/
/*                                                                           */
/*							      Dateline()                                 */
/*                                                                           */
/*		Function to display date & file information at top of plot           */
/*		Parameters:                                                          */
/*			BOOL ct_flag = flag to control Points & Tau display              */
/*			int nAF      = averaging factor (multiplier) for tau             */
/*		Returns nothing (void)                                               */
/*                                                                           */
/*		Revision record:                                                     */
/*			07/13/96	Adapted from dateline() of Stable/DOS                */
/*			01/30/97	Added provisions for displaying stability filename   */
/*			08/30/03	Added nAF parameter                                  */
/*			03/01/07	Added f_flag parameter                               */
/*                                                                           */
/*****************************************************************************/

void WINAPI Dateline(BOOL ct_flag, BOOL f_flag, int nAF)
{
	#include <time.h>

	// Local macros
	#define LABEL_STR_SIZE 100

	// Local variables
	char label_str[LABEL_STR_SIZE];
	char date_str[9];
	char time_str[9];
	F_TYPE fTau;

	// Select font
	fntchg('\313');                                    /* simplex.fnt */

	// Write date and time at upper left
	_strdate(date_str);
	_strtime(time_str);
	strlcpy(label_str, "  Date: ", sizeof(label_str));
	strlcat(label_str, date_str, sizeof(label_str));
	strlcat(label_str, "  Time: ", sizeof(label_str));
	strlcat(label_str, time_str, sizeof(label_str));
	tmargin(0);
	ltline(label_str, (float)0.075);
	
	// Write data point and tau info at upper center
	if(ct_flag)
	{
		if(bDataType==FREQ_DATA)
		{
			// Get tau
			GetWindowText(hwndFreqTau, (LPSTR)label_str,
				LABEL_STR_SIZE-1);
			fTau=(F_TYPE)atof(label_str);
			fTau*=nAF;

			// Compose string
			_snprintf(label_str, LABELSIZE,
				"Data Points %-1.0f thru %-1.0f of %-1.0f\
			Tau=%-10.7e", fFreqData[1], fFreqData[2], fFreqData[0],	fTau);
			ShortenExp(label_str);
		}
		else // Phase Data
		{
			// Get tau
			GetWindowText(hwndPhaseTau, (LPSTR)label_str,
				LABEL_STR_SIZE-1);
			fTau=(F_TYPE)atof(label_str);
			fTau*=nAF;

			// Compose string
			_snprintf(label_str, LABELSIZE,
			"Data Points %-1.0f thru %-1.0f of %-1.0f\
			Tau=%-10.7e", fPhaseData[1], fPhaseData[2], fPhaseData[0], fTau);
			ShortenExp(label_str);
		}
		tmargin(0);
		ctline(label_str, (float)0.075);
	}

	if(f_flag)
	{
		// Write filename at upper right
		strlcpy(label_str, "File: ", sizeof(label_str));
		if(nPlotType==READ_PLOT)
		{
			strlcat(label_str, szStabFileTitle, sizeof(label_str));
		}
		else
		{
			strlcat(label_str, szFileTitle, sizeof(label_str));
		}
		label_str[36]='\0'; /* truncate string */
		strlcat(label_str, "   ", sizeof(label_str));
		tmargin(0);
		rtline(label_str, (float)0.075) ;
	}
}                                                          /* end Dateline() */

/*****************************************************************************/
/*                                                                           */
/*		Plot dialog box procedure                                            */
/*                                                                           */
/*		Revision record:                                                     */
/*			07/13/96	Written                                              */
/*			11/16/96	Added trap for plot with too few analysis points     */
/*			03/19/97	Added autoplot logic                                 */
/*			06/29/97	Use GET_WM_COMMAND_ID, etc. WIN32 compatibility      */
/*						macros to process WM_COMMAND messages:               */
/*						wParam <- GET_WM_COMMAND_ID(wParam, lParam)          */
/*                                                                           */
/*****************************************************************************/

#ifndef _MSC_VER
	#pragma argsused
#endif

BOOL CALLBACK PlotDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam)
{
	// Local variables
	// Handles
	HWND hChildWnd=NULL;
	HANDLE hChildAccel=NULL;
	// Chars
	// char szBuffer[BUFFER_SIZE+1];   // Text buffer

	// Put plot dialog box handle into global
	hPlotBox=hDlg;

	switch(message)
	{
		case WM_INITDIALOG:
		{
			// Assign global dialog box handle
			hDialog=hDlg;

			// Make sure plot subtitles are correct
			strlcpy(sPPlot.subtitle, szPhaseFileTitle, SUBTITLESIZE);
			strlcpy(sFPlot.subtitle, szFreqFileTitle, SUBTITLESIZE);

			// Autoplot
			// Doing this gives immediate plot when pressing Plot toolbutton
			// Handy, both in general & as part of future automatic "Wizard"
			if(bAutoPlot)
			{
				PostMessage(hDlg, WM_COMMAND,
					GET_WM_COMMAND_MPS(IDC_PLOT_PLOT, NULL, 0));
			}

			return TRUE;
		}

		case WM_COMMAND:
		{
			switch(GET_WM_COMMAND_ID(wParam, lParam))
			{
				// Respond to help button
				case IDHELP:
				{
					#if(0)
					// Invoke help file
					HtmlHelp(hDlg, "Stable32.chm::PLOT_FUNCTION.HTM",
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(0) // New code 11/29/11
					// Invoke help file
					strlcpy(szBuffer, szHelpFile, sizeof(szBuffer));
					strlcat(szBuffer, "::PLOT_FUNCTION.HTM", sizeof(szBuffer));
					HtmlHelp(hDlg, szBuffer,
						HH_DISPLAY_TOPIC, 0L);
					#endif

					#if(1) // Trial code 11/30/11
					// Invoke help file using CallHelp() function
					CallHelp(hDlg, "PLOT_FUNCTION");
					#endif
				}
				break;

				// Respond to plot button
				case IDC_PLOT_PLOT:
				{
					// Check for enough analysis points - need at least 4
					if(fData[2]-fData[1]<3)
					{
						TooFewMessage();
						break;
					}

					// Disable buttons
					EnableWindow(GETHCTL(IDCANCEL), FALSE);
					EnableWindow(GETHCTL(IDC_PLOT_PLOT), FALSE);
					EnableWindow(GETHCTL(IDC_PLOT_OPTIONS), FALSE);
					EnableWindow(GETHCTL(IDC_PLOT_LINES), FALSE);
					EnableWindow(GETHCTL(IDC_PLOT_NOTES), FALSE);
					EnableWindow(GETHCTL(IDHELP), FALSE);
					
					// Create child window for plot
					GPCWINCreate(hChildWnd, hInst, hDlg, SW_SHOWNORMAL,
						&hChildAccel, NULL);
				}
				break;

				// Respond to options button
				case IDC_PLOT_OPTIONS:
				{
					// Disable buttons
					EnableWindow(GETHCTL(IDCANCEL), FALSE);
					EnableWindow(GETHCTL(IDC_PLOT_PLOT), FALSE);
					EnableWindow(GETHCTL(IDC_PLOT_OPTIONS), FALSE);
					EnableWindow(GETHCTL(IDC_PLOT_LINES), FALSE);
					EnableWindow(GETHCTL(IDC_PLOT_NOTES), FALSE);
					EnableWindow(GETHCTL(IDHELP), FALSE);

					// Open options box
					if(nPlotType==FREQ_PLOT)
					{
						// Open freq plot options dialog box
						InvokeDialogBox(hInst, "DataPlotBox", hwndMain,
							(DLGPROC)FreqPlotDlgProc);
					}
					else // Phase plot
					{
						// Open phase plot options dialog box
						InvokeDialogBox(hInst, "DataPlotBox", hwndMain,
							(DLGPROC)PhasePlotDlgProc);
					}

					// Enable buttons
					EnableWindow(GETHCTL(IDCANCEL), TRUE);
					EnableWindow(GETHCTL(IDC_PLOT_PLOT), TRUE);
					EnableWindow(GETHCTL(IDC_PLOT_OPTIONS), TRUE);
					EnableWindow(GETHCTL(IDC_PLOT_LINES), TRUE);
					EnableWindow(GETHCTL(IDC_PLOT_NOTES), TRUE);
					EnableWindow(GETHCTL(IDHELP), TRUE);

					// Give plot control panel the focus
					SetFocus(hDlg);
				}
				break;

				// Respond to lines button
				case IDC_PLOT_LINES:
				{
					// Disable buttons
					EnableWindow(GETHCTL(IDCANCEL), FALSE);
					EnableWindow(GETHCTL(IDC_PLOT_PLOT), FALSE);
					EnableWindow(GETHCTL(IDC_PLOT_OPTIONS), FALSE);
					EnableWindow(GETHCTL(IDC_PLOT_LINES), FALSE);
					EnableWindow(GETHCTL(IDC_PLOT_NOTES), FALSE);
					EnableWindow(GETHCTL(IDHELP), FALSE);

					// Open lines box
					if(nPlotType==FREQ_PLOT)
					{
						// Open freq line options dialog box
						InvokeDialogBox(hInst, "PlotLineBox", hwndMain,
							(DLGPROC)FreqLineDlgProc);
					}
					else // Phase plot
					{
						// Open phase plot options dialog box
						InvokeDialogBox(hInst, "PlotLineBox", hwndMain,
							(DLGPROC)PhaseLineDlgProc);
					}

					// Enable buttons
					EnableWindow(GETHCTL(IDCANCEL), TRUE);
					EnableWindow(GETHCTL(IDC_PLOT_PLOT), TRUE);
					EnableWindow(GETHCTL(IDC_PLOT_OPTIONS), TRUE);
					EnableWindow(GETHCTL(IDC_PLOT_LINES), TRUE);
					EnableWindow(GETHCTL(IDC_PLOT_NOTES), TRUE);
					EnableWindow(GETHCTL(IDHELP), TRUE);

					// Give plot control panel the focus
					SetFocus(hDlg);
				}
				break;

				// Respond to options button
				case IDC_PLOT_NOTES:
				{
					// Disable buttons
					EnableWindow(GETHCTL(IDCANCEL), FALSE);
					EnableWindow(GETHCTL(IDC_PLOT_PLOT), FALSE);
					EnableWindow(GETHCTL(IDC_PLOT_OPTIONS), FALSE);
					EnableWindow(GETHCTL(IDC_PLOT_LINES), FALSE);
					EnableWindow(GETHCTL(IDC_PLOT_NOTES), FALSE);
					EnableWindow(GETHCTL(IDHELP), FALSE);

					// Open notes box
					if(nPlotType==FREQ_PLOT)
					{
						// Open frequency annotations dialog box
						InvokeDialogBox(hInst, "PlotNoteBox", hwndMain,
							(DLGPROC)FreqNoteDlgProc);
					}
					else // Phase plot
					{
						// Open phase plot options dialog box
						InvokeDialogBox(hInst, "PlotNoteBox", hwndMain,
							(DLGPROC)PhaseNoteDlgProc);
					}

					// Enable buttons
					EnableWindow(GETHCTL(IDCANCEL), TRUE);
					EnableWindow(GETHCTL(IDC_PLOT_PLOT), TRUE);
					EnableWindow(GETHCTL(IDC_PLOT_OPTIONS), TRUE);
					EnableWindow(GETHCTL(IDC_PLOT_LINES), TRUE);
					EnableWindow(GETHCTL(IDC_PLOT_NOTES), TRUE);
					EnableWindow(GETHCTL(IDHELP), TRUE);

					// Give plot control panel the focus
					SetFocus(hDlg);
				}
				break;

				// Respond to cancel button
				case IDCANCEL:
				{
					// Close dialog box
					EndDialog (hDlg, 0);
				}
				return TRUE;
			}
		}
		break;
	 }
	 return FALSE;
}

/*****************************************************************************/
/*                                                                           */
/*						        TVARLabel()                                  */
/*                                                                           */
/*		TVAR line labeling function                                          */
/*		Parameters:                                                          */
/*			int val     = exponent of tvar line, seconds                     */
/*			char *label = label string for tvar line                         */
/*							                                                 */
/*      Returns nothing (void)                                               */
/*                                                                           */
/*		Revision record:                                                     */
/*			10/26/96	Created from Stable/DOS function of same name        */
/*                                                                           */
/*****************************************************************************/
void WINAPI TVARLabel(int val, char *label)
{
	// Note: Size of label string is LABELSIZE

	switch(val)
	{
		case  6:	strlcpy(label, "1Ms", LABELSIZE);
					break;
		case  5:	strlcpy(label, "100ks", LABELSIZE);
					break;
		case  4:	strlcpy(label, "10ks", LABELSIZE);
					break;
		case  3:	strlcpy(label, "1ks", LABELSIZE);
					break;
		case  2:	strlcpy(label, "100s", LABELSIZE);
					break;
		case  1:	strlcpy(label, "10s", LABELSIZE);
					break;
		case  0:	strlcpy(label, "1s", LABELSIZE);
					break;
		case -1:	strlcpy(label, "100ms", LABELSIZE);
					break;
		case -2:	strlcpy(label, "10ms", LABELSIZE);
					break;
		case -3:	strlcpy(label, "1ms", LABELSIZE);
					break;
		case -4:	strlcpy(label, "100us", LABELSIZE);
					break;
		case -5:	strlcpy(label, "10us", LABELSIZE);
					break;
		case -6:	strlcpy(label, "1us", LABELSIZE);
					break;
		case -7:	strlcpy(label, "100ns", LABELSIZE);
					break;
		case -8:	strlcpy(label, "10ns", LABELSIZE);
					break;
		case -9:	strlcpy(label, "1ns", LABELSIZE);
					break;
		case -10:	strlcpy(label, "100ps", LABELSIZE);
					break;
		case -11:	strlcpy(label, "10ps", LABELSIZE);
					break;
		case -12:	strlcpy(label, "1ps", LABELSIZE);
					break;
		case -13:	strlcpy(label, "100fs", LABELSIZE);
					break;
		case -14:	strlcpy(label, "10fs", LABELSIZE);
					break;
		case -15:	strlcpy(label, "1fs", LABELSIZE);
					break;
		default:    _snprintf(label, LABELSIZE, "%-4.0e", pow(10.0,val));
					ShortenExp(label);
					break;
	}                                                          /* end switch */
}                                                        /* end tvar_label() */

/*****************************************************************************/
/*                                                                           */
/*						        ClipPlot()                                   */
/*                                                                           */
/*		Clip lines to plot area                                              */
/*							                                                 */
/*		Code suggested by Steve Kelley/Scientific Endeavors                  */
/*							                                                 */
/*		No parameters                                                        */
/*							                                                 */
/*      Returns nothing (void)                                               */
/*                                                                           */
/*		Revision record:                                                     */
/*			03/15/97	Created                                              */
/*                                                                           */
/*****************************************************************************/

void WINAPI ClipPlot(void)
{
	xl_cropq=xphysorq;
	yl_cropq=yphysorq;
	xh_cropq=xphysorq+xlenq;
	yh_cropq=yphysorq+ylenq;
}

/*****************************************************************************/
/*                                                                           */
/*						        UnclipPlot()                                 */
/*                                                                           */
/*		Reset clipping to defaults                                           */
/*							                                                 */
/*		Code suggested by Steve Kelley/Scientific Endeavors                  */
/*							                                                 */
/*		No parameters                                                        */
/*							                                                 */
/*      Returns nothing (void)                                               */
/*                                                                           */
/*		Revision record:                                                     */
/*			03/15/97	Created                                              */
/*                                                                           */
/*****************************************************************************/

void WINAPI UnclipPlot(void)
{
	xl_cropq=xbaseq;
	yl_cropq=ybaseq;
	xh_cropq=acrossq;
	yh_cropq=topq;
}

/*****************************************************************************/
/*                                                                           */
/*								InsertPlot()                                 */
/*                                                                           */
/*		Function to insert small plot into another plot                      */
/*		Intended to show freq or phase data plot on sigma plot               */
/*		                                                                     */
/*      Parameters:                                                          */
/*			x = lower left x plot location in pixels                         */
/*			y = lower left y plot location in pixels                         */
/*      	plotname = name of tkf plot to insert                            */
/*                                                                           */
/*		Screen has 4096 x 3120 pixels                                        */
/*      Bottom left corner is at (x,y) = (0,0)                               */
/*      Top right corner is at (x,y) = (4095,3119)                           */
/*		Character height is 64 pixels                                        */
/*		Vertical margin is 30 pixels                                         */
/*		Horizontal margin is 40 pixels                                       */
/*		Panel color 447 (white) prints OK                                    */
/*		Returns nothing (void)                                               */
/*                                                                           */
/*		Revision record:                                                     */
/*			12/12/98	Adapted from MessagePlot()                           */
/*                                                                           */
/*****************************************************************************/

void WINAPI InsertPlot( int x, int y, char *plotname)
{
	// local macros
	#define PLOT_HEIGHT 2000					 /* height of plot in pixels */
	#define PLOT_WIDTH 3000                       /* width of plot in pixels */

	// Local variables
	float *xpan;                                /* pointer to x vertex array */
	float *ypan;                                /* pointer to y vertex array */

	// Start of code
	// Allocate memory for x and y vertex arrays which are in user plot units
	if((xpan=(float*)malloc((NUM_SIDES+1)*sizeof(float)))==NULL)
	{
		AllocErrorMessage();
		return;
	}

	if((ypan=(float*)malloc((NUM_SIDES+1)*sizeof(float)))==NULL)
	{
		AllocErrorMessage();
		free(xpan);
		return;
	}

	// Shift pixel location wrt physical origin
	x+=xphysorq;
	y+=yphysorq;

	// Load box vertices into array with user units
	// pixtouser() converts pixel units to user units
	// Vertices are as follows: [3  ]    [2  ]
	//                          [0,4]    [1  ]
	// Note: The 350 pixel fudge factor narrows the width of the panel
	// which would otherwise be wider than the plot
	pixtouser(x, y, xpan, ypan);
	pixtouser(x+PLOT_WIDTH-350, y, xpan+1, ypan+1);
	pixtouser(x+PLOT_WIDTH-350, y+PLOT_HEIGHT, xpan+2, ypan+2);
	xpan[3]=xpan[0];
	ypan[3]=ypan[2];
	xpan[4]=xpan[0];             /* include these points to complete the box */
	ypan[4]=ypan[0];

	// Define panel area for plot - panel uses user units

	// This gives a bright white panel background w/o border
	panel(xpan, ypan, NUM_SIDES, PAN_COLOR, FALSE);
	
	// This gives a light gray panel background w/o border
	// panel(xpan, ypan, NUM_SIDES, 230, FALSE);

	// Process panel
	panproc();

	// Insert plot
	// insert() uses inch units, so pixel units are converted to inches
	insert(plotname, 1, pixtoin(x), pixtoin(y), pixtoin(PLOT_HEIGHT), 0);

	// Free x & y vertex arrays
	free(xpan);
	free(ypan);
}

/*****************************************************************************/
/*                                                                           */
/*						      AutocorrelationPlot()                          */
/*                                                                           */
/*		Function to plot autocorrelation sequence                            */
/*      Parameters:                                                          */
/*			y[] = array of autocorrelation data (w/o header)                 */
/*		p plotdata struct elements:                                          */
/*          data_title = plot title                                          */
/*          data_subtitle = plot subtitle                                    */
/*			x_label = x-axis label                                           */
/*			y_label = y-axis label                                           */
/*			x_offset = x-axis scale offset                                   */
/*			x_mult = x-axis scale multiplier                                 */
/*			y_offset = y-axis scale offset                                   */
/*			y_mult = y-axis scale multiplier                                 */
/*          scale_min = y-axis scale minimun                                 */
/*          scale_max = y-axis scale maximum                                 */
/*          y_div = # of y-axis major divisions                              */
/*          y_tic = # of y-axis tics between major divisions                 */
/*			do_box = draw box flag                                           */
/*      	do_phase_line = draw regression line flag                        */
/*			do_date = write date flag                                        */
/*     		do_mouse = activate mouse/cursor flag                            */
/*			new_file = new basic phase data file flag                        */
/*			new_name = new exact phase data flag flag                        */
/*			position = position of message box                               */
/*          phase_plot_filename = .tkf filename for plot                     */
/*                                                                           */
/*          No notes, lines, or options                                      */
/*                                                                           */
/*		Returns nothing (void)                                               */
/*                                                                           */
/*		Revision record:                                                     */
/*			08/05/03	Adapted from PhasePlot()                             */
/*			10/02/03	Changed plot insert code                             */
/*                                                                           */
/*****************************************************************************/

void WINAPI AutocorrelationPlot(float y[], struct plotdata *p)
{
	// Local macros
	#define XFORMAT_SIZE	8
	#define YFORMAT_SIZE	8
	
	// Local variables
	float *x;
	float width;
	float x_max, x_min;                                    /* x scale limits */
	float y_max, y_min;                                    /* y scale limits */
	float xste;                                        /* x-axis tic spacing */
	float yste;                                        /* y-axis tic spacing */
	float range;										     /* y-axis range */
	float dmin;                                                  /* data min */
	float dmax;                                                  /* data max */
	float dintercept;           /* lag 1 scatter plot linear fit y-intercept */
	float dslope;                     /* lag 1 scatter plot linear fit slope */
	int i;                                                  /* general index */
	int npts;                                    /* # autocorrelation points */
	int ndat;			                                    /* # data points */
	int nstart;	                                     /* analysis start point */
	int lgth;                                    /* message length in pixels */
	int line_flag=FALSE;             /* flag to draw horizontal line at zero */
	int x_div;						           /* # x-scale div for roundq() */
	int y_div;						           /* # y-scale div for roundq() */

	#ifdef DEMO_VERSION                               /* watermark variables */
	int x_pix, y_pix, x_pix_min, y_pix_min, x_pix_max, y_pix_max;
	#endif

	char buffer[BUFFER_SIZE+1];                               /* text buffer */
	char yformat[YFORMAT_SIZE];                       /* y-axis label format */
	char xformat[XFORMAT_SIZE];                       /* x-axis label format */

	// Colors
	int background_color=BRT_WHITE;
	int grid_color=BLACK;
	int box_color=BLACK;
	int label_color=BLUE;
	int data_color=RED;
	int annotation_color=BLACK;
	int line_color=GREEN;

	// Cursor variables
	float *fx;                              /* pointer to x-axis point array */
	float *fy;                              /* pointer to y-axis point array */
	int find;					                   /* point array dimensions */
	FILE *file;									             /* file pointer */
	
	// Set # autocorrelation data points
	npts=p->num;

	// Allocate memory for plot x array
	if((x=(float*)malloc((npts+1)*sizeof(float)))==NULL)
	{
		AllocErrorMessage();
		return;
	}

	// This is the begining of the actual GraphiC plotting code
	// Sequence of basic calls is per page I-34 of manual:
	//	   bgnplot()            	Initializations
	//	   startplot()          	Starts graphics
	//	   font()               	Loads fonts
	//	   page()               	Sets overall picture size
	//	   heading()				Draws title
	//	   xname(), yname()		 	Draws axis labels
	//	   area2d()					Defines axis lengths
	//

	// Write log info
	WriteLog(37, p->plot_filename);

	bgnplot(1,'g',p->plot_filename);                      /* initialize plot */
	startplot(background_color);         /* start plot with background color */
	font(4,"news.fnt",'\310',"swiss.fnt",'\311',"newsgrm.fnt",'\312',
		 "simplex.fnt",'\313');                                /* load fonts */

	page(FULLPAGE);                  /* Sets the maximum allowable page size */
	heading("");    /* Blank heading allows space for title & subtitle later */
	fillfont(1);                                         /* Use filled fonts */

	// Kill the beep
	GPCSetBeepDefaults(0, 0);

	// Avoid unwanted clipping 
	UnclipPlot();
	
	// Axis labeling code
	fntchg('\310');                                              /* news.fnt */
	if(nStyle==MODERN_STYLE)                           /* Use "modern" style */
	{
		fntchg('\311');                                          /*swiss.fnt */
		upright(1);                          /* upright y-axis label numbers */
		numht((float)0.18);                           /* larger axis numbers */
		xnamht((float)0.22);                         /* larger x-axis labels */
		ynamht((float)0.22);                         /* larger y-axis labels */
	}
	color(label_color);                                        /* all labels */
	yname(p->left_y_label);                                 /* labels y-axis */
	xname(p->x_label);                                      /* labels x-axis */

	// Set plot area
	area2d((float)7.8, (float)5.3);             /* Sets the area of the plot */

	// Insert lag scatter plot
	if(p->do_table)
	{
		// Define area for plot insert
		gwindow((float)6.65, (float)4.0, (float)8.65, (float)6.0);
	}	

	// Draw box
	color(box_color);                                  /* set box line color */
	if(p->do_box)
	{
		box();                                    /* draw box around picture */
	}                                                              /* end if */

	// Draw grid & frame
	// The grid() function draws the major grid lines (at tics)
	// The fgrid() function draws the fine grid lines (between tics)
	// The 1st fgrid() arg is: 0=no ticks, -1=tick marks
	// The 2nd fgrid() arg is # ticks=# intervals-1
	color(grid_color);                          /* set box & grid line color */
	grid(9);                         /* draws dotted grid through tick marks */
	fgrid(-1, 4);                /* fine grid tick marks between major ticks */
	frame(1,1);                          /* add frame with ticks around plot */
	upright(1);                        /* causes y-axis labels to be upright */
	fntchg('\310');                                              /* news.fnt */

	// Determine x-scale
	// Min is 0, max is npts, # divs & div size set by DetermineXScale()
	x_min=0.0;
	x_max=(float)npts;
	sAPlot.x_min=x_min;
	sAPlot.x_max=x_max;
	DetermineXScale(&sAPlot);
	x_div=sAPlot.x_div;
	x_max=sAPlot.x_max;
	x_min=sAPlot.x_min;
	xste=(float)((x_max-x_min)/x_div);

	// Adjust the x-scale format to avoid too long tic labels
	if(xste>=5000.0)
	{
		strlcpy(xformat, "%-1.1e", XFORMAT_SIZE);
	}
	else if(xste<=5.0)
	{
		strlcpy(xformat, "%-1.1f", XFORMAT_SIZE);
	}
	else
	{
		strlcpy(xformat, "%-1.0f", XFORMAT_SIZE);
	}

	// Determine y-scale
	// Max is always 1.0 and divisions are always 0.1
	// Min is whatever necessary to cover data range
	// # tics then determined accordingly
	minmax(&y_min, &y_max, y, npts);
	y_max=(float)1.0;
	range=y_max-y_min;
	yste=(float)0.1;
	y_div=(int)ceil(range/yste);
	y_min=y_max-yste*y_div;

	// Round y_min to avoid the dreaded 0.000000
	_snprintf(yformat, YFORMAT_SIZE, "%-1.3f", y_min);
	y_min=(float)atof(yformat);

	// Set x and y formats
	strlcpy(yformat, "%-1.1f", YFORMAT_SIZE);

	// Set plot scales
	graf(xformat, x_min, xste, x_max, yformat, y_min, yste, y_max);

	// Draw title & subtitle
	fntchg('\311');                                             /* swiss.fnt */
	color(label_color);                                   /* set label color */
	width=strwidth(p->title,(float)0.3);          /* get half-width of title */
	prtfnt((float)(4.75-width),(float)6.40,p->title,(float)0.3,0);  /* title */
	width=strwidth(p->subtitle,(float)0.15);   /* get half-width of subtitle */
	prtfnt((float)(4.75-width),(float)6.175,p->subtitle,(float)0.15,0); 

	fntchg('\310');                                              /* news.fnt */

	// Load x data
	for(i=0; i<=npts; i++)
	{
		x[i]=(float)i;
	}                                                             /* end for */
	
	color(data_color);                                         /* data color */

	// Set plot line thickness
	// 0 is default, 20 is wider
	tline(p->thick);

	// Clip phase data plot
	ClipPlot();

	for(i=0; i<npts-1; i++)                     /* plot autocorrelation data */
	{
		uline(*(x+i),*(y+i),*(x+i+1),*(y+i+1),1);
	}                                                             /* end for */

	// Unclip - probably unnecessary
	UnclipPlot();

	// Restore plot line thickness
	tline(0);

	fntchg('\313');                                           /* simplex.fnt */
	color(annotation_color);                       /* annotation color=black */

	// Write date
	if(p->do_date)
	{
		Dateline(1, 1, p->af);               /* put date & file info on plot */
	}                                                              /* end if */

	// Draw zero line
	if(p->do_line)
	{
		// Clip phase data plot
		ClipPlot();

		// Draw horizontal line at zero
		color(line_color);                                     /* line color */
		uline(0.0, 0.0, x_max, 0.0, 1);                         /* draw line */
		color(annotation_color);                   /* annotation color=black */

		// Avoid unwanted clipping 
		UnclipPlot();
	}                                                              /* end if */

	// Draw lag # marker
	if(p->do_table)
	{
		// Clip phase data plot
		ClipPlot();

		// Draw dashed vertical line at lag # - will get clipped as necessary
		color(line_color);                                     /* line color */
		dashf(4);
		uline((float)p->win, (float)-1.0, (float)p->win, (float)1.0, 1);
		                                                        /* draw line */
		color(annotation_color);                   /* annotation color=black */
		dashf(1);

		// Avoid unwanted clipping 
		UnclipPlot();
	}                                                              /* end if */

	// Display message box
	// Locations are x, y in pixels, origin at bottom left, 8192 x 6266 space
	// Find half length of message box in pixels
	lgth=(H_MARGIN+strwidtq(p->message_str, CHAR_HGTH));

	// Write message
	if(p->message_str[0]!='\0')         /* don't display a blank message box */
	{
		switch(p->position)
		{
			case MSG_TOP_LEFT:            /* message box at top left of plot */
			{
				MsgBox(300,4400,p->message_str);
				break;
			}                                                    /* end case */
			case MSG_MID_LEFT:         /* message box at middle left of plot */
			{
				MsgBox(300,2270,p->message_str);
				break;
			}                                                    /* end case */
			case MSG_BOT_LEFT:         /* message box at bottom left of plot */
			{
				MsgBox(300,200,p->message_str);
				break;
			}                                                    /* end case */
			case MSG_TOP_CENTER:        /* message box at top center of plot */
			{
				MsgBox(3470-lgth,4400, p->message_str);
				break;
			}                                                    /* end case */
			case MSG_MID_CENTER:     /* message box at middle center of plot */
			{
				MsgBox(3470-lgth,2270,p->message_str);
				break;
			}                                                    /* end case */
			case MSG_BOT_CENTER:     /* message box at bottom center of plot */
			{
				MsgBox(3470-lgth,200,p->message_str);
				break;
			}                                                    /* end case */
			case MSG_TOP_RIGHT:          /* message box at top right of plot */
			{
				MsgBox(6400-2*lgth,4400,p->message_str);
				break;
			}                                                    /* end case */
			case MSG_MID_RIGHT:       /* message box at middle right of plot */
			{
				MsgBox(6400-2*lgth,2270,p->message_str);
				break;
			}                                                    /* end case */
			case MSG_BOT_RIGHT:       /* message box at bottom right of plot */
			{
				MsgBox(6400-2*lgth,200,p->message_str);
				break;
			}                                                    /* end case */
		}                                                      /* end switch */
	}

	// Insert plot if bDoACFPlotInsert is set and not doing lag scatter plot
	if(bDoACFPlotInsert && !p->do_table)
	{
		// ACF plot insert filename is szACFPlotInsertFile
		// Try to open it
		if((file=fopen(szACFPlotInsertFile, "r"))!=NULL)
		{
			// Immediately release file pointer
			fclose(file);

			// Insert data plot at bottom left of sigma plot
			// Note:  This must be a tkf file or this will fail
			InsertPlot(300, 200, szACFPlotInsertFile);

		}
	}

	// Write label
	if(bPlotLabel)
	{
		UnclipPlot();
		color(annotation_color);                         /* annotation color */
		width=(float)intopix(strwidth(szPlotLabel, (float)0.05));
		putlabel(szPlotLabel, 8192-2*(width+20), 20, (float)0.05, 0,
			PIXEL_UNITS);
	}

	// Activate mouse cursor
	if(p->do_mouse)
	{
		// Allocate memory for x and y point arrays
		fx=(float*)gpcalloc(64, sizeof(float));
		fy=(float*)gpcalloc(64, sizeof(float));

		curson(0, 0, &fx, &fy, &find);                /* turn on mouse cursor*/

		// Free memory - this assumes that point info isn't needed
		gpcfree((void**)&fx);
		gpcfree((void**)&fy);
	}                                                              /* end if */

	rightax(0);

	// Avoid unwanted clipping 
	UnclipPlot();

	#ifdef DEMO_VERSION
	// Add watermark for demo version
	// Get plot size in pixels
	usertopix(x_max, y_max, 0.0, &x_pix_max, &y_pix_max);
	usertopix(x_min, y_min, 0.0, &x_pix_min, &y_pix_min);
	x_pix=x_pix_max-x_pix_min;
	y_pix=y_pix_max-y_pix_min;
	// Select hatched swiss font
	fntchg('\311');                                              /* news.fnt */
	fontfill(2, 230, 0);
	// Display watermark
	pltfnt((float)x_min, (float)y_min, "Stable32 Demo Version", (float)0.6,
		(int)(180*atan2((double)y_pix, (double)x_pix)/PI));
	#endif

	#ifdef VITSAS_VER
	// Add watermark for V-ITSAS version
	color(227);
	tmargin((float)0.15);
	ltline(" Stable32 V-ITSAS", (float)0.12);
	tmargin((float)0.15);
	rtline("Evaluation Version ", (float)0.12);
	#endif

	#if(1) // New code 11/23/11
	// Process bCmdM command to copy plot metafile to clipboard
	if(bCmdM)
	{
		// Send copy metafile message to GraphiC
		PostMessage(hGPC, WM_COMMAND,
			GET_WM_COMMAND_MPS(IDM_COPYMETA, 0, 0));
	}

	// Process bCmdT command to print plot
	if(bCmdT)
	{
		// Send print message to GraphiC
		PostMessage(hGPC, WM_COMMAND,
			GET_WM_COMMAND_MPS(IDM_PRINT, 0, 0));
	}

	// Process bCmdX command to close plot
	if(bCmdX)
	{
		// Show the plot briefly
		Sleep(1000);

		// Close plot and plot dialog box
		PostMessage(hPlot, WM_CLOSE, (WPARAM)0, (LPARAM)0);
		PostMessage(hPlotBox, WM_CLOSE, (WPARAM)0, (LPARAM)0);
	}
	
	#if(1)
	// End here w/o scatter plot
	// if(bCmdM || bCmdT || bCmdX)
	if(bCmdA) // Note that bCmdA is not reset until after plot is done
	{
		endplot();
		free(x);
		stopplot();
		return;
	}
	#endif
	#endif

	endplot();
									/* finish plot and wait for instructions */
												/* to exit or draw next plot */
										/* resets file pointers and defaults */
	// Get # data analysis points
	ndat=(int)(fData[2]-fData[1]+1);

	// The # of scatter plot points is the # of analysis points
	// minus the lag # = ndat - p->win

	// Insert lag scatter plot
	if(p->do_table && ndat-p->win>2)
	{
		// Start insert plot
		startplot(background_color);
		
		// Do font scaling
		setscale(1);

		// Draw box around plot area
		color(box_color);
		box();

		// Write title
		color(label_color);
		_snprintf(buffer, sizeof(buffer), "Lag %d Scatter Plot", p->win);
		heading(buffer);

		// Reallocate memory for scatter plot x array
		if((x=(float*)realloc(x, (ndat)*sizeof(float)))==NULL)
		{
			AllocErrorMessage();
			return;
		}

		// Get analysis start point
		nstart=(int)fData[1];

		// Fill x array with data points
		// Note:  y axis will use x array offset by lag #
		//for (i=0; i<ndat-p->win; i++)
		for (i=0; i<ndat; i++)
		{
			x[i]=(float)fData[nstart+i+ARRAY_OFFSET-1];
		}

		// Set up plot scales
		axesoff(AXESOFF);
		color(grid_color);
		scales(10, 10, x, x, ndat-p->win);

		// Draw scatter plot (points w/o lines)
		scatplot(1);
		color(data_color);
		if(ndat>10000)
		{
			sympick(16); // Small dot
		}
		else
		{
			sympick(12); // Big dot
		}

		// Clip scatter plot
		ClipPlot();
		
		// Draw curve
		curve(x, x+p->win, ndat-p->win, 1);

		// Restore normal curves
		scatplot(0);

		// Calc linear fit
		minmax(&dmin, &dmax, x, ndat-p->win);
		CalcLinFit(x, x+p->win, ndat-p->win, &dintercept, &dslope);

		// Draw fit line (data has zero mean)
		color(line_color);
		uline(dmin, dintercept+dmin*dslope, dmax, dintercept+dmax*dslope, 1);

		// Stop clipping
		UnclipPlot();

		// Show slope
		_snprintf(buffer, sizeof(buffer), "Slope=%1.3f", dslope);
		prtfnt((float)4.0, (float)0.5, buffer, (float)0.3, 0);
		
		// End plot insert
		endplot();
	}

	// Free plot array
	free(x);

	// Done
	stopplot();                                        /* close files & exit */
}

/*****************************************************************************/
/*                                                                           */
/*  						   CalcLinFit()                                  */
/*                                                                           */
/*		Function to calculate linear fit y=a+bx                              */
/*                                                                           */
/*		Parameters:		float x[]   = x data array                           */
/*                      floay y[]   = y data array                           */
/*			            int n       = array size                             */
/*      	            float *a    = pointer to y-intercept                 */
/*      	            float *b    = pointer to slope                       */
/*                                                                           */
/*      Return:         none (void)                                          */
/*						                                                     */
/*      Note: Must have at least 2 data points - if not, a & b = 0           */
/*                                                                           */
/*		Revision record:                                                     */
/*			08/16/03	Created                                              */
/*			08/24/03	Changed summation variables to double to avoid       */
/*						problems due to numerical precision                  */
/*                                                                           */
/* (c) Copyright 12003  Hamilton Technical Services  All Rights Reserved     */
/*                                                                           */
/****************************************************************************/

void WINAPI CalcLinFit(float x[], float y[], int n, float *a, float *b)
{
	// Local variables
	int i;
	double sum_x  = 0;
	double sum_y =  0;
	double sum_xx = 0;
	double sum_yy = 0;
	double sum_xy = 0;

	// Check for at least 2 data points
	if(n<2)
	{
		// Error
		*a = 0.0;
		*b = 0.0;
		return;
	}

	// Do summations
	for(i=0; i<n; i++)
	{
		sum_x  += x[i];
		sum_y  += y[i];
		sum_xx += x[i]*x[i];
		sum_yy += y[i]*y[i];
		sum_xy += x[i]*y[i];
	}                                                           

	// Calc coefficients
	*b = (float)((sum_xy - ((sum_x) * (sum_y) / n)));
	*b = (float)(*b / (sum_xx- ((sum_x) * (sum_x)) / n));
	*a = (float)(((sum_y) / n) - (*b * sum_x / n));

	return;
}                                                        /* end CalcLinFit() */

/*****************************************************************************/
/*                                                                           */
/*						      LagScatterPlot()                               */
/*                                                                           */
/*		Function to plot lag scatter plot                                    */
/*      Parameters:                                                          */
/*			F_TYPE fData[]     = array of phase or frequency data            */
/*			struct plotdata p* = lag scatter plot data structure             */
/*                                                                           */
/*		Returns nothing (void)                                               */
/*                                                                           */
/*		Revision record:                                                     */
/*			08/20/03	Adapted from AutocorrelationPlot()                   */
/*                                                                           */
/*****************************************************************************/

void WINAPI LagScatterPlot(F_TYPE fData[], struct plotdata *p)
{
	// Local macros
	#define FORMAT_SIZE	8
	
	// Local variables
	// Ints
	int i;                                                  /* general index */
	int ndat;			                                    /* # data points */
	int nstart;	                                     /* analysis start point */
	int exp;                                        /* scale factor exponent */
	int div;                                                 /* # scale divs */

	// Chars
	char buffer[BUFFER_SIZE+1];                               /* text buffer */
	char format[FORMAT_SIZE];                          /* scale label format */

	// Floats
	float dmin;                                                  /* data min */
	float dmax;                                                  /* data max */
	float dintercept;           /* lag 1 scatter plot linear fit y-intercept */
	float dslope;                     /* lag 1 scatter plot linear fit slope */
	float *x;										  /* x data for plotting */
	float width;                                             /* string width */
	float mult;										     /* scale multiplier */
	float m, s;                                            /* mean & std dev */
	float avg;                                                    /* average */

	// Lag plot x and y scale values for graf()
	float min;                                                    /* maximum */
	float max;                                                    /* minimum */
	float inc;                                     /* increment per division */

	// F_TYPES
	F_TYPE fMean;                                               /* data mean */
	F_TYPE fStdDev;                                          /* data std dev */
	F_TYPE fTau;						                         /* data tau */

	// Colors
	int background_color=BRT_WHITE;
	int grid_color=BLACK;
	int box_color=BLACK;
	int label_color=BLUE;
	int data_color=RED;
	int annotation_color=BLACK;
	int line_color=GREEN;

	// Cursor variables
	float *fx;                              /* pointer to x-axis point array */
	float *fy;                              /* pointer to y-axis point array */
	int find;					                   /* point array dimensions */

	#ifdef DEMO_VERSION
	// Watermark variables
	float x_max, x_min;                                    /* x scale limits */
	float y_max, y_min;                                    /* y scale limits */
	int x_pix, y_pix, x_pix_min, y_pix_min, x_pix_max, y_pix_max;
	#endif

	// Start plot
	bgnplot(1,'g',p->plot_filename);                      /* initialize plot */
	startplot(background_color);         /* start plot with background color */
	font(4,"news.fnt",'\310',"swiss.fnt",'\311',"newsgrm.fnt",'\312',
		 "simplex.fnt",'\313');                                /* load fonts */

	page(FULLPAGE);                  /* Sets the maximum allowable page size */
	heading("");    /* Blank heading allows space for title & subtitle later */
	fillfont(1);                                         /* Use filled fonts */

	// Kill the beep
	GPCSetBeepDefaults(0, 0);

	// Get scale multiplier & # divs
	if(bDataType==FREQ_DATA)
	{
		// Get scale values from sFPlot struct:
		mult=sFPlot.y_mult;
		div=sFPlot.y_div;
		min=mult*sFPlot.y_min;
		max=mult*sFPlot.y_max;
		inc=(max-min)/div;
		avg=mult*sFPlot.y_avg;

		// Get freq tau
        GetWindowText(hwndFreqTau, buffer, BUFFER_SIZE);
        fTau=(F_TYPE)atof(buffer);

	}
	else // Phase data
	{
		// Get scale values from sPPlot struct:
		mult=sPPlot.y_mult;
		div=sPPlot.y_div;
		min=mult*sPPlot.y_min;
		max=mult*sPPlot.y_max;
		inc=(max-min)/div;
		avg=mult*sPPlot.y_avg;

		// Get phase tau
        GetWindowText(hwndPhaseTau, buffer, BUFFER_SIZE);
        fTau=(F_TYPE)atof(buffer);
	}

	// Round tic separation to avoid the dreaded 0.000000
	_snprintf(format, sizeof(format), "%-1.3f", inc);
	inc=(float)atof(format);

	// Determine scale format to avoid equal adjacent tic labels
	if(inc>=10.)
	{
		strlcpy(format, "%-1.0f", FORMAT_SIZE);
	}
	else if(inc>=1.0)
	{
		strlcpy(format, "%-1.1f", FORMAT_SIZE);
	}
	else if(inc>=0.1)
	{
		strlcpy(format, "%-1.2f", FORMAT_SIZE);
	}
	else
	{
		strlcpy(format, "%-1.3f", FORMAT_SIZE);
	}

	// Convert multiplier into exponent
	if(mult>0)
	{
		exp=(int)(ceil(log10(mult)));
	}
	else
	{
		exp=(int)(floor(log10(mult)));
	}

	// Avoid unwanted clipping 
	UnclipPlot();
	
	// Axis labeling code
	fntchg('\310');                                              /* news.fnt */
	if(nStyle==MODERN_STYLE)                           /* Use "modern" style */
	{
		fntchg('\311');                                          /*swiss.fnt */
		upright(1);                          /* upright y-axis label numbers */
		numht((float)0.18);                           /* larger axis numbers */
		xnamht((float)0.22);                         /* larger x-axis labels */
		ynamht((float)0.22);                         /* larger y-axis labels */
	}
	color(label_color);                                        /* all labels */
	if(bDataType==FREQ_DATA)
	{
		if(exp>0)
		{
			_snprintf(buffer, sizeof(buffer), "Frequency, y(t+1), "
				"pp10[%d]", exp);
			yname(buffer);                                  /* labels y-axis */
			_snprintf(buffer, sizeof(buffer), "Frequency, y(t), "
				"pp10[%d]", exp);
			xname(buffer);									/* labels x-axis */
		}
		else if(exp==0)
		{
			_snprintf(buffer, sizeof(buffer), "Frequency, y(t+1)");
			yname(buffer);                                  /* labels y-axis */
			_snprintf(buffer, sizeof(buffer), "Frequency, y(t)");
			xname(buffer);									/* labels x-axis */
		}
		else
		{
			_snprintf(buffer, sizeof(buffer), "Frequency, y(t+1), "
				"x10[%d]", -exp);
			yname(buffer);                                  /* labels y-axis */
			_snprintf(buffer, sizeof(buffer), "Frequency, y(t), 	x10[%d]",
				-exp);
			xname(buffer);									/* labels x-axis */
		}
	}
	else // Phase data
	{
		if(exp>0)
		{
			_snprintf(buffer, sizeof(buffer), "Phase, x(t+1), Seconds x10[%d]",
				-exp);
			yname(buffer);                                  /* labels y-axis */
			_snprintf(buffer, sizeof(buffer), "Phase, x(t), Seconds x10[%d]",
				-exp);
			xname(buffer);                                  /* labels x-axis */
		}
		else if(exp==0)
		{
			_snprintf(buffer, sizeof(buffer), "Phase, x(t+1)");
			yname(buffer);                                  /* labels y-axis */
			_snprintf(buffer, sizeof(buffer), "Phase, x(t)");
			xname(buffer);                                  /* labels x-axis */
		}
		else
		{
			_snprintf(buffer, sizeof(buffer), "Phase, x(t+1), Seconds x10[%d]",
				-exp);
			yname(buffer);                                  /* labels y-axis */
			_snprintf(buffer, sizeof(buffer), "Phase, x(t), Seconds x10[%d]",
				-exp);
			xname(buffer);                                  /* labels x-axis */
		}
	}

	// Set plot area
	area2d((float)7.8, (float)5.3);             /* Sets the area of the plot */

	// Draw box
	color(box_color);                                  /* set box line color */
	if(p->do_box)
	{
		box();                                    /* draw box around picture */
	}                                                              /* end if */

	// Draw grid & frame
	// The grid() function draws the major grid lines (at tics)
	// The fgrid() function draws the fine grid lines (between tics)
	// The 1st fgrid() arg is: 0=no ticks, -1=tick marks
	// The 2nd fgrid() arg is # ticks=# intervals-1
	color(grid_color);                          /* set box & grid line color */
	grid(9);                         /* draws dotted grid through tick marks */
	fgrid(-1, 4);                /* fine grid tick marks between major ticks */
	frame(1,1);                          /* add frame with ticks around plot */
	upright(1);                        /* causes y-axis labels to be upright */

	// Draw title & subtitle
	fntchg('\311');                                             /* swiss.fnt */
	color(label_color);                                   /* set label color */
	_snprintf(buffer, sizeof(buffer), "LAG %d SCATTER PLOT", p->win);
	width=strwidth(buffer, (float)0.3);           /* get half-width of title */
	prtfnt((float)(4.75-width), (float)6.40, buffer, (float)0.3, 0);
                                                               /* draw title */
	// Note: Use same subtitle as autocorrelation plot (could use sFileTitle)
	width=strwidth(sAPlot.subtitle, (float)0.15);  /* half-width of subtitle */
	prtfnt((float)(4.75-width), (float)6.175, sAPlot.subtitle, (float)0.15,0);
                                                            /* draw subtitle */

	// Get # data analysis points
	ndat=(int)(fData[2]-fData[1]+1);

	// Reallocate memory for scatter plot x array
	// Note: y-axis data uses same array offset by lag
	if((x=(float*)malloc(ndat*sizeof(float)))==NULL)
	{
		AllocErrorMessage();
		return;
	}

	// Get analysis start point
	nstart=(int)fData[1];

	// Fill x array with data points
	for (i=0; i<ndat; i++)
	{
		x[i]=(float)fData[nstart+i+ARRAY_OFFSET-1];
		x[i]*=mult;
	}

	// Set up plot scales
	fntchg('\310');                                              /* news.fnt */
	color(grid_color);
	graf(format, min, inc, max, format, min, inc, max);

	// Draw scatter plot (points w/o lines)
	scatplot(1);
	color(data_color);

	// Set plot symbol
	if(ndat<10000)
	{
		sympick(12); // Solid dot
		symht((float)0.035);
	}
	else
	{
		sympick(4); // Cross
		symht((float)0.075);
	}

	// Clip phase data plot
	ClipPlot();
		
	// Draw curve
	curve(x, x+p->win, ndat-p->win, 1);

	// Restore normal curves
	scatplot(0);

	// Find data min & max
	minmax(&dmin, &dmax, x, ndat);

	// Calc linear fit
	CalcLinFit(x, x+p->win, ndat-p->win, &dintercept, &dslope);

	// Draw fit line
	color(line_color);
	uline(dmin, avg-(avg-dmin)*dslope, dmax, avg+(dmax-avg)*dslope, 1);

	// Calc mean & std dev
	// Note that freq std dev is used for both phase & freq data
	CalcMean(fData, &fMean, bDataType);
	CalcFreqStdDev(fData, &fStdDev);
	m=mult*(float)fMean;
	s=mult*(float)fStdDev;

	// Draw sigma boxes
	color(line_color);

	// Clip phase data plot
	ClipPlot();

	// Draw dashed boxes for 1, 2, & 3 sigma bounds
	dashf(4);
	fntchg('\311');                                              /* news.fnt */
	for(i=1; i<4; i++)
	{
		uline(m-i*s, m-i*s, m-i*s, m+i*s, 1);
		uline(m-i*s, m+i*s, m+i*s, m+i*s, 1);
		uline(m+i*s, m+i*s, m+i*s, m-i*s, 1);
		uline(m+i*s, m-i*s, m-i*s, m-i*s, 1);

		_snprintf(buffer, sizeof(buffer), "%ds", i);
		pltfnt((float)(m+i*s), (float)(m+i*s), buffer, (float)0.1, (int)0.0);
	}
	dashf(1);

	// Stop clipping
	UnclipPlot();

	// Choose annotation color
	color(annotation_color);

	// Sigma box annotation
	tmargin((float)6.655);
	fntchg('\313');                                           /* simplex.fnt */
	ctline("Boxes are 1, 2 & 3 sigma bounds",(float)0.075);

	// Write date
	if(p->do_date)
	{
		Dateline(1, 1, p->af);               /* put date & file info on plot */
	}                                                              /* end if */

	// Show slope
	fntchg('\313');                                           /* simplex.fnt */
	_snprintf(buffer, sizeof(buffer), "Slope = %1.3f", dslope);
	if(dslope>0)
	{
		MsgBox(300, 4400, buffer);
	}
	else // Negative slope
	{
		MsgBox(300,200, buffer);
	}

	// Activate mouse cursor
	if(p->do_mouse)
	{
		// Allocate memory for x and y point arrays
		fx=(float*)gpcalloc(64, sizeof(float));
		fy=(float*)gpcalloc(64, sizeof(float));

		// Turn on mouse cusor
		curson(0, 0, &fx, &fy, &find);

		// Free memory - this assumes that point info isn't needed
		gpcfree((void**)&fx);
		gpcfree((void**)&fy);
	}                                                              /* end if */

	// Turn off right hand axis
	rightax(0);

	// Avoid unwanted clipping 
	UnclipPlot();

	#ifdef DEMO_VERSION
	// Add watermark for demo version
	// Get plot size in pixels
	// Note:  These should really be scale max & min, but don't know them
	// so use data max & min instead
	x_max=dmax;
	y_max=dmax;
	x_min=dmin;
	y_min=dmin;
	usertopix(x_max, y_max, 0.0, &x_pix_max, &y_pix_max);
	usertopix(x_min, y_min, 0.0, &x_pix_min, &y_pix_min);
	x_pix=x_pix_max-x_pix_min;
	y_pix=y_pix_max-y_pix_min;
	// Select hatched swiss font
	fntchg('\311');                                              /* news.fnt */
	fontfill(2, 230, 0);
	// Display watermark
	pltfnt((float)x_min, (float)y_min, "Stable32 Demo Version", (float)0.6,
		(int)(180*atan2((double)y_pix, (double)x_pix)/PI));
	#endif

	#ifdef VITSAS_VER
	// Add watermark for V-ITSAS version
	color(227);
	tmargin((float)0.15);
	ltline(" Stable32 V-ITSAS", (float)0.12);
	tmargin((float)0.15);
	rtline("Evaluation Version ", (float)0.12);
	#endif

	#if(1) // New code 11/23/11
	// Process bCmdM command to copy plot metafile to clipboard
	if(bCmdM)
	{
		// Send copy metafile message to GraphiC
		PostMessage(hGPC, WM_COMMAND,
			GET_WM_COMMAND_MPS(IDM_COPYMETA, 0, 0));
	}

	// Process bCmdT command to print plot
	if(bCmdT)
	{
		// Send print message to GraphiC
		PostMessage(hGPC, WM_COMMAND,
			GET_WM_COMMAND_MPS(IDM_PRINT, 0, 0));
	}

	// Process bCmdX command to close plot
	if(bCmdX)
	{
		// Show the plot briefly
		Sleep(1000);

		// Close plot and plot dialog box
		PostMessage(hPlot, WM_CLOSE, (WPARAM)0, (LPARAM)0);
		PostMessage(hPlotBox, WM_CLOSE, (WPARAM)0, (LPARAM)0);
	}
	#endif

	// End plot insert
	endplot();

	// Free plot array
	free(x);

	// Done
	stopplot();                                        /* close files & exit */
}

/*****************************************************************************/
/*                                                                           */
/*							DynamicSigmaPlot()                               */
/*                                                                           */
/*		Function to plot Dynamic Allan variance data                         */
/*                                                                           */
/*      Surface of log sigma values defined by 3D matrix of multiple sets	 */
/*		of log AF points                                                     */
/*                                                                           */
/*		Revision record:                                                     */
/*			11/09/05    Created - based on D3TEST.C                          */
/*			11/11/05	2nd test version - based on FILTEST.C                */
/*			11/16/05	Pretty much done                                     */
/*			11/19/05	Activated in release 1.46 now under development      */
/*			11/29/05	Added variable colors                                */
/*			11/30/05	Added color surface plot grid control                */
/*			12/26/06	Added provisions for adjustable viewpoint            */
/*			07/24/10	Fixed typo in minmax() call                          */
/*			08/09/11	Still getting DAVAR crash for large data sets        */
/*						Corrected zmat size argument ib ninmax() call        */
/*                                                                           */
/*****************************************************************************/

void WINAPI DynamicSigmaPlot(struct d3plotdata *p)
{
	// Line types
	#define MAJOR_GRID	1
	#define	MINOR_GRID	9
	#define SOLID_LINE	1

	// Variance types
	#define DHVARTYPE 0
	#define DAVARTYPE 1

	// Variables
	char txt[BUFFER_SIZE+1];  // Text buffer
	char buf[5*MESSAGESIZE+1]; // Text buffer
	char msg[5*MESSAGESIZE+1]; // Message buffer
	int i;					 // Index
	int j;					 // Index
	int k;					 // Index
	int q;					 // Index
	int r;					 // Index
	int s;					 // Start index
	int lgth;                // Message length in pixels
	int yscale;				 // y-axis scale factor 
	float width;             // Half-width of label string
	float zmin;				 // Min z array value
	float zmax;				 // Max z array value
	float zdec;				 // Z-axis decade
	int xdec;				 // X-axis decade

	// Panel matrix
	float xx[4];			 // Panel x corners
	float yy[4];			 // Panel y corners
	float zz[4];			 // Panel z corners

	// Grid line locations
	float xgrid;			 // x-axis grid line location
	float ygrid;			 // y-axis grid line location
	float zgrid;			 // z-axis grid line location

	// Colors
	int background_color=BRT_WHITE;
	int grid_color=BLACK;
	int box_color=BLACK;
	int label_color=BLUE;
	int data_color=RED;
	int annotation_color=BLACK;
	int line_color=GREEN;

	// 3D surface colors (#=20)
	int colors[]=
		{249,248,255,297,333,331,330,292,299,298,335,370,446,444,442,436,\
		425,426,382,412};

	// Write log info
	WriteLog(71, p->plot_filename);

	// Open plot session
	bgnplot(1, 'g', "DAVAR.tkf"); 
	
	// Plot in inches
	metricunits(0);

	// Prepare to do DAVAR plot
	startplot(background_color);                    /* White plot background */
	page(FULLPAGE);                                      /* Define page size */
	area2d(9.0, 6.0);                                    /* Define plot size */

	// Select fonts
	font(4,"news.fnt",'\310',"swiss.fnt",'\311',"newsgrm.fnt",'\312',
		 "simplex.fnt",'\313');                                /* load fonts */
	fillfont(1);                                         /* Use filled fonts */

	// Kill the beep
	GPCSetBeepDefaults(0, 0);

	// Compose title
	color(label_color);                                        /* blue title */
	strlcpy(buf, "\311", sizeof(buf));
	strlcat(buf, p->title, sizeof(buf));
	d3head(buf, 't');                                          /* Draw title */

	// Set y-axis scale factor & label
	if(p->ny>1000)
	{
		yscale=100;
		y3name("\311Window @# x100");
	}
	else if(p->ny>100)
	{
		yscale=10;
		y3name("\311Window @# x10");
	}
	else
	{
		yscale=1;
		y3name("\311Window @#");
	}
	
	// Set plot x & z axis labels
	x3name("\311Log AF");                                 /* Draw axis names */
	z3name("\311Log Sigma");

	// Set up 3D plot volume
	// Horizontal aspect ratio chosen to fill page better
	volm3d((float)1.0, (float)1.0, (float)0.5);       /* Define aspect ratio */
	vuabs(p->xvu, p->yvu, p->zvu);                          /* Set viewpoint */

	// Set up axes
	color(grid_color);                /* Draw black axes with simplex labels */
	fntchg('\313');

	// Note:  The axis scales set in graf3d apparently do not affect the
	// surmatr() irregularly-spaced surface plot.  The axis scales should
	// agree with the surmatr() grid values, but the two sets of parameters
	// are apparently independent.  Furthermore, it appears that the grid
	// values in surmatr() must be the exact min & max values of the x and y
	// arrays, not "nice" plot scale values.  So, to keep everything right,
	// get the min & max of the x & y arrays, and use those in both graf3d()
	// and surmatr().
	
	#if(0) // For debugging
	// Display message as subtitle
	sprintf(p->subtitle, "npts=%d, xsize*ysize=%d", p->npts, p->xsize*p->ysize);
	// Draw subtitle
	tmargin(6.5);
	color(label_color);
	strlcpy(buf, "\311", sizeof(buf));
	strlcat(buf, p->subtitle, sizeof(buf));
	ctline(buf, (float)0.15);
	#endif
	
	// Get min & max of x and y arrays and set grid limits
	minmax(&p->xgmin, &p->xgmax, p->x, p->npts);
	minmax(&p->ygmin, &p->ygmax, p->y, p->npts);

	// Get min & max of z array and set scale limits
	// minmax(&zmin, &zmax, p->zmat, p->npts); // Fixed typo z instead of zmat 07/24/10
	//                                            as used in Ver. 1.57 but DAVAR plot
	//                                            crashes for large data sets
	minmax(&zmin, &zmax, p->zmat, p->xsize*p->ysize); // Perhaps right 08/09/11

	// Seems better to start y-axis at zero
	// (avoids scales like 1, 11, 22, etc.)
	p->ygmin=0;

	// Set up 3D plot axes
	graf3d(p->xgmin, 0.5, p->xgmax, p->ygmin/yscale, 10, p->ygmax/yscale,
		zmin, 0.5, zmax);

	// Draw y plane at ygmin behind plot
	xx[0]=p->xgmax;
	yy[0]=p->ygmin/yscale;
	zz[0]=zmax;
	xx[1]=p->xgmax;
	yy[1]=p->ygmin/yscale;
	zz[1]=zmin;
	xx[2]=p->xgmin;
	yy[2]=p->ygmin/yscale;
	zz[2]=zmin;
	xx[3]=p->xgmin;
	yy[3]=p->ygmin/yscale;
	zz[3]=zmax;
	panel3d(xx, yy, zz, 4, 174, 1);
	panproc();

	// Draw x plane at xgmin behind plot
	xx[0]=p->xgmin;
	yy[0]=p->ygmin/yscale;
	zz[0]=zmin;
	xx[1]=p->xgmin;
	yy[1]=p->ygmax/yscale;
	zz[1]=zmin;
	xx[2]=p->xgmin;
	yy[2]=p->ygmax/yscale;
	zz[2]=zmax;
	xx[3]=p->xgmin;
	yy[3]=p->ygmin/yscale;
	zz[3]=zmax;
	panel3d(xx, yy, zz, 4, 174, 1);
	panproc();

	// Draw vertical log grid lines in y plane at ygmin/scale behind plot
	// Draw AF grid lines
	// Loop thru AFs (1 thru nStabPoints=p->nx) in decades
	k=1;
	for(i=1; i<=p->nx; i+=k)
	{
		for(j=1; j<=10; j++)
		{
			if(j==1 || j==10)
			{
				dashf(MAJOR_GRID);
			}
			else
			{
				dashf(MINOR_GRID);
			}

			xgrid=(float)log10((double)(j*k));
			// Don't go past xgmax
			if(xgrid>p->xgmax)
			{
				break;
			}
			d3line(xgrid, p->ygmin/yscale, zmin, xgrid, p->ygmin/yscale, zmax);
		}
		k*=10;
	}

	// Draw full log AF grid lines in bottom z plane
	// Set xdec to bottom log AF decade value (0)
	xdec=1;

	// Loop thru log AF x-axis decades
	// # decades = ceil(xgmax)
	for(i=1; i<=p->nx; i+=xdec)
	{
		// Loop thru log AF increments 1-10
		for(j=1; j<=10; j++)
		{
			if(j==1 || j==10)
			{
				dashf(MAJOR_GRID);
			}
			else
			{
				dashf(MINOR_GRID);
			}

			// Set x value where line goes
			xgrid=(float)log10((double)(j*xdec));

			// Don't go above xgmax
			if(xgrid<=p->xgmax)
			{
				d3line(xgrid, p->ygmin/yscale, zmin, xgrid,
					p->ygmax/yscale, zmin);
			}
		}
		xdec*=10;
	}
	
	// Restore solid line
	dashf(MAJOR_GRID);

	// Draw Window # lines in x plane at back
	// The spacing is always 10
	for(i=1; i<10; i++)
	{
		ygrid=(float)((i*10));
		// Don't go past ygmax
		if(ygrid>p->ygmax/yscale)
		{
			break;
		}
		d3line(p->xgmin, ygrid, zmin, p->xgmin, ygrid, zmax);
	}
	
	// Draw Window # lines in z plane at bottom
	// The spacing is always 10
	for(i=1; i<10; i++)
	{
		ygrid=(float)((i*10));
		// Don't go past ygmax
		if(ygrid>p->ygmax/yscale)
		{
			break;
		}
		d3line(p->xgmin, ygrid, zmin, p->xgmax, ygrid, zmin);
	}

	// Draw horizontal log grid lines in y plane at ygmin/scale behind plot
	// Draw sigma grid lines
	// Set zdec to bottom sigma decade value (e.g. 1e-11)
	zdec=(float)pow(10, floor(zmin));

	// Loop thru log sigma decades from zmin to zmax
	// # decades = ceil(zmax-zmin)
	for(i=0; i<(int)(ceil(zmax-zmin)); i++)
	{
		// Loop thru log sigma increments 1-10
		for(j=1; j<=10; j++)
		{
			if(j==1 || j==10)
			{
				dashf(MAJOR_GRID);
			}
			else
			{
				dashf(MINOR_GRID);
			}

			// Get z value where line goes
			zgrid=(float)log10((double)(j*zdec));

			// Don't go below zmin or above zmax
			if((zgrid>=zmin)&&(zgrid<=zmax))
			{
				d3line(p->xgmin, p->ygmin/yscale, zgrid, p->xgmax,
					p->ygmin/yscale, zgrid);
			}
		}
		zdec*=10;
	}

	// Draw horizontal log grid lines in rear x plane at xgmin behind plot
	// Draw sigma grid lines
	// Set zdec to bottom sigma decade value (e.g. 1e-11)
	zdec=(float)pow(10, floor(zmin));

	// Loop thru log sigma decades from zmin to zmax
	// # decades = ceil(zmax-zmin)
	for(i=0; i<(int)(ceil(zmax-zmin)); i++)
	{
		// Loop thru log sigma increments 1-10
		for(j=1; j<=10; j++)
		{
			if(j==1 || j==10)
			{
				dashf(MAJOR_GRID);
			}
			else
			{
				dashf(MINOR_GRID);
			}

			// Get z value where line goes
			zgrid=(float)log10((double)(j*zdec));

			// Don't go below zmin or above zmax
			if((zgrid>=zmin)&&(zgrid<=zmax))
			{
				d3line(p->xgmin, p->ygmin/yscale, zgrid, p->xgmin,
					p->ygmax/yscale, zgrid);
			}
		}
		zdec*=10;
	}

	// Restore line type
	dashf(SOLID_LINE);

	// Draw box
	color(box_color);                                
	if(p->do_box)
	{
		box();                    
	}

	// Grid control (uses p->grid)
	// Control color grid: 0=No grid, 1=normal grid
	// 2 and higher = use surmatc() instead of surmat()
	// and use grid as ixpts & iypts to reduce grid spacing
	// grid is element of d3plotdata struct with control in DAVAR dlg box
	// Applies only to color surface plot (p->colors=1)

	// Set plot color
	if(p->colors)
	{
		// Variable colors
		color(grid_color);
		if(p->grid)
		{
			d3color(colors, 20, DRAW_MESH);
		}
		else // No grid
		{
			d3color(colors, 20, 0);
		}
	}
	else
	{
		// All red
		color(data_color);
		d3color(colors, 0, DRAW_MESH);
	}

	// Plot 3D surface from z matrix
	if((!p->colors) || (p->grid<2)) // Normal code for no colors or fine grid
	{
		// Plot z matrix of sigma data
		surmat(p->zmat, p->xsize, p->ysize);
	}
	else // Colors with coarse grid
	{
		// Coarse grid code
		// Plot z matrix of sigma data
		// Last 2 args set # x & y mesh points to skip
		// Something like this can look good, but plotting is much slower
		// In general, it's better to let user choose settings (# windows)
		// It's also somewhat confusing when grid gets coarser
		// than plotted points
		// But this is available if wanted
		surmatc(p->zmat, p->xsize, p->ysize, p->grid, p->grid);
	}

	// Draw subtitle
	tmargin(6.5);
	color(label_color);
	strlcpy(buf, "\311", sizeof(buf));
	strlcat(buf, p->subtitle, sizeof(buf));
	ctline(buf, (float)0.15);

	// Write date
	color(annotation_color);
	fntchg('\313');
	if(p->do_date)
	{
		Dateline(1, 1, 1);
	}

	// Plot scale annotations
	// Sigma annotation
	// The sigma range is from p->smin to p->smax
	if(p->vartype==DAVARTYPE)
	{
		strlcpy(txt, "Sigma Type:\n ADEV", sizeof(txt));
	}
	else // HDEV
	{
		strlcpy(txt, "Sigma Type:\n HDEV", sizeof(txt));
	}
	_snprintf(buf, sizeof(buf),
		"\nSigma Range:\n %5.3e\n     to\n %5.3e", p->smin, p->smax);
	
	strlcat(txt, buf, sizeof(txt));
	ShortenExp(txt);
	// putlabel(txt, 350, 5000, (float)0.10, 1, PIXEL_UNITS);
	// Sigma annotation moved up and left 12/26/06
	putlabel(txt, 200, 5900, (float)0.10, 1, PIXEL_UNITS);

	// Tau annotation
	// The tau (x) range is from tau0 to max AF * tau0 where max AF = p->nx
	_snprintf(buf, sizeof(buf),
		"Tau Range:\n %5.3e\n     to\n %5.3e", p->tau0, p->nx*p->tau0);
	ShortenExp(buf);
	// putlabel(buf, 6200, 900, (float)0.10, 1, PIXEL_UNITS);
	// Tau annotation moved down and  right 12/26/06
	putlabel(buf, 7200, 600, (float)0.10, 1, PIXEL_UNITS);
	
	// Window annotation
	_snprintf(buf, sizeof(buf),
		"Analysis Windows:\n %d Windows\n of Size %d\n & Step Size %d\n"
		"Time Span:\n %5.3e sec",
		p->ny, p->winsize, p->stepsize, p->tau0*p->ny);
	ShortenExp(buf);
	// putlabel(buf, 350, 1190, (float)0.10, 1, PIXEL_UNITS);
	// Window annotation moved down and left 12/26/06
	putlabel(buf, 200, 890, (float)0.10, 1, PIXEL_UNITS);

	// Display message box
	// Locations are x, y in pixels, origin at bottom left, 8192 x 6266 space

	// Copy message into working buffer
	// This done to preserve original \n chars for display and ini saving
	strlcpy(msg, p->message_str, sizeof(msg));

	// Initialize lgth;
	lgth=0;

	// Write message
	if(msg[0]!='\0')         /* Don't display a blank message box */
	{
		// Allow message to respond to \n as newline
		// Without this code \n works directly in putlabel string
		// but not in message
		// Set j to total original message length
		j=strlen(msg);

		// Set row start index
		s=0;

		// Loop through copy of message string replacing \n chars with newline
		for(i=0; i<j; i++)
		{
			// Look for \n sequence - first check for backslash character
			if(msg[i]=='\\')
			{
				// Then check for n character
				if(msg[i+1]=='n')
				{
					// If detect \n character sequence, then replace backslash
					// with newline character
					msg[i]='\n';
					// Shift up the rest of the characters in the string
					// including the \0 EOS at the end
					k=i+1;
					while(k<j)
					{
						msg[k]=msg[k+1];
						k++;
					}

					// Shorten overall length
					j--;

					// Find length of longest line
					// Get difference between start and current indices
					// Calc length of current line & use it if longest so far
					if(i-s>lgth) // Current line is longest so far
					{
						lgth=i-s-1;

						// Save longest line
						r=0;
						for(q=s; q<i; q++)
						{
							buf[r]=msg[q];
							r++;
						}
						buf[r]='\0';
					}

					// Reset row start index
					s=i;

					// Advance main index
					i++;
				}
			}
		}
		
		// Find half length of message box in pixels
		if(lgth>0) // Determined by half of length of longest \n line
		{
			if((i-s)>lgth) // Last line is longest
			{
				lgth=i-s-1;

				// Save longest line
				r=0;
				for(q=s; q<i; q++)
				{
					buf[r]=msg[q];
					r++;
				}
				buf[r]='\0';
			}

			// Find half length in pixels
			lgth=(H_MARGIN+strwidtq(buf, CHAR_HGTH));
		}
		else // Message is just 1 line
		{
			// Find half length in pixels
			lgth=(H_MARGIN+strwidtq(msg, CHAR_HGTH));
		}		

		// Write message
		switch(p->position)
		{
			case MSG_TOP_LEFT:            /* message box at top left of plot */
			{
				putlabel(msg, 300, 5400, (float)0.10,
					2, PIXEL_UNITS);
				break;
			}                                                    
			case MSG_MID_LEFT:         /* message box at middle left of plot */
			{
				putlabel(msg, 300, 2270, (float)0.10,
					2, PIXEL_UNITS);
				break;
			}                                                    
			case MSG_BOT_LEFT:         /* message box at bottom left of plot */
			{
				putlabel(msg, 300, 200, (float)0.10,
					2, PIXEL_UNITS);
				break;
			}                                                    
			case MSG_TOP_CENTER:        /* message box at top center of plot */
			{
				putlabel(msg, 4200-(float)lgth, 5400, (float)0.10,
					2, PIXEL_UNITS);
				break;
			}                                                    
			case MSG_MID_CENTER:     /* message box at middle center of plot */
			{
				putlabel(msg, 4200-(float)lgth, 2270, (float)0.10,
					2, PIXEL_UNITS);
				break;
			}                                                    
			case MSG_BOT_CENTER:     /* message box at bottom center of plot */
			{
				putlabel(msg, 4200-(float)lgth, 200, (float)0.10,
					2, PIXEL_UNITS);
				break;
			}                                                    
			case MSG_TOP_RIGHT:          /* message box at top right of plot */
			{
				putlabel(msg, 7000-(float)lgth, 5400, (float)0.10,
					2, PIXEL_UNITS);
				break;
			}                                                    
			case MSG_MID_RIGHT:       /* message box at middle right of plot */
			{
				putlabel(msg, 7000-(float)lgth, 2270, (float)0.10,
					2, PIXEL_UNITS);
				break;
			}                                                    
			case MSG_BOT_RIGHT:       /* message box at bottom right of plot */
			{
				putlabel(msg, 7000-(float)lgth, 200, (float)0.10,
					2, PIXEL_UNITS);
				break;
			}                                                    
		}                                                      
	}

	// Write label
	if(bPlotLabel)
	{
		UnclipPlot();
		color(annotation_color);                         /* annotation color */
		width=(float)intopix(strwidth(szPlotLabel, (float)0.05));
		putlabel(szPlotLabel, (float)(8192-2*(width+20)), (float)20.0,
			(float)0.05, 0, PIXEL_UNITS);
	}

	#if(1) // New code 11/23/11
	// Process bCmdM command to copy plot metafile to clipboard
	if(bCmdM)
	{
		// Send copy metafile message to GraphiC
		PostMessage(hGPC, WM_COMMAND,
			GET_WM_COMMAND_MPS(IDM_COPYMETA, 0, 0));
	}

	// Process bCmdT command to print plot
	if(bCmdT)
	{
		// Send print message to GraphiC
		PostMessage(hGPC, WM_COMMAND,
			GET_WM_COMMAND_MPS(IDM_PRINT, 0, 0));
	}

	// Process bCmdX command to close plot
	if(bCmdX)
	{
		// Show the plot briefly
		Sleep(1000);

		// Close plot and plot dialog box
		PostMessage(hPlot, WM_CLOSE, (WPARAM)0, (LPARAM)0);
		PostMessage(hPlotBox, WM_CLOSE, (WPARAM)0, (LPARAM)0);
	}
	#endif

	// End plot and session
	endplot();                                               /* End of plot */
	stopplot();                                         /* End plot session */
}

/*****************************************************************************/
/*                                                                           */
/*							     lmfunc()                                    */
/*                                                                           */
/*		Function to evaluate function for Levenberg-Marquart curve fit       */
/*                                                                           */
/*		It evaluates the function for parameter vector p[] at n points       */
/*		putting the results into vector x[]                                  */
/*		p is the parameter vector                                            */
/*		x is the function value vector                                       */
/*		m is the # parameters = p[] dimension                                */
/*		n is the # measurements = x[] dimension                              */
/*      adata is pointer to additional data = pointer to function string     */
/*                                                                           */
/*		Revision record:                                                     */
/*			12/17/07    Created                                              */
/*                                                                           */
/*****************************************************************************/

void lmfunc(double *p, double *x, int m, int n, void *adata)
{
	char szParam[BUFFER_SIZE+1];		// Parameter letter
	int i;								// Index
	int a;								// Return flag
	int r;								// Return value
	double di;							// i as double value
	
	// Set the parameter values
	// Note that they must be in alphabetical order without any gaps
	for(i=0; i<m; i++)
	{
		szParam[0]='a'+i;
		szParam[1]='\0';
		SetValue(szParam, &p[i]);
	}
	
	// Evaluate expression
	for(i=0; i<n; i++)
	{
		di=(double)i;
		SetValue("t", &di);
		r=Evaluate(adata, &x[i], &a );
	}
}

#if(0) // Not part of normal program - original obsolete version
/****************************************************************************/
/*                                                                          */
/*							   jumps()                                      */
/*                                                                          */
/*		Function to find jumps in frequency data                            */
/*		Parameters:                                                         */
/*			double y[]		    	frequency data array                    */
/*			int		 num			# data points                           */
/*			int		 avg_factor     averaging factor                        */
/*			double	 limit			jump limit                              */
/*                                                                          */
/*		Return:                                                             */
/*			int		 # jumps                                                */
/*                                                                          */
/*		Note:	A jumps is defined as a change in frequency of more than    */
/*				the limit between adjacent averages of avg_factor points.   */
/*                                                                          */
/*		Revision record:                                                    */
/*			10/08/92	Created                                             */
/*			12/11/92	Added tests to avoid divide by zero                 */
/*			12/13/92	Eliminated unused variables                         */
/*			01/25/08	Copied from MMS1.C                                  */
/*						y[] array changed to float for testing              */
/*			                                                                */
/****************************************************************************/

int jumps(float y[], int num, int avg_factor, double limit)
{
	int i;                                          /* outer index for data */
	int j;                                     /* inner index for averaging */
	int jmps=0;                                                  /* # jumps */
	double sum;                                /* partial sum for averaging */
	double points;                                     /* # points averaged */
	double avg1, avg2;                                          /* averages */

	/* pad data by adding zeros at end as required to make final group */
	while(num%avg_factor)
	{
		y[num++]=0;
	}                                                          /* end while */

	/* search for jumps */
	for(i=0; i<num-2*avg_factor; i+=avg_factor)       /* loop thru all data */
	{
		/* form 1st moving average of avg_factor points */
		sum=0;
		points=0;
		for(j=0; j<avg_factor; j++)                            
		{
			if(y[i+j])										  /* skip gaps */
			{
				sum+=y[i+j];
				points++;
			}                                                     /* end if */
		}                                                        /* end for */
		avg1=0;
		if(points)                                  /* avoid divide by zero */
		{
			avg1=sum/points;
		}                                                         /* end if */

		/* form 2nd moving average of avg_factor points */
		sum=0;
		points=0;
		for(j=avg_factor; j<2*avg_factor; j++)                                               
		{
			if(y[i+j])										   /* skip gaps */
			{
				sum+=y[i+j];
				points++;
			}                                                     /* end if */
		}                                                        /* end for */
		avg2=0;
		if(points)
		{
			avg2=sum/points;
		}                                                         /* end if */

		/* if both averages exist, */
		/* check if difference in averages exceeds limit */
		if( (avg1) && (avg2) && fabs(avg2-avg1)>limit )
		{
			jmps++;
		}                                                         /* end if */
	}                                                            /* end for */

	return(jmps);                                                /* # jumps */
}                                                            /* end jumps() */

/****************************************************************************/
#endif

#if(1) // Now part of normal program
/****************************************************************************/
/*                                                                          */
/*							   blkjumps()                                   */
/*                                                                          */
/*		Function to find jumps in frequency data                            */
/*      using blocks of analysis window pairs                               */
/*                                                                          */
/*		Parameters:                                                         */
/*			double	 y[]		    frequency data array                    */
/*			int		 num			# data points                           */
/*			int		 length			window length                           */
/*			int		 offset			wundow offset                           */
/*			float	 limit			jump limit                              */
/*          float	 mean[]			mean value array                        */
/*                                                                          */
/*		Return:                                                             */
/*			int		 # jumps                                                */
/*                                                                          */
/*		Note:	A jumps is defined as a change in frequency of more than    */
/*				the limit between adjacent averages of length points.       */
/*                                                                          */
/*		Revision record:                                                    */
/*			10/08/92	Created                                             */
/*			12/11/92	Added tests to avoid divide by zero                 */
/*			12/13/92	Eliminated unused variables                         */
/*			01/25/08	Copied from MMS1.C                                  */
/*						y[] array changed to float for testing              */
/*			01/30/08	Created from jumps()                                */
/*			02/02/08	Fully implemented                                   */
/*			02/03/08	Added offset argument                               */		
/*			02/08/08	Main loop test changed from < to <= to fix problem  */
/*			            when # points is exact multiple of window length    */
/*			                                                                */
/****************************************************************************/

int blkjumps(float y[], int num, int length, int offset, float limit,
			 float mean[])
{
	int i;                                          /* outer index for data */
	int j;                                     /* inner index for averaging */
	int jmps=0;                                                  /* # jumps */
	BOOL flag=0;                                               /* jump flag */
	double sum;                                /* partial sum for averaging */
	double points;                                     /* # points averaged */
	double avg1, avg2;                                          /* averages */

	/* search for jumps */
	for(i=offset; i<=num-2*length+offset; i+=length)          /* loop thru all data */
	{
		/* form 1st moving average of length points */
		sum=0;
		points=0;
		for(j=0; j<length; j++)                            
		{
			if(y[i+j])										   /* skip gaps */
			{
				sum+=y[i+j];
				points++;
			}                                                     /* end if */
		}                                                        /* end for */
		avg1=0;
		if(points)                                  /* avoid divide by zero */
		{
			avg1=sum/points;
		}                                                         /* end if */

		/* form 2nd moving average of length points */
		sum=0;
		points=0;
		for(j=length; j<2*length; j++)                                               
		{
			if(y[i+j])										   /* skip gaps */
			{
				sum+=y[i+j];
				points++;
			}                                                     /* end if */
		}                                                        /* end for */
		avg2=0;
		if(points)
		{
			avg2=sum/points;
		}                                                         /* end if */

		/* if both averages exist, */
		/* check if difference in averages exceeds limit */
		if( (avg1) && (avg2) && fabs(avg2-avg1)>limit )
		{
			// Increment jump count
			jmps++;

			// Set jump flag
			flag=1;
			
		}                                                         /* end if */
		else // Not a jump
		{
			// Clear jump flag
			flag=0;
		}

		// Plot the averages
		// They have nothing to do with the jumps
		// They just show the average values in each block
		// Put 1st point average into mean plot array
		for(j=0; j<length; j++)
		{
			mean[i+j]=(float)avg1;
		}

		// Put 2nd point average into mean plot array
		for(j=0; j<length; j++)
		{
			mean[i+j+length]=(float)avg2;
		}

		// Make "marker" at jump
		if(flag)
		{
			// This elmminates the vertical line at a jump
			// and puts a zero value in the jump file
			mean[i+length-1]=0.0;
			flag=0;
		}
	}                                                            /* end for */
	
	return(jmps);                                                /* # jumps */
}                                                         /* end blkjumps() */

/****************************************************************************/
#endif

#if(0) // Not part of normal program - just for some special tests
/****************************************************************************/
/*                                                                          */
/*							      stars()                                   */
/*                                                                          */
/*      Sequential t-Test Analysis of Regine Shifts                         */
/*                                                                          */
/*		Function to find jumps in frequency data                            */
/*		Parameters:                                                         */
/*			float	y[]		    frequency data array						*/
/*			int		num			# data points								*/
/*			int		lgth		length of analysis window					*/
/*			double	prob		probability level							*/
/*          float	mean[]		mean value array                            */
/*			double	*thresh		jump limit threshold (sigmas)               */
/*                                                                          */
/*     The jump decision limit is made by determining whether or not        */
/*     there has been a statistically significant change in the mean        */
/*     based on the Student's t distribution:                               */
/*                                                                          */
/*     Is the change in the mean value > t/sqrt(2*V/N)                      */
/*                                                                          */
/*     where:		t	Value of t for certain probably p                   */
/*                      for given # degrees of freedom = 2(N-1)             */
/*                  N	Size of window used to determine local mean         */
/*                  V   Variance of window data (assumed constant)          */
/*                                                                          */
/*      We use the invstudenttdistribution() function to calc t  for a      */
/*      certain probability (e.g., 0.90) and window size (e.g., 30), and    */
/*      use the standard variance of the whole data set (rather than AVAR)  */
/*		at AF=window size for the variance (assumed to be constant).        */
/*                                                                          */
/*      This is similar to what we did previously in the jump() function    */
/*		by setting the limit at a certain multiple of the sigma, but it is  */
/*		now based on a statistical principles using a known probability     */
/*		value and is independent of the window size.                        */
/*                                                                          */
/*      The limit parameter is therefore changed to the probability level   */
/*                                                                          */
/*		Return:                                                             */
/*			int		 # jumps (or -1 if error)                               */
/*                                                                          */
/*		Notes:                                                              */
/*			1.	A jumps is defined as a change in frequency of more than    */
/*				the limit between adjacent averages of avg_factor points.   */
/*              Compared with the original jumps() function, this one (a)   */
/*              uses a criterion based on the Student's t distribution      */
/*              to define a change in the mean, (b) steps the window        */
/*              point-by-point, and (b) uses acumulative sum to validate    */
/*              the jump.                                                   */
/*			2.	Make sure y[] array is allocated for any additional points  */
/*				that are added to make final averaging group.               */
/*          3.  The mean[] array must be pre-allocated to the same size as  */
/*              the frequency data array.  The mean() array will be filled  */
/*              with the average value of each regime point - it can be     */
/*				plotted to show the regimes and jumps between them.  Its    */
/*              first differences are either 0 (no jump) or the size (and   */
/*              location) of the jump -which can be summarized in a table.  */
/*                                                                          */
/*      References:                                                         */
/*          1.	S.N. Rodionov, "A Sequential Algorithm for Testing Climate  */
/*				Regime Shifts", Geophysical Research Lettere, Vol. 31,      */
/*				L09204, 2004.                                               */
/*          2.	S.N. Rodionov and J.E. Overland, "Application of a          */
/*				Sequential Regime Shift Detection Method to the Bering      */
/*              Sea Ecosystem, ICES Journal of Marine Science, Vol. 62,     */
/*				pp. 328-332, 2005.                                          */
/*                                                                          */
/*                                                                          */
/*		Revision record:                                                    */
/*			10/08/92	Created                                             */
/*			12/11/92	Added tests to avoid divide by zero                 */
/*			12/13/92	Eliminated unused variables                         */
/*			01/25/08	Copied from MMS1.C                                  */
/*						y[] array changed to float for testing              */
/*          01/26/08	Revised function based on statistical principles    */
/*                      of references                                       */
/*			01/28/08	Implemented STARS algorithm                         */
/*			                                                                */
/****************************************************************************/

int stars(float y[], int num, int lgth, double prob, float mean[],
	double *thresh)
{
	int i;                                              /* data array index */
	int j;                                         /* position within group */
	int k;                                                       /* group # */
	int g;					                                    /* # groups */
	int df;			                                  /* degrees of freedom */
	int jmps=0;                                                  /* # jumps */
	int dir;                                           /* direction of jump */
	double sum;                                        /* sum for averaging */
	double sumsqr;                           /* sum of squares for variance */
	double points;                                     /* # points averaged */
	double var;						                            /* variance */
	double avg;                                     /* overall data average */
	double limit;						                      /* jump limit */
	double min, max;	                              /* min and max limits */
	double t;								           /* Student's t value */
	double shift;                                         /* amount of jump */
	double rsi;				                          /* regime shift index */
	double meanval;					                          /* mean value */

	
	// Note: This code follows the Reference 1 algorthm
	// unless otherwise noted

	// Pad data by adding zeros at end as required to make final group
	// Note:  Is this necessary? Could adjust loop limits instead.
	// but this seems to be the easier way for now anyway
	// Increase y[] and meas[] array allocations by lgth to be sure
	// that they are big enough, or calc num%lgth and use that increment
	while(num%lgth)
	{
		y[num++]=0;
	}
	
	// Find # of groups
	g=num/lgth;

	// Step 1 of algorithm is done: group (regime or window) size l=lgth

	// Step 2 of algorithm is to determine the jump diff=limit
	var=sumsqr/(points-1);

	// Find average of variances for size=lgth intervals over entire data set
	// This is a strange statistic
	// It's not the standard N-sample variance
	// nor is it the N-sample variance after a certain averaging factor
	// It's the lgth-sample variance in the same sense that
	// the Allan variance is a 2-sample variance
	var=0.0;
	// Loop thru the g data windows of length lgth
	for(i=0; i<g; i++)
	{
		// Calc average over the current window
		sum=0.0;
		points=0;
		for(j=0; j<lgth; j++)                            
		{
			// Skip gaps
			if(y[i*lgth+j])										  
			{
				sum+=y[i*lgth+j];
				points++;
			}                                                     
		}                                                        
		avg=0.0;

		// Avoid divide by zero
		if(points)                                  
		{
			avg=sum/points;
		}                                                         

		// Calc std variance over the current window
		sumsqr=0.0;
		points=0;
		for(j=0; j<lgth; j++)                            
		{
			// Skip gaps
			if(y[i*lgth+j])										  
			{
				sumsqr+=(y[i*lgth+j]-avg)*(y[i*lgth+j]-avg);
				points++;
			}                                                     
		}                                                        
		var+=sumsqr/(points-1);
	}
	var/=g;

	// TRACE_EXP(var);

	// Calc t
	// Ref: Crow et al, Statistics Manual, Table 3
	// prob is the confidence level that the mean changed
	// This is a two-tailed test because
	// the jump can be up or down
	// hence prob is divided by 2
	// The choice prob or (1-prob) depends on
	// details of the inverse t calc
	// which changes sign of resulting t
	// The fabs() takes care of this anyway
	df=2*lgth-2;
	
	// This 2nd arg gives negative t (same magnitude as using 1-prob/2.0)
	// so would need fabs()
	// Better to use 1-prob/2.0 as 2nd arg
	// t= invstudenttdistribution(df, prob/2.0);
	// For the following, use small prob values (e.g. 0.05)
	// Don't need fabs()
	// prob is confidence level that reported jump didn't actually happen
	// Smaller prob gives wider test limit
	// Smaller df gives wider test limit
	// t value nearly constant for df > 20 or so (lgth 10 or so)
	// t value change more versus df for smaller prob
	t= invstudenttdistribution(df, 1-prob/2.0);
	// t= fabs(invstudenttdistribution(df, 1-prob/2.0));

	// TRACE_EXP(t);

	// Calc jump limit - applies to entire data set
	// This expression is the Student's t-test for
	// comparing two means having the same variance var
	// and sample size lgth
	// Ref: Numerical Recipes Ch. 14 Eqns. 14.2.1 & 14-2-2
	// and Wikipedia "Students t-test"
	limit=t*sqrt(2*var/lgth);

	// For testing
	// This changes jump limit and # jumps detected
	// Seem to get much better results if limits increased
	// even with small prob
	// limit*=2;

	// TRACE_EXP(limit);

	// Set threshold = limit in sigmas
	*thresh=(double)(limit/sqrt(var));

	// Step 3 of algorithm is to calc mean of 1st group
	// and the min and max values corresponding to a jump
	// Calc average of first lgth points
	// having indices from 0 to lgth-1
	sum=0.0;
	points=0;
	for(i=0; i<lgth; i++)                            
	{
		// Skip gaps
		if(y[i])										  
		{
			sum+=y[i];
			points++;
		}                                                     
	}                                                        
	avg=0.0;

	// Avoid divide by zero
	if(points)                                  
	{
		avg=sum/points;
	}
	
	// TRACE_EXP(avg);
	
	// Set mean value
	meanval=avg;
	
	// Put avg of 1st group into mean[] array
	// There doesn't seem to be any other choice
	// The analysis starts at i=lgth
	for (i=0; i<lgth; i++)
	{
		mean[i]=(float)meanval;
	}

	// Calc first jump limits
	min=avg-limit;
	max=avg+limit;

	// TRACE_EXP(min);
	// TRACE_EXP(max);
	
	// Step 4 of the algorithm begins here
	
	// Loop thru all data
	// starting at i=lgth
	i=lgth;
	// Try starting at 2nd point
	//i=1;
	while(i<g*lgth)
	{
		// Is point outside limits
		if( (y[i]<min) || (y[i]>max) )
		{
			// Step 5
			// Possible jump at this point
			j=i;

			// Initialize RSI to zero
			rsi=0.0;

			// Save direction of shift
			if(y[i]>max) // Shift up
			{
				dir=1;
			}
			if(y[i]<min) // Shift down
			{
				dir=-1;
			}

			while( (rsi>=0.0) && (i<j+lgth) )
			{
				// Jump still possible
				// Calculate RSI
				if(dir>0) // Shift up
				{
					shift=y[i]-avg;
				}
				else // Shift down
				{
					shift=avg-y[i];
				}
				rsi+=shift/(lgth*sqrt(var));

				// Increment data index
				i++;
			}

			if(rsi>0) // Jump confirmed
			{
				// Increment jump count
				jmps++;

				// For testing
				// Jump point
				// TRACE_INT(j);
				// Jump value
				// TRACE_EXP(y[j]);
				
				// Calc avg for new regime
				sum=0.0;
				points=0;

				// for(k=j; k<i; k++)
				
				// This seems better
				// because i was incremented above
				// and plot may look better too
				// Think about it
				for(k=j; k<i-1; k++)                            
				{
					// Skip gaps
					if(y[k])										  
					{
						sum+=y[k];
						points++;
					}                                                     
				}                                                        
				avg=0.0;

				// Avoid divide by zero
				if(points)                                  
				{
					avg=sum/points;
				} 
				
				// Recalc first jump limits
				min=avg-limit;
				max=avg+limit;

				// Save new mean value
				meanval=avg;

				// Save avg in array
				// This doesn't seem to make any difference
				// whether it is included or not
				// mean[i]=(float)meanval;
			}

			// Resume testing at i=j+1;
			i=j+1;

			//TRACE_INT(j);
			
			// i=j here causes program to totally fail 
		}
		else // Not a possble jump
		{
			// Jump not detected
			// Recalc avg with new value
			// excluding earliest one
			sum=0.0;
			points=0;
			for(k=i; k>i-lgth; k--)                            
			{
				// Skip gaps
				if(y[k])										  
				{
					sum+=y[k];
					points++;
				}                                                     
			}                                                        
			avg=0.0;

			// Avoid divide by zero
			if(points)                                  
			{
				avg=sum/points;
			} 
			
			// Recalc first jump limits
			min=avg-limit;
			max=avg+limit;

			// Save previous mean value in array
			mean[i]=(float)meanval;

			// Don't get vertical lines w/o this
			mean[i-1]=(float)meanval;

			// Note: It is also necessary to initialize the m[] array
			// to all zeros to avoid spikes in the plot
			// apparently due to unitialized values
			// that this function sometimes fails to set 
			
			// Increment data index
			i++;
		}
	}
	
	return(jmps);                                                /* # jumps */
}                                                            /* end stars() */

/****************************************************************************/
#endif

#if(1) // Not part of normal program - possible alternative to blkjumps()
	   // Not yet working corectly - may not care
/****************************************************************************/
/*                                                                          */
/*							      seqjumps()                                */
/*                                                                          */
/*      Sequential Jump Detection                                           */
/*                                                                          */
/*		Function to find jumps in frequency data                            */
/*		Parameters:                                                         */
/*			float	y[]		    frequency data array						*/
/*			int		num			# data points								*/
/*			int		lgth		length of analysis window					*/
/*			int		offset		window offset (not used)                    */
/*			float	limit		jump threshold								*/
/*          float	mean[]		mean value array                            */
/*                                                                          */
/*		Return:                                                             */
/*			int		 # jumps (or -1 if error)                               */
/*                                                                          */
/*		Notes:                                                              */
/*			1.	A jumps is defined as a change in frequency of more than    */
/*				the limit between adjacent averages of lgth points.         */
/*			2.	Make sure y[] array is allocated for any additional points  */
/*				that are added to make final averaging group.               */
/*          3.  The mean[] array must be pre-allocated to the same size as  */
/*              the frequency data array.  The mean() array will be filled  */
/*              with the average value of each regime point - it can be     */
/*				plotted to show the regimes and jumps between them.  Its    */
/*              first differences are either 0 (no jump) or the size (and   */
/*              location) of the jump -which can be summarized in a table.  */
/*                                                                          */
/*      References:                                                         */
/*          1.	S.N. Rodionov, "A Sequential Algorithm for Testing Climate  */
/*				Regime Shifts", Geophysical Research Lettere, Vol. 31,      */
/*				L09204, 2004.                                               */
/*                                                                          */
/*		Revision record:                                                    */
/*			02/03/08	Created from start()                                */
/*			            Function signature changed to that of blkjumps()    */
/*			            offset arg will probably not be used                */
/*			            limit arg replaces prob of start()                  */
/*			            thresh arg eliminated                               */
/*			02/21/08	Extensive rewrite for improved algorithm            */
/*						Good results - probably better than blkjumps()      */
/*			                                                                */
/****************************************************************************/

int seqjumps(float y[], int num, int lgth, int offset, float limit,
			 float mean[])
{
	int i;                                              /* data array index */
	int j;                                         /* position within group */
	int jmps=0;                                                  /* # jumps */
	int p;                                       /* point index in RSI calc */
	double sum;                                        /* sum for averaging */
	double points;                                     /* # points averaged */
	double avg;                                     /* overall data average */
	double min, max;	                              /* min and max limits */
	double meanval;					                          /* mean value */

	// Note: This code follows general flow of the Reference 1 algorthm
	// It has been modified to use a certain jump threshold limit
	// instead of a limit calculated by a t-test
	// and to use a simple average of points after a potential jump

	// Step 1 of algorithm is done: group (regime or window) size l=lgth
	// Step 2 of algorithm is to determine the jump diff=limit
	// is also done - it is also an input argument
	// Step 3 of algorithm is to calc mean of 1st group
	// and the min and max values corresponding to a jump
	// Calc average of first lgth points
	// having indices from 0 to lgth-1
	sum=0.0;
	points=0;
	for(i=0; i<lgth; i++)                            
	{
		// Skip gaps
		if(y[i])										  
		{
			sum+=y[i];
			points++;
		}                                                     
	}                                                        
	avg=0.0;

	// Avoid divide by zero
	if(points)                                  
	{
		avg=sum/points;
	}
	else // No average possible in first group
	{
		// Error message - need to do something better than this
		// TRACE_STR("No average found");
		return -1; // Error code
	}

	// Set mean value
	meanval=avg;
	
	// Put avg of 1st group into mean[] array
	// There doesn't seem to be any other choice
	// The analysis starts at i=lgth
	for (i=0; i<lgth; i++)
	{
		mean[i]=(float)meanval;
	}

	// Calc first jump limits
	min=avg-limit;
	max=avg+limit;

	// Step 4 of the algorithm begins here
	// Loop thru all data starting at i=lgth
	// Look for point outside limits that becomes potential jump
	i=lgth;
	//while(i<g*lgth)
	while(i<num)
	{
		// Is point outside limits
		if( ((y[i]<min) || (y[i]>max)) && (i<num) )
		{
			// Step 5
			// Possible jump at this point - save its index as j
			j=i;
			sum=y[i];

			// Check average for next group of points
			// letting size of group grow point by point
			// up to size = lgth
			// Reject jump any time if avg is inside limits
			// Confirm jump if avg outside limits at end
			while( ((sum<min)||(sum>max)) && (i<j+lgth) && (i<num) )
			{
				// Jump still possible
				// Calculate next average
				// i-j+1 is # of points contributing to sum
				sum=0.0;
				points=0;
				for(p=j; p<j+lgth; p++)
				{
					// Don't go past end of data array
					if(p==num-1)
					{
						// Put mean value into rest of its array
						for(p=j; p<num; p++)
						{
							mean[p]=(float)meanval;
						}
						
						// Done
						return jmps;
					}
					
					// Skip gap
					if(y[p])
					{
						sum+=y[p];
						points++;
					}
				}
				sum/=points;
					
				// Increment data index
				i++;
			}

			// Here we either broke out of while loop
			// thereby rejecting jump
			// or completed while loop thereby confirming jump

			if((sum<min)||(sum>max)) // Jump confirmed
			{
				// Increment jump count
				jmps++;

				// For testing
				// Jump point
				// TRACE_INT(j);
				// New mean value
				// TRACE_EXP(sum);
				
				// Save new mean value
				meanval=sum;
				
				// Recalc first jump limits
				min=meanval-limit;
				max=meanval+limit;

				// Put zero into array to denote jump
				mean[j]=(float)0.0;
				// mean[j]=(float)meanval;
			}
			else // Jump rejected
			{
				// Put mean value into array
				mean[j]=(float)meanval;
			}

			// Resume testing at i=j+1;
			i=j+1;
		}
		else // Not a possible jump
		{
			// Save mean value in array
			mean[i]=(float)meanval;

			// Increment data index
			i++;
		}
	}
	
	return(jmps);                                                /* # jumps */
}                                                         /* end seqjumps() */

/****************************************************************************/
#endif

#if(1) // Now part of normal program
/****************************************************************************/
/*                                                                          */
/*							       cusum()                                  */
/*                                                                          */
/*		Function to calculate cumulative sum of frequency data array        */
/*      Cusum slope indicates local data values wrt average                 */
/*      Flat cusum indicates period of data near average                    */
/*      Straight cusum indicates period of constant data values             */
/*      A sudden change in cusum direction indicates jump in data           */
/*                                                                          */
/*		Parameters:                                                         */
/*			float	y[]		    frequency data array						*/
/*			int		num			# data points = size of y[] and c[]			*/
/*			float	c[]			cumulative sum array                        */
/*          float	*min		minimum cusum value                         */
/*          float	*max		maximum cusum value                         */
/*          int		*imin		minimum cusum point #                       */
/*          int		*imax		maximum cusum point #                       */
/*                                                                          */
/*		Return:                                                             */
/*			int					# non-zero points, or -1 if error           */
/*                                                                          */
/*		Notes:                                                              */
/*			 1. Zero denotes gap in frequency data.                         */
/*           2. Final cusum value S/B zero, but won't be exactly.           */
/*           3. c[] array size S/B y[] array size +1.                       */
/*				It is not in this code - the c[0]=0.0 point gets            */
/*              overwritten by c[1].  This is OK because we know that       */
/*              c[0] is always exactly zero.                                */
/*                                                                          */
/*      References:                                                         */
/*          1.	W.A. Taylor, "Change-Point Analysis: APowerful New Tool     */
/*				for Detecting Changes", Taylor Enterprises, Inc.,           */
/*				http://www.variation.com/cpa/changepoint.html.              */
/*                                                                          */
/*		Revision record:                                                    */
/*			02/07/08	Created                                             */
/*			                                                                */
/****************************************************************************/

int cusum(float y[], int num, float c[], float *min, float *max, int *imin,
	int *imax)
{
	// Local variables
	int i;				// Index
	int points;			// # non-zero data points
	float avg;			// Average
	float cusum;		// Cumulative sum

	// Calc average of entire data set
	avg=0.0;
	points=0;

	// Loop thru all data
	for(i=0; i<num; i++)
	{
		// Skip gaps
		if(y[i])										  
		{
			// Sum non-zero points
			avg+=y[i];
			points++;
		}                                                     
	}                                                        

	// Avoid divide by zero
	if(points)                                  
	{
		avg/=points;
	}
	else
	{
		// Error - no non-zero data
		return -1;
	}
	
	// Calc cumulative sums
	cusum=0.0;
	c[0]=0.0; // As-is, this gets overwritten

	// Loop thru all data
	for(i=0; i<num; i++)
	{
		// Skip gaps
		if(y[i])										  
		{
			// Sum non-zero points
			cusum+=(y[i]-avg);
		}

		// Store cumulative sum
		// It is unchanged if point was gap (zero)
		c[i]=cusum;
	}
	
	// Find min and max cumulative sum values and their point #s
	*min=c[0];
	*max=c[0];
	*imin=0;
	*imax=0;

	// Loop thru all cusum values
	for(i=0; i<num; i++)
	{
		if(c[i]<*min)
		{
			*min=c[i];
			*imin=i;
		}

		if(c[i]>*max)
		{
			*max=c[i];
			*imax=i;
		}
	}

	// Return # non-zero points
	return points;                                                
}                                                         

/****************************************************************************/
#endif

#if(1) // Trial code 02/21/08 - works well
/****************************************************************************/
/*                                                                          */
/*							      avgjumps()                                */
/*                                                                          */
/*      Average Detected Jumps                                              */
/*                                                                          */
/*		Function to find averages between jumps in frequency data           */
/*      Intended to follow seqjumps() function                              */
/*      Jumps are identified as zero values in mean[] array                 */
/*      Find averages of y[] freq array between jumps                       */
/*      and put those values into mean[] array                              */
/*      Zeros remain in mean[] arrray to denote jumps                       */
/*                                                                          */
/*		Parameters:                                                         */
/*			float	y[]		    frequency data array						*/
/*			int		num			# data points								*/
/*          float	mean[]		mean value array                            */
/*                                                                          */
/*		Return:                                                             */
/*			int		 # jumps (or -1 if error)                               */
/*                                                                          */
/*		Notes:                                                              */
/*                                                                          */
/*		Revision record:                                                    */
/*			02/21/08	Created                                             */
/*			                                                                */
/****************************************************************************/

int avgjumps(float y[], int num, float mean[])
{
	int i;                                        /* outer mean array index */
	int j;                               /* inner mean and freq array index */
	int start;                              /* start index of jump interval */
	int end;                                  /* end index of jump interval */
	int points;                                    /* non-zero points count */
	int jumps;                                                   /* # jumps */
	double avg;                            /* freq average in jump interval */
	double sum;                                          /* summation value */
	
	// Initialize start index
	start=0;
	
	// Initialize jump count
	jumps=0;

	// Loop thru mean[] array looking for jumps (zero values)
	for(i=0; i<num; i++)
	{
		if( (mean[i]==0.0) || (i==num-1) ) // Jump or last point
		{
			// Set end index
			end=i;

			// Find avg freq in jump interval
			// From start to end-1 (jump itself is at end)
			points=0;
			sum=0.0;
			for(j=start; j<end; j++)                            
			{
				// Skip gaps
				if(y[j])										  
				{
					sum+=y[j];
					points++;
				}                                                     
			}                                                        
			
			// Avoid divide by zero
			if(points)                                  
			{
				avg=sum/points;
			}
			else // No average possible in first group
			{
				// Error message - need to do something better than this
				// TRACE_STR("No average found");
				return -1; // Error code
			}

			// For testing
			// TRACE_EXP(avg);
			
			// Put average into mean[] array
			for(j=start; j<end; j++)                            
			{
				mean[j]=(float)avg;
			}

			// Set next start index
			// mean[end] value remains a zero (jump)
			start=end+1;

			// Is this a jump?
			if(mean[i]==0.0)
			{
				// Increment jump count
				jumps++;
			}
		}

		// Last point
		mean[num-1]=(float)avg;
	}

	return jumps;                                                /* # jumps */
}                                                         /* end avgjumps() */

/****************************************************************************/
#endif
