/*****************************************************************************/
/*                                                                           */
/*                             STABLE_W.H                                    */
/*                                                                           */
/*  Stable for Windows95/NT header file                                      */
/*                                                                           */
/*  Revision record:                                                         */
/*      06/30/97    Replaced FAR PASCAL _export with WINAPI                  */
/*      07/17/97    Added STABLE_H function prototypes                       */
/*      07/24/97    Changes made for Visual C++ compliation w/o warnings     */
/*      07/25/97    Added provisions for NIST special verion                 */
/*      11/30/97    Added provisions for license code                        */
/*	    05/22/99	Added provisions for Lite version                        */
/*		03/21/03	Remove prototypes for functions moved to FrequenC DLL    */
/*	    07/25/03	Added provisions for Demo version                        */
/*                                                                           */
/*  (c) 1997-2009  W. Riley Hamilton Technical Services All Rights Reserved  */
/*                                                                           */
/*****************************************************************************/

// Macro for testing Quartzlock A7PSD DLL
#if(0)
	#define A7PSD
#endif

// Define for Full version - see notes below re changes for different versions
#if(1)
	#define FULL_VER
#endif

// Define for "Student Version"
// Note:  Must also manually comment out the Stable32 Play menu item
// and the 5110 and Auto # items from the Utility menu
// and the Database item from the File menu
// and the GraphiC Printer Setup and Print menu items in the stable_w.rc file
// [Save original rc file as Stable32.rc]
// and copy correct splash screen bitmap into splash.bmp
// Also: Must link with Licenses.lib instead of Licens32.lib to use License.dll
// instead of Licens32.dll to give correct license code for student version
// and remove Stable_b.c from project
// And: Change between Stable32.ico and Stables.ico 2 places in Stable_w.rc
// Note 05/08/12: Added automatic menu selection for full and student versions
#if(0)
    #define STUDENT_VER
#endif

// Define for "Lite Version"
// Note:  Must also manually comment out the Add, Read, Print, Filenames,
// Regularize, Timetags, Domain, Configure and Play menu items
// and the GraphiC Printer Setup and Print menu items in the stable_w.rc file
// and copy correct splash screen bitmap into splash.bmp
// Also: Must link with Licensel.lib instead of Licens32.lib to use Licensel.dll
// instead of Licens32.dll to give correct license code for lite version
#if(0)
	#define LITE_VER
#endif

// Define for "Special NIST Version"
#if(0)
    #define SPECIAL_VERSION
#endif

// Define for demo version to check 30-day license and add watermark on plots
// Note: Define DEMO_VERSION and DEMO_VER here and DEMO_MESSAGE in WinMain()
// Keep: FULL_VER also defined
// Use: Same Stable32.hlp file and Stable32.ico, same menu and rc file
// Also: Link with LicensD.dll to use LicenseD.dll
// And: Use splash_demo_141.bmp (or whatever) as splash.bmp
// Additionally: Make sure Stable32.ini has [Version] and [License} sections
#if(0)
	#define DEMO_VERSION
#endif

// Define for demo version of license dll
// Note: Don't forget to link with right license dll library (LicenseD.lib)
#if(0)
	#define DEMO_VER
#endif

// Define for V-ITSAS version of license dll
// Also define FULL_VER with this
// Note: Don't forget to link with right license dll library (LicenseV.lib)
#if(0)
	#define VITSAS_VER
#endif

#ifndef _MSC_VER
// Insert notice into .EXE file
#pragma comment (exestr, "Copyright 1996-2008, Hamilton Technical Services")
#endif

// Macro to define for extended memory allocation error message
// Activates AllocErrorMessageEx() instead of AllocErrorMessage()
// Not recommended for shipping version
#if(0)
	#define MEM_DEBUG
#endif

// Macro to activate combined edf function usage
#if(1)
	#define NEWEDF
#endif

// Macro to activate Database function File menu item
#if(1)
	#define SHOW_SQL
#endif

// Include Windows header files
#include <windows.h>
#include <windowsx.h>
#include <commdlg.h>
#include <commctrl.h>

// HTML Help header file
#include "htmlhelp.h"

// Include GraphiC header files
#include "graphic.h"
#include "mygpcdef.h"

// Include standard C headers
#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include <commdlg.h>
#include <direct.h>
#include <math.h>
#include <malloc.h>
#include <time.h>
#include <dos.h>

// SQL headers
#include "libpq-fe.h"
#include "postgres_ext.h"

// Algebraic expression evaluation header
// #include "ee.h" // Causes many redefinition errors
// Algebraic expression evaluation function definition
// Type of 2nd argument explicitly made double
int Evaluate( char* e, double* result, int* a );
int SetValue( char* name, double* value );
int GetValue( char* name, double* value );

// Virtual keycode definitions
#include "keycode.h"

// Debugging header and macros
// Note: Define NDEBUG to disable asserts
// #define NDEBUG
#include <assert.h>

// Assert macro Ref: DDJ Feb 98 p.10
// Does nothing if x is TRUE or if NDEBUG is defined
// If x is FALSE, execution immediately stops and debugger opens at ASSERT line
#ifdef NDEBUG
	#define ASSERT(x)
#else
	#define ASSERT(x) if(x);else{*((void**)0)=0;}
#endif

// FrequenC library header
#include "frequenc.h"

// DataTable header
#include "datatbl.h"

// Quinn-Curtin Science & Engineering TC-006 Lib header
// Note: fft_.h is special version of fft.h with function prototypes & defines
// for FFT functions. It calls reeltype.h which defines realtype=float.
#include "fft_.h"

// Macro to simplify getting handle to dialog box control
// Note: 1st arg of dialog box proc MUST be named hDlg
#define GETHCTL(id) GetDlgItem(hDlg, (id))

// Notepad program name
#define NOTEPAD "notepad.exe"

// Stable license codes
#define STABLE_W_LICENSE_CODE 1
#define STABLE32_BETA_LICENSE_CODE 3 // Note: 2 was never used!
#define STABLE32_LICENSE_CODE 3 
#define STABLE32_STUDENT_LICENSE_CODE 4
#define STABLE_LITE_LICENSE_CODE 5
#define STABLE_DEMO_LICENSE_CODE 6
#define STABLE_VITSAS_LICENSE_CODE 7
#define STABLE32_150_LICENSE_CODE 150 // Version 1.50
#define STABLE32_151_LICENSE_CODE 151 // Version 1.51
#define STABLE32_152_LICENSE_CODE 152 // Version 1.52
#define STABLE32_153_LICENSE_CODE 153 // Version 1.53
#define STABLE32_154_LICENSE_CODE 154 // Version 1.54
#define STABLE32_155_LICENSE_CODE 155 // Version 1.55
#define STABLE32_156_LICENSE_CODE 156 // Version 1.56
#define STABLE32_157_LICENSE_CODE 157 // Version 1.57
#define STABLE32_158_LICENSE_CODE 158 // Version 1.58
#define STABLE32_159_LICENSE_CODE 159 // Version 1.59

// FrequenC DLL Version #
// Was 130 until 03/13/03
// Was 200 until 12/31/06
#define FREQUENC_DLL_VERSION_NUMBER 300

// STABLE_N defines
#define SWAP(a,b) tempr=(a);(a)=(b);(b)=tempr
#define M1 259200L                                       /* made L 2/13/93 */
#define IA1 7141L                                                 /* ditto */
#define IC1 54773L                                                /* ditto */
#define RM1 (1.0/M1)
#define M2 134456L                                                /* ditto */
#define IA2 812                                                   /* ditto */
#define IC2 28411L                                                /* ditto */
#define RM2 (1.0/M2)
#define M3 243000L                                                /* ditto */
#define IA3 4561L                                                 /* ditto */
#define IC3 51349L                                                /* ditto */

// Math constants
#define SQRT2 1.414213562

// Encryption key
#define KEY_0 1
#define KEY_1 10
#define KEY_2 100
#define KEY_3 1000

// Initial encrypted install date values: v0=v1=0
#define V_ZERO 1273899965
#define V_ONE 58541052

// Help filename macros
#define HELPFILESTRING "Stable32.chm"
#define HELPFILENAME Stable32.chm

// Macros

// Trace, debug & display macros
// Require global variables char szTrace[BUFFER_SIZE+1} and HWND hwndMain

// Trace int
// Usage  TRACE_INT(nTrace); where nTrace is int variable to be displayed
#define TRACE_INT(var) sprintf(szTrace,#var "=%d",var); \
    MessageBox(hwndMain,szTrace,"Trace Int",MB_OK)

// Debug int
// Usage  DEBUG_INT(nTrace); where nTrace is int variable to be displayed
#define DEBUG_INT(var) sprintf(szTrace,"\n" #var "=%d",var); \
    OutputDebugString(szTrace)

// Display int
// Usage  DISPLAY_INT(nTrace); where nTrace is int variable to be displayed
#define DISPLAY_INT(var) sprintf(szTrace,"int " #var "=%d",var); \
    DebugMessageBox(hwndMain,__FILE__,__LINE__,szTrace)

// Trace unsigned int
// Usage  TRACE_UINT(uTrace); where uTrace is unsigned int variable to disp
#define TRACE_UINT(var) sprintf(szTrace,#var "=%u",var); \
    MessageBox(hwndMain,szTrace,"Trace Unsigned Int",MB_OK)

// Debug unsigned int
// Usage  DEBUG_UINT(uTrace); where uTrace is uint variable to be displayed
#define DEBUG_UINT(var) sprintf(szTrace,"\n" #var "=%u",var); \
    OutputDebugString(szTrace)

// Display unsigned int
// Usage  DISPLAY_UINT(uTrace); where uTrace is uint variable to be displayed
#define DISPLAY_UINT(var) sprintf(szTrace,"uint " #var "=%u",var); \
    DebugMessageBox(hwndMain,__FILE__,__LINE__,szTrace)

// Trace long
// Usage  TRACE_LONG(lnTrace); where lnTrace is long int to be displayed
#define TRACE_LONG(var) sprintf(szTrace,#var "=%ld",var); \
    MessageBox(hwndMain,szTrace,"Trace Long",MB_OK)

// Debug long
// Usage  DEBUG_LONG(lnTrace); where lnTrace is long variable to be displayed
#define DEBUG_LONG(var) sprintf(szTrace,"\n" #var "=%ld",var); \
    OutputDebugString(szTrace)

// Display long
// Usage  DISPLAY_LONG(lnTrace); where lnTrace is long variable to be displayed
#define DISPLAY_LONG(var) sprintf(szTrace,"long " #var "=%ld",var); \
    DebugMessageBox(hwndMain,__FILE__,__LINE__,szTrace)

// Trace real (float or double)
// Usage  TRACE_EXP(fTrace); where fTrace is float or double to be displayed
#define TRACE_EXP(var) sprintf(szTrace,#var "=%e",var); \
    MessageBox(hwndMain,szTrace,"Trace Exp",MB_OK)

// Debug real
// Usage  DEBUG_EXP(fTrace); where fTrace is real variable to be displayed
#define DEBUG_EXP(var) sprintf(szTrace,"\n" #var "=%e",var); \
    OutputDebugString(szTrace)

// Display real
// Usage  DISPLAY_EXP(fTrace); where fTrace is real variable to be displayed
#define DISPLAY_EXP(var) sprintf(szTrace,"real " #var "=%e",var); \
    DebugMessageBox(hwndMain,__FILE__,__LINE__,szTrace)

// Trace address (pointer)
// Usage  TRACE_ADR(pTrace); where pTrace is pointer to be displayed
#define TRACE_ADR(var) sprintf(szTrace,#var "=%p",var); \
    MessageBox(hwndMain,szTrace,"Trace Adr",MB_OK)

// Debug pointer
// Usage  DEBUG_ADR(pTrace); where pTrace is pointer variable to be displayed
#define DEBUG_ADR(var) sprintf(szTrace,"\n" #var "=%p",var); \
    OutputDebugString(szTrace)

// Display int
// Usage  DISPLAY_ADR(pTrace); where pTrace is pointer variable to be displayed
#define DISPLAY_ADR(var) sprintf(szTrace,"pointer " #var "=%p",var); \
    DebugMessageBox(hwndMain,__FILE__,__LINE__,szTrace)

// Trace string
// Usage  TRACE_STR(szTrace); where szTrace is string to be displayed
#define TRACE_STR(var) MessageBox(hwndMain,var,"Trace Str",MB_OK)

// Debug string
// Usage  DEBUG_STR(szTrace); where szTrace is string variable to be displayed
#define DEBUG_STR(var) OutputDebugString(var)

// Display string
// Usage  DISPLAY_STR(szTrace); where szTrace is string variable to be shown
#define DISPLAY_STR(var) DebugMessageBox(hwndMain,__FILE__,__LINE__,var)

// File name & title sizes
#define FILE_NAME_SIZE 257
#define FILE_TITLE_SIZE 257
#define DLG_TITLE_SIZE 40

// # previous filenames
#define NUM_FILENAMES   4       // 0=new, 1=most recent thru Nth=oldest

// Data type
#define F_TYPE double			// For most Stable32 floating point variables
#define polytype double			// For S&E Tools polynominal curve fitting

// Data array numbers
#define MIN_ARRAY_SIZE     1    // Relates to min size of data table
#define ARRAY_OFFSET       3    // Offset to 1st data point
#define EXTRA_MEM          0    // # extra bytes to allocate
#define MAX_NUM_COLS      32    // Maximum # of input data columns
#define STUDENT_MAX		 513	// Max data array size for student version
#define LITE_MAX		 513	// Max data array size for lite version

// Max # of function fit parameters
#define NUMPARAMS 10

// Max # of PSD spurs
#define NUMSPURS		  100	// Max # PSD plot discrete spurs

// Limit size for student version
#ifdef STUDENT_VER
    #define MAX_DATA_FILE_SIZE  STUDENT_MAX // Max allowable size of data array
#else
    #define MAX_DATA_FILE_SIZE  999999 // Maximum allowable size of data array
#endif

#define MIN_DATA_FILE_SIZE     4    // Minimum allowable size of data array

// Plot struct array sizes
#define FILENAMESIZE 257            /* size of char array to hold filename */
                                                  /* was 31 until 04/04/98 */
#define TITLESIZE 40 // Was 28 until 3/4/07          /* size of plot title */
#define SUBTITLESIZE 90 // Was 50 until 3/4/07    /* size of plot subtitle */
#define XLABELSIZE 40  // Was 31 until 3/4/07 /* size of x-axis plot label */
#define YLABELSIZE 80  // Was 50 until 3/4/07 /* size of y-axis plot label */
#define MESSAGESIZE 60                             /* size of plot message */
#define LABELSIZE 128                        /* size of general plot label */
#define BIGLABELSIZE 256                         /* size of big plot label */
#define WIDELINESIZE 20                        /* width of wide plot lines */
#define NOTESIZE 256                        /* length of maximum note size */
#define MODESIZE 3								   /* file write mode size */
#define FUNCTIONSIZE 80			           /* function fit expression size */

// TooBig options
#define BIG_ABORT   0                        /* Abort data read operation  */
#define BIG_AVERAGE 1                        /* Average data as it is read */
#define BIG_FIRST   2                        /* Read first portion of data */
#define BIG_LAST    3                        /* Read last portion of data  */
#define BIG_OK      4                        /* File size is not too big   */
#define BIG_DOAVG   5						 /* Force averaging            */
#define BIG_ALL     6	  /* Read all data w/o avgering regardless of size */

// # Toolbuttons
#ifdef LITE_VER
	#define NUM_TOOLS	 16
#endif

#ifdef STUDENT_VER
	#define NUM_TOOLS    36
#endif

#ifdef FULL_VER
	#define NUM_TOOLS    42
#endif

// Toolbutton string sizes
#define TOOLLABELSIZE   25 

#define TOOLPROMPTSIZE  70

// # plot title, subtitle & messages options to save
#define NUM_TITLES 16
#define NUM_SUBTITLES 16
#define NUM_MESSAGES 16

// Buffer sizes
#define BUFFER_SIZE          128
#define BIG_BUFFER_SIZE     1024

// Sigma data array size
#define SIGMA_SIZE             1  // Dynamically adjusted

// Toolbutton states
#define TOOLBUTTON_BLANK       0
#define TOOLBUTTON_DIM         1
#define TOOLBUTTON_OUT         2
#define TOOLBUTTON_IN          3

// Function key menu items
// Note: F1 is Help
#define IDM_F2				3002
#define IDM_F3				3003
#define IDM_F4				3004
#define IDM_F5				3005
#define IDM_F6				3006
#define IDM_F7				3007
#define IDM_F8				3008
#define IDM_F9				3009
#define IDM_F10				3010
#define IDM_F11				3011
#define IDM_F12				3012

// Shifted function key menu items
#define IDM_SHIFT_F1		3101
#define IDM_SHIFT_F2		3102

// Command Line function
#define IDM_X				3200

// Toolbutton Actions
#define TOOLBUTTON_MOMENTARY   0
#define TOOLBUTTON_TOGGLE      1

// Conversion Types
#define NO_CONVERSION          0
#define PHASE_TO_FREQ          1
#define FREQ_TO_PHASE          2

// Frequency timetag types			// Used for phase-frequency conversions
#define FTAG_FIRST			   0	// Freq timetag is 1st phase timetag
#define FTAG_MID			   1	// Freq timetag is avg phase timetag
#define FTAG_LAST			   2	// Freq timetag is 2nd phase timetag

// bDataType Data Types
#define PHASE_DATA             0
#define FREQ_DATA              1
#define EITHER_DATA            2
#define UNKNOWN_DATA           3

// # GraphiC plot pixels
#define PLOT_PIXELS			   8192  // # GraphiC plot pixels

// nPlotType Data Types
#define SAMPLE_PLOT           -1
#define PHASE_PLOT             0
#define FREQ_PLOT              1
#define HISTO_PLOT             2
#define SPECT_PLOT             3
#define SIGMA_PLOT             4
#define READ_PLOT              5
#define AUTO_PLOT			   6
#define SCATTER_PLOT		   7
#define DAVAR_PLOT			   8
#define DOMAIN_SIGMA_PLOT	   9
#define DOMAIN_PSD_PLOT		  10

// Sigma Types
#define NORMAL_SIGMA           0
#define OVERLAPPING_SIGMA      1
#define MODIFIED_SIGMA         2
#define TIME_SIGMA             3
#define HADAMARD_SIGMA         4
#define OVERLAPHAD_SIGMA       5
#define TOTAL_SIGMA            6
#define MODTOTAL_SIGMA		   7
#define TIMETOTAL_SIGMA		   8
#define HADTOTAL_SIGMA		   9
#define TIERMS_SIGMA           10
#define MTIE_SIGMA             11
#define THEO1_SIGMA			   12

// Run Types
#define NORMAL_RUN             0
#define OVERLAPPING_RUN        1
#define MODIFIED_RUN           2
#define TIME_RUN               3
#define HADAMARD_RUN           4
#define OVERLAPHAD_RUN		   5
#define TOTAL_RUN              6
#define MODTOTAL_RUN		   7
#define TIMETOTAL_RUN		   8
#define HADTOTAL_RUN		   9
#define BOTH_RUN              10
#define TIERMS_RUN            11
#define MTIE_RUN              12
#define THEO1_RUN			  13
#define FULL_RUN              14
#define CROSS_RUN			  15

// Run Max Sizes
#define NORMAL_MAX             10000000 // 10M
#define OVERLAPPING_MAX        10000000 // 10M
#define MODIFIED_MAX           10000000 // 10M
#define TIME_MAX               10000000 // 10M
#define HADAMARD_MAX           10000000 // 10M
#define OVERLAPHAD_MAX		   10000000 // 10M
#define TOTAL_MAX              10000000 // 10M
#define MODTOTAL_MAX		   2000		// 2k
#define TIMETOTAL_MAX		   2000		// 2k
#define HADTOTAL_MAX		   20000	// 20k
#define BOTH_MAX               10000000 // 10M
#define TIERMS_MAX             10000000	// 10M
#define MTIE_MAX               1000000  // 1M
#define THEO1_MAX			   50000	// 50k
#define FULL_MAX               50000	// 50k

// Plot styles
#define ORIGINAL_STYLE		   0
#define MODERN_STYLE		   1

// Run Tau Increment Types
#define TAU_DECADE             0
#define TAU_OCTAVE             1
#define TAU_ALL                2

// Noise Types (Alpha)
#define W_PM                   2
#define F_PM                   1
#define W_FM                   0
#define F_FM                  -1
#define RW_FM                 -2
#define FW_FM                 -3
#define RR_FM				  -4

// Domain Conversion Types
#define PSD_Y                  1
#define PSD_X                  2
#define PSD_P                  3
#define PSD_L                  4
#define SIG_Y                  5
#define MODSIG_Y               6
#define SIG_X                  7

// Drift Types
// Freq data
#define LINEAR_DRIFT           0
#define LOG_DRIFT              1
#define BISECTION_DRIFT        2
#define DIFFUSION_DRIFT        3
#define AR_DRIFT			   4
// Phase data
#define QUADRATIC_DRIFT        0
#define SECDIFF_DRIFT          1
#define THREEPT_DRIFT          2
#define GREENHALL_DRIFT		   3
#define FREQ_OFFSET            4
#define FIRSTDIFF              5
#define ENDPOINTS			   6

// Jump Detection Methods
#define BLKAVG				   0
#define SEQAVG				   1

// Find Types
#define DATA_GREATERTHAN       0
#define DATA_EQUAL             1
#define DATA_LESSTHAN          2

// Edit Timetag Format Types
#define TAGFORMAT_MJD          0
#define TAGFORMAT_DOY          1
#define TAGFORMAT_DATE         2
#define TAGFORMAT_EXP          3

// Stats Timetag Types
#define TAGTYPE_NONE         0
#define TAGTYPE_MJD          1
#define TAGTYPE_DOY          2
#define TAGTYPE_DATE         3
#define TAGTYPE_MISC		 4

// FFT Windowing Types
#define RECTANGULAR_WIN 0
#define HANNING_WIN     1
#define HAMMING_WIN     2
#define MULTITAPER_WIN  3

// ReadIni() & WriteIni() Section Types
#define INI_ALL     0
#define INI_FILES   1
#define INI_TZ      2
#define INI_PREFS   3
#define INI_FREQ    4
#define INI_PHASE   5
#define INI_SIGMA   6
#define INI_SPECT   7
#define INI_HISTO   8
#define INI_TOOLS   9
#define INI_FLINE  10
#define INI_PLINE  11
#define INI_SLINE  12
#define INI_FNOTE  13
#define INI_PNOTE  14
#define INI_SNOTE  15
#define INI_INPUTS 16
#define INI_AUTO   17
#define INI_DAVAR  18
#define INI_SQL    19
#define INI_AUDIO  20

// Search Result Error Codes
#define FIND_NO_MATCH         -1     // Value outside range of OK row #s
#define FIND_CANCEL           -2     // Another one

// Frequency Data Plot Codes
#define FPLOT_NONE  0               // No special lines or plots
#define FPLOT_LINE  1               // Linear fit
#define FPLOT_LOG   2               // Log fit
#define FPLOT_DIFF  3               // Diffusion fit
#define FPLOT_AVG	4				// Average fit
#define FPLOT_POLY	5				// Polynominal fit
#define FPLOT_FUNC	6				// Function fit
#define FPLOT_JUMP	7				// Jump fit

// Phase Data Plot Codes
#define PPLOT_NONE  0               // No special lines or plots
#define PPLOT_QUAD  1               // Quadratic fit
#define PPLOT_AVG	2				// Average fit
#define PPLOT_POLY	3				// Polynominal fit
#define PPLOT_FUNC	4				// Function fit

// Phase Plot Line # & Types
// Changes 07/24/10 to activate Freq Offset line type
// PLINE_LIN changed from 6 to 5
// PLINE_NULL changed from 5 to 6
#define PLINE_NUMLINES 12           // # possible lines
#define PLINE_NONE      0           // No line
#define PLINE_END       1           // Line between endpoints
#define PLINE_QUAD      2           // Quadratic fit
#define PLINE_LIN       5           // Linear fit - NOT USED until 07/24/10
#define PLINE_AVG       3           // Horiz line at avg value
#define PLINE_MARK      4           // Vert marker line
#define PLINE_NULL      6           // Null code used during line entry proc

// Sigma Plot Line # & Types
#define SLINE_NUMLINES  12          // # possible lines
#define SLINE_NONE      0           // No line
#define SLINE_END       1           // Line between endpoints
#define SLINE_HORIZ     2           // Horizontal line
#define SLINE_VERT      3           // Vertical line
#define SLINE_NOISE     4           // Noise line
#define SLINE_MASK		5			// Mask plot
#define SLINE_TDEV      6           // TDEV lines
#define SLINE_NULL      7           // Null code used during line entry proc

// Initial size of sigma plot mask data arrays
#define MASKSIZE     2

// Plot Note #s
#define FNOTE_NUMNOTES  6
#define PNOTE_NUMNOTES  6
#define SNOTE_NUMNOTES  6
#define FNOTE_NONE      0
#define PNOTE_NONE      0
#define SNOTE_NONE      0

// # Freq plot line types
#define FLINE_NUMLINES 12           // # possible lines

// # Tabs
#define FTAB_NUMTABS	12			// # possible freq tabs
#define PTAB_NUMTABS	12			// # possible phase tabs

// Message Box Sizes
#define NUM_SIDES 4
#define CHAR_HGTH 3*42
#define V_MARGIN  40
#define H_MARGIN  40
#define PAN_COLOR 447

// Data plot x-axis scale #s
#define X_POINT		   0
#define X_KPOINT	   1
#define X_MILLISECOND  2
#define X_SECOND	   3
#define X_MINUTE	   4
#define X_HOUR		   5
#define X_DAY		   6
#define X_WEEK		   7
#define X_DOY		   8
#define X_MJD		   9
#define X_TIMETAG	  10
#define NUM_X_SCALES  10

// Custom messages 80-85
// Search and Replace window messages
#define IDC_FIND_ROWNUM        80    // Move to matching row
#define IDC_REPLACE_ROWNUM     81    // Move to matching row
#define IDC_REPLACE_ROWCHANGE  82    // Change data at matching row

// Misc IDs  90-95
#define IDC_ABOUT_VER         90
#define IDC_ABOUT_DLL         91
#define IDC_ABOUT_DATE        92
#define IDC_ABOUT_LICENSE     93
#define IDC_AUTOREAD_ARCHIVE  94
#define IDC_ABOUT_TEXT        95

// Main Menu IDs 96-156
// MAIN_ added to some to avoid conflict with GraphiC
#define IDM_MAIN_OPEN        100
#define IDM_MAIN_SAVE        101
#define IDM_HELP             102
#define IDM_USINGHELP        103
#define IDM_ADD              104
#define IDM_READ             105
#define IDM_MAIN_PRINT       106
#define IDM_MAIN_EXIT        107
#define IDM_MAIN_EDIT        108
#define IDM_CONV             109
#define IDM_NORM             110
#define IDM_AVG              111
#define IDM_FILL             112
#define IDM_SCALE            113
#define IDM_CLEAR            114
#define IDM_STAT             115
#define IDM_CHECK            116
#define IDM_DRIFT            117
#define IDM_SIGMA            118
#define IDM_RUN              119
#define IDM_DAVAR			 120
#define IDM_FILENAMES		 121
#define IDM_POWER            122
#define IDM_HIST             123
#define IDM_PHASE_PLOT       124
#define IDM_FREQ_PLOT        125
#define IDM_NOISE            126
#define IDM_CAL              127
#define IDM_PLAY             128
#define IDM_MAIN_ABOUT       129
#define IDM_TIMETAG          130
#define IDM_REGULARIZE       131
#define IDM_DOMAIN           132
#define IDM_PART             133
#define IDM_CONFIG           134
#define IDM_NOTEPAD          135
// Note: These must be in numerical order for indexing code to work
#define IDM_FILE1            136
#define IDM_FILE2            137
#define IDM_FILE3            138

#define IDM_MAIN_BETA        139 // Beta version message
#define IDM_MAIN_SPECIAL     140 // Special version message
#define IDM_MAIN_START       141 // Standard startup message
#define IDM_MAIN_WELCOME     142 // Welcome messgae
#define IDM_MAIN_DEMO		 143 // Demo version messgae
#define IDM_WEB				 144 // Spawn web browser

#define IDM_MAIN_FIND		 145 // Launch Find modeless dialog box
#define IDM_MAIN_REPLACE	 146 // Launch Replace modeless dialog box
#ifdef LITE_VER
	#define IDM_DATUM		 147 // Go to Datum web site
#endif
#define IDM_FEEDBACK		 148 // Registration/Feedback E-Mail
#define IDM_5110COMM		 149 // Launch 5110Comm program
#define IDM_AUTO1			 150 // Program automation script 1
#define IDM_AUTO2			 151 // Program automation script 2 
#define IDM_AUTO3			 152 // Program automation script 3
#define IDM_INIEDIT			 153 // Launch IniEdit program
#define IDM_LOG				 154 // Examine Stable32 log file
#define IDM_CORN			 155 // #-Cornered Hat
#define IDM_INPUTS			  99 // Inputs dialog box
#define IDM_AUTO			  98 // Autocorrelation plot
#define IDM_INSERT			  97 // Insert dialog box
#define IDM_SQL				  96 // Database dialog box
#define IDM_AUDIO			 156 // Write WAV file & launch media player
#define IDM_VIBRA          11001 // Vibration & FM spectral components
#define IDM_FILTER		   11002 // Filter function main menu ID	
#define IDM_STEP		   11003 // Unstep dialog box	

// Welcome dialog box controls 86-89
#define IDC_WELCOME_SHOW      86

// Button IDs
#define IDC_PUSHBUTTON1 377
#define IDC_PUSHBUTTON2 378
#define IDC_GROUPBOX2   379
#define IDC_PUSHBUTTON3 380

// Multicolumn Data File Dialog Box 915-949
// Note: These radiobutton #s MUST be in order
#define IDC_MCOL_T1          915
#define IDC_MCOL_T2          916
#define IDC_MCOL_T3          917
#define IDC_MCOL_T4          918
#define IDC_MCOL_T5          919
#define IDC_MCOL_T6          920
#define IDC_MCOL_T7          921
#define IDC_MCOL_T8          922
#define IDC_MCOL_D1          923
#define IDC_MCOL_D2          924
#define IDC_MCOL_D3          925
#define IDC_MCOL_D4          926
#define IDC_MCOL_D5          927
#define IDC_MCOL_D6          928
#define IDC_MCOL_D7          929
#define IDC_MCOL_D8          930
#define IDC_MCOL_TEXT        931
#define IDC_MCOL_MORE        932
#define IDC_MCOL_DETAILS	 933
// Custom MCOL Messages
#define IDC_MCOL_SETNCOL     934
#define IDM_MCOL_TAG         935
#define IDM_MCOL_DAT         936
#define IDM_MCOL_NCOL        937

// Custom File Open Dialog Box  2152-2155
#define IDC_FILE_FREQ        2152
#define IDC_FILE_PHASE       2153
#define IDC_FILE_ARCHIVE     2154
#define IDC_FILE_AF          2155

// Custom File Save Dialog Box  155
#define IDC_SAVE_TIMETAGS    155

// TooBig Dialog Box 157-169
#define IDC_BIG_OK           157
#define IDC_BIG_CANCEL       158
#define IDC_BIG_AVGFACTOR    159
#define IDC_BIG_OPTIONS      160
#define IDC_BIG_AVG          161
#define IDC_BIG_FIRST        162
#define IDC_BIG_LAST         163
#define IDC_BIG_NUM          164
#define IDC_BIG_AF           165
#define IDC_BIG_POINTS       166
#define IDC_BIG_ALL			 167
#define IDC_BIG_LIMIT		 168

// File Dialog Box 170-189
#define IDC_FILE_PHASEPLOT	 170
#define IDC_FILE_FREQPLOT	 171
#define IDC_FILE_SIGMAPLOT	 172
#define IDC_FILE_HISTOPLOT	 173
#define IDC_FILE_SPECTPLOT	 174
#define IDC_FILE_PHASEDATA	 175
#define IDC_FILE_FREQDATA	 176
#define IDC_FILE_STABDATA	 177
#define IDC_FILE_PATH        178
#define IDC_FILE_SET         179
#define IDC_FILE_RESET       180
#define IDC_FILE_PSDDATA     181
#define IDC_FILE_AUTOPLOT    182
#define IDC_FILE_AUTODATA    183
#define IDC_FILE_DAVARPLOT	 184
#define IDC_FILE_HELP		 185
#define IDC_FILE_ACCEPT      186
#define IDC_FILE_CANCEL      187

// Status Bar Controls 200-210
#define IDC_PHASESELECT      201
#define IDC_FREQSELECT       202
#define IDC_PHASEFILENAME    203
#define IDC_FREQFILENAME     204
#define IDC_PHASETAU         205
#define IDC_FREQTAU          206
#define IDC_PHASESTART       207
#define IDC_FREQSTART        208
#define IDC_PHASEEND         209
#define IDC_FREQEND          210

// Status Bar Access 1950-1959
#define IDC_PHASETAUSELECT   1950
#define IDC_PHASESTARTSELECT 1951
#define IDC_PHASEENDSELECT   1952
#define IDC_PHASEFILESELECT  1953
#define IDC_FREQTAUSELECT    1954
#define IDC_FREQSTARTSELECT  1955
#define IDC_FREQENDSELECT    1956
#define IDC_FREQFILESELECT   1957

// Misc main window controls
#define IDC_ACTIVATE         213
#define IDC_REFRESH			 214

// Toolbutton Controls 215-219
#define IDC_TOOLBUTTON       215

#define IDC_PHASERESET 211
#define IDC_FREQRESET  212

// Macros for DrawDataPlots()
#define OLD_DATA 0 // Use stored bitmaps
#define NEW_DATA 1 // Redraw plot(s) from data

// Sigma Menu Items  220-229
#define IDM_SIGMA_PRINT      220
#define IDM_SIGMA_BITMAP     221
#define IDM_SIGMA_METAFILE   222

// Check Menu Items  230-239
#define IDM_CHECK_PRINT      230
#define IDM_CHECK_BITMAP     231
#define IDM_CHECK_METAFILE   232

// Tabs Menu Items 790-799
#define IDM_TABS_SHOW		 790
#define IDM_TABS_CLEAR		 791
#define IDM_TABS_CLEARALL	 792
#define IDM_TABS_FILE		 793
#define IDM_TABS_CHANGE		 794
#define IDM_TABS_NOISE		 795
#define IDM_TABS_SAVE		 796
#define IDM_TABS_WRITE		 797
#define IDM_TABS_RENAME		 798
#define IDM_TABS_EDIT		 799

// Custom File Open/Save Common Dialog Box 1030-1049
#define IDC_GROUPBOX1       1039
#define IDC_RADIOBUTTON1    1041
#define IDC_RADIOBUTTON2    1042

// Dialog Box IDs
// Sigma Dialog Box 245-290, 295-299
#define IDC_SIGMA_NOISES     249
#define IDC_SIGMA_AVGFACTOR  250
#define IDC_SIGMA_VALUE      251
#define IDC_SIGMA_SHOW       252
#define IDC_SIGMA_PARAMS     253
#define IDC_SIGMA_NOISETYPE  254
#define IDC_SIGMA_MU         255
#define IDC_SIGMA_KN         256
#define IDC_SIGMA_CONFIDENCE 257
#define IDC_SIGMA_SINGLE     258
#define IDC_SIGMA_MIN        259
#define IDC_SIGMA_MAX        260
#define IDC_SIGMA_CI         261
#define IDC_SIGMA_CF         262
#define IDC_SIGMA_DF         263
#define IDC_SIGMA_NUM        264
#define IDC_SIGMA_ALPHA      265
#define IDC_SIGMA_NOISE      266
#define IDC_SIGMA_B1RN       267
#define IDC_SIGMA_SIGMA      268
#define IDC_SIGMA_TAU        269
#define IDC_SIGMA_BWFACTOR   270
#define IDC_SIGMA_RESULTS    271
#define IDC_SIGMA_TYPE       273
#define IDC_SIGMA_LABEL      274
#define IDC_SIGMA_PROMPT     275
#define IDC_SIGMA_NOCONF     276
#define IDC_SIGMA_NONOISE    277
#define IDC_SIGMA_RATIO      278
#define IDC_SIGMA_DOUBLE     279
#define IDC_SIGMA_CALC       280
#define IDC_SIGMA_CLOSE      281
#define IDC_SIGMA_MINLABEL   282
#define IDC_SIGMA_MAXLABEL   283
#define IDC_SIGMA_SETNOISE   284
#define IDC_SIGMA_COPY		 248
#define IDC_SIGMA_CICALC	 247
#define IDC_SIGMA_NOISEID    246
#define IDC_SIGMA_CHECK		 245
#define IDC_SIGMA_DEADTIME   272
#define IDC_SIGMA_B2		 295
#define IDC_SIGMA_B3		 296
#define IDC_SIGMA_THEO1BIAS  297
#define IDC_SIGMA_ACFNOISEID 298
#define IDC_SIGMA_R1		 299
#define IDC_SIGMA_A			 289
#define IDC_SIGMA_ACFID		 290
#define IDC_SIGMA_TOOFEW	 288

// Average Dialog Box 1285-1288
#define IDC_AVG_FACTOR       1285
#define IDC_AVG_PROMPT       1286
#define IDC_AVG_CANCEL       1287
#define IDC_AVG_ACCEPT       1288

// Fill Dialog Box  292-294
#define IDC_FILL_GAPS        292
#define IDC_FILL_PROMPT      293

// Regularize Dialog Box  300-309
#define IDC_REGULARIZE_GAPS    300
#define IDC_REGULARIZE_CANCEL  302
#define IDC_REGULARIZE_ACCEPT  303
#define IDC_REGULARIZE_MISSING 304
#define IDC_REGULARIZE_TAU     305

// Normalize Dialog Box 310-315
#define IDC_NORM_AVERAGE     310
#define IDC_GROUPBOX13  311

// Convert Dialog Box 330-349
#define IDC_CONV_TYPE        331
#define IDC_CONV_PTOF        332
#define IDC_CONV_FTOP        333
#define IDC_CONV_NORM        334
#define IDC_CONV_PROMPT      335
#define IDC_CONV_TAGS        336
#define IDC_CONV_USETAGS	 337

// Statistics Dialog Box 350-370, 830-840
#define IDC_STATS_PTS        351
#define IDC_STATS_GAPS       352
#define IDC_STATS_MIN        353
#define IDC_STATS_MAX        354
#define IDC_STATS_AVG        355
#define IDC_STATS_MED        356
#define IDC_STATS_SD         357
#define IDC_STATS_SIG        358
#define IDC_STATS_PROMPT     359
#define IDC_STATS_PLOT       360
#define IDC_STATS_PLOTDATA   361
#define IDC_STATS_FILE       362
#define IDC_STATS_READOUT    363
#define IDC_STATS_TITLE      364
#define IDC_STATS_SCROLL	 365
#define IDC_STATS_TRACK      366
#define IDC_STATS_ZOOM		 367
#define IDC_STATS_ALL		 368
#define IDC_STATS_SWAP		 369
#define IDC_STATS_TAGTYPE    370
#define IDC_STATS_POINTS	 830
#define IDC_STATS_NOISE      831
#define IDC_STATS_COPY       832
#define IDC_STATS_PLOTPOINTS 833
#define IDC_STATS_DELETE	 834

// Scale Dialog Box 371-385
#define IDC_SCALE_ADD        371
#define IDC_SCALE_MULT       372
#define IDC_SCALE_SLOPE      373
#define IDC_SCALE_PROMPT     374
#define IDC_SCALE_CANCEL     375
#define IDC_SCALE_ACCEPT     376
#define IDC_SCALE_FIRST      377
#define IDC_SCALE_AVG        378
#define IDC_SCALE_LINE       379
#define IDC_SCALE_REMOVE     380
#define IDC_SCALE_REVERSE    381

// Check Dialog Box 386-408
#define IDC_CHECK_FACTOR     390
#define IDC_CHECK_OUTLIERS   391
#define IDC_CHECK_REMOVE     392
#define IDC_CHECK_SHOW       393
#define IDC_CHECK_WHICH      394
#define IDC_CHECK_SORT       395
#define IDC_CHECK_SIZE       396
#define IDC_CHECK_NUM        397
#define IDC_CHECK_PROMPT     398
#define IDC_CHECK_NONE       399
#define IDC_CHECK_SEL        401
#define IDC_CHECK_LRG        402
#define IDC_CHECK_ALL        403
#define IDC_CHECK_DEV        404
#define IDC_CHECK_TABLE      405
#define IDC_CHECK_CALC       406
#define IDC_CHECK_CLOSE      407
#define IDC_CHECK_PRINT      408
#define IDC_CHECK_COPY		 389
#define IDC_CHECK_WRITE		 388

// Timetag Dialog Box 409-419 & 468-469
#define IDC_TIMETAG_CANCEL   468
#define IDC_TIMETAG_ACCEPT   469
#define IDC_TIMETAG_START    409
#define IDC_TIMETAG_INCLABEL 410
#define IDC_TIMETAG_INC      411
#define IDC_TIMETAG_UNITS    412
#define IDC_TIMETAG_SECS     413
#define IDC_TIMETAG_DAYS     414
#define IDC_TIMETAG_OTHER    415
#define IDC_TIMETAG_TYPE     416
#define IDC_TIMETAG_PHASE    417
#define IDC_TIMETAG_FREQ     418
#define IDC_TIMETAG_PROMPT   419

// Drift Dialog Boxes 420-430, 1423-1437
#define IDC_DRIFT_TYPE       420
#define IDC_DRIFT_SLOPE      421
#define IDC_DRIFT_REMOVE     422
#define IDC_DRIFT_SHOW       423
#define IDC_DRIFT_PROMPT     424
#define IDC_DRIFT_EQN       1424
#define IDC_DRIFT_FIT        425
#define IDC_DRIFT_EQNS       426
#define IDC_DRIFT_DPROMPT   1423
#define IDC_DRIFT_MODEL      427
#define IDC_DRIFT_C          428
#define IDC_DRIFT_B          429
#define IDC_DRIFT_A          430
#define IDC_DRIFT_COPY		1425
#define IDC_DRIFT_AF		1426
#define IDC_DRIFT_CALC		1427
#define IDC_DRIFT_AFLABEL	1428
#define IDC_DRIFT_CLOSE		1429
#define IDC_DRIFT_ALABEL	1430
#define IDC_DRIFT_BLABEL	1431
#define IDC_DRIFT_CLABEL	1432
#define IDC_DRIFT_MLABEL	1433
#define IDC_DRIFT_SLABEL	1434
#define IDC_DRIFT_TLABEL	1435
#define IDC_DRIFT_ICON		1436
#define IDC_DRIFT_PROMPT2   1437

// Drift Menu Items  432-439
#define IDM_DRIFT_PRINT      432
#define IDM_DRIFT_BITMAP     433
#define IDM_DRIFT_METAFILE   434

// Noise Dialog Box  440-459
#define IDC_NOISE_PARAM      440
#define IDC_NOISE_RWFM       441
#define IDC_NOISE_FFM        442
#define IDC_NOISE_WFM        443
#define IDC_NOISE_FPM        444
#define IDC_NOISE_WPM        445
#define IDC_NOISE_POINTS     446
#define IDC_NOISE_NUM        447
#define IDC_NOISE_TAU        448
#define IDC_NOISE_FREQ       449
#define IDC_NOISE_OFFSET     450
#define IDC_NOISE_DRIFT      451
#define IDC_NOISE_PROMPT     452
#define IDC_NOISE_CANCEL     453
#define IDC_NOISE_ACCEPT     454
#define IDC_NOISE_SINE		 455
#define IDC_NOISE_PERIOD	 456
#define IDC_NOISE_COPY		 457
#define IDC_NOISE_ACTIVE	 458

// Plot Dialog Box 460-479
#define IDC_PLOT_PLOT        460
#define IDC_PLOT_OPTIONS     461
#define IDC_PLOT_LINES       462
#define IDC_PLOT_NOTES       463


// Clear Dialog Box 915-925
#define IDC_CLEAR_WHAT      915
#define IDC_CLEAR_PHASEDATA 916
#define IDC_CLEAR_PHASETAGS 917
#define IDC_CLEAR_FREQDATA  918
#define IDC_CLEAR_FREQTAGS  919
#define IDC_CLEAR_PROMPT    920
#define IDC_CLEAR_ALL       921

// Rename Tab Dialog Box 950-959
#define IDC_RENAMETAB_CANCEL	950
#define IDC_RENAMETAB_ACCEPT	951
#define IDC_RENAMETAB_FILENAME	952
#define IDC_RENAMETAB_PROMPT	953

// Calendar Dialog Box 1000-1019
#define IDC_CAL_CANCEL      1001
#define IDC_CAL_YRUP        1002
#define IDC_CAL_YRDN        1003
#define IDC_CAL_MOUP        1004
#define IDC_CAL_MODN        1005
#define IDC_CAL_TODAY       1006
#define IDC_CAL_MONTH       1007
#define IDC_CAL_YEAR        1008
#define IDC_CAL_GPS         1009
#define IDC_CAL_COPY		1010		

// Calendar Dialog Box Days 1100-1149
#define IDC_CAL_DAY0        1100  // This is used to calc the actual ID #
#define IDC_CAL_DAY1        1101  // To do so, must keep the ID #s in order
#define IDC_CAL_DAY2        1102
#define IDC_CAL_DAY3        1103
#define IDC_CAL_DAY4        1104
#define IDC_CAL_DAY5        1105
#define IDC_CAL_DAY6        1106
#define IDC_CAL_DAY7        1107
#define IDC_CAL_DAY8        1108
#define IDC_CAL_DAY9        1109
#define IDC_CAL_DAY10       1110
#define IDC_CAL_DAY11       1111
#define IDC_CAL_DAY12       1112
#define IDC_CAL_DAY13       1113
#define IDC_CAL_DAY14       1114
#define IDC_CAL_DAY15       1115
#define IDC_CAL_DAY16       1116
#define IDC_CAL_DAY17       1117
#define IDC_CAL_DAY18       1118
#define IDC_CAL_DAY19       1119
#define IDC_CAL_DAY20       1120
#define IDC_CAL_DAY21       1121
#define IDC_CAL_DAY22       1122
#define IDC_CAL_DAY23       1123
#define IDC_CAL_DAY24       1124
#define IDC_CAL_DAY25       1125
#define IDC_CAL_DAY26       1126
#define IDC_CAL_DAY27       1127
#define IDC_CAL_DAY28       1128
#define IDC_CAL_DAY29       1129
#define IDC_CAL_DAY30       1130
#define IDC_CAL_DAY31       1131
#define IDC_CAL_DAY32       1132
#define IDC_CAL_DAY33       1133
#define IDC_CAL_DAY34       1134
#define IDC_CAL_DAY35       1135
#define IDC_CAL_DAY36       1136
#define IDC_CAL_DAY37       1137
#define IDC_CAL_DAY38       1138
#define IDC_CAL_DAY39       1139
#define IDC_CAL_DAY40       1140
#define IDC_CAL_DAY41       1141
#define IDC_CAL_DAY42       1142

// Domain Dialog Box 470-499
#define IDC_DOMAIN_DSPPSD   470
#define IDC_DOMAIN_DSPSIG   471
#define IDC_DOMAIN_BWLABEL  472
#define IDC_DOMAIN_CLEAR    473
#define IDC_DOMAIN_COPY     474
#define IDC_DOMAIN_JITTER   475
#define IDC_DOMAIN_RESIDUAL 476
#define IDC_DOMAIN_JIT      477
#define IDC_DOMAIN_PS       478
#define IDC_DOMAIN_FM       479
// These Sigma items must be in order so they can be indexed as
// i=IDC_DOMAIN_TRWF+alpha+2
#define IDC_DOMAIN_TRWF     480
#define IDC_DOMAIN_TFF      481
#define IDC_DOMAIN_TWF      482
#define IDC_DOMAIN_TFP      483
#define IDC_DOMAIN_TWP      484
#define IDC_DOMAIN_TALL     485
#define IDC_DOMAIN_AF       486
#define IDC_DOMAIN_BW       487
#define IDC_DOMAIN_MHZ      488
#define IDC_DOMAIN_SIG      489
#define IDC_DOMAIN_PSD      490
#define IDC_DOMAIN_TAU      491
#define IDC_DOMAIN_FREQ     492
#define IDC_DOMAIN_FALL     493
// These PSD items must be in order so they can be indexed as
// i=IDC_DOMAIN_FRWF+alpha+2
#define IDC_DOMAIN_FRWF     494
#define IDC_DOMAIN_FFF      495
#define IDC_DOMAIN_FWF      496
#define IDC_DOMAIN_FFP      497
#define IDC_DOMAIN_FWP      498

#define IDC_DOMAIN_FHIGH    499
#define IDC_DOMAIN_FLABEL   500

// These PSD labels must be in order
#define IDC_DOMAIN_PSD0    1500
#define IDC_DOMAIN_PSD1    1501
#define IDC_DOMAIN_PSD2    1502
#define IDC_DOMAIN_PSD3    1503
#define IDC_DOMAIN_PSD4    1504
#define IDC_DOMAIN_PSD5    1505

// These Sigma labels must be in order
#define IDC_DOMAIN_SIG0    1510
#define IDC_DOMAIN_SIG1    1511
#define IDC_DOMAIN_SIG2    1512
#define IDC_DOMAIN_SIG3    1513
#define IDC_DOMAIN_SIG4    1514
#define IDC_DOMAIN_SIG5    1515

// Domain plot controls
#define IDC_DOMAIN_STARTFREQ	1520
#define IDC_DOMAIN_ENDFREQ		1521
#define IDC_DOMAIN_STARTTAU		1522
#define IDC_DOMAIN_ENDTAU		1523
#define IDC_DOMAIN_PSDPLOT		1524
#define IDC_DOMAIN_SIGMAPLOT	1525

// Domain Dialog Box Sub-Procedures 240-243
#define IDC_DOMAIN_TTOF     240
#define IDC_DOMAIN_FTOT     241
#define IDC_DOMAIN_TOTAL    242

// Domain Dialog Box Sub-Procedures 465-466
#define IDC_DOMAIN_PLOTSIGMA   465
#define IDC_DOMAIN_PLOTPSD     466

// Edit Dialog Box 501-531, 244
#define IDC_EDIT_ACCEPT      501
#define IDC_EDIT_TABLE       502
#define IDC_EDIT_GOTO        503
#define IDC_EDIT_POINT       504
#define IDC_EDIT_FINDS       505
#define IDC_EDIT_GAP         506
#define IDC_EDIT_OUTLIER     507
#define IDC_EDIT_SIGMAFACTOR 508
#define IDC_EDIT_POINTNUM    509
#define IDC_EDIT_PREV        510
#define IDC_EDIT_NEXT        511
#define IDC_EDIT_SEARCH      512
#define IDC_EDIT_FIND        513
#define IDC_EDIT_REPLACE     514
#define IDC_EDIT_INSERT      515
#define IDC_EDIT_GAPS        516
#define IDC_EDIT_NUMGAPS     517
#define IDC_EDIT_TIMETAG     518
#define IDC_EDIT_AUTO        519
#define IDC_EDIT_COLORGAPS   520
#define IDC_EDIT_COLOROUTS   521
#define IDC_EDIT_FORMAT      522
#define IDC_EDIT_DATE        523
#define IDC_EDIT_EXP         524
#define IDC_EDIT_PROMPT      525
#define IDC_EDIT_DOY         526
#define IDC_EDIT_MJD         527
#define IDC_EDIT_GROUP       528
#define IDC_EDIT_MODE        529
#define IDC_EDIT_DELS        530
#define IDC_EDIT_SFLABEL     531
#define IDC_EDIT_REDRAW 	 244

// Find Dialog Box 1150-1169
#define IDC_FIND_WHAT       1150
#define IDC_FIND_NEXT       1151
#define IDC_FIND_DIR        1152
#define IDC_FIND_UP         1153
#define IDC_FIND_DOWN       1154
#define IDC_FIND_TEST       1155

// Replace Dialog Box  1170-1179
#define IDC_REPLACE_WHAT    1170
#define IDC_REPLACE_WITH    1171
#define IDC_REPLACE_FIND    1172
#define IDC_REPLACE_REPLACE 1173
#define IDC_REPLACE_ALL     1174
#define IDC_REPLACE_DIR     1175
#define IDC_REPLACE_UP      1176
#define IDC_REPLACE_DOWN    1177
#define IDC_REPLACE_TEST    1178
#define IDC_REPLACE_CONFIRM 1179

// Run Dialog Box 1180-1199, 532-536, 545-561
#define IDC_RUN_STOP		1180  // Stop during calc - not used
#define IDC_RUN_COPY        1192
#define IDC_RUN_ALABEL      1190
#define IDC_RUN_RUN         1181
#define IDC_RUN_NOTES       1182
#define IDC_RUN_TYPE        1183
#define IDC_RUN_CFLABEL     1184
#define IDC_RUN_REMOVE      1185
#define IDC_RUN_WRITE       1186
#define IDC_RUN_OCTAVE      1187
#define IDC_RUN_DECADE      1188
#define IDC_RUN_ALLTAU      1189
#define IDC_RUN_CF           532
#define IDC_RUN_PLOT         545
#define IDC_RUN_PRINT        546
#define IDC_RUN_SETCF        550
#define IDC_RUN_DRIFT        547
#define IDC_RUN_PROMPT       548
#define IDC_RUN_DISPLAY      551  // Display results
#define IDC_RUN_RESTORE      552  // Restore data after run
#define IDC_RUN_PHASE        553  // Process phase data
#define IDC_RUN_FREQ         554  // Process freq data
#define IDC_RUN_NOISE        555  // Calc noise type
#define IDC_RUN_ERRORBAR     556  // Find error bar limits
#define IDC_RUN_CLEAR        557  // Clear results
#define IDC_RUN_OPTIONS      558
#define IDC_RUN_LINES        559
#define IDC_RUN_ALPHA        560
#define IDC_RUN_TABLE        561  // Data table for results
#define IDC_RUN_HEADING     1191  // Write table heading
#define IDC_RUN_SIGMASIZE    533  // Calc size of sigma data arrays
#define IDC_RUN_REALLOC      534  // Realloc size of sigma data arrays
#define IDC_RUN_1OF2		1193  // Scale variance for 1 of 2 units
#define IDC_RUN_AF			1194  // Start AF
#define IDC_RUN_AFLABEL		1195  // Start AF Label
#define IDC_RUN_ERROR		1196  // Display run error message
#define IDC_RUN_ZEROSIG		1197  // Display zero sigma error message
#define IDC_RUN_SETSTOP	    1198  // Set nStopRatio
#define IDC_RUN_MODSIG		1199  // Internal subroutine for mod sigma calc
#define IDC_RUN_DEADTIME	 535  // Edit control for fR dead time ratio
#define IDC_RUN_RLABEL		 536  // Text label for dead time ratio

// Data Plot Dialog Box 316-329, 562-598
#define IDC_DPLOT_XSTART     316
#define IDC_DPLOT_XEND       317
#define IDC_DPLOT_MESSAGES   329
#define IDC_DPLOT_XAXIS      562
#define IDC_DPLOT_YAXIS      563
#define IDC_DPLOT_XLABEL     564
#define IDC_DPLOT_YLABEL     565
#define IDC_DPLOT_READ       321
#define IDC_DPLOT_TITLE      318
#define IDC_DPLOT_SUBTITLE   319
#define IDC_DPLOT_MESSAGE    320
#define IDC_DPLOT_XOFFSET    566
#define IDC_DPLOT_XMULT      567
#define IDC_DPLOT_YOFFSET    568
#define IDC_DPLOT_YMULT      569
#define IDC_DPLOT_OPTIONS    570
#define IDC_DPLOT_DATE       571
#define IDC_DPLOT_BOX        572
#define IDC_DPLOT_FIT        573
#define IDC_DPLOT_FILENAME   574
#define IDC_DPLOT_YMAX       575
#define IDC_DPLOT_YMIN       576
#define IDC_DPLOT_YDIV       577
#define IDC_DPLOT_YTIC       578
#define IDC_DPLOT_XDIV       323
#define IDC_DPLOT_XTIC       324
#define IDC_DPLOT_RESET      579
#define IDC_DPLOT_DATAMAX    580
#define IDC_DPLOT_DATAMIN    581
#define IDC_DPLOT_CURSOR     583
#define IDC_DPLOT_POSITION   584
#define IDC_DPLOT_YMULTLABEL 585
#define IDC_DPLOT_YOFFLABEL  586
#define IDC_DPLOT_YLABLABEL  587
#define IDC_DPLOT_XMULTLABEL 588
#define IDC_DPLOT_XOFFLABEL  589
#define IDC_DPLOT_XLABLABEL  590
#define IDC_DPLOT_TICLABEL   591
#define IDC_DPLOT_DIVLABEL   592
#define IDC_DPLOT_CANCEL     593
#define IDC_DPLOT_ACCEPT     594
#define IDC_DPLOT_WRITE      322
#define IDC_DPLOT_DOFIT		 325
#define IDC_DPLOT_WIDE		 326
#define IDC_DPLOT_XSCALE	 327
#define IDC_DPLOT_XSTICK	 328
#define IDC_DPLOT_ORDER		 595
#define IDC_DPLOT_POLY       596
#define IDC_DPLOT_FUNCT		 597
#define IDC_DPLOT_PARAM		 598

// Part Dialog Box 2000-2049
#define IDC_PART_ENDTAG       2000
#define IDC_PART_TAGTYPE      2001
#define IDC_PART_STARTUP      2002
#define IDC_PART_STARTDOWN    2003
#define IDC_PART_ENDUP        2004
#define IDC_PART_ENDDOWN      2005   
#define IDC_PART_START        2006
#define IDC_PART_END          2007
#define IDC_PART_RANGE        2008
#define IDC_PART_PROMPT       2009
#define IDC_PART_CANCEL       2010
#define IDC_PART_ACCEPT       2011
#define IDC_PART_INITIALIZE   2012
#define IDC_PART_STARTTAG	  2013
#define IDC_PART_SHOWSTARTTAG 2014
#define IDC_PART_SHOWENDTAG   2015

// Multi Dialog Box 670-677
#define IDC_MULTI_TAGS        670
#define IDC_MULTI_DATA        671
#define IDC_MULTI_COLUMNS     672
#define IDC_MULTI_PROMPT      673
#define IDC_MULTI_CANCEL      674
#define IDC_MULTI_ACCEPT      675
#define IDC_MULTI_NUM		  676
#define IDC_MULTI_DETAILS	  677

// Print Dialog Box 602-614
#define IDC_PRINT_COPY		 602
#define IDC_PRINT_START      603
#define IDC_PRINT_END        604
#define IDC_PRINT_RANGE      605
#define IDC_PRINT_TYPE       606
#define IDC_PRINT_PHASE      607
#define IDC_PRINT_FREQ       608
#define IDC_PRINT_PROMPT     609
#define IDC_PRINT_TAGS       610
#define IDC_PRINT_ALL        611
#define IDC_PRINT_LIMITS     612
#define IDC_PRINT_CANCEL     613
#define IDC_PRINT_ACCEPT     614

// Data Plot Line Options Dialog Box 615-640, 661-662
#define IDC_DLINE_UP         615
#define IDC_DLINE_DOWN       616
#define IDC_DLINE_CHECK      617
#define IDC_DLINE_READ       618
#define IDC_DLINE_WRITE      619
#define IDC_DLINE_RESET      620
#define IDC_DLINE_NUM        621
#define IDC_DLINE_TYPE       622
#define IDC_DLINE_XSTART     623
#define IDC_DLINE_XEND       624
#define IDC_DLINE_PARAMLAB   625
#define IDC_DLINE_XSTARTLAB  626
#define IDC_DLINE_YSTART     627
#define IDC_DLINE_YEND       628
#define IDC_DLINE_PARAM      629
#define IDC_DLINE_XENDLAB    630
#define IDC_DLINE_Y          631
#define IDC_DLINE_X          632
#define IDC_DLINE_LINES      633
#define IDC_DLINE_UPDATE     634
#define IDC_DLINE_CLEAR      635
#define IDC_DLINE_COUNT      636
#define IDC_DLINE_CANCEL     637
#define IDC_DLINE_ACCEPT     638
#define IDC_DLINE_YSTARTLAB  639
#define IDC_DLINE_YENDLAB    640
#define IDC_DLINE_PRINT		 661
#define IDC_DLINE_COPY		 662

// Data Plot Annotations Dialog Box 641-660
#define IDC_DNOTE_NUM        641
#define IDC_DNOTE_UP         642
#define IDC_DNOTE_DOWN       643
#define IDC_DNOTE_SIZE       644
#define IDC_DNOTE_TEXT       645
#define IDC_DNOTE_EDIT       646
#define IDC_DNOTE_POS        647
#define IDC_DNOTE_Y          648
#define IDC_DNOTE_X          649
#define IDC_DNOTE_NOTES      650
#define IDC_DNOTE_BORDER     651
#define IDC_DNOTE_CLR        652
#define IDC_DNOTE_UPDATE     653
#define IDC_DNOTE_CLEAR      654
#define IDC_DNOTE_COUNT      655
#define IDC_DNOTE_CANCEL     656
#define IDC_DNOTE_ACCEPT     657
#define IDC_DNOTE_READ       658
#define IDC_DNOTE_WRITE      659
#define IDC_DNOTE_OPAQUE	 660

// Archive Dialog Box 680-700
#define IDC_ARCHIVE_MEAS     680
#define IDC_ARCHIVE_REF      681
#define IDC_ARCHIVE_RECORD   682
#define IDC_ARCHIVE_START    683
#define IDC_ARCHIVE_END      684
#define IDC_ARCHIVE_NUM      685
#define IDC_ARCHIVE_MJD      686
#define IDC_ARCHIVE_ALL      687
#define IDC_ARCHIVE_LAST     688
#define IDC_ARCHIVE_CANCEL   689
#define IDC_ARCHIVE_ACCEPT   690
#define IDC_ARCHIVE_FILE     691
#define IDC_ARCHIVE_READ     692
#define IDC_ARCHIVE_TAU      693
#define IDC_ARCHIVE_FIRST    694
#define IDC_ARCHIVE_DISPLAY  695
#define IDC_ARCHIVE_CONFIG   696
#define IDC_ARCHIVE_LASTMJD  697
#define IDC_ARCHIVE_INDEX    698
#define IDC_ARCHIVE_MSPIN    699
#define IDC_ARCHIVE_RSPIN    700

// Data Plot Function Fit Box 2500-2525
#define IDC_FUNC_FUNC		2500
#define IDC_FUNC_A			2501
#define IDC_FUNC_B			2502
#define IDC_FUNC_C			2503
#define IDC_FUNC_D			2504
#define IDC_FUNC_E			2505
#define IDC_FUNC_F			2506
#define IDC_FUNC_G			2507
#define IDC_FUNC_H			2508
#define IDC_FUNC_I			2509
#define IDC_FUNC_J			2510
#define IDC_FUNC_ACCEPT		2511
#define IDC_FUNC_CANCEL		2512
#define IDC_FUNC_RESET		2513
#define IDC_FUNC_ALABEL		2514
#define IDC_FUNC_BLABEL		2515
#define IDC_FUNC_CLABEL		2516
#define IDC_FUNC_DLABEL		2517
#define IDC_FUNC_ELABEL		2518
#define IDC_FUNC_FLABEL		2519
#define IDC_FUNC_GLABEL		2520
#define IDC_FUNC_HLABEL		2521
#define IDC_FUNC_ILABEL		2522
#define IDC_FUNC_JLABEL		2523
#define IDC_FUNC_REMOVE		2524

// Data Plot Jump Box 2550-2570
#define IDC_JUMP_ACCEPT		2550
#define IDC_JUMP_CANCEL		2551
#define IDC_JUMP_RESET		2552
#define IDC_JUMP_SIZE		2553
#define IDC_JUMP_OFFSET		2554
#define IDC_JUMP_FREQ		2555
#define IDC_JUMP_SIGMA		2556
#define IDC_JUMP_CUSUM		2557
#define IDC_JUMP_CONF		2558
#define IDC_JUMP_CALCSIGMA  2559
#define IDC_JUMP_BLKAVG		2560
#define IDC_JUMP_SEQAVG		2561
#define IDC_JUMP_ALTCOLOR	2562

// Read Archive Configuration Dialog Box 800-820
#define IDC_ARCCONFIG_NUM		800
#define IDC_ARCCONFIG_MEAS		801
#define IDC_ARCCONFIG_REF		802
#define IDC_ARCCONFIG_ACCEPT	803
#define IDC_ARCCONFIG_CANCEL	804
#define IDC_ARCCONFIG_HELP		805
#define IDC_ARCCONFIG_READINI	806
#define IDC_ARCCONFIG_WRITEINI	807
#define IDC_ARCCONFIG_CSPIN     808
#define IDC_ARCCONFIG_MSPIN     809
#define IDC_ARCCONFIG_RSPIN     810

// Read Dialog Box 701-710
#define IDC_READ_PLOT        701
#define IDC_READ_PRINT       702
#define IDC_READ_PROMPT      703
#define IDC_READ_TYPE        704
#define IDC_READ_FILE        705
#define IDC_READ_TABLE       706
#define IDC_READ_CLEAR       707
#define IDC_READ_OPTIONS     708
#define IDC_READ_LINES       709
#define IDC_READ_NOTES       710

// Corn Dialog Box 1701-1724
#define IDC_CORN_PLOT        1701
#define IDC_CORN_PRINT       1702
#define IDC_CORN_PROMPT      1703
#define IDC_CORN_TYPE        1704
#define IDC_CORN_FILE        1705
#define IDC_CORN_TABLE       1706
#define IDC_CORN_CLEAR       1707
#define IDC_CORN_OPTIONS     1708
#define IDC_CORN_LINES       1709
#define IDC_CORN_NOTES       1710
#define IDC_CORN_CALC        1711
#define IDC_CORN_A           1712
#define IDC_CORN_B           1713
#define IDC_CORN_C           1714
#define IDC_CORN_READ        1715
#define IDC_CORN_COPY        1716
#define IDC_CORN_BROWSE		 1717
#define IDC_CORN_UNIT		 1718
#define IDC_CORN_COLOR		 1719
#define IDC_CORN_DF			 1720
#define IDC_CORN_ERRORBAR	 1721
#define IDC_CORN_WRITE		 1722
#define IDC_CORN_HAVEMM		 1723
#define IDC_CORN_HAVEDF		 1724

// Configuration Dialog Box 711-767, 3768-3779
#define IDC_CONFIG_AVGSIZE	   711
#define IDC_CONFIG_AVGMAX      712
#define IDC_CONFIG_LFSKIP      713
#define IDC_CONFIG_SMOOTH      714
#define IDC_CONFIG_PPO         715
#define IDC_CONFIG_DAVAR       716
#define IDC_CONFIG_AUTO        717
#define IDC_CONFIG_MANY        718
#define IDC_CONFIG_INPUTS      719
#define IDC_CONFIG_WRITESIGMA  720
#define IDC_CONFIG_UP          721
#define IDC_CONFIG_DOWN        722
#define IDC_CONFIG_TZ          723
#define IDC_CONFIG_PLOT        724
#define IDC_CONFIG_PHASE       725
#define IDC_CONFIG_FREQ        726
#define IDC_CONFIG_SIGMA       727
#define IDC_CONFIG_HISTO       728
#define IDC_CONFIG_SPECT       729
#define IDC_CONFIG_HR          730
#define IDC_CONFIG_TOOLBAR     731
#define IDC_CONFIG_TOOLBUTTONS 732
#define IDC_CONFIG_MISC        733
#define IDC_CONFIG_SHOWOPENED  734
#define IDC_CONFIG_PLOTLABEL   735
#define IDC_CONFIG_INCEXT      736
#define IDC_CONFIG_AUTOCALC    737
#define IDC_CONFIG_AUTOPLOT    738
#define IDC_CONFIG_OK          739
#define IDC_CONFIG_LABEL       740
#define IDC_CONFIG_LABELTEXT   741
#define IDC_CONFIG_CANCEL      742
#define IDC_CONFIG_STATPLOTS   743
#define IDC_CONFIG_SIZE        744
#define IDC_CONFIG_SKIP        745
#define IDC_CONFIG_COMMA	   746
#define IDC_CONFIG_WARN        747
#define IDC_CONFIG_SMART       748
#define IDC_CONFIG_HEADER	   749
#define IDC_CONFIG_WEIGHT	   750
#define IDC_CONFIG_DEFAULTS	   751
#define IDC_CONFIG_MANYSIZE	   752
#define IDC_CONFIG_MANYRESET   753
#define IDC_CONFIG_ADD1        754
#define IDC_CONFIG_MULT1       755
#define IDC_CONFIG_TAU1        756
#define IDC_CONFIG_TAGSCALE1   757
#define IDC_CONFIG_TAGOFFSET1  758
#define IDC_CONFIG_ADD2        759
#define IDC_CONFIG_MULT2       760
#define IDC_CONFIG_TAU2        761
#define IDC_CONFIG_TAGSCALE2   762
#define IDC_CONFIG_TAGOFFSET2  763
#define IDC_CONFIG_NOGREEK     764
#define IDC_CONFIG_SPLASH	   765
#define IDC_CONFIG_NOTEPAD     766
#define IDC_CONFIG_SIGWEIGHT   767
#define IDC_CONFIG_POINTSIZE   3768
#define IDC_CONFIG_AUDIOPLAYER 3769
#define IDC_CONFIG_SAMPLERATE  3770
#define IDC_CONFIG_WAVFILE     3771
#define IDC_CONFIG_ZP		   3772
#define IDC_CONFIG_TAG0        3773
#define IDC_CONFIG_TAG1        3774
#define IDC_CONFIG_TAG2        3775
#define IDC_CONFIG_SPURLIM	   3776
#define IDC_CONFIG_RUNTIME     3777
#define IDC_CONFIG_ORIGINAL	   3778
#define IDC_CONFIG_MODERN	   3779

// Opened Dialog Box 768-789
#define IDC_OPENED_TAGVAL      768
#define IDC_OPENED_DATVAL      769
#define IDC_OPENED_GROUP       770
#define IDC_OPENED_TAU         771
#define IDC_OPENED_PLOT        772
#define IDC_OPENED_ACCEPT      773
#define IDC_OPENED_PLOTDATA    774
#define IDC_OPENED_DISPLAY     775
#define IDC_OPENED_SCALE	   776
#define IDC_OPENED_ADD         777
#define IDC_OPENED_MULT        778
#define IDC_OPENED_INPUTS	   779
#define IDC_OPENED_TAUTYPE     780
#define IDC_OPENED_TAUSCALE    781
#define IDC_OPENED_FILE        782
#define IDC_OPENED_TYPE        783
#define IDC_OPENED_NUM         784
#define IDC_OPENED_GAPS        785
#define IDC_OPENED_MIN         786
#define IDC_OPENED_MAX         787
#define IDC_OPENED_TAGCOL      788
#define IDC_OPENED_DATCOL      789

// Sigma Plot Dialog Box 859-894
#define IDC_SPLOT_MINMAX     859
#define IDC_SPLOT_TABPOS     860
#define IDC_SPLOT_WRITE      861
#define IDC_SPLOT_READ       883
#define IDC_SPLOT_XAXIS      862
#define IDC_SPLOT_YAXIS      863
#define IDC_SPLOT_TAUMAX     864
#define IDC_SPLOT_TAUMIN     865
#define IDC_SPLOT_XMAX       866
#define IDC_SPLOT_XMIN       867
#define IDC_SPLOT_ERRBAR     868
#define IDC_SPLOT_STABFILE   869
#define IDC_SPLOT_OPTIONS    870
#define IDC_SPLOT_DATE       871
#define IDC_SPLOT_BOX        872
#define IDC_SPLOT_FILENAME   874
#define IDC_SPLOT_YMAX       875
#define IDC_SPLOT_YMIN       876
#define IDC_SPLOT_RESET      879
#define IDC_SPLOT_SIGMAMAX   880
#define IDC_SPLOT_SIGMAMIN   881
#define IDC_SPLOT_XLABEL     882
#define IDC_SPLOT_YLABEL     891
#define IDC_SPLOT_FIT		 892
#define IDC_SPLOT_POSITION   884
#define IDC_SPLOT_YLABLABEL  885
#define IDC_SPLOT_XLABLABEL  886
#define IDC_SPLOT_CANCEL     887
#define IDC_SPLOT_ACCEPT     888
#define IDC_SPLOT_TABLE      889
#define IDC_SPLOT_TITLE      873
#define IDC_SPLOT_SUBTITLE   877
#define IDC_SPLOT_MESSAGE    878
#define IDC_SPLOT_SLABEL     890
#define IDC_SPLOT_WIDE       893
#define IDC_SPLOT_APPEND	 894	// Append stability data flag

// Automatic Processing Dialog Box 900-940
#define IDC_AUTO_PHASEDATA		900
#define IDC_AUTO_FREQDATA		901
#define IDC_AUTO_FILEOPEN		902
#define IDC_AUTO_CONVERT		903
#define IDC_AUTO_OUTLIERS		904
#define IDC_AUTO_DRIFT			905
#define IDC_AUTO_PHASEDATAPLOT	906
#define IDC_AUTO_FREQDATAPLOT	907
#define IDC_AUTO_ADDDELAY       908
#define IDC_AUTO_RUN			909
#define IDC_AUTO_STABPLOT		910
// Don't use 911
#define IDC_AUTO_STABTABLE		912
#define IDC_AUTO_CLOSE			913
#define IDC_AUTO_FILENAME		914
#define IDC_AUTO_DATAPLOT		915
#define IDC_AUTO_SIGMAFACTOR	916
#define IDC_AUTO_VARIANCE		917
#define IDC_AUTO_ACCEPT			918
#define IDC_AUTO_CANCEL			919
#define IDC_AUTO_SCRIPTNUM		920
#define IDC_AUTO_DRIFTTYPE		921
#define IDC_AUTO_ICON			922			
#define IDC_AUTO_AVERAGE		923
#define IDC_AUTO_AVGFACTOR		924
#define IDC_AUTO_SCRIPTNAME		925
#define	IDC_AUTO_DATATYPE		926
#define IDC_AUTO_GO				927
#define IDC_AUTO_READINI		928
#define IDC_AUTO_WRITEINI		929
#define IDC_AUTO_RUNPLOT		930
#define IDC_AUTO_DATAPRINT		931
#define IDC_AUTO_DATAPLOTTYPE	932
#define IDC_AUTO_SETCONTROLS    933
#define IDC_AUTO_DELAYTIME		934
#define IDC_AUTO_BROWSE         935		
#define IDC_AUTO_PART           936		
#define IDC_AUTO_START          937		
#define IDC_AUTO_END            938
#define IDC_AUTO_NORM			939
#define IDC_AUTO_REG			940	

// Comm Dialog Box 1070-1083
#define IDC_COMM_LBBOTTOM    1070
#define IDC_COMM_OPENPORT    1071
#define IDC_COMM_CLOSEPORT   1072
#define IDC_COMM_POINTS		 1073
#define IDC_COMM_OPEN        1074
#define IDC_COMM_SETTINGS    1075
#define IDC_COMM_COMM        1076
#define IDC_COMM_FILENAME    1077
#define IDC_COMM_TEXT        1078
#define IDC_COMM_START       1079
#define IDC_COMM_CLOSE       1080
#define IDC_COMM_HELP        1081

// Custom Open and Save As Dialog Boxs
#define IDC_OPEN_HELP        1084
#define IDC_SAVE_HELP        1085
#define IDC_OPEN_ICON        1086
#define IDC_SAVE_ICON        1087
#define IDC_STAB_HELP        1088
#define IDC_STAB_ICON        1089

// Sigma Plot Line Options Dialog Box 1900-1934
#define IDC_SLINE_RESET      1900
#define IDC_SLINE_READ       1901
#define IDC_SLINE_TYPE       1902
#define IDC_SLINE_XSTART     1903
#define IDC_SLINE_XEND       1904
#define IDC_SLINE_WRITE      1905
#define IDC_SLINE_NUM        1906
#define IDC_SLINE_YSTART     1907
#define IDC_SLINE_YEND       1908
#define IDC_SLINE_PARAM      1909
#define IDC_SLINE_Y          1910
#define IDC_SLINE_X          1911
#define IDC_SLINE_LINES      1912
#define IDC_SLINE_NOISE      1913
#define IDC_SLINE_SLOPE      1914
#define IDC_SLINE_UPDATE     1915
#define IDC_SLINE_CLEAR      1916
#define IDC_SLINE_COUNT      1917
#define IDC_SLINE_XSTARTLAB  1918
#define IDC_SLINE_XENDLAB    1919
#define IDC_SLINE_YSTARTLAB  1920
#define IDC_SLINE_YENDLAB    1921
#define IDC_SLINE_SIGMALAB   1922
#define IDC_SLINE_SLOPELAB   1923
#define IDC_SLINE_CANCEL     1924
#define IDC_SLINE_INITIALIZE 1925
#define IDC_SLINE_XFIRST     1926
#define IDC_SLINE_XLAST      1927
#define IDC_SLINE_ACCEPT     1928
#define IDC_SLINE_SIGMA1     1929
#define IDC_SLINE_UP         1930
#define IDC_SLINE_DOWN       1931
#define IDC_SLINE_TAUUPDATE  1932
#define IDC_SLINE_PRINT		 1933
#define IDC_SLINE_MASKS		 1934

// Inputs dialog box 1940-1949
#define IDC_INPUTS_TAU		 1940
#define IDC_INPUTS_ADD		 1941
#define IDC_INPUTS_MULT		 1942
#define IDC_INPUTS_PROMPT	 1943
#define IDC_INPUTS_TEXT		 1944
#define IDC_INPUTS_CANCEL	 1945
#define IDC_INPUTS_ACCEPT	 1946
#define IDC_INPUTS_TAGSCALE  1947
#define IDC_INPUTS_TAGOFFSET 1948

// Power Spectrum Plot Dialog Box 1850-1899
#define IDC_PSPLOT_WINS     1850
#define IDC_PSPLOT_FACTOR   1851
#define IDC_PSPLOT_PSDFILE  1852
#define IDC_PSPLOT_AVERAGE  1853
#define IDC_PSPLOT_VARIANCE 1854
#define IDC_PSPLOT_YDIV     1855
#define IDC_PSPLOT_YTIC     1856
#define IDC_PSPLOT_YMAX     1857
#define IDC_PSPLOT_YMIN     1858
#define IDC_PSPLOT_XAXIS    1859
#define IDC_PSPLOT_YAXIS    1860
#define IDC_PSPLOT_FIT      1861
#define IDC_PSPLOT_FBIN     1862
#define IDC_PSPLOT_WIN      1863
#define IDC_PSPLOT_NUM      1864
#define IDC_PSPLOT_PSD      1865
#define IDC_PSPLOT_FMAX     1866
#define IDC_PSPLOT_NFFT     1867
#define IDC_PSPLOT_YLABEL   1868
#define IDC_PSPLOT_XLABEL   1869
#define IDC_PSPLOT_OPTIONS  1870
#define IDC_PSPLOT_DATE     1871
#define IDC_PSPLOT_BOX      1872
#define IDC_PSPLOT_FILENAME 1873
#define IDC_PSPLOT_RESET    1874
#define IDC_PSPLOT_POSITION 1875
#define IDC_PSPLOT_CANCEL   1876
#define IDC_PSPLOT_POINTS   1877
#define IDC_PSPLOT_CURSOR   1878
#define IDC_PSPLOT_TITLE    1879
#define IDC_PSPLOT_SUBTITLE 1880
#define IDC_PSPLOT_MESSAGE  1881
#define IDC_PSPLOT_PLOT     1882
#define IDC_PSPLOT_INFO     1883
#define IDC_PSPLOT_CARRIER  1884
#define IDC_PSPLOT_WRITE    1885
#define IDC_PSPLOT_READ     1886
#define IDC_PSPLOT_WIDE		1887
#define IDC_PSPLOT_DATAMAX  1888
#define IDC_PSPLOT_DATAMIN  1889
#define IDC_PSPLOT_SMOOTH	1890
#define IDC_PSPLOT_NPSD		1891
#define IDC_PSPLOT_MAXAF	1892
#define IDC_PSPLOT_DISPLAY	1893
#define IDC_PSPLOT_ENBW		1894
#define IDC_PSPLOT_SPUR		1895
#define IDC_PSPLOT_NOSPURPLOT		1896
#define IDC_PSPLOT_NOSPURDATA		1897
#define IDC_PSPLOT_OPTS		1898


// Histogram Plot Dialog Box 1759-1795
#define IDC_HPLOT_XAXIS     1759
#define IDC_HPLOT_YAXIS     1760
#define IDC_HPLOT_FIT       1761
#define IDC_HPLOT_NORM      1762
#define IDC_HPLOT_YLABEL    1763
#define IDC_HPLOT_XLABEL    1764
#define IDC_HPLOT_OPTIONS   1765
#define IDC_HPLOT_DATE      1766
#define IDC_HPLOT_BOX       1767
#define IDC_HPLOT_FILENAME  1768
#define IDC_HPLOT_RESET     1769
#define IDC_HPLOT_POSITION  1770
#define IDC_HPLOT_CANCEL    1771
#define IDC_HPLOT_CURSOR    1772
#define IDC_HPLOT_TITLE     1773
#define IDC_HPLOT_SUBTITLE  1774
#define IDC_HPLOT_MESSAGE   1775
#define IDC_HPLOT_PLOT      1776
#define IDC_HPLOT_AVG       1777
#define IDC_HPLOT_READ		1778
#define IDC_HPLOT_FILL		1779
#define IDC_HPLOT_WRITE     1780
#define IDC_HPLOT_NUMBINS	1781
#define IDC_HPLOT_BINSIZE	1782
#define IDC_HPLOT_DATAMAX	1783
#define IDC_HPLOT_DATAMIN	1784
#define IDC_HPLOT_BINMAX	1785
#define IDC_HPLOT_BINMIN	1786
#define IDC_HPLOT_YMAX		1787
#define IDC_HPLOT_YMIN		1788
#define IDC_HPLOT_XMAX		1789
#define IDC_HPLOT_XMIN		1790
#define IDC_HPLOT_XSTEP		1791
#define IDC_HPLOT_YSTEP		1792
#define IDC_HPLOT_OFFSET	1793
#define IDC_HPLOT_MULT		1794
#define IDC_HPLOT_UPDATE	1795

// Dynamic Stability Plot Dialog Box 2759-2799
#define IDC_DAVAR_HELP         9
#define IDC_DAVAR_XAXIS     2759
#define IDC_DAVAR_YAXIS     2760
#define IDC_DAVAR_AVAR      2761
#define IDC_DAVAR_HVAR      2762
#define IDC_DAVAR_YLABEL    2763
#define IDC_DAVAR_XLABEL    2764
#define IDC_DAVAR_OPTIONS   2765
#define IDC_DAVAR_DATE      2766
#define IDC_DAVAR_BOX       2767
#define IDC_DAVAR_FILENAME  2768
#define IDC_DAVAR_RESET     2769
#define IDC_DAVAR_SETTINGS	2770
#define IDC_DAVAR_POSITION  2771
#define IDC_DAVAR_CANCEL    2772
#define IDC_DAVAR_ZLABEL    2773
#define IDC_DAVAR_TITLE     2774
#define IDC_DAVAR_SUBTITLE  2775
#define IDC_DAVAR_MESSAGE   2776
#define IDC_DAVAR_PLOT      2777
#define IDC_DAVAR_ZAXIS     2778
#define IDC_DAVAR_READ		2779
#define IDC_DAVAR_WRITE		2780
#define IDC_DAVAR_WINSIZE   2781
#define IDC_DAVAR_NUMWIN	2782
#define IDC_DAVAR_STEPSIZE	2783
#define IDC_DAVAR_CALC		2784
#define IDC_DAVAR_PROGRESS  2785
#define IDC_DAVAR_ABORT     2786
#define IDC_DAVAR_COLORS	2787
#define IDC_DAVAR_GRID		2788
#define IDC_DAVAR_GRIDLABEL	2789
#define IDC_DAVAR_HORIZ		2790
#define IDC_DAVAR_VERT		2791
#define IDC_DAVAR_REV		2792

// Autocorrelation Plot Dialog Box 2050-2097
#define IDC_APLOT_WINS     2050
#define IDC_APLOT_FACTOR   2051
#define IDC_APLOT_PSDFILE  2052
#define IDC_APLOT_AVERAGE  2053
#define IDC_APLOT_VARIANCE 2054
#define IDC_APLOT_YDIV     2055
#define IDC_APLOT_YTIC     2056
#define IDC_APLOT_YMAX     2057
#define IDC_APLOT_YMIN     2058
#define IDC_APLOT_XAXIS    2059
#define IDC_APLOT_YAXIS    2060
#define IDC_APLOT_ZERO     2061
#define IDC_APLOT_FBIN     2062
#define IDC_APLOT_WIN      2063
#define IDC_APLOT_NUM      2064
#define IDC_APLOT_AUTOFILE 2065
#define IDC_APLOT_FMAX     2066
#define IDC_APLOT_NFFT     2067
#define IDC_APLOT_YLABEL   2068
#define IDC_APLOT_XLABEL   2069
#define IDC_APLOT_OPTIONS  2070
#define IDC_APLOT_DATE     2071
#define IDC_APLOT_BOX      2072
#define IDC_APLOT_FILENAME 2073
#define IDC_APLOT_RESET    2074
#define IDC_APLOT_POSITION 2075
#define IDC_APLOT_CANCEL   2076
#define IDC_APLOT_POINTS   2077
#define IDC_APLOT_CURSOR   2078
#define IDC_APLOT_TITLE    2079
#define IDC_APLOT_SUBTITLE 2080
#define IDC_APLOT_MESSAGE  2081
#define IDC_APLOT_PLOT     2082
#define IDC_APLOT_INFO     2083
#define IDC_APLOT_CARRIER  2084
#define IDC_APLOT_WRITE    2085
#define IDC_APLOT_READ     2086
#define IDC_APLOT_WIDE	   2087
#define IDC_APLOT_DATAMAX  2088
#define IDC_APLOT_DATAMIN  2089
#define IDC_APLOT_R1	   2090
#define IDC_APLOT_LAG1     2091
#define IDC_APLOT_ALL	   2092
#define IDC_APLOT_AF	   2093
#define IDC_APLOT_TAU	   2094
#define IDC_APLOT_LAGNUM   2095
#define IDC_APLOT_SCATTER  2096
#define IDC_APLOT_NOISEID  2097

// Plot Inserts dialog box 2100-2129
#define IDC_INSERT_PHASEFILE	2100
#define IDC_INSERT_FREQFILE		2101
#define IDC_INSERT_STABFILE		2102
#define IDC_INSERT_ACFFILE		2103
#define IDC_INSERT_PHASEDEL		2104
#define IDC_INSERT_FREQDEL		2105
#define IDC_INSERT_STABDEL		2106
#define IDC_INSERT_ACFDEL		2107
#define IDC_INSERT_ALLDEL		2108
#define IDC_INSERT_CLOSE		2109
#define IDC_INSERT_NONE         2110
#define IDC_INSERT_PHASEON		2111
#define IDC_INSERT_FREQON		2112
#define IDC_INSERT_STABON		2113
#define IDC_INSERT_ACFON		2114
#define IDC_INSERT_PHASEBROWSE	2115
#define IDC_INSERT_FREQBROWSE	2116
#define IDC_INSERT_STABBROWSE	2117
#define IDC_INSERT_ACFBROWSE	2118
#define IDC_INSERT_PHASEDEF		2119
#define IDC_INSERT_FREQDEF		2120
#define IDC_INSERT_STABDEF		2121
#define IDC_INSERT_ACFDEF		2122
#define IDC_INSERT_PHASECLR		2123
#define IDC_INSERT_FREQCLR		2124
#define IDC_INSERT_STABCLR		2125
#define IDC_INSERT_ACFCLR		2126
#define IDC_INSERT_TKF			2127

// Unstep dialog box controls 2130-2149
#define IDC_STEP_NUM			2130
#define IDC_STEP_SPAN			2131
#define IDC_STEP_CANCEL			2132
#define IDC_STEP_ACCEPT			2133
#define IDC_STEP_GAP			2134

// SQL Database function dialog box controls 7000-7099
#define IDC_SQLCONFIG_HELP                9
#define IDC_SQL_CANCEL                 7002
#define IDC_SQL_REFCLK                 7003
#define IDC_SQL_MEASCLK                7004
#define IDC_SQL_MEASCLKDES             7005
#define IDC_SQL_MEASTAB                7006
#define IDC_SQL_REFTAB                 7007
#define IDC_SQL_MEASINFO               7008
#define IDC_SQL_REFCLKDES              7009
#define IDC_SQL_UTC                    7070
#define IDC_SQL_MJD                    7011
#define IDC_SQL_HELP                   7012
#define IDC_SQL_READ                   7013
#define IDC_SQL_START                  7014
#define IDC_SQL_END                    7015
#define IDC_SQL_REFTABLE               7016
#define IDC_SQL_CONFIG                 7017
#define IDC_SQL_STARTMJD               7018
#define IDC_SQL_ENDMJD                 7019
#define IDC_SQLCONFIG_CANCEL           7020
#define IDC_SQLCONFIG_ACCEPT           7021
#define IDC_SQLCONFIG_HOST             7022
#define IDC_SQLCONFIG_DATABASE         7023
#define IDC_SQLCONFIG_USER             7024
#define IDC_SQLCONFIG_PASSWORD         7025
#define IDC_SQLCONFIG_PROMPT           7026
#define IDC_SQL_REFCLOCKID             7027
#define IDC_SQL_MEASSYSTEMID           7028
#define IDC_SQL_DETAILS                7029
#define IDC_SQL_MEASSYSNAME            7029
#define IDC_SQL_MEASCLOCKID            7030
#define IDC_SQL_REFCHANNEL             7031
#define IDC_SQL_MEASTAU                7032
#define IDC_SQL_REFCLOCKNAME           7032
#define IDC_SQL_MEASCHANNEL            7033
#define IDC_SQL_REFSOURCEID            7034
#define IDC_SQL_MEASSOURCEID           7035
#define IDC_SQL_REFBEGUNBY             7036
#define IDC_SQL_REFMEASID              7037
#define IDC_SQL_MEASBEGUNBY            7038
#define IDC_SQL_MEASMEASID             7039
#define IDC_SQL_REFENDEDBY             7040
#define IDC_SQL_MEASENDEDBY            7041
#define IDC_SQL_PROGRESS               7042
#define IDC_SQL_MEASCLOCKNAME          7042
#define IDC_SQL_MESSAGE                7043
#define IDC_SQL_READTAU                7045
#define IDC_SQL_LENGTH                 7046
#define IDC_SQL_SIZE                   7047
#define IDC_SQL_RESET                  7054
#define IDC_SQL_AF                     7055
#define IDC_SQL_REFSYSTEMID            7056
#define IDC_SQL_MEASFREQ               7057
#define IDC_SQL_REFFREQ                7058
#define IDC_SQL_REFSYSNAME             7059
#define IDC_SQL_NOTE                   7061
#define IDC_SQLCONFIG_STOP			   7062
#define IDC_SQL_SQLHELP				   7063

// Filter function dialog box controls 7100-7199
#define IDC_FILTER_TYPE				   7100
#define IDC_FILTER_HIGH				   7101
#define IDC_FILTER_LOW				   7102
#define IDC_FILTER_BAND				   7103
#define IDC_FILTER_STOP				   7104
#define IDC_FILTER_FREQ				   7105
#define IDC_FILTER_UPPER			   7106
#define IDC_FILTER_LOWER			   7107
#define IDC_FILTER_MAX				   7108
#define IDC_FILTER_MIN				   7109
#define IDC_FILTER_PROMPT			   7110
#define IDC_FILTER_ACCEPT			   7111
#define IDC_FILTER_CANCEL			   7112
#define IDC_FILTER_HELP				   7113
#define IDC_FILTER_HI				   7114
#define IDC_FILTER_LO				   7115
#define IDC_FILTER_TEXT				   7116
#define IDC_FILTER_MAXFREQ			   7117
#define IDC_FILTER_MINFREQ			   7118
#define IDC_FILTER_ICON				   7119

// Vibra function dialog box controls
#define IDC_VIBRA_CANCEL               11002
#define IDC_VIBRA_MHZLABEL             11003
#define IDC_VIBRA_SOURCE               11004
#define IDC_VIBRA_MHZ                  11005
#define IDC_VIBRA_GAMMALABEL           11006
#define IDC_VIBRA_GAMMA                11007
#define IDC_VIBRA_VIB                  11008
#define IDC_VIBRA_GLABEL               11009
#define IDC_VIBRA_G                    11010
#define IDC_VIBRA_FVIBLABEL            11011
#define IDC_VIBRA_FVIB                 11012
#define IDC_VIBRA_RESULTS              11013
#define IDC_VIBRA_DBCLABEL             11014
#define IDC_VIBRA_CALC                 11016
#define IDC_VIBRA_HELP                 11017
#define IDC_VIBRA_INFO                 11018
#define IDC_VIBRA_SINE                 11019
#define IDC_VIBRA_RAND                 11020
#define IDC_VIBRA_ICON                 11021
#define IDC_VIBRA_DBC                  11022
#define IDC_VIBRA_SETUP                11023
#define IDC_VIBRA_SHOW                 11024
#define IDC_VIBRA_RESULT               11025
#define IDC_VIBRA_FM                   11026
#define IDC_VIBRA_COPY				   11027

// Details function dialog box controls
#define IDC_DETAILS_TABLE				8000
#define IDC_DETAILS_HELP				8001
#define IDC_DETAILS_CANCEL				8002
#define IDC_DETAILS_DATECOL				8003
#define IDC_DETAILS_DATEFORMAT			8004
#define IDC_DETAILS_TIMECOL				8005
#define IDC_DETAILS_TIMRFORMAT			8006
#define IDC_DETAILS_TITLE				8007
#define IDC_DETAILS_FILE				8008
#define IDC_DETAILS_COLS				8009
#define IDC_DETAILS_DELIM				8010
#define IDC_DETAILS_DP					8011
#define IDC_DETAILS_DATE				8012
#define IDC_DETAILS_TIME				8013
#define IDC_DETAILS_DATETYPE			8014
#define IDC_DETAILS_TIMETYPE			8015
#define IDC_DETAILS_MJD					8016
#define IDC_DETAILS_CALCMJD				8017
#define IDC_DETAILS_DATETIME			8018
#define IDC_DETAILS_FIRST				8019
#define IDC_DETAILS_LAST				8020
#define IDC_DETAILS_SHOW				8021
#define IDC_DETAILS_SETUP				8022
#define IDC_DETAILS_COPY				8023
#define IDC_DETAILS_ROWS				8024
#define IDC_DETAILS_REJECTS				8025
#define IDC_DETAILS_DISPLAY				8026
#define IDC_DETAILS_COMMENTS			8027

// Set toolbar position with these macros
// TB_TAB added to FULL_VER 01/12/07 after TB_SQL
// and following ones pushed down
// TB_VIBRA added to FULL_VER 05/21/08 after TB_FILE
// and following ones pushed down
// TB_FILTER added to FULL_VER 07/17/08 after TB_NOISE
// and following ones pushed down
// TB_STEP added to FULL_VER 05/25/11 after TB_SCALE
// and following ones pushed down
#ifdef FULL_VER
	#define TB_OPEN                0
	#define TB_SAVE                1
	#define TB_ADD                 2
	#define TB_READ                3
	#define TB_SQL				   4
	#define TB_TAB				   5
	#define TB_PRINT               6
	#define TB_EDIT                7
	#define TB_CONV                8
	#define TB_NORM                9
	#define TB_AVG                10
	#define TB_FILL               11
	#define TB_SCALE              12
	#define TB_STEP				  13
	#define TB_CLEAR              14
	#define TB_PART               15
	#define TB_STAT               16
	#define TB_CHECK              17
	#define TB_DRIFT              18
	#define TB_SIGMA              19
	#define TB_RUN                20
	#define TB_DAVAR			  21
	// Note:  Keep these next three in order
	#define TB_AUTO1			  22
	#define TB_AUTO2			  23
	#define TB_AUTO3			  24
	#define TB_POWER              25
	#define TB_HIST               26
	#define TB_ACS				  27
	#define TB_PLOT               28
	#define TB_TIMETAG            29
	#define TB_REGULARIZE         30
	#define TB_NOISE              31
	#define TB_FILTER			  32
	#define TB_CAL                33
	#define TB_DOMAIN             34
	#define TB_CONF				  35
	#define TB_FILE               36
	#define TB_VIBRA			  37
	#define TB_PLAY				  38
	#define TB_NOTEPAD			  39
	#define TB_COMM				  40
	#define TB_HELP				  41
#endif

// TB_TAB added to STUDENT_VER 05/2/07 after TB_PRINT
// and following ones pushed down
// TB_VIBRA and TB_FILTER added 04/29/09
// TB_STEP added to FULL_VER 05/08/12 after TB_SCALE
// and following ones pushed down
#ifdef STUDENT_VER
	#define TB_OPEN                0
	#define TB_SAVE                1
	#define TB_ADD                 2
	#define TB_READ                3
	#define TB_PRINT               4
	#define TB_TAB				   5
	#define TB_EDIT                6
	#define TB_CONV                7
	#define TB_NORM                8
	#define TB_AVG                 9
	#define TB_FILL               10
	#define TB_SCALE              11
	#define TB_STEP				  12
	#define TB_CLEAR              13
	#define TB_PART               14
	#define TB_STAT               15
	#define TB_CHECK              16
	#define TB_DRIFT              17
	#define TB_SIGMA              18
	#define TB_RUN                19
	#define TB_DAVAR			  20 
	#define TB_POWER              21
	#define TB_HIST               22
	#define TB_PLOT               23
	#define TB_TIMETAG            24
	#define TB_REGULARIZE         25
	#define TB_ACS				  26
	#define TB_NOISE              27
	#define TB_FILTER			  28
	#define TB_CAL                29
	#define TB_DOMAIN             30
	#define TB_CONF				  31
	#define TB_FILE               32
	#define TB_VIBRA			  33
	#define TB_NOTEPAD			  34
	#define TB_HELP               35
#endif

#ifdef LITE_VER
	#define TB_OPEN                0
	#define TB_SAVE                1
	#define TB_EDIT                2
	#define TB_CONV                3
	#define TB_NORM                4
	#define TB_AVG                 5
	#define TB_SCALE               6
	#define TB_CLEAR               7
	#define TB_PART                8
	#define TB_STAT                9
	#define TB_CHECK              10
	#define TB_DRIFT              11
	#define TB_SIGMA              12
	#define TB_RUN                13
	#define TB_PLOT               14
	#define TB_HELP               15
#endif

// Outlier table macros
#define OT_NUM_COLS  2          // # of columns in table
#define OT_NUM_COL_NUM 0        // Point number column #
#define OT_OUT_COL_NUM 1        // Outlier column #
#define OT_NUM_NUM_CHARS 7      // # characters in point # column
								// Was 5 until 05/29/01
#define OT_NUM_OUT_CHARS 20     // # characters in data column
                                // Sign + leading digit + decimal point +
                                // 13 digit fractional part + e +
                                // exponent sign + 2 exponent digits
                                // Outlier data table row data structure

// Read table macros
#define RT_NUM_COLS  5          // # of columns in table
#define RT_TAU_COL_NUM 0        // Tau column #
#define RT_NUM_COL_NUM 1        // # Points number column #
#define RT_MIN_COL_NUM 2        // Min Sigma column #
#define RT_SIG_COL_NUM 3        // Sigma column #
#define RT_MAX_COL_NUM 4        // Max Sigma column #
#define RT_NUM_TAU_CHARS 9      // # characters in tau data column
                                // Leading digit + decimal point +
                                // 3 digit fractional part + e +
                                // exponent sign + 2 exponent digits
#define RT_NUM_NUM_CHARS 7      // # characters in point # column
#define RT_NUM_MIN_CHARS 9      // # characters in min sigma data column
#define RT_NUM_SIG_CHARS 9      // # characters in sigma data column
#define RT_NUM_MAX_CHARS 9      // # characters in max sigma data column
#define RT_NUM_EXTRA_CHARS 4	// # extra chars required for
								// read table data
								// The +4 is needed for full display of
								// last column because each e format field
								// needs 1 more character for its 3-digit
								// exponent before it is shortened

// Run table macros
#define RUN_NUM_COLS  7         // # of columns in table
#define RUN_AF_COL_NUM 0        // AF column #
#define RUN_TAU_COL_NUM 1       // Tau column #
#define RUN_NUM_COL_NUM 2       // # Points number column #
#define RUN_ALPHA_COL_NUM 3     // Alpha number column #
#define RUN_MIN_COL_NUM 4       // Min Sigma column #
#define RUN_SIG_COL_NUM 5       // Sigma column #
#define RUN_MAX_COL_NUM 6       // Max Sigma column #
#define RUN_NUM_AF_CHARS 6      // # characters in AF column
#define RUN_NUM_TAU_CHARS 10    // # characters in tau data column
                                // Leading digit + decimal point +
                                // 4 digit fractional part + e +
                                // exponent sign + 2 exponent digits
#define RUN_NUM_NUM_CHARS 7     // # characters in point # column
#define RUN_NUM_ALPHA_CHARS 5   // # characters in alpha column
#define RUN_NUM_MIN_CHARS 10    // # characters in min sigma data column
#define RUN_NUM_SIG_CHARS 10    // # characters in sigma data column
#define RUN_NUM_MAX_CHARS 10    // # characters in max sigma data column
#define RUN_NUM_EXTRA_CHARS 4	// # extra chars required for run table data
								// The +4 is needed for full display of
								// last column because each e format field
								// needs 1 more character for its 3-digit
								// exponent before it is shortened
// Corn table macros
#define CT_NUM_COLS  4          // # of columns in table
#define CT_TAU_COL_NUM 0        // Tau column #
#define CT_A_COL_NUM 1			// Sigma A column #
#define CT_B_COL_NUM 2			// Sigma B column #
#define CT_C_COL_NUM 3			// Sigma C column #
#define CT_NUM_TAU_CHARS 9     // # characters in tau data column
                                // Leading digit + decimal point +
                                // 3 digit fractional part + e +
                                // exponent sign + 2 exponent digits + spare
#define CT_NUM_A_CHARS 9		// # characters in sigma a data column
#define CT_NUM_B_CHARS 9		// # characters in sigma b data column
#define CT_NUM_C_CHARS 9		// # characters in sigma c data column
#define CT_NUM_EXTRA_CHARS 4	// # extra chars required for corn table data
								// The +4 is needed for full display of
								// last column because each e format field
								// needs 1 more character for its 3-digit
								// exponent before it is shortened

// Outlier data row structure
typedef struct tagOUTROWSTRUCT
{
    int nPoint;                           // Outlier data point #
    char szValue[OT_NUM_OUT_CHARS+1];     // Outlier value
} OUTROWSTRUCT;

// Struct for toobutton parameters
// An array of toolbutton structures is used to define a toolbar
typedef struct tagTOOLBUTTON
{
    HICON hIcon[4];     // Array of toolbutton icons
                        // ID #s same as toolbutton states:
                        // 0=Empty (all transparent) icon
                        // 1=Grayed version of button icon
                        // 2=Unpressed version of button icon
                        // 3=Pressed version of button icon
                        // Index icons as tb[i].hIcon[tb[i].state
                        // where tb[] is array of toolbutton structs

    RECT  rect;         // Toolbutton rectangle
    int state;          // Visual condition of button: TOOLBUTTON_BLANK
                        //                             TOOLBUTTON_DIM
                        //                             TOOLBUTTON_OUT
                        //                             TOOLBUTTON_IN
    int prev_state;     // Previous button condition (redraw if changed)
    BOOL flag;          // Logic state of button (used for toggle type)
    BOOL abort;         // Flag to indicate mouse left pressed toolbutton
    BOOL show_flag;     // Flag to control whether toolbutton is displayed
    int position;       // Screen position (0-NUM_TOOLS-1 or -1 to hide)
    int type;           // Behavior of button:  TOOLBUTTON_MOMENTARY
                        //                      TOOLBUTTON_TOGGLE
    char label[TOOLLABELSIZE];      // Toolbutton label text
    char prompt[TOOLPROMPTSIZE];    // Char string containing user prompt
                                    // describing toolbutton function
} TOOLBUTTON;

// Struct for plot data
struct plotdata                          /* structure template for plot data */
{
    float x_offset;                             /* x-axis data offset factor */
    float x_mult;                           /* x-axis data multiplier factor */
    float y_offset;                             /* y-axis data offset factor */
    float y_mult;                           /* y_axis data multiplier factor */
	float y_avg;                                      /* y-axis data average */
    float x_min;                                      /* x-axis plot minimum */
    float x_max;                                      /* x-axis plot maximum */
    float y_min;                                      /* y-axis plot minimum */
    float y_max;                                      /* y-axis plot maximum */
	float x_step;								   /* x-axis scale step size */
	float y_step;								   /* y-axis scale step size */
	float bw;										            /* bandwidth */
    float carrier;                                      /* carrier frequency */
	float limit;                         /* jump detection or spur threshold */
	float sigma;                                              /* sigma value */
	double *param;                                        /* parameter array */
    char *title;                                               /* plot title */
    char *subtitle;                                         /* plot subtitle */
    char *x_label;                                      /* plot x-axis label */
    char *left_y_label;                       /* plot y-axis left side label */
    char *right_y_label;                     /* plot y-axis right side label */
    char *plot_filename;                               /* plot .TKF filename */
    char *message_str;                                /* plot message string */
	char *function;                           /* expression for function fit */
    int do_date;                                /* flag to draw date on plot */
    int do_box;                              /* flag to draw box around plot */
    int do_errbar;                     /* flag to include error bars on plot */
    int do_line;                 /* code to control drawing of lines on plot */
              /* Freq plot line codes: 0=None, 1=Line, 2=Log, 3=Menu, 4=Dual */
    int do_mouse;               /* flag to activate mouse after drawing plot */
    int do_table;         /* flag to write sigma-tau table on stability plot */
	int do_fit;			    /* flag to show fit parameters at bottom of plot */
	int do_wide;			                  /* flag to make plot line wide */
	int do_cusum; /* flag to show cusum sub-plot on jump detection freq plot */
	int do_conf;                      /* flag to calc jump confidence factor */
	int do_spur;                  /* flag to show discrete spurs in PSD plot */
    int new_file;                   /* flag that plot is for a new data file */
    int new_name;              /* flag that plot is for a new basic filename */
    int plotype;                        /* code to identify the type of plot */
    int position;         /* code to control position of message box on plot */
	int order;		                                /* polynominal fit order */
    int table_position;         /* code to control position of table on plot */
    int x_div;                                   /* # x-axis major divisions */
    int x_tic;                      /* # x-axis tics between major divisions */
    int y_div;                                   /* # y-axis major divisions */
    int y_tic;                      /* # y-axis tics between major divisions */
    int config;                        /* flag for active configuration file */
    int win;                                               /* windowing type */
    int num;                                           /* # windowings, etc. */
    int nfft;                                                /* # fft points */
	int af;											       /* # fft averages */
	int thick;											   /* line thickness */
	int smooth;				               /* flag for PSD smoothing applied */
	int ppo;					        /* # points per decade for smoothing */
	int weight;							       /* flag for weighted line fit */
	int length;				                 /* jump detection window length */
	int offset;                              /* jump detection window offset */
	int method;					                    /* jump detection method */
	int data_color;                                       /* data plot color */
	int nospur_plot;				   /* flag to remove spurs from PSD plot */
	int nospur_data;         /* flag to remove spurs from phase or freq data */
	int remove;       /* flag to remove function fit from phase or freq plot */
};

// Struct for 3D DAVAR plot data
// Surface plot of log sigma (z) vs. log tau (x) with time (y) as parameter
// Tau expressed as log2 AF - Default message gives equivalent min & max tau
// Time is sigma-tau data set # - same for all sigma-tau in a plane
// Default message also relates set # to time min, max & step size
// Names of 1st 10 struct items correspond to arguments of Graphic surmatr()
// function for plotting a 3D surface from irregularly-spaced data points
// Using that function allows AF to vary as all or many tau, not just octaves
// The remaining items are similar to those of standard plotdata struct
// xvu, yvu & zvu added 12/26/06
struct d3plotdata                      /* structure template for 3dplot data */
{
	float *x;                                     /* x data = tau as log2 AF */
	float *y;                            /* y data = time as sigma-tau set # */
	float *z;     /* z data - sigma as log10 sigma - a function of t and tau */
	float *zmat;	                   /* z matrix for array of sigma values */
	int xsize; /* x dim of zmat */
	int ysize; /* y dim of zmat */
	int npts;                                         /* # x,y,z data points */
	int nx;										    /* # x-axis points (AFs) */
	int ny;										   /* # y-axis points (sets) */
	int winsize;                                              /* window size */
	int stepsize;                                               /* step size */
    float xgmin;                                           /* x-grid minimum */
    float xgmax;                                           /* x-grid maximum */
	int nxpts;                                     /* # x-grid intersections */
    float ygmin;                                           /* y-grid minimum */
    float ygmax;                                           /* y-grid maximum */
	float smin;                                                 /* min sigma */
	float smax;                                                 /* max sigma */
	int nypts;                                     /* # y-grid intersections */
	float tau0;						                           /* tau0 value */
    char *title;                                               /* plot title */
    char *subtitle;                                         /* plot subtitle */
    char *plot_filename;                               /* plot .TKF filename */
    char *message_str;                                /* plot message string */
    int do_date;                                /* flag to draw date on plot */
    int do_box;                              /* flag to draw box around plot */
    int vartype;      /* code to identify plot variance type: 0=HVAR, 1=AVAR */
    int position;         /* code to control position of message box on plot */
	int colors;		       /* flag to use variable colors in 3D surface plot */
	int grid;				      /* code to control color surface plot grid */
	                    /* 0=no grid, 1=normal grid, >1=# grid lines to skip */
	float xvu;                                       /* x viewpoint position */
	float yvu;                                       /* y viewpoint position */
	float zvu;                                       /* z viewpoint position */
 };

// Struct for sigma Run data
// *df added 12/19/01 to support error bars in 3-cornered hat
// *falpha added 01/21/04 to support detailed noise identification
// *sign added 04/10/10 to support cross-correlation sigma
struct sigmadata                        /* structure template for sigma data */
{
    int points;                               /* number of sigma data points */
	int rows;					         /* # rows of results = # tau values */
    float *tau;                      /* pointer to averaging time data array */
    float *num;                    /* pointer to number of data points array */
    float *sigma;                             /* pointer to sigma data array */
    float *ci;         /* pointer to confidence interval from SIGMA.TAU file */
    float *sig_min;                /* pointer to lower sigma error bar array */
    float *sig_max;                /* pointer to upper sigma error bar array */
    float *std_dev;                   /* pointer to standard deviation array */
	float *df;						  /* pointer to degrees of freedom array */
	float *falpha;			                    /* alpha as decimal fraction */
    int *alpha;            /* pointer to power-law noise type exponent array */
    int *af;                            /* pointer to averaging factor array */
	int *sign;	   /* sign of sigma - applies only to cross-correlation ADEV */
};

// Struct for 3-cornered hat sigma data
struct corndata                /* structure template for 3-cornered hat data */
{
	int points;						               /* number of sigma points */
    float *tau;                      /* pointer to averaging time data array */
	float *num_a;				 /* pointer to number of a data points array */
	float *num_b;				 /* pointer to number of b data points array */
	float *num_c;				 /* pointer to number of c data points array */
    float *sig_a;                           /* pointer to sigma a data array */
    float *sig_b;                           /* pointer to sigma b data array */
    float *sig_c;                           /* pointer to sigma c data array */
	float *sig_min_a;				    /* pointer to min sigma a data array */
	float *sig_min_b;				    /* pointer to min sigma b data array */
	float *sig_min_c;				    /* pointer to min sigma c data array */
	float *sig_max_a;				    /* pointer to max sigma a data array */
	float *sig_max_b;				    /* pointer to max sigma b data array */
	float *sig_max_c;				    /* pointer to max sigma c data array */
	float *df_a;					/* pointer to degrees of freedom array a */
	float *df_b;					/* pointer to degrees of freedom array b */
	float *df_c;					/* pointer to degrees of freedom array c */
};

// Struct for plot line data
struct linedata
{
	char *szMaskFile;	// Filename of mask file
    int nLineType;
    int nSlope;			// Power law slope for noise line
    int nXStart;
    int nXEnd;
    float fSlope;		// Linear slope for regression fit
    float fSigma1;		// Sigma(1) value for power law noise fit
	float fAverage;		// Average line value

    F_TYPE fXStart;
    F_TYPE fXEnd;
    F_TYPE fYStart;
    F_TYPE fYEnd;
};

// Struct for plot note data
struct notedata
{
    char* szText;
    F_TYPE fX;
    F_TYPE fY;
    int nSize;
    BOOL bBorder;
	BOOL bOpaque;
};

// Struct for tab data
struct tabdata
{
	char* szTitle;		// File title string
	BOOL bTags;			// Timetag flag
	F_TYPE fTau;		// Tau of data
    F_TYPE *fData;		// Pointer to data array
    F_TYPE *fTags;		// Pointer to timetag array
};

// Struct for PSD spur data
struct spur
{
	int num;			// # spurs
	int *index;			// Spur array index in PSD data
	int *first;			// Spur array index of first point removed
	int *last;			// Spur array index of last point removed
	int max;			// Spur array index of largest spur
	float *freq;		// Pointer to spur freq array
	float *amp;			// Pointer to spur amplitude array
	float corr;			// NB log amplitude correction
};

// Global variables
// Toolbar data structures
extern TOOLBUTTON tb[NUM_TOOLS];

// Edit class procedure
extern FARPROC lpfnOldEdit;
// Function pointer to Edit control subclass

extern FARPROC lpfnEditProc;

// For modeless dialog boxes
extern HWND hDlgModeless;
extern HWND hDlgModeless2;

// Printing control global variables
extern BOOL   bUserAbort;
extern HWND   hDlgPrint;

// For trace macro
extern char szTrace[BUFFER_SIZE+1];

// Date buffer
extern char szDate[BUFFER_SIZE+1];

// Buffer for command line averaging factor
extern char szCmdAF[BUFFER_SIZE+1];

// Buffer for command line start and end points
extern char szCmdStart[BUFFER_SIZE+1];
extern char szCmdEnd[BUFFER_SIZE+1];

// Data input file buffers
extern char szFirstRaw[BIG_BUFFER_SIZE+1];		// Large text buffer for first raw line of data file
extern char szFirstParse[BIG_BUFFER_SIZE+1];	// Large text buffer for first parsed line of data file
extern char szRaw[BIG_BUFFER_SIZE+1]; 			// Large text buffer for raw input data file
extern char szParse[BIG_BUFFER_SIZE+1];			// Large text buffer for parsed input data file

// Buffers for date & time string
extern char szMDYHM[BUFFER_SIZE+1];
extern char szMDYHMS[BUFFER_SIZE+1];

// Status bar repaint flag
extern BOOL bPaintFlag;

// Screen metrics
extern int cxChar;
extern cyChar;
extern int cxIcon;
extern cyIcon;
extern int cxMain;
extern cyMain;
extern int cxClient;
extern int cyClient;

// Data Flags
extern BOOL bDataType;
extern BOOL bLastOpened;		// Data type of last file opened
extern BOOL bPhaseFlag;
extern BOOL bFreqFlag;
extern BOOL bPhaseData;
extern BOOL bFreqData;
extern BOOL bPhaseTimetags;
extern BOOL bFreqTimetags;
extern BOOL bPhaseDataChanged;
extern BOOL bFreqDataChanged;
extern BOOL bPhaseScaleChanged; // Flag=new phase data plot scale needed
extern BOOL bAutoPhaseDataRead;	// Phase data read since last Auto opened
extern BOOL bAutoFreqDataRead;	// Freq data read since last Auto opened
extern BOOL bFreqScaleChanged;  // Flag=new freq data plot scale needed
extern BOOL bNoiseGenerated;    // Flag for noise generated
extern BOOL bPhaseRedraw;       // Flag=phase data plot needs to be redrawn
extern BOOL bFreqRedraw;        // Flag=freq data plot needs to be redrawn
extern BOOL bArchiveData;       // Flag=Archive data selected
extern BOOL bPhaseTauDefault;	// Flag=no phase tau input in INI file
extern BOOL bFreqTauDefault;	// Flag=no freq tau input in INI file
extern BOOL bComma;				// Flag for European comma decimal point
extern BOOL bNoZeroFreq;		// Flag to replace zero freq with 1e-99
extern BOOL bSQL;				// Flag to use SQL database dialog
extern BOOL bPhaseDataUnsaved;	// Flag that phase data is unsaved
extern BOOL bFreqDataUnsaved;	// Flag that freq data is unsaved

// Data Filenames
extern char *szFile;
extern char *szFileTitle;
extern char *szFreqFile;
extern char *szFreqFileTitle;
extern char *szPhaseFile;
extern char *szPhaseFileTitle;
extern char *szStabFile;
extern char *szPSDFile;
extern char *szAutoFile;
extern char *szStabFileTitle;
extern char *szPrevStabFile;
extern char *szPrevStabFileTitle;
extern char *szPath;
extern char *szHelpFile;
extern char *szIniFile;				// Full path & filename to Stable32 ini
extern char *szPlayFile;			// Full path & filename to Play/Win
extern char *szArcIndexFile;		// Full path & name to archive index file
extern char *szLogFile;				// Full path & filename for log file
extern char *sz5110CommFile;		// Full path & fileneme for 5110Comm program
extern char *szCornFileA;			// 3-cornered hat stability data file a
extern char *szCornFileB;			// 3-cornered hat stability data file b
extern char *szCornFileC;			// 3-cornered hat stability data file c
extern char *szPhasePlotInsertFile; // Filename of phase plot insert
extern char *szFreqPlotInsertFile;  // Filename of frequency plot insert
extern char *szStabPlotInsertFile;  // Filename of stability plot insert
extern char *szACFPlotInsertFile;   // Filename of autocorrelation plot insert
extern char *szWaveFilename;		// Wave sound filename

// Notepad program name
extern char *szNotepad;

// Audio player filename
extern char *szAudioPlayer; 

// Globals to pass data for nonlinear fit evaluation (ugly, but works)
extern int nGlobalNumParam;
extern char *pGlobalExpression;

// Plot Label Variables
extern BOOL bPlotLabel;
extern char *szPlotLabel;

// Arrays of pointers to full filename strings
extern char *szPreviousPhaseFilename[NUM_FILENAMES];
extern char *szPreviousFreqFilename[NUM_FILENAMES];

// Print message string
extern char *szPrnMsg;

// Dialog Box Title
extern char *szBoxTitle;

// Global variables for data file reading
extern int nDataFileSize;		// Doesn't have to be long in 32-bit version
extern int nDataFileRejects;	// # rejected data file lines
extern int nBigAvgFactor;		// Avg factor to use when reading large data files
extern int nMaxSize;			// Max allowable size of data file
extern int nTooBigOption;
extern F_TYPE fFileTau;
extern char *szFileText;
extern BOOL bCancelDataRead;
extern BOOL bWarnZeroFreq;		// Warn if 2 adjacent phase pts equal
extern int nComments;			// # UNIX # comment lines in data file

// Global variables for data parameters
extern F_TYPE fPhaseOffsetRemoved;      // Avg value removed from phase data
extern F_TYPE fFreqOffsetRemoved;       // Avg value removed from freq data
extern F_TYPE fPhaseSlopeRemoved;       // Freq slope removed from phase data
extern F_TYPE fFreqSlopeRemoved;        // Freq slope removed from freq data
extern int nSigmaSize;                  // Size of sigma data array

// Global variables for plot labels
extern int nPPlotX;				// Phase data plot x-axis label #
extern int nPPlotY;				// Phase data plot y-axis label # (not used)
extern int nFPlotX;				// Freq data plot x-axis label #
extern int nFPlotY;				// Freq data plot y-axis label # (not used)
extern BOOL bFXDefault;			// Initialize freq data plot x-scale to default
extern BOOL bPXDefault;			// Initial phase data plot x-scale to default
extern BOOL bAXDefault;			// Initial auto data plot x-scale to default

// Global value of run calc time limit
extern float fRunLimit;			// Run calc time limit, sec

// Global variables for main window size & position
extern int nMainLeft;					// Main window left position in pixels
extern int nMainTop;					// Main window top position in pixels
extern int nMainRight;					// Main window right position in pixels
extern int nMainBottom;					// Main window bottom in pixels

extern int nSkipChar;			// # non-numeric chars to skip in data line

// Global variable for last configure property sheet page # (zero-based)
extern int nConfigPage;					// Last open config page #

// Global variables for file tabs
extern int nNumFreqTabs;		// # active freq tabs
extern int nNumPhaseTabs;		// # active phase tabs
extern int nTab;				// Selected tab #
extern BOOL bTabFile;			// Flag to create tab if new data file
extern BOOL bTabChange;			// Flag to create tab if changed data file
extern BOOL bTabNoise;			// Flag to create tab if noise data generated
extern BOOL bTabEdit;			// Flag to create tab if data edited

// Global variables for slope, etc. parameters
extern F_TYPE fLogA;				// Calculated log fit a parameter
extern F_TYPE fLogB;				// Calculated log fit b parameter
extern F_TYPE fLogSlope;			// Calculated log fit slope/tau at end
extern F_TYPE fDiffusionSlope;		// Calculated diffusion fit slope at end
extern F_TYPE fDiffB;				// Calculated diffusion fit b parameter
extern F_TYPE fDiffC;				// Calculated diffusion fit c parameter
extern F_TYPE fPhaseAddend;         // Offset added to phase data
extern F_TYPE fFreqAddend;          // Offset added to freq data
extern F_TYPE fPhaseScaled;         // Phase data scaling factor
extern F_TYPE fFreqScaled;          // Freq data scaling factor
extern F_TYPE fSlopeSpec;			// Log drift slope spec value
extern BOOL bSlopeSpec;			    // Log drift slope spec flag

// Global variables for control preferences
// Used for ini file access - local statics then initialized to these values
extern int nGlobalSigmaType;		// Sigma type
extern int nGlobalRunType;			// Run type
extern int nGlobalPhaseDriftType;	// Phase drift type
extern int nGlobalFreqDriftType;	// Freq drift type
extern int nFTag;					// Freq timetag type

extern BOOL bGlobalNormFreq;		// Global flg = freq norm during conv
extern BOOL bGlobalXferTags;		// Global flg = timetag xfer during conv

// Global current MJD value
extern long int lnMJD;              // Current Modified Julian Day #

// Tau value inputs from INI file
extern F_TYPE fPhaseTauInput;       // Phase tau value from ini file
extern F_TYPE fFreqTauInput;        // Freq tau value from ini file

extern int nPhaseGapsFilled;        // # gaps filled in phase data
extern int nFreqGapsFilled;         // # gaps filled in freq data
extern int nOutliersRemoved;        // # outliers removed from freq data
extern int nManySize;				// # points for many tau plot screen

// Edit box column #s
extern int nTagCol;                     // Column # of timetag
extern int nDatCol;                     // Column # of data

// Plot type
extern int nPlotType;
extern int nSigmaPlotType;

// Tau increment type
extern int nTauIncrement;

// Dummy variables
extern int nDummy;              // To avoid compiler warnings

// Timing variables - for use with GetTickCount()
extern int nTick;				// For timing
extern int nTock;				// Ditto

// Printing font size (height) value and point size
extern int nFontHeight;			// logfont.lfHeight font height
extern int nPointSize;			// Text point size for printouts

// Audio variables
int nSampleRate;				           // Audio sampling rate

// Web addresses
extern char szURL[BUFFER_SIZE+1];		// HTS web site URL
extern char szEMail[BUFFER_SIZE+1];		// HTS E-Mail address

// Process Flags
extern BOOL bOutRem;            // Flag=outliers removed
extern BOOL bPhaseGapFill;      // Flag=phase gaps filled
extern BOOL bFreqGapFill;       // Flag=frequency gaps filled
extern BOOL bPhaseNorm;         // Flag=phase data normalized
extern BOOL bFreqNorm;          // Flag=frequency data normalized
extern BOOL bLinDriftRem;       // Flag=linear drift removed from freq data
extern BOOL bLogDriftRem;       // Flag=log drift removed from freq data
extern BOOL b1of2;				// Flag=scale variance for 1 of 2 units
extern BOOL bOpenScale;			// Flag to scale data when file opened
extern BOOL bBusy;				// Flag to indicate process underway
extern BOOL bManyTau;			// Flag to use many rather than all tau
extern BOOL bACFNoiseID;		// Flag to use lag 1 ACF noise ID method
extern BOOL bDoPhasePlotInsert;	// Flag to put insert into phase plot
extern BOOL bDoFreqPlotInsert;	// Flag to put insert into frequency plot
extern BOOL bDoStabPlotInsert;	// Flag to put insert into stability plot
extern BOOL bDoACFPlotInsert;	// Flag to put insert into autocorrelation plot
extern BOOL bAutoRunPlot;		// Flag to automatically do stability plot
extern BOOL bAutoPowerPlot;		// Flag to automatically do power spectrum plot
extern BOOL bAutoACFPlot;		// Flag to automatically do autocorr plot
extern BOOL bAutoHistoPlot;		// Flag to automatically do histogram plot
extern BOOL bZeroPad;			// Flag to use zero padding in PSD FFTs
extern BOOL bNormPhasePlot;		// Flag that phase data must be normalized for plot
extern BOOL bNormFreqPlot;		// Flag that freq data must be normalized for plot

// Process values
extern int nCmdVarianceType;	// Command line variance type

// Data file header items
extern int nDCol;				// Column # of data (1 based)
extern int nTCol;				// Column # of timetags (1 based)

// Automation flags
extern BOOL bAuto;				// Flag for automated operation
extern BOOL bAuto1;				// Flag for automation script 1
extern BOOL bAuto2;				// Flag for automation script 2
extern BOOL bAuto3;				// Flag for automation script 3
extern BOOL bAutoCmd;			// Flag that auto script invoked on cmd line 

// Automation values
extern int nAuto;				// Script #
char *szScriptname;				// Script name

// Drift removed, etc. flags
extern BOOL bDiffDriftRem;      // Flag=diffusion drift removed from freq data
extern BOOL bQuadDriftRem;      // Flag=quadratic drift removed from phase data
extern BOOL bFreqOffsetRem;     // Flag=freq offset removed from phase data
extern BOOL bPhaseAddend;       // Flag=offset added to phase data
extern BOOL bFreqAddend;        // Flag=offset added to freq data
extern BOOL bPhaseScaled;       // Flag=phase data scaled
extern BOOL bFreqScaled;        // Flag=freq data scaled

// Input parameters
extern F_TYPE fPhaseAddendInput;     // Addend to be added to phase data
extern F_TYPE fFreqAddendInput;      // Addend to be added to freq data
extern F_TYPE fPhaseMultiplierInput; // Multiplier factor for phase data
extern F_TYPE fFreqMultiplierInput;  // Multiplier factor for freq data
extern F_TYPE fPhaseTagScale;		 // Mult factor for phase tag time scale					
extern F_TYPE fFreqTagScale;		 // Mult factor for freq tag time scale					
extern F_TYPE fPhaseTagOffset;		 // Offset value for phase tag time scale					
extern F_TYPE fFreqTagOffset;		 // Offset value for freq tag time scale					

// Other Flags
extern BOOL bDriftDetails;
extern BOOL bSigmaDetails;
extern BOOL bCheckDetails;
extern BOOL bWideEdit;
extern BOOL bSaveTimetags;
extern BOOL bUseFreqPlotIni;
extern BOOL bUsePhasePlotIni;
extern BOOL bUseSigmaPlotIni;
extern BOOL bUseHistoPlotIni;
extern BOOL bUseSpectPlotIni;
extern BOOL bUseAutoPlotIni;	// Use auto plot params from ini file
extern BOOL bUseDAVARPlotIni;	// Use DAVAR plot params from ini file
extern BOOL bAbort;             // Abort flag
extern BOOL bYield;             // Yield flag
extern BOOL bShowFileOpened;    // Show file opened dlg box flag
extern BOOL bIncExtension;      // Increment filename extension flag
extern BOOL bWriteSigmaFile;    // Flag to write stability data file to disk
extern BOOL bAdd;               // Flag for data file added
extern BOOL bRemove;            // Run drift remove flag
extern BOOL bSynch;             // Data synch flag (phase & freq data equiv)
extern BOOL bAutoCalc;          // Flag for automatic calculation
extern BOOL bAutoPlot;          // Flag for automatic plotting
extern BOOL bAutoExec;          // Flag for automatic execution
extern BOOL bAllTau;            // All tau increment flag
extern BOOL bLongLine;          // Flag for multicol data input line >80 chars
extern bStatusPlot;             // Flag to do status bar data plots
extern BOOL bTest;              // General test flag
extern BOOL bDetailedLog;		// Detailed log flag
extern BOOL bShowWelcome;       // Flag to show opening welcome box
extern BOOL bShowPlot;			// Flag to control display of status plots
extern BOOL bSplash;			// Flag to control display of splash screen
extern BOOL bSmartScale;		// Flag for "nice" data plot scales
extern BOOL bHeader;	 		// Flag to write header at top of data file
extern BOOL bSkip;				// Flag to skip multicolumn & file opened
								// dialogs when reading data from command line
extern BOOL bCommandTau;		// Flag that tau entered on cmd line
extern BOOL bNewInputs;			// Flag that inputs changed
extern BOOL bNoGreek;			// Don't use Greek characters
extern BOOL bForceTagTransfer;	// Flag to force timetag transfer in Convert
extern BOOL bUseTags;			// Flag to use timetags for tau in convert
extern BOOL bTabs;				// Flag for showing file tabs
extern BOOL bWriteAppend;		// Flag for appending stability file
extern BOOL bUnixComment;		// Flag for UNIX comment in data file

// Plot style
extern int nStyle;				// Plot style (0=original or 1=modern)

// Data Arrays and handles
extern HANDLE hFreqData;
extern HANDLE hPhaseData;
extern F_TYPE *fData;
extern F_TYPE *fFreqData;
extern F_TYPE *fPhaseData;
extern F_TYPE *fFreqTimetags;
extern F_TYPE *fPhaseTimetags;
extern F_TYPE *fTags;
extern F_TYPE *fNew;

// Power Spectrum data arrays
extern float *fFreq;
extern float *fPSD;
extern float *fAF;

// Histogram bins and counts
extern float *fBins;
extern float *fHist;

// Autocorrelation data array
extern float *fAuto;

// Plotdata structures
extern struct plotdata sFPlot;  // Freq data plot data
extern struct plotdata sFPrev;  // Previous freq data plot data
extern struct plotdata sPPlot;  // Phase data plot data
extern struct plotdata sPPrev;  // Previous phase data plot data
extern struct plotdata sSPlot;  // Sigma plot data
extern struct plotdata sSPrev;  // Previous sigma plot data
extern struct plotdata sHPlot;  // Histo plot data
extern struct plotdata sHPrev;  // Previous histo plot data
extern struct plotdata sPSPlot; // Power spectrum plot data
extern struct plotdata sPSPrev; // Previous power spectrum plot data
extern struct plotdata sAPlot;  // Autocorrelation plot data
extern struct plotdata sAPrev;  // Previous autocorrelation data plot data

// d3plotdata structure
extern struct d3plotdata sDPlot;  			// Dynamic stability plot data

// Linedata structures
extern struct linedata sFLine[FLINE_NUMLINES]; // Array of freq plot line data
extern struct linedata sPLine[PLINE_NUMLINES]; // Array of phase plot line data
extern struct linedata sSLine[SLINE_NUMLINES]; // Array of sigma plot line data

// Notedata structures
extern struct notedata sFNote[FNOTE_NUMNOTES]; // Array of freq plot note data
extern struct notedata sPNote[PNOTE_NUMNOTES]; // Array of phase plot note data
extern struct notedata sSNote[SNOTE_NUMNOTES]; // Array of sigma plot note data

// Sigmadata structures
extern struct sigmadata sNormSigData;	 // Normal & overlapping sigma data struct
extern struct sigmadata sModSigData;	 // Modified & time sigma data struct
extern struct sigmadata sAllNormSigData; // All tau norm & overlap sigma data struct
extern struct sigmadata sAllModSigData;  // All tau mod & time sigma data struct

// Corndata structures
extern struct corndata sCornData;			// 3-cornered hat data struct
extern struct corndata sCornResults;		// 3-cornered hat results struct

// Tabdata structures
extern struct tabdata sFTab[FTAB_NUMTABS];	// Array of freq tab data
extern struct tabdata sPTab[PTAB_NUMTABS];	// Array of phase tab data

// Spur struct
extern struct spur sSpur;					// PSD spur data struct

// Plot option title, subtitle & message storage pointer arrays
extern char *szPlotTitle[NUM_TITLES];
extern char *szPlotSubtitle[NUM_SUBTITLES];
extern char *szPlotMessage[NUM_MESSAGES];

extern int nUserTitles;       // # user-entered title strings
extern int nUserSubtitles;    // # user-entered subtitle strings
extern int nUserMessages;     // # user-entered message strings

// PSD auto AF plot parameters
extern int nPSDAvgSize;
extern int nPSDAvgMax;
extern int nPSDLFSkip;

// Dialog Box Handle
extern HWND hDialog;

// Plot window handle
extern HWND hPlot;

// Plot box handle
extern HWND hPlotBox;						

// GraphiC main window handle
extern HWND hGPC;							

// Bitmap handles
extern HBITMAP hUnsavedBitmap;
extern HBITMAP hTimetagsBitmap;
extern HBITMAP hTagSrcBitmap;
extern HBITMAP hTagMskBitmap;
extern HBITMAP hTooFewBitmap;
extern HBITMAP hFewSrcBitmap;
extern HBITMAP hFewMskBitmap;
extern HBITMAP hLimitsBitmap;
extern HBITMAP hLimitSrcBitmap;
extern HBITMAP hLimitMskBitmap;
extern HBITMAP hSynchBitmap;
extern HBITMAP hSynchSrcBitmap;
extern HBITMAP hSynchMskBitmap;
extern HBITMAP hUnsynchBitmap;
extern HBITMAP hSplashBitmap;
extern HBITMAP hPhaseColorBitmap;
extern HBITMAP hPhaseMonoBitmap;
extern HBITMAP hFreqColorBitmap;
extern HBITMAP hFreqMonoBitmap;

// Button handles
extern HWND hwndPhaseSelectButton;
extern HWND hwndFreqSelectButton;
extern HWND hwndFreqResetButton;
extern HWND hwndPhaseResetButton;

// Handles of phase & freq plot windows
extern HWND hwndPhasePlot;
extern HWND hwndFreqPlot;
extern HWND hwndPhaseFileLabel;
extern HWND hwndFreqFileLabel;
extern HWND hwndPhaseLimLabel;
extern HWND hwndFreqLimLabel;
extern HWND hwndPhaseLim;
extern HWND hwndFreqLim;
extern HWND hwndPhaseNumLabel;
extern HWND hwndFreqNumLabel;
extern HWND hwndPhaseNum;
extern HWND hwndFreqNum;
extern HWND hwndPhaseTauLabel;
extern HWND hwndFreqTauLabel;
extern HWND hwndPhaseStartLabel;
extern HWND hwndFreqStartLabel;
extern HWND hwndPhaseEndLabel;
extern HWND hwndFreqEndLabel;
extern HWND hwndFreqFilename;
extern HWND hwndPhaseFilename;
extern HWND hwndFreqTau;
extern HWND hwndPhaseTau;
extern HWND hwndFreqStart;
extern HWND hwndPhaseStart;
extern HWND hwndFreqEnd;
extern HWND hwndPhaseEnd;
extern HWND hwndTab;			// Tab control window handle

// Command line variables
extern char *szCommandFile;     // Filename from command line
extern BOOL bAutoload;          // Flag for autoloading command line data file
extern BOOL bCommandFileType;   // Data type from command line
extern F_TYPE fCommandTau;      // Tau value from command line

// Automation thread variables
extern HANDLE hAutoThread;		// Handle to automation thread
extern DWORD dwAutoThreadID;	// Automation thread ID

// Msc global variables
extern HANDLE hInst;
extern HWND hwndMain;
extern HWND hwndToolbar;
extern HBRUSH hBrush;
extern HDC hdc;
extern HMENU hMenu;
extern HCURSOR hWait;
extern HCURSOR hArrow;
extern TEXTMETRIC tm;
extern RECT rc;
extern PAINTSTRUCT ps;
extern int nTagFormat;
extern int nTimeZone;
extern char *szDrive;			// DOS drive name where program started
extern char *szDirectory;		// DOS directory where program started
extern char *szExtensionFilter;	// Pointer to string of filename extensions
extern char *szExternalPattern; // Pointer to external filename pattern string

// Function command flags
extern BOOL bCmdLine;			// Flag for any cmd line function
extern BOOL bCmdX;				// Flag to close plot
extern BOOL bCmdC;				// Flag for convert function 
extern BOOL bCmdA;				// Flag for autocorrelation function
extern BOOL bCmdS;				// Flag for spectrum function 
extern BOOL bCmdP;				// Flag for data plot function 
extern BOOL bCmdR;				// Flag for run function 
extern BOOL bCmdN;				// Flag for normalize function 
extern BOOL bCmdV;				// Flag for average function 
extern BOOL bCmdO;				// Flag for check function 
extern BOOL bCmdD;				// Flag for drift function 
extern BOOL bCmdM;				// Flag for copy function 
extern BOOL bCmdZ;				// Flag to close program 
extern BOOL bCmdT;				// Flag for print function 
extern BOOL bCmdH;				// Flag for histogram 
extern BOOL bCmdQ;				// Flag to display command line help 
extern BOOL bCmdU;				// Flag to select part of data 

// Special command line command for diagnostics
extern BOOL bSpecialCmd;		// Flag for special diagnostics 

// Mask data arrays
extern float *fMaskSigma[SLINE_NUMLINES];
extern float *fMaskTau[SLINE_NUMLINES];
extern int nMaskRows[SLINE_NUMLINES];	// # rows of mask data (array size)

// LICENSE.DLL function prototype
int WINAPI CheckLicense(void);

// STABLE_A function prototypes - no longer in project

// STABLE_B function prototypes
DWORD WINAPI AutoThread(LPVOID n);
BOOL CALLBACK AutoDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam);

// STABLE_C function prototypes - no longer in project

// STABLE_D function prototypes
BOOL CALLBACK AboutDlgProc (HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
BOOL CALLBACK WelcomeDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
BOOL CALLBACK SigmaDlgProc (HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
void WINAPI SigmaControls(HWND hDlg, int nSigmaType, BOOL bSigmaDetails,
    BOOL bSetEnable, BOOL bSetNoise, BOOL bApply);
BOOL CALLBACK AvgDlgProc (HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
BOOL CALLBACK ArcConfigDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam);
BOOL CALLBACK NormDlgProc (HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
BOOL CALLBACK FillDlgProc (HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
BOOL CALLBACK ConvertDlgProc (HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
int WINAPI ConvertData(UINT wConvType, BOOL bNormalize, BOOL bTransfer,
	BOOL bUpdate, BOOL bUseTags, int nFTag);
BOOL CALLBACK StatsDlgProc (HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
BOOL CALLBACK ScaleDlgProc (HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
BOOL CALLBACK CheckDlgProc (HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
int WINAPI GetOutlierData(LPVMSTRUCT lpData, int nOutArray[], int nNumRows);
int OutlierCompare(const void *a, const void *b);
BOOL CALLBACK DriftDlgProc (HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
BOOL CALLBACK NoiseDlgProc (HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
BOOL CALLBACK CalendarDlgProc (HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
void WINAPI WriteCalendar(HWND hDlg, int nMonth, int nThisMonth, int nYear,
    int nThisYear, int nToday, BOOL bClip);
void WINAPI DateConv(int *lpnMonth, int *lpnDaysInMonth, int *lpnYear,
    int *lpnDOW, int *lpnDOY, long *lplnMJD);
BOOL CALLBACK ConfigureDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
BOOL CALLBACK FileDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam);
BOOL CALLBACK InputsDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
void WINAPI CopyDialog(HWND hDlg, int nXCrop, int nYCrop);
BOOL CALLBACK PlotInsertDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam);
void WINAPI CopyMeta(HWND hWin, int nXCrop, int nYCrop);
BOOL CALLBACK RenameTabDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam);
BOOL CALLBACK PhaseFuncDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam);
BOOL CALLBACK FreqFuncDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam);
BOOL CALLBACK FreqJumpDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam);
BOOL CALLBACK VibraDlgProc(HWND hDlg, UINT msg, WPARAM wParam, LPARAM lParam);
BOOL CALLBACK DetailsDlgProc(HWND hDlg, UINT msg, WPARAM wParam, LPARAM lParam);
BOOL CALLBACK StepDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam);

// STABLE_E function prototypes
BOOL CALLBACK EditDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
int WINAPI GetRowData(LPVMSTRUCT lpData, int nRows);
BOOL CALLBACK FindDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
BOOL CALLBACK ReplaceDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);

// STABLE_F Function prototypes
void FileInitialize(BOOL Custom, BOOL bRead, HWND hwnd, HANDLE hInstance,
    LPSTR lpstrTitle, int nExt);
void InsertFileInitialize (HWND hwnd, HANDLE hInstance,	LPSTR lpstrTitle);
BOOL FileOpenDlg(BOOL Custom, HWND hwnd, LPSTR lpstrFileName,
    LPSTR lpstrTitleName);
BOOL FileSaveDlg(BOOL Custom, HWND hwnd, LPSTR lpstrFileName,
    LPSTR lpstrTitleName);
UINT CALLBACK FileOpenHookProc(HWND hdlg, UINT msg, WPARAM wParam,
    LPARAM lParam);
UINT CALLBACK FileSaveHookProc(HWND hdlg, UINT msg, WPARAM wParam,
    LPARAM lParam);
UINT CALLBACK StabOpenHookProc(HWND hDlg, UINT msg, WPARAM wParam,
	LPARAM lParam);
LONG FileLength(int hFile);
int DataRead(LPSTR lpstrFileName);
int MulticolumnDataRead(LPSTR lpstrFileName, int nTagCol, int nDatCol,
    int nTooBigOption);
int MulticolumnDataAdd(LPSTR lpstrFileName, int nTagCol, int nDatCol,
    int nSize, int nDataFileSize);
int FileSize(LPSTR lpstrFileName);
long FileInfo(LPSTR lpstrFileName, int *nCols, int *nRejects,
	int *nComments, LPSTR lpstrText);
BOOL FileRead(LPSTR lpstrFileName);
BOOL FileWrite(HWND hwndEdit, LPSTR lpstrFileName);
int WINAPI SigmaRead(LPSTR lpstrFileName, int nSigmaType);
int WINAPI ReallocSigmaArrays(int nSize);
int WINAPI DataWrite(LPSTR lpstrFileName);
int WINAPI PSDWrite(LPSTR lpstrFileName, float fFreq[], float fPSD[],
	float fAF[], int nNum, BOOL bSmooth);
int WINAPI AutoWrite(LPSTR lpstrFileName, float fAuto[], int nNum);
int WINAPI WaveWrite(LPSTR szFileName);
int WINAPI CommonDialogError(LPSTR szErrorCode);
BOOL TauInfo(LPSTR lpstrFileName, F_TYPE *fTau);
BOOL AddendInfo(LPSTR lpstrFileName, F_TYPE *fAdd);
BOOL MultiplierInfo(LPSTR lpstrFileName, F_TYPE *fMult);
BOOL TagScaleInfo(LPSTR lpstrFileName, F_TYPE *fScale);
BOOL TagOffsetInfo(LPSTR lpstrFileName, F_TYPE *fOffset);
int RemoveWhitespace(char *str);

// STABLE_G function prototypes
LONG WINAPI GPCWndProc(HWND hWnd, UINT message, UINT wParam, LONG lParam);

// STABLE_H function prototypes - no longer in project

// STABLE_I function prototypes
BOOL WINAPI RegularizeCount(F_TYPE fData[], F_TYPE fTags[],
	int *nInterruptions, int *nMissings);
BOOL WINAPI RegularizeInsert(F_TYPE fData[], F_TYPE fTags[]);
int WINAPI ConvPhaseToFreqUsingTimetags(F_TYPE x[], F_TYPE y[], F_TYPE t[],
	F_TYPE scale, F_TYPE *avg, BOOL z);
void WINAPI DetermineXScale(struct plotdata *sPlot);
void WINAPI DetermineXMult(struct plotdata *sPlot, int nPlotX, F_TYPE fTau);

// STABLE_K function prototypes
int WINAPI CalcFastMTIE(F_TYPE fX[], struct sigmadata *pResults);

// STABLE_L Property sheet function prototypes
VOID DisplayProperties(HWND hWnd);
BOOL CALLBACK Page1Proc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam);
BOOL CALLBACK Page2Proc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam);
BOOL CALLBACK Page3Proc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam);
BOOL CALLBACK Page4Proc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam);
BOOL CALLBACK Page5Proc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam);
BOOL CALLBACK Page5Proc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam);
BOOL CALLBACK Page6Proc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam);
BOOL CALLBACK Page7Proc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam);
BOOL CALLBACK Page8Proc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam);

// STABLE_M function prototypes
BOOL CALLBACK TimetagDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
BOOL CALLBACK RegularizeDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
BOOL CALLBACK ClearDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
BOOL CALLBACK MulticolumnDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
BOOL CALLBACK DomainDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
BOOL CALLBACK RunDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
int WINAPI GetRunData(LPVMSTRUCT lpVMData);
BOOL CALLBACK ReadDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
BOOL CALLBACK CornDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam);
int WINAPI GetSigmaData(LPVMSTRUCT lpVMData);
int WINAPI GetCornData(LPVMSTRUCT lpVMData);
int WINAPI GetCornResults(LPVMSTRUCT lpVMData);
BOOL CALLBACK PrintDataDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
BOOL CALLBACK AbortProc (HDC hdcPrn, short nCode);
BOOL CALLBACK PrintDlgProc (HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
BOOL CALLBACK PartDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
BOOL CALLBACK MultiDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam);
BOOL CALLBACK FilterDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam);

// STABLE_N function prototypes
int WINAPI GenerateNoise(F_TYPE fSigma[], F_TYPE fOffset, F_TYPE fDrift,
    F_TYPE fTau, int nNum);
int WINAPI GenNoise(int n_pts, double x[], float Q_d, float b, int *idum,
    int add_flag);
void WINAPI four1(double *data, int nn, int isign);
float WINAPI gasdev(int *idum);
float WINAPI ran1(int *idum);
void WINAPI realft(double *data, int n, int isign);

// STABLE_O function prototypes
BOOL CALLBACK SQLDlgProc(HWND hDlg, UINT msg, WPARAM wParam, LPARAM lParam);
BOOL CALLBACK AboutDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam);
BOOL CALLBACK SQLDetailsDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam);
BOOL CALLBACK SQLConfigDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam);
int WINAPI GetSQLTableData(LPVMSTRUCT lpData, char ** MMSTab, char ** ChTab,
	char ** StartTab, char ** EndTab, BOOL bMJD, int nSys, BOOL bRef);
char ** AllocCharArray(int r, int c);
char ** ReallocCharArray(char **p, int oldr, int newr, int c);
void ClearCharArray(char ** p, int r);
void FreeCharArray(char **p, int r);
int TimestampToMJD(char *timestamp, char *mjd, double *mjdval);
//int DateToMJD(int day, int month, int year);
void MJDtoDate(int mjd, int *day, int *month, int *year);
void FractionalDayToHMS(double fd, int *hr, int *min, int *sec);
//BOOL ValidateInteger(HWND hwnd, int nVal, int nMin,	int nMax);
//BOOL ValidateFloat(HWND hwnd, double fVal, double fMin,	double fMax);
//BOOL ValidateMJD(HWND hwnd, double fVal, double fMin, double fMax);
BOOL ValidateTimestamp(HWND hwnd, char *szTimestamp, double fMinMJD,
	double fMaxMJD);
void MJDtoTimestamp(double mjd, char *timestamp);
PGresult *DoSQL(PGconn *conn, char *cmd);
void WINAPI SQLYieldControl(HWND hDialog);
void WINAPI Encode(unsigned int *v, unsigned int *k);
void WINAPI Decode(unsigned int *v, unsigned int *k);

// STABLE_P function prototypes
void WINAPI FreqPlot(F_TYPE f_data[], F_TYPE aux_data[], struct plotdata *p);
void WINAPI SigmaPlot(struct plotdata *p, BOOL autoscale_s, BOOL autoscale_t,
    BOOL read_flag);
void WINAPI PowerSpectrumPlot(float f_data[], float s_data[], int points,
    int type, struct plotdata *p);
void WINAPI FindSpurs(int points, int type, float s_data[], float f_data[],
	float limit, float intercept, float slope, struct spur *sspur,
	BOOL remove);
void WINAPI PhasePlot(F_TYPE p_data[], struct plotdata *p);
void WINAPI MsgBox( int x, int y, char *message_str);
void WINAPI TableBox(int type, int points, int position);
void WINAPI HistoPlot(float f_data[], float h_data[], int bins,
    struct plotdata *p);
void WINAPI Dateline(BOOL ct_flag, BOOL f_flag, int nAF);
BOOL CALLBACK PlotDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
void WINAPI TVARLabel(int val, char *label);
void WINAPI ClipPlot(void);
void WINAPI UnclipPlot(void);
void WINAPI InsertPlot( int x, int y, char *plotname);
void WINAPI AutocorrelationPlot(float a_data[], struct plotdata *p);
void WINAPI CalcLinFit(float x[], float y[], int n, float *a, float *b);
void WINAPI LagScatterPlot(F_TYPE fData[], struct plotdata *p);
void WINAPI DynamicSigmaPlot(struct d3plotdata *p);
void WINAPI AllTableBox(int type, int points, int position);

// STABLE_R function prototypes
float WINAPI Theo1(F_TYPE x[], F_TYPE *p_sig, F_TYPE tau, int m,
	BOOL *bAbort, BOOL bProgress,
	void (*ProgressFunction)(int nPercentDone, char *szMessage));
float WINAPI NewTheo1(F_TYPE x[], F_TYPE *p_sig, F_TYPE tau, int m,
	float *fBias, int *nNoise, BOOL *bAbort, BOOL bProgress, BOOL bCalcBias,
	void (*ProgressFunction)(int nPercentDone, char *szMessage));
float WINAPI TheoBR(F_TYPE x[], F_TYPE *p_sig, F_TYPE tau, int m,
	float *fBias, int *nNoise, BOOL *bAbort, BOOL bProgress, BOOL bCalcBias,
	BOOL bAutoAlpha, void (*ProgressFunction)(int nPercentDone,
	char *szMessage));
float WINAPI Theo1EDF(int nAlpha, int nNum,	float fRatio);
// float WINAPI Theo1Bias(int nAlpha); // Obsolete
float WINAPI Theo1Bias(int nAlpha, float fTau);
// int WINAPI Theo1BiasToAlpha(float fBias); // Obsolete
float WINAPI AutoTheo1Bias(F_TYPE x[], F_TYPE fTau); 
// float WINAPI AutoTheoBRBias(F_TYPE x[], F_TYPE fTau); // Obsolete
float WINAPI AutoTheoBRBias(F_TYPE x[], F_TYPE fTau, int nBA);
int WINAPI Theo1BiasToAlpha(float fBias, int nAvgFactor);
int WINAPI ElimEqualTimetags(F_TYPE x[], F_TYPE t[]);
int WINAPI CountEqualTimetags(F_TYPE x[], F_TYPE t[]);
float WINAPI CombinedEDF(int N, int m, int a, int d, int F, int S, int v);
double WINAPI GetMJD(void);
void WINAPI Encode(unsigned int *v, unsigned int *k);
void WINAPI Decode(unsigned int *v, unsigned int *k);
int WINAPI AutocorrelationCalc(F_TYPE fZ[], float a[], int nLags, int nAF,
	BOOL bType,	BOOL bMethod, BOOL bZero);
int WINAPI ACFNoiseID(F_TYPE fZ[], BOOL bDataType, int nAF, float *fR1,
	float *fAlpha, int *nAlpha, int nDmax, int nDmin);
int WINAPI AutoSpectrumCalc(F_TYPE y[], realtype xdata[], realtype ydata[],
	float adata[], float tau, int *nfft, int win_num, int win_type,
	int phase_noise_type, float correction_factor, int *maxaf, int data_type);
int WINAPI Prewhiten(F_TYPE y[], F_TYPE rho);
void WINAPI ReverseData(F_TYPE z[]);
void WINAPI ReverseTimetags(F_TYPE t[]);
int FFTSpurRemoval(F_TYPE z[], int type, struct spur *s, float a, float b,
	float bin, int psd, int af);
int FFTFilter(F_TYPE z[], int type, int filter, int low, int high);
char *strptime (const char *buf, const char *format, struct tm *timeptr);
int GreenhallDrift(F_TYPE fData[], F_TYPE fTau, F_TYPE *fDrift);
int CompressData(F_TYPE z[], BOOL datype, int p);

#if(1) // For testing of A7PSD DLL
// A7PSD DLL function Driver
int WINAPI A7PSDSpectrumCalc(F_TYPE y[], realtype xdata[],
	realtype ydata[], float tau, int n, int win_num, int win_type,
	int phase_noise_type, float correction_factor, int af, int data_type);
#endif
	
// STABLE_S function prototypes
int WINAPI PlotScale(F_TYPE min, F_TYPE max, F_TYPE *p_scale_min,
	F_TYPE *p_scale_max);
int WINAPI BasScale (double XMin, double XMax, int N, double* SMin,
	double* Step);
void WINAPI RoundAxes(F_TYPE *a1, F_TYPE *a2, F_TYPE *tics);

// STABLE_T function prototypes
LRESULT CALLBACK ToolbarWndProc(HWND hwnd, UINT message, WPARAM wParam,
    LPARAM lParam);
void WINAPI RedrawToolbar(TOOLBUTTON tb[], BOOL bDraw);
void WINAPI WritePromptMessage(UINT wFunction);
void WINAPI WriteAd(LPSTR szLine1, LPSTR szLine2, LPSTR szLine3);
void WINAPI InitializeToolbar(TOOLBUTTON tb[]);
void WINAPI ActivateFunctions(UINT wEnable);
LRESULT CALLBACK EditProc(HWND hwnd, UINT message, WPARAM wParam,
    LPARAM lParam);
void WINAPI WriteMessage(LPSTR szMessage);

// STABLE_U function prototypes
int WINAPI InvokeDialogBox(HANDLE hInst, LPSTR lpBoxName, HWND hwnd,
    DLGPROC lpDlgProc);
int WINAPI ClearDataArray(BOOL bDataType);
int WINAPI ClearTimetagArray(BOOL bDatType);
F_TYPE WINAPI CalcSearchLimit(LPSTR szVal);
void WINAPI DrawBitmap(HDC hdc, HBITMAP hBitmap, short xStart, short yStart);
void DrawTransparentBitmap( HDC hdc, HBITMAP hBmpSrc, HBITMAP hBmpMsk,
    short xStart, short yStart);
void WINAPI WriteOutput(HWND hCtrl, LPSTR lpszOutput);
BOOL WINAPI ValidateInteger(HWND hwnd, int nVal, int nMin, int nMax);
BOOL WINAPI ValidateFloat(HWND hwnd, F_TYPE fVal, F_TYPE fMin, F_TYPE fMax);
void WINAPI AllocErrorMessage(void);
void WINAPI AllocErrorMessageEx(char *szFile, int nLine, int nSize);
void WINAPI TooFewMessage(void);
void WINAPI ZeroRangeMessage(void);
void WINAPI MustNormalizeMessage(void);
int WINAPI IncExtension( char *filename, int type);
void WINAPI CannotBeZero(HWND hwnd);
void WINAPI YieldControl(void);
void WINAPI ClearLines(void);
void WINAPI ShortenExp( char *szValue);
BOOL WINAPI CheckPath(char *szPath, HWND hWnd, char *szTitle);
BOOL WINAPI CheckFilename(char *szFile, char *szTitle, char *szPath,
	char *szName, char *szExt, HWND hWnd, char *szLabel);
BOOL WINAPI ValidateMJD(HWND hwnd, F_TYPE fVal, F_TYPE fMin,
	F_TYPE fMax);
void WINAPI DebugMessageBox(HWND hWnd, char *szFile, int nLine,
	char *szText);
void WINAPI WriteLog(int nID, char *szText);
BOOL WINAPI IsNumeric(char cChar, BOOL *bDigit);
void WINAPI Flash(void);
void WINAPI LinFit(float x[], float y[], int ndata, float sig[], int mwt,
	float *a, float *b, float *siga, float *sigb, float *chi2, float *q);
void WINAPI SmoothPSD(float freq[], float psd[],  float avg[], int *ndata,
	int ppo, int *maxaf);
void WINAPI SemiLogFit(float x[], float y[], int ndata, float sig[], int mwt,
	float *a, float *b, float *siga, float *sigb, float *chi2, float *q);
size_t strlcpy(char *dst, const char *src, size_t siz);
size_t strlcat(char *dst, const char *src, size_t siz);

// STABLE_W Function prototypes
int APIENTRY WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance,
    LPSTR lpszCmdParam, int nCmdShow);
LRESULT CALLBACK WndProc(HWND hwnd, UINT message, WPARAM wParam,
	LPARAM lParam);
void ParseCommandLine(BOOL *bAutoload, BOOL *bDataType,  BOOL *bArchiveData,
	char *szFile, F_TYPE *fTau);
// Tab control functions
HWND WINAPI CreateTabControl(HWND hwndParent); 
void WINAPI UpdateTabControl(void); 
void WINAPI CreateTab(void);
void WINAPI SetTabMenu(void);
void WINAPI CallHelp(HWND hDlg, char *szTopic);
 
// STABLE_Q Function prototypes
void ReadIni(int nSection);
void WriteIni(int nSection);
void ReadFileInfo(void);
void WriteFileInfo(void);
void UpdateFileInfo(char *szFilename[]);
BOOL ReadDataFile(int *pnCols, int *pnTagCol, int *pnDatCol);
BOOL CALLBACK TooBigDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
BOOL CALLBACK OpenedDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);

// STABLE_X function prototypes
BOOL CALLBACK PhasePlotDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
BOOL CALLBACK FreqPlotDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
BOOL CALLBACK SigmaPlotDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
BOOL CALLBACK ReadPlotDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
BOOL CALLBACK FreqLineDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
BOOL CALLBACK PhaseLineDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
BOOL CALLBACK SigmaLineDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
BOOL CALLBACK SpectrumPlotDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
BOOL CALLBACK HistoPlotDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
BOOL CALLBACK FreqNoteDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
BOOL CALLBACK PhaseNoteDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
BOOL CALLBACK SigmaNoteDlgProc(HWND hDlg, UINT message, WPARAM wParam,
    LPARAM lParam);
void WINAPI InitPhasePlotParams(BOOL bAll);
void WINAPI InitFreqPlotParams(BOOL bAll);
void WINAPI InitSigmaPlotParams(void);
void WINAPI InitReadPlotParams(void);
void WINAPI InitAutocorrelationPlotParams(BOOL bAll);
void WINAPI UpdatePlotSubtitles(void);
int  WINAPI CalcSigmaPlotScale(void);
BOOL CALLBACK AutocorrelationPlotDlgProc(HWND hDlg, UINT message,
	WPARAM wParam,	LPARAM lParam);
BOOL CALLBACK DynamicStabilityDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam);

// STABLE_Y function prototypes
void WINAPI CreateStatusBar(HWND hwnd, LPSTR lpPhaseFile, LPSTR lpFreqFile);
void WINAPI MoveStatusBarControls(HWND hwnd);
void WINAPI UpdateStatusBar(HWND hwnd, BOOL bNewData);
void WINAPI DestroyStatusBarControls(HWND hwnd);
void WriteProgressMessage(int nPercentDone, char *szMessage, BOOL bUpdateMsg);
void WINAPI WriteDateMessage(void);
void WINAPI DrawDataPlots(BOOL bNewData);
void WINAPI DisplayLims(void);
void WINAPI DeleteStatusBarFont(void);
void WINAPI DisplayPlotCursor(int nPosition, BOOL bMode);

// STABLE_Z function prototypes
F_TYPE WINAPI ReadArchiveFile(int nSelChan, int nRefChan, int nRecord,
    F_TYPE fTau, F_TYPE fFirstMJD, F_TYPE fLastMJD, F_TYPE fMJDStart,
	F_TYPE fMJDEnd); 
int WINAPI ResizeArrays(int nSize);
BOOL CALLBACK ArchiveDlgProc(HWND hDlg, UINT message, WPARAM wParam,
	LPARAM lParam);

// STABLE_AA and STABLE_EE function prototypes
void svdfit(float x[], float y[], float sig[], int ndata, float a[], int ma,
	float **u, float **v, float w[], float *chisq,
	void (*funcs)(float, float [], int));
void svdcmp(float **a, int m, int n, float w[], float **v);
void svbksb(float **u, float w[], float **v, int m, int n, float b[], float x[]);
float pythag(float a, float b);
void fpoly(float x, float p[], int np);
float *nrcvector(long nl, long nh);
void free_nrcvector(float *v, long nl, long nh);
float **nrcmatrix(long nrl, long nrh, long ncl, long nch);
void free_nrcmatrix(float **m, long nrl, long nrh, long ncl, long nch);
float *nrvector(long nl, long nh);
void free_nrvector(float *v, long nl, long nh);
float **nrmatrix(long nrl, long nrh, long ncl, long nch);
void free_nrmatrix(float **m, long nrl, long nrh, long ncl, long nch);
int *nrivector(long nl, long nh);
void free_nrivector(int *v, long nl, long nh);

// STABLE_BB function prototypes
// The functions in this file are used for polynomial fitting
// Their realtype is changed to polytype which is defined as double
void PolyCurveFit(polytype *indvar, polytype *depvar, int numobs, int order,
	polytype *coef, polytype *yest, polytype *resid, polytype *see,
	polytype *coefsig, polytype *rsq, polytype *r, char *cferror);
void  MatTxTiX(polytype *aryin, int numrow, int numcol, polytype *aryout);
void MatYTiX(polytype *aryy, polytype *aryx, int numrow,
	int numcol, polytype *aryout);
void ResAnalysis(polytype *regmat, polytype *ymat, polytype *regcoef,
	polytype *aryinv, int numrow, int numcol, polytype *yest,
	polytype *resid, polytype *see, polytype *coefsig,
	polytype *rsq, polytype *r);
void MultipleReg(polytype *indvardat, polytype *depvardat, int numiv, int numobs,
	polytype *regcoef, polytype *yest, polytype *resid, polytype *see,
	polytype *coefsig, polytype *rsq, polytype *r, char *regerror);
void GaussJordan(polytype *coefary, polytype *constary,
	int numcol, polytype *solcoef, polytype *invary,
	polytype *det);
void gjswap(polytype *s1, polytype *s2);
polytype *GetPolyMem(int n);
void CheckBadMem(void *p);
int *GetIntMem(int n);
double CalcPolyOverflow(polytype num);
void SetQC_Error (int new_err);

// STABLE_GG function prototypes
double studenttdistribution(int k, double t);
double invstudenttdistribution(int k, double p);

// STABLE_JJ function prototype
int WINAPI CalcPhaseCrossSigma(F_TYPE x1[],
	F_TYPE x2[], F_TYPE *p_sig, F_TYPE tau, int m, int *sign);

// String macros
// Each group of <=16 should begin with multiple of 16

// Toolbar prompt strings
#define IDS_TB_OPEN         4928
#define IDS_TB_ADD          4929
#define IDS_TB_READ         4930
#define IDS_TB_SAVE         4931
#define IDS_TB_EDIT         4932
#define IDS_TB_CLEAR        4933
#define IDS_TB_CONV         4934
#define IDS_TB_STAT         4935
#define IDS_TB_CHECK        4936
#define IDS_TB_SIGMA        4937
#define IDS_TB_RUN          4938
#define IDS_TB_NORM         4939
#define IDS_TB_AVG          4940
#define IDS_TB_PLOT         4941
#define IDS_TB_DRIFT        4942
#define IDS_TB_POWER        4943
#define IDS_TB_HIST         4944
#define IDS_TB_CAL          4945
#define IDS_TB_PRINT        4946
#define IDS_TB_NOISE        4947
#define IDS_TB_FILL         4948
#define IDS_TB_SCALE        4949
#define IDS_TB_PLAY         4950
#define IDS_TB_TIMETAG      4951
#define IDS_TB_REGULARIZE   4952
#define IDS_TB_DOMAIN       4953
#define IDS_TB_PART         4954
#define IDS_TB_HELP         4955
#define IDS_TB_NOTEPAD      4956
#define IDS_TB_CONF         4957
#define IDS_TB_FILE         4958
#define IDS_TB_COMM			4959
#define IDS_TB_AUTO1		4964
#define IDS_TB_AUTO2		4965
#define IDS_TB_AUTO3		4966
#define IDS_TB_ACS			4967
#define IDS_TB_DAVAR		4968
#define IDS_TB_SQL			4969
#define IDS_TB_TAB			4970
#define IDS_TB_VIBRA		4971
#define IDS_TB_FILTER	    4972
#define IDS_TB_STEP			4973

// Phase plot y-axis labels
#define NUM_PPLOT_YLABELS      4
#define IDS_PPLOT_YLABEL_0  4960
#define IDS_PPLOT_YLABEL_1  4961
#define IDS_PPLOT_YLABEL_2  4962
#define IDS_PPLOT_YLABEL_3  4963

// Freq plot y-axis labels
#define NUM_FPLOT_YLABELS      4
#define IDS_FPLOT_YLABEL_0  4976
#define IDS_FPLOT_YLABEL_1  4977
#define IDS_FPLOT_YLABEL_2  4978
#define IDS_FPLOT_YLABEL_3  4979

// Sigma plot y-axis labels
#define NUM_SPLOT_YLABELS     15 // Was 9 before 03/14/99,
// 12 before 10/29/00, 13 before 02/09/03, 14 before 02/16/03
#define NUM_SPLOT_YNAMES       4
// Was 3 before 11/29/11
// This sequency started at 4980 before 11/29/11
// Changed to 6680 on that date to allow room for
// another set of sigma plot y-axis labels
#define IDS_SPLOT_YLABEL_0				6680
#define IDS_SPLOT_YLABEL_1				6681
#define IDS_SPLOT_YLABEL_2				6682
#define IDS_SPLOT_YLABEL_3				6683
#define IDS_SPLOT_YLABEL_4				6684
#define IDS_SPLOT_YLABEL_5				6685
#define IDS_SPLOT_YLABEL_6				6686
#define IDS_SPLOT_YLABEL_7				6687
#define IDS_SPLOT_YLABEL_8				6688
#define IDS_SPLOT_YLABEL_9				6689
#define IDS_SPLOT_YLABEL_10				6690
#define IDS_SPLOT_YLABEL_11				6691
#define IDS_SPLOT_YLABEL_12				6692
#define IDS_SPLOT_YLABEL_13				6693
#define IDS_SPLOT_YLABEL_14				6694
#define IDS_SPLOT_YLABEL_15				6695
#define IDS_SPLOT_YLABEL_16				6696
#define IDS_SPLOT_YLABEL_17				6697
#define IDS_SPLOT_YLABEL_18				6698
#define IDS_SPLOT_YLABEL_19				6699
#define IDS_SPLOT_YLABEL_20				6700
#define IDS_SPLOT_YLABEL_21				6701
#define IDS_SPLOT_YLABEL_22				6702
#define IDS_SPLOT_YLABEL_23				6703
#define IDS_SPLOT_YLABEL_24				6704
#define IDS_SPLOT_YLABEL_25				6705
#define IDS_SPLOT_YLABEL_26				6706
#define IDS_SPLOT_YLABEL_27				6707
#define IDS_SPLOT_YLABEL_28				6708
#define IDS_SPLOT_YLABEL_29				6709
#define IDS_SPLOT_YLABEL_30				6710
#define IDS_SPLOT_YLABEL_31				6711
#define IDS_SPLOT_YLABEL_32				6712
#define IDS_SPLOT_YLABEL_33				6713
#define IDS_SPLOT_YLABEL_34				6714
#define IDS_SPLOT_YLABEL_35				6715
#define IDS_SPLOT_YLABEL_36				6716
#define IDS_SPLOT_YLABEL_37				6717
#define IDS_SPLOT_YLABEL_38				6718
#define IDS_SPLOT_YLABEL_39				6719
#define IDS_SPLOT_YLABEL_40				6720
#define IDS_SPLOT_YLABEL_41				6721
#define IDS_SPLOT_YLABEL_42				6722
#define IDS_SPLOT_YLABEL_43				6723
#define IDS_SPLOT_YLABEL_44				6724
#define IDS_SPLOT_YLABEL_45				6725
#define IDS_SPLOT_YLABEL_46				6726
#define IDS_SPLOT_YLABEL_47				6727
#define IDS_SPLOT_YLABEL_48				6728
#define IDS_SPLOT_YLABEL_49				6729
#define IDS_SPLOT_YLABEL_50				6730
#define IDS_SPLOT_YLABEL_51				6731
#define IDS_SPLOT_YLABEL_52				6732
#define IDS_SPLOT_YLABEL_53				6733
#define IDS_SPLOT_YLABEL_54				6734
#define IDS_SPLOT_YLABEL_55				6735
#define IDS_SPLOT_YLABEL_56				6736
#define IDS_SPLOT_YLABEL_57				6737
#define IDS_SPLOT_YLABEL_58				6738
#define IDS_SPLOT_YLABEL_59				6739

/* Note: RPLOT items not used
// Read plot y-axis labels
#define NUM_RPLOT_YLABELS      6
#define IDS_RPLOT_YLABEL_0  5312
#define IDS_RPLOT_YLABEL_1  5313
#define IDS_RPLOT_YLABEL_2  5314
#define IDS_RPLOT_YLABEL_3  5315
#define IDS_RPLOT_YLABEL_4  5316
#define IDS_RPLOT_YLABEL_5  5317
#define IDS_RPLOT_YLABEL_6  5318
#define IDS_RPLOT_YLABEL_7  5319

// Read plot x-axis labels
#define NUM_RPLOT_XLABELS      1
#define IDS_RPLOT_XLABEL_0  5328
*/

// Data plot message position strings
#define NUM_DPLOT_POSITIONS        9
#define IDS_DPLOT_POSITION_0    5028
#define IDS_DPLOT_POSITION_1    5029
#define IDS_DPLOT_POSITION_2    5030
#define IDS_DPLOT_POSITION_3    5031
#define IDS_DPLOT_POSITION_4    5032
#define IDS_DPLOT_POSITION_5    5033
#define IDS_DPLOT_POSITION_6    5034
#define IDS_DPLOT_POSITION_7    5035
#define IDS_DPLOT_POSITION_8    5036

// Table position strings
#define NUM_TABLE_POSITIONS        4
#define IDS_TABLE_POSITION_0    5780
#define IDS_TABLE_POSITION_1    5781
#define IDS_TABLE_POSITION_2    5782
#define IDS_TABLE_POSITION_3    5783

// Data plot message location codes
#define MSG_TOP_LEFT    0
#define MSG_TOP_CENTER  1
#define MSG_TOP_RIGHT   2
#define MSG_MID_LEFT    3
#define MSG_MID_CENTER  4
#define MSG_MID_RIGHT   5
#define MSG_BOT_LEFT    6
#define MSG_BOT_CENTER  7
#define MSG_BOT_RIGHT   8

// Stability plot table location codes
#define TAB_TOP_LEFT    0
#define TAB_TOP_RIGHT   1
#define TAB_BOT_LEFT    2
#define TAB_BOT_RIGHT   3

// Phase plot titles
#define NUM_PPLOT_TITLES    3
#define IDS_PPLOT_TITLE_0   5472
#define IDS_PPLOT_TITLE_1   5473
#define IDS_PPLOT_TITLE_2   5474

// Phase plot subtitles
#define NUM_PPLOT_SUBTITLES     2
#define IDS_PPLOT_SUBTITLE_0    5488
#define IDS_PPLOT_SUBTITLE_1    5489
#define IDS_PPLOT_SUBTITLE_2    5490

// Phase plot messages
#define NUM_PPLOT_MESSAGES     5
#define IDS_PPLOT_MESSAGE_0    5504
#define IDS_PPLOT_MESSAGE_1    5505
#define IDS_PPLOT_MESSAGE_2    5506
#define IDS_PPLOT_MESSAGE_3    5507
#define IDS_PPLOT_MESSAGE_4    5508
#define IDS_PPLOT_MESSAGE_5    5509
#define IDS_PPLOT_MESSAGE_6    5510
#define IDS_PPLOT_MESSAGE_7    5511
#define IDS_PPLOT_MESSAGE_8    5512
#define IDS_PPLOT_MESSAGE_9    5513
#define IDS_PPLOT_MESSAGE_10   5514
#define IDS_PPLOT_MESSAGE_11   5515
#define IDS_PPLOT_MESSAGE_12   5516
#define IDS_PPLOT_MESSAGE_13   5517
#define IDS_PPLOT_MESSAGE_14   5518

// Phase plot line fit types
#define NUM_PPLOT_FITS     4
#define IDS_PPLOT_FIT_0 5324
#define IDS_PPLOT_FIT_1 5325
#define IDS_PPLOT_FIT_2 5326
#define IDS_PPLOT_FIT_3 5327

// Freq plot titles
#define NUM_FPLOT_TITLES    3
#define IDS_FPLOT_TITLE_0   5424
#define IDS_FPLOT_TITLE_1   5425
#define IDS_FPLOT_TITLE_2   5426

// Freq plot subtitles
#define NUM_FPLOT_SUBTITLES     2
#define IDS_FPLOT_SUBTITLE_0    5440
#define IDS_FPLOT_SUBTITLE_1    5441
#define IDS_FPLOT_SUBTITLE_2    5442

// Freq plot messages
#define NUM_FPLOT_MESSAGES     5
#define IDS_FPLOT_MESSAGE_0    5456
#define IDS_FPLOT_MESSAGE_1    5457
#define IDS_FPLOT_MESSAGE_2    5458
#define IDS_FPLOT_MESSAGE_3    5459
#define IDS_FPLOT_MESSAGE_4    5460
#define IDS_FPLOT_MESSAGE_5    5461
#define IDS_FPLOT_MESSAGE_6    5462
#define IDS_FPLOT_MESSAGE_7    5463
#define IDS_FPLOT_MESSAGE_8    5764
#define IDS_FPLOT_MESSAGE_9    5765
#define IDS_FPLOT_MESSAGE_10   5766
#define IDS_FPLOT_MESSAGE_11   5767
#define IDS_FPLOT_MESSAGE_12   5768
#define IDS_FPLOT_MESSAGE_13   5769
#define IDS_FPLOT_MESSAGE_14   5770
#define IDS_FPLOT_MESSAGE_15   5771
#define IDS_FPLOT_MESSAGE_16   5772
#define IDS_FPLOT_MESSAGE_17   5773
#define IDS_FPLOT_MESSAGE_18   5774
#define IDS_FPLOT_MESSAGE_19   5775
#define IDS_FPLOT_MESSAGE_20   5776
#define IDS_FPLOT_MESSAGE_21   5777
#define IDS_FPLOT_MESSAGE_22   5778
#define IDS_FPLOT_MESSAGE_23   5779

// Freq plot line fit types
#define NUM_FPLOT_FITS     8
#define IDS_FPLOT_FIT_0 5040
#define IDS_FPLOT_FIT_1 5041
#define IDS_FPLOT_FIT_2 5042
#define IDS_FPLOT_FIT_3 5043
#define IDS_FPLOT_FIT_4 5044
#define IDS_FPLOT_FIT_5 5045
#define IDS_FPLOT_FIT_6 5046
#define IDS_FPLOT_FIT_7 5047

// Sigma plot titles
#define NUM_SPLOT_TITLES    3
#define IDS_SPLOT_TITLE_0   5520
#define IDS_SPLOT_TITLE_1   5521
#define IDS_SPLOT_TITLE_2   5522

// Sigma plot subtitles
#define NUM_SPLOT_SUBTITLES     2
#define IDS_SPLOT_SUBTITLE_0    5536
#define IDS_SPLOT_SUBTITLE_1    5537
#define IDS_SPLOT_SUBTITLE_2    5538

// Sigma plot messages
#define NUM_SPLOT_MESSAGES     0
#define IDS_SPLOT_MESSAGE_0    5552
#define IDS_SPLOT_MESSAGE_1    5553
#define IDS_SPLOT_MESSAGE_2    5554
#define IDS_SPLOT_MESSAGE_3    5555
#define IDS_SPLOT_MESSAGE_4    5556
#define IDS_SPLOT_MESSAGE_5    5557
#define IDS_SPLOT_MESSAGE_6    5558
#define IDS_SPLOT_MESSAGE_7    5559

// Sigma plot line fit types
#define NUM_SPLOT_FITS     4
#define IDS_SPLOT_FIT_0 5056

// Spectrum plot titles
#define NUM_PSPLOT_TITLES 1

// Spectrum plot subtitles
#define NUM_PSPLOT_SUBTITLES 2

// Spectrum plot messages
#define NUM_PSPLOT_MESSAGES 0

// Histo plot titles
#define NUM_HPLOT_TITLES 1

// Histo plot subtitles
#define NUM_HPLOT_SUBTITLES 2

// DAVAR plot titles
#define NUM_DAVAR_TITLES 1

// DAVAR plot subtitles
#define NUM_DAVAR_SUBTITLES 2

// Auto plot messages
#define NUM_APLOT_MESSAGES 0

// Auto plot titles
#define NUM_APLOT_TITLES 1

// Auto plot subtitles
#define NUM_APLOT_SUBTITLES 2

// Histo plot messages
#define NUM_HPLOT_MESSAGES 0

// DAVAR plot messages
#define NUM_DAVAR_MESSAGES 0

// Phase & freq plot x-axis labels
#define NUM_DPLOT_XLABELS     11
#define IDS_DPLOT_XLABEL_0  5072
#define IDS_DPLOT_XLABEL_1  5073
#define IDS_DPLOT_XLABEL_2  5074
#define IDS_DPLOT_XLABEL_3  5075
#define IDS_DPLOT_XLABEL_4  5076
#define IDS_DPLOT_XLABEL_5  5077
#define IDS_DPLOT_XLABEL_6  5078
#define IDS_DPLOT_XLABEL_7  5079
#define IDS_DPLOT_XLABEL_8  5080
#define IDS_DPLOT_XLABEL_9	5081
#define IDS_DPLOT_XLABEL_10	5082

// Sigma plot x-axis labels
#define NUM_SPLOT_XLABELS      3
#define IDS_SPLOT_XLABEL_0  5088
#define IDS_SPLOT_XLABEL_1  5089
#define IDS_SPLOT_XLABEL_2  5090

// Phase & freq line option types
#define NUM_DLINE_TYPES        5 // Was 6 until 07/24/10
#define IDS_DLINE_TYPE_0    5104
#define IDS_DLINE_TYPE_1    5105
#define IDS_DLINE_TYPE_2    5106
#define IDS_DLINE_TYPE_3    5107
#define IDS_DLINE_TYPE_4    5108
#define IDS_DLINE_TYPE_5    5109

// Freq plot line # & type codes
#define FLINE_NONE  0   // No line
#define FLINE_END   1   // Line between endpoints
#define FLINE_LIN   2   // Linear fit
#define FLINE_AVG   3   // Horiz line at avg value
#define FLINE_MARK  4   // Vert marker line
#define FLINE_NULL  5   // Null code used during line entry proc

// Sigma sigma types
#define NUM_SIGMA_TYPES         13
#define IDS_SIGMA_TYPE_0      6080
#define IDS_SIGMA_TYPE_1      6081
#define IDS_SIGMA_TYPE_2      6082
#define IDS_SIGMA_TYPE_3      6083
#define IDS_SIGMA_TYPE_4      6084
#define IDS_SIGMA_TYPE_5      6085
#define IDS_SIGMA_TYPE_6      6086
#define IDS_SIGMA_TYPE_7      6087
#define IDS_SIGMA_TYPE_8	  6088
#define IDS_SIGMA_TYPE_9      6089
#define IDS_SIGMA_TYPE_10	  6090
#define IDS_SIGMA_TYPE_11	  6091
#define IDS_SIGMA_TYPE_12	  6092

// Run sigma types
#define NUM_RUN_TYPES         15
#define IDS_RUN_TYPE_0      5120
#define IDS_RUN_TYPE_1      5121
#define IDS_RUN_TYPE_2      5122
#define IDS_RUN_TYPE_3      5123
#define IDS_RUN_TYPE_4      5124
#define IDS_RUN_TYPE_5      5125
#define IDS_RUN_TYPE_6      5126
#define IDS_RUN_TYPE_7      5127
#define IDS_RUN_TYPE_8      5128
#define IDS_RUN_TYPE_9      5129
#define IDS_RUN_TYPE_10		5130
#define IDS_RUN_TYPE_11		5131 // Added 05/05/00
#define IDS_RUN_TYPE_12     5132 // Added 10/29/00
#define IDS_RUN_TYPE_13		5133 // Added 02/09/03

// Run line types
#define NUM_RUN_ALPHA          6
#define IDS_RUN_ALPHA_0     5824
#define IDS_RUN_ALPHA_1     5825
#define IDS_RUN_ALPHA_2     5826
#define IDS_RUN_ALPHA_3     5827
#define IDS_RUN_ALPHA_4     5828
#define IDS_RUN_ALPHA_5     5829
#define IDS_RUN_ALPHA_6     5830
#define IDS_RUN_ALPHA_7     5831

// Stats noise types
#define IDS_STATS_NOISE_0   5832
#define IDS_STATS_NOISE_1   5833
#define IDS_STATS_NOISE_2   5834
#define IDS_STATS_NOISE_3   5835
#define IDS_STATS_NOISE_4   5836
#define IDS_STATS_NOISE_5   5837

// Run line types
#define NUM_RUN_LINETYPES      7
#define IDS_RUN_LINE_0      5136
#define IDS_RUN_LINE_1      5137
#define IDS_RUN_LINE_2      5138
#define IDS_RUN_LINE_3      5139
#define IDS_RUN_LINE_4      5140
#define IDS_RUN_LINE_5      5141
#define IDS_RUN_LINE_6		5142

// Run noise types
#define NUM_RUN_NOISES        6
#define IDS_RUN_MDEV_0     5152
#define IDS_RUN_ADEV_0     5153
#define IDS_RUN_ADEV_1     5154
#define IDS_RUN_ADEV_2     5155
#define IDS_RUN_ADEV_3     5156
#define IDS_RUN_ADEV_4     5157
#define IDS_RUN_ADEV_5     5158
#define IDS_RUN_ADEV_6     5159
#define IDS_RUN_ADEV_7     5160
#define IDS_RUN_TDEV_0     5161
#define IDS_RUN_TDEV_1     5162
#define IDS_RUN_TDEV_2     5163
#define IDS_RUN_TDEV_3     5164
#define IDS_RUN_TDEV_4     5165
#define IDS_RUN_TDEV_5     5166


// Run checkbox labels
#define IDS_RUN_BOX_0      5144
#define IDS_RUN_BOX_1      5145

// Domain info
#define NUM_DOMAIN_TYPES       6

// PSD info
#define IDS_DOMAIN_PSD_L0   5168
#define IDS_DOMAIN_PSD_L1   5169
#define IDS_DOMAIN_PSD_L2   5170
#define IDS_DOMAIN_PSD_L3   5171
#define IDS_DOMAIN_PSD_L4   5172
#define IDS_DOMAIN_PSD_L5   5173

#define IDS_DOMAIN_PSD_P0   5174
#define IDS_DOMAIN_PSD_P1   5175
#define IDS_DOMAIN_PSD_P2   5176
#define IDS_DOMAIN_PSD_P3   5177
#define IDS_DOMAIN_PSD_P4   5178
#define IDS_DOMAIN_PSD_P5   5179

#define IDS_DOMAIN_PSD_X0   5180
#define IDS_DOMAIN_PSD_X1   5181
#define IDS_DOMAIN_PSD_X2   5182
#define IDS_DOMAIN_PSD_X3   5183
#define IDS_DOMAIN_PSD_X4   5184
#define IDS_DOMAIN_PSD_X5   5185

#define IDS_DOMAIN_PSD_Y0   5186
#define IDS_DOMAIN_PSD_Y1   5187
#define IDS_DOMAIN_PSD_Y2   5188
#define IDS_DOMAIN_PSD_Y3   5189
#define IDS_DOMAIN_PSD_Y4   5190
#define IDS_DOMAIN_PSD_Y5   5191

// Sigma info
#define IDS_DOMAIN_SIG_Y0   5192
#define IDS_DOMAIN_SIG_Y1   5193
#define IDS_DOMAIN_SIG_Y2   5194
#define IDS_DOMAIN_SIG_Y3   5195
#define IDS_DOMAIN_SIG_Y4   5196
#define IDS_DOMAIN_SIG_Y5   5197

#define IDS_DOMAIN_SIG_M0   5198
#define IDS_DOMAIN_SIG_M1   5199
#define IDS_DOMAIN_SIG_M2   5200
#define IDS_DOMAIN_SIG_M3   5201
#define IDS_DOMAIN_SIG_M4   5202
#define IDS_DOMAIN_SIG_M5   5203

#define IDS_DOMAIN_SIG_X0   5204
#define IDS_DOMAIN_SIG_X1   5205
#define IDS_DOMAIN_SIG_X2   5206
#define IDS_DOMAIN_SIG_X3   5207
#define IDS_DOMAIN_SIG_X4   5208
#define IDS_DOMAIN_SIG_X5   5209

// Strings for domain PSD type listbox
#define NUM_DOMAIN_PSDTYPES        4
#define IDS_DOMAIN_PSDTYPE_0    5216
#define IDS_DOMAIN_PSDTYPE_1    5217
#define IDS_DOMAIN_PSDTYPE_2    5218
#define IDS_DOMAIN_PSDTYPE_3    5219

// Strings for domain sigma type listbox
#define NUM_DOMAIN_SIGTYPES        3
#define IDS_DOMAIN_SIGTYPE_0    5220
#define IDS_DOMAIN_SIGTYPE_1    5221
#define IDS_DOMAIN_SIGTYPE_2    5222

// Strings for drift types
// Phase data
#define IDS_PDRIFT_TYPE_0		6560
#define IDS_PDRIFT_TYPE_1       6561
#define IDS_PDRIFT_TYPE_2       6562
#define IDS_PDRIFT_TYPE_3       6563
#define IDS_PDRIFT_TYPE_4       6564
#define IDS_PDRIFT_TYPE_5       6565
#define IDS_PDRIFT_TYPE_6       6566
// Freq data
#define IDS_FDRIFT_TYPE_0       5266
#define IDS_FDRIFT_TYPE_1       5267
#define IDS_FDRIFT_TYPE_2       5268
#define IDS_FDRIFT_TYPE_3       5269
#define IDS_FDRIFT_TYPE_4		5270

// Strings for drift equations
// Phase data
#define IDS_PDRIFT_EQN_0        6571
#define IDS_PDRIFT_EQN_1        6572
#define IDS_PDRIFT_EQN_2        6573
#define IDS_PDRIFT_EQN_3        6574
#define IDS_PDRIFT_EQN_4        6575
#define IDS_PDRIFT_EQN_5		6576
#define IDS_PDRIFT_EQN_6		6577
// Freq data
#define IDS_FDRIFT_EQN_0        5277
#define IDS_FDRIFT_EQN_1        5278
#define IDS_FDRIFT_EQN_2        5279
#define IDS_FDRIFT_EQN_3        5280
#define IDS_FDRIFT_EQN_4		5281

// Strings for drift noise models
// Phase data
#define IDS_PDRIFT_MODEL_0      6582
#define IDS_PDRIFT_MODEL_1      6583
#define IDS_PDRIFT_MODEL_2      6584
#define IDS_PDRIFT_MODEL_3      6585
#define IDS_PDRIFT_MODEL_4      6586
#define IDS_PDRIFT_MODEL_5		6587
#define IDS_PDRIFT_MODEL_6		6588
// Freq data
#define IDS_FDRIFT_MODEL_0      5288
#define IDS_FDRIFT_MODEL_1      5289
#define IDS_FDRIFT_MODEL_2      5290
#define IDS_FDRIFT_MODEL_3      5291
#define IDS_FDRIFT_MODEL_4		5292

// Message strings
#define IDS_MESSAGE_NOTIMP      5232
#define IDS_MESSAGE_LOGDFT      5233
#define IDS_MESSAGE_TOOBIG      5234
#define IDS_MESSAGE_MEMERR      5235
#define IDS_MESSAGE_TOOFEW      5236
#define IDS_MESSAGE_NOZERO      5237
#define IDS_MESSAGE_NEVER       5238
#define IDS_MESSAGE_CALCMODSIG  5239
#define IDS_MESSAGE_CALC        5240
#define IDS_MESSAGE_NA          5241
#define IDS_MESSAGE_NONOISE     5242
#define IDS_MESSAGE_TOOFEWRUN   5243
#define IDS_MESSAGE_ZERORANGE   5244
#define IDS_MESSAGE_TOOMANY     5245
#define IDS_MESSAGE_NONE        5246
#define IDS_MESSAGE_MODSIG      5247
#define IDS_MESSAGE_TIMESIG     5248
#define IDS_MESSAGE_ALLTAU      5249
#define IDS_MESSAGE_NOSUCHPATH  5250
#define IDS_MESSAGE_REPORT      5251
#define IDS_MESSAGE_PRINT       5252
#define IDS_MESSAGE_DATA        5253
#define IDS_MESSAGE_NGOPEN      5254
#define IDS_MESSAGE_CONFIGURE   5255
#define IDS_MESSAGE_CANTOPEN    5256
#define IDS_MESSAGE_BLANKTAG    5257
#define IDS_MESSAGE_ZEROSIGMA   5258
#define IDS_MESSAGE_ZERORUNSIG  5259
#define IDS_MESSAGE_ZEROFREQ    5293
#define IDS_MESSAGE_TOOBIGINT   5295
#define IDS_MESSAGE_TOOMANYCOLS 5296
#define IDS_MESSAGE_MUSTNORM    5796
#define IDS_MESSAGE_ABORT       5797
#define IDS_MESSAGE_ALLTAUCALC  5798
#define IDS_MESSAGE_INVALID     5799
#define IDS_MESSAGE_SIGDONE     5800
#define IDS_MESSAGE_MANYMISSING 5801
#define IDS_MESSAGE_NGLINFIT    5802
#define IDS_MESSAGE_NGQUADFIT   5803
#define IDS_MESSAGE_NOPHASEDATA 5804
#define IDS_MESSAGE_NGREFPROC   5805
#define IDS_MESSAGE_NGCLKPROC   5806
#define IDS_MESSAGE_NODATA      5807
#define IDS_MESSAGE_NOFREQDATA  5856
#define IDS_MESSAGE_CALCLOGFIT  5857
#define IDS_MESSAGE_CALCDIFFIT  5858
#define IDS_MESSAGE_LINENG      5859
#define IDS_MESSAGE_OMITLINE    5860
#define IDS_MESSAGE_START       5861
#define IDS_MESSAGE_FILENAMES   5862
#define IDS_MESSAGE_NOARCHIVE   5863
#define IDS_MESSAGE_NGARCHIVE   5864
#define IDS_MESSAGE_CHANSEQUAL  5865
#define IDS_MESSAGE_MTIECALC    5866
#define IDS_MESSAGE_LITE		5867
#define IDS_MESSAGE_NOISEMEM	5868
#define IDS_MESSAGE_GAPS		5870
#define IDS_MESSAGE_RUNERROR	5294
#define IDS_MESSAGE_NEWTAU		5869
#define IDS_MESSAGE_RUNDONE		5871

// Heading strings
#define IDS_HEADING_1           5392
#define IDS_HEADING_2           5393
#define IDS_HEADING_3           5394
#define IDS_HEADING_4           5395
#define IDS_HEADING_5           5396
#define IDS_HEADING_6           5397
#define IDS_HEADING_7           5398
#define IDS_HEADING_8           5399
#define IDS_HEADING_9           5400
#define IDS_HEADING_10          5401
#define IDS_HEADING_11          5402
#define IDS_HEADING_12          5403
#define IDS_HEADING_13          5404
#define IDS_HEADING_14          5405
#define IDS_HEADING_15          5406
#define IDS_HEADING_16          5407
#define IDS_HEADING_17          5408
#define IDS_HEADING_18          5409
#define IDS_HEADING_19          5410
#define IDS_HEADING_20          5411
#define IDS_HEADING_21          5412
#define IDS_HEADING_22			5413
#define IDS_HEADING_23			5427
#define IDS_HEADING_24			5428
#define IDS_HEADING_25			5429
#define IDS_HEADING_26			5389
#define IDS_HEADING_27			5390
#define IDS_HEADING_28          5414
#define IDS_HEADING_29          5415

// Title strings
#define IDS_TITLE_READOPT       5344
#define IDS_TITLE_READLINE      5345
#define IDS_TITLE_READNOTE      5346
#define IDS_TITLE_SIGMAOPT      5347
#define IDS_TITLE_SIGMALINE     5348
#define IDS_TITLE_SIGMANOTE     5349
#define IDS_TITLE_PHASEOPT      5350
#define IDS_TITLE_PHASELINE     5351
#define IDS_TITLE_PHASENOTE     5352
#define IDS_TITLE_FREQOPT       5353
#define IDS_TITLE_FREQLINE      5354
#define IDS_TITLE_FREQNOTE      5355
#define IDS_TITLE_SIGPLOT       5356
#define IDS_TITLE_SIGFILE       5357
#define IDS_TITLE_SPECTPLOT     5358
#define IDS_TITLE_SPECTOPT      5359
#define IDS_TITLE_SPECTLINE     5316
#define IDS_TITLE_SPECTNOTE     5317
#define IDS_TITLE_LINENG        5318
#define IDS_TITLE_FREQPLOT      5319
#define IDS_TITLE_PHASEPLOT     5320

// Format strings
#define IDS_FORMAT_GT           5360
#define IDS_FORMAT_LT           5361
#define IDS_FORMAT_1            5362
#define IDS_FORMAT_2            5363
#define IDS_FORMAT_3            5364
#define IDS_FORMAT_4            5365
#define IDS_FORMAT_5            5366
#define IDS_FORMAT_6            5367
#define IDS_FORMAT_7            5368
#define IDS_FORMAT_8            5369
#define IDS_FORMAT_9            5370
#define IDS_FORMAT_10           5371
#define IDS_FORMAT_11           5372
#define IDS_FORMAT_12           5373
#define IDS_FORMAT_13           5374
#define IDS_FORMAT_14           5375
#define IDS_FORMAT_15           5376
#define IDS_FORMAT_16           5377
#define IDS_FORMAT_17           5378
#define IDS_FORMAT_18           5379
#define IDS_FORMAT_19           5380
#define IDS_FORMAT_20           5381
#define IDS_FORMAT_21           5382
#define IDS_FORMAT_22           5383
#define IDS_FORMAT_23           5384
#define IDS_FORMAT_24           5385
#define IDS_FORMAT_25			5386
#define IDS_FORMAT_26			5387
#define IDS_FORMAT_27			5388
#define IDS_FORMAT_28           5391
#define IDS_FORMAT_29			5416
#define IDS_FORMAT_30			5417
#define IDS_FORMAT_31			5418

// Sigma plot x-axis labels
#define IDS_SPLOT_XAXIS_0       5584

// Format string labels for sigma line messages
#define IDS_FORMAT_LINE_0		5590
#define IDS_FORMAT_LINE_1		5591
#define IDS_FORMAT_LINE_2		5592
#define IDS_FORMAT_LINE_3		5593
#define IDS_FORMAT_LINE_4		5594
#define IDS_FORMAT_LINE_5		5595

// Format strings for phase plot line printout
#define IDS_FORMAT_PLINE_0		6100
#define IDS_FORMAT_PLINE_1		6101
#define IDS_FORMAT_PLINE_2		6102
#define IDS_FORMAT_PLINE_3		6103
#define IDS_FORMAT_PLINE_4		6104
#define IDS_FORMAT_PLINE_5		6105 // Added 07/24/10
#define IDS_FORMAT_PLINE_PH		6108
#define IDS_FORMAT_PLINE_CH		6109

// Format strings for freq plot line printout
#define IDS_FORMAT_FLINE_0		6110
#define IDS_FORMAT_FLINE_1		6111
#define IDS_FORMAT_FLINE_2		6112
#define IDS_FORMAT_FLINE_3		6113
#define IDS_FORMAT_FLINE_4		6114
#define IDS_FORMAT_FLINE_PH		6118
#define IDS_FORMAT_FLINE_CH		6119

// Format strings for sigma plot line printout
#define IDS_FORMAT_SLINE_0		6120
#define IDS_FORMAT_SLINE_1		6121
#define IDS_FORMAT_SLINE_2		6122
#define IDS_FORMAT_SLINE_3		6123
#define IDS_FORMAT_SLINE_4		6124
#define IDS_FORMAT_SLINE_5		6125
#define IDS_FORMAT_SLINE_6		6126
#define IDS_FORMAT_SLINE_PH		6128
#define IDS_FORMAT_SLINE_CH		6129

// Sigma plot y-axis labels
#define IDS_SPLOT_YAXIS_0       5600
#define IDS_SPLOT_YAXIS_1       5601
#define IDS_SPLOT_YAXIS_2       5602
#define IDS_SPLOT_YAXIS_3       5603
#define IDS_SPLOT_YAXIS_4       5604
#define IDS_SPLOT_YAXIS_5       5605
#define IDS_SPLOT_YAXIS_6       5606
#define IDS_SPLOT_YAXIS_7       5607
#define IDS_SPLOT_YAXIS_8       5608

// Spectrum plot axis labels
#define IDS_PSPLOT_XLABEL       5432
#define IDS_PSPLOT_YLABEL_0     5433
#define IDS_PSPLOT_YLABEL_1     5434
#define IDS_PSPLOT_YLABEL_2     5435
#define IDS_PSPLOT_YLABEL_3     5436
#define IDS_PSPLOT_YLABEL_4     5437
#define IDS_PSPLOT_YLABEL_5     5438
#define IDS_PSPLOT_XLABEL_0     5872
#define IDS_PSPLOT_YLABEL_6     5873
#define IDS_PSPLOT_YLABEL_7     5874
#define IDS_PSPLOT_YLABEL_8     5875
#define IDS_PSPLOT_YLABEL_9     5876
#define IDS_PSPLOT_YLABEL_10    5877
#define IDS_PSPLOT_YLABEL_11    5878
#define IDS_PSPLOT_YLABEL_12    5879

// Spectrum plot PSD types
#define IDS_PSDTYPE_0           5616
#define IDS_PSDTYPE_1           5617
#define IDS_PSDTYPE_2           5618
#define IDS_PSDTYPE_3           5619

// Spectrum windowing types
#define IDS_WINTYPE_0           5464
#define IDS_WINTYPE_1           5465
#define IDS_WINTYPE_2           5466
#define IDS_WINTYPE_3			5467

// Histogram plot axis labels
#define IDS_HPLOT_XLABEL_0      5480
#define IDS_HPLOT_XLABEL_1      5481
#define IDS_HPLOT_XLABEL_2      5482
#define IDS_HPLOT_XLABEL_3      5483
#define IDS_HPLOT_YLABEL_0      5484
#define IDS_HPLOT_YLABEL_1      5485

// Sigma noise types
#define IDS_SIGMA_NOISE_0       5808
#define IDS_SIGMA_NOISE_1       5809
#define IDS_SIGMA_NOISE_2       5810
#define IDS_SIGMA_NOISE_3       5811
#define IDS_SIGMA_NOISE_4       5812
#define IDS_SIGMA_NOISE_5       5813
#define IDS_SIGMA_NOISE_6       5814

// Audio sampling rates
#define NUM_CONFIG_SAMPLERATES  5
// These must be in order
#define IDS_CONFIG_RATE_0		6375
#define IDS_CONFIG_RATE_1		6376
#define IDS_CONFIG_RATE_2		6377
#define IDS_CONFIG_RATE_3		6378
#define IDS_CONFIG_RATE_4		6379

 // INI file sections
#define IDS_INI_SECTION_0       5888
#define IDS_INI_SECTION_1       5889
#define IDS_INI_SECTION_2       5890
#define IDS_INI_SECTION_3       5891
#define IDS_INI_SECTION_4       5892
#define IDS_INI_SECTION_5       5893
#define IDS_INI_SECTION_6       5894
#define IDS_INI_SECTION_7       5895
#define IDS_INI_SECTION_8       5896
#define IDS_INI_SECTION_9       5897
#define IDS_INI_SECTION_10      5898
#define IDS_INI_SECTION_11      5899
#define IDS_INI_SECTION_12      6000
#define IDS_INI_SECTION_13      6001
#define IDS_INI_SECTION_14      6002
#define IDS_INI_SECTION_15      6003 // Read-only inputs
#define IDS_INI_SECTION_16		6093 // Autocorrelation plot
#define IDS_INI_SECTION_17		6094 // DAVAR plot
#define IDS_INI_SECTION_18		6095 // Audio

// INI file keys
#define IDS_INI_KEY_0           6016
#define IDS_INI_KEY_1           6017
#define IDS_INI_KEY_2           6018
#define IDS_INI_KEY_3           6019
#define IDS_INI_KEY_4           6020
#define IDS_INI_KEY_5           6021
#define IDS_INI_KEY_6           6022
#define IDS_INI_KEY_7           6023
#define IDS_INI_KEY_8           6024
#define IDS_INI_KEY_9           6025
#define IDS_INI_KEY_10          6026
#define IDS_INI_KEY_11          6027
#define IDS_INI_KEY_12          6028
#define IDS_INI_KEY_13          6029
#define IDS_INI_KEY_14          6030
#define IDS_INI_KEY_15          6031
#define IDS_INI_KEY_16          6032
#define IDS_INI_KEY_17          6033
#define IDS_INI_KEY_18          6034
#define IDS_INI_KEY_19          6035
#define IDS_INI_KEY_20          6036
#define IDS_INI_KEY_21          6037
#define IDS_INI_KEY_22          6038
#define IDS_INI_KEY_23          6039
#define IDS_INI_KEY_24          6040
#define IDS_INI_KEY_25          6041
#define IDS_INI_KEY_26          6042
#define IDS_INI_KEY_27          6043
#define IDS_INI_KEY_28          6044
#define IDS_INI_KEY_29          6045
#define IDS_INI_KEY_30          6046
#define IDS_INI_KEY_31          6047
#define IDS_INI_KEY_32          6048
#define IDS_INI_KEY_33          6049
#define IDS_INI_KEY_34          6050
#define IDS_INI_KEY_35          6051
#define IDS_INI_KEY_36          6052
#define IDS_INI_KEY_37          6053
#define IDS_INI_KEY_38          6054
#define IDS_INI_KEY_39          6055
#define IDS_INI_KEY_40          6056
#define IDS_INI_KEY_41          6057
#define IDS_INI_KEY_42          6058
#define IDS_INI_KEY_43          6059
#define IDS_INI_KEY_44          6060
#define IDS_INI_KEY_45          6061
#define IDS_INI_KEY_46          6062
#define IDS_INI_KEY_47          6063
#define IDS_INI_KEY_48          6064
#define IDS_INI_KEY_49          6065
#define IDS_INI_KEY_50          6066
#define IDS_INI_KEY_51          6067
#define IDS_INI_KEY_52          6068
#define IDS_INI_KEY_53          6069
#define IDS_INI_KEY_54          6070
#define IDS_INI_KEY_55          6071
#define IDS_INI_KEY_56          6072 
#define IDS_INI_KEY_57          6073
#define IDS_INI_KEY_58			6074
#define IDS_INI_KEY_59			6075
#define IDS_INI_KEY_60			6076
#define IDS_INI_KEY_61			6077
#define IDS_INI_KEY_62			6004
#define IDS_INI_KEY_63			6005
#define IDS_INI_KEY_64			6006
#define IDS_INI_KEY_65			6007
#define IDS_INI_KEY_66			6008
#define IDS_INI_KEY_67			6009
#define IDS_INI_KEY_68			6010
#define IDS_INI_KEY_69			6011
#define IDS_INI_KEY_70			6012
#define IDS_INI_KEY_71			6013
#define IDS_INI_KEY_72			6014
#define IDS_INI_KEY_73			6015
#define IDS_INI_KEY_74		    6078
#define IDS_INI_KEY_75			6079
#define IDS_INI_KEY_76			6300
#define IDS_INI_KEY_77		    6301
#define IDS_INI_KEY_78		    6302
#define IDS_INI_KEY_79		    6303
#define IDS_INI_KEY_80		    6304
#define IDS_INI_KEY_81		    6305
#define IDS_INI_KEY_82		    6306
#define IDS_INI_KEY_83		    6307
#define IDS_INI_KEY_84		    6308
#define IDS_INI_KEY_85		    6309
#define IDS_INI_KEY_86			6310
#define IDS_INI_KEY_87			6311
#define IDS_INI_KEY_88			6312
#define IDS_INI_KEY_89			6313
#define IDS_INI_KEY_90		    6314
#define IDS_INI_KEY_91		    6315
#define IDS_INI_KEY_92		    6316
#define IDS_INI_KEY_93		    6317
#define IDS_INI_KEY_94		    6318
#define IDS_INI_KEY_95		    6319
#define IDS_INI_KEY_96		    6320
#define IDS_INI_KEY_97		    6321
#define IDS_INI_KEY_98		    6322
#define IDS_INI_KEY_99		    6323
#define IDS_INI_KEY_100		    6324
#define IDS_INI_KEY_101		    6325
#define IDS_INI_KEY_102		    6326
#define IDS_INI_KEY_103		    6327
#define IDS_INI_KEY_104		    6328
#define IDS_INI_KEY_105		    6329
#define IDS_INI_KEY_106		    6330
#define IDS_INI_KEY_107			6331
#define IDS_INI_KEY_108			6332
#define IDS_INI_KEY_109			6333
#define IDS_INI_KEY_110			6334
#define IDS_INI_KEY_111			6335
#define IDS_INI_KEY_112			6336
#define IDS_INI_KEY_113			6337
#define IDS_INI_KEY_114			6338
#define IDS_INI_KEY_115			6339
#define IDS_INI_KEY_116			6340
#define IDS_INI_KEY_117			6341
#define IDS_INI_KEY_118			6342
#define IDS_INI_KEY_119			6343
#define IDS_INI_KEY_120			6344
#define IDS_INI_KEY_121			6345
#define IDS_INI_KEY_122			6346
#define IDS_INI_KEY_123			6347
#define IDS_INI_KEY_124			6348
#define IDS_INI_KEY_125			6349
#define IDS_INI_KEY_126			6350
#define IDS_INI_KEY_127			6351
#define IDS_INI_KEY_128			6352
#define IDS_INI_KEY_129			6353
#define IDS_INI_KEY_130			6354
#define IDS_INI_KEY_131			6355
#define IDS_INI_KEY_132			6356
#define IDS_INI_KEY_133			6357
#define IDS_INI_KEY_134			6358
// The keys below are spares
#define IDS_INI_KEY_135			6359
#define IDS_INI_KEY_136			6360
#define IDS_INI_KEY_137			6361
#define IDS_INI_KEY_138			6362
#define IDS_INI_KEY_139			6363
#define IDS_INI_KEY_140			6364
// Strings 6365-6374 are additional spares

// Max run sizes
#define IDS_INI_KEY_141			6381  
#define IDS_INI_KEY_142			6382  
#define IDS_INI_KEY_143			6383  
#define IDS_INI_KEY_144			6384  
#define IDS_INI_KEY_145			6385  
#define IDS_INI_KEY_146			6386  
#define IDS_INI_KEY_147			6387  
#define IDS_INI_KEY_148			6388  
#define IDS_INI_KEY_149			6389  
#define IDS_INI_KEY_150			6390  
#define IDS_INI_KEY_151			6391  
#define IDS_INI_KEY_152			6392  
#define IDS_INI_KEY_153			6393 
#define IDS_INI_KEY_154			6394  
#define IDS_INI_KEY_155			6395
// The keys below are spares  
#define IDS_INI_KEY_156			6396  
#define IDS_INI_KEY_157			6397  
#define IDS_INI_KEY_158			6398  
#define IDS_INI_KEY_159			6399  

// Misc strings
#define IDS_OPENED_ADD          5568

// Version information
#define IDS_VERSION_NUMBER      5840
#define IDS_VERSION_DATE        5841
#define IDS_FREQUENC_VER        5842
#define IDS_VERSION_STUNUM      5843
#define IDS_VERSION_STUDATE     5844
#define IDS_VERSION_LITENUM     5845
#define IDS_VERSION_LITEDATE    5846
#define IDS_VERSION_DEMONUM     5847
#define IDS_VERSION_DEMODATE    5848

// Log file strings
#define IDS_LOG_0               6200
#define IDS_LOG_1               6201
#define IDS_LOG_2               6202
#define IDS_LOG_3               6203
#define IDS_LOG_4               6204
#define IDS_LOG_5               6205
#define IDS_LOG_6               6206
#define IDS_LOG_7               6207
#define IDS_LOG_8               6208
#define IDS_LOG_9               6209
#define IDS_LOG_10              6210
#define IDS_LOG_11              6211
#define IDS_LOG_12              6212
#define IDS_LOG_13              6213
#define IDS_LOG_14              6214
#define IDS_LOG_15              6215
#define IDS_LOG_16              6216
#define IDS_LOG_17              6217
#define IDS_LOG_18              6218
#define IDS_LOG_19              6219
#define IDS_LOG_20              6220
#define IDS_LOG_21              6221
#define IDS_LOG_22              6222
#define IDS_LOG_23              6223
#define IDS_LOG_24              6224
#define IDS_LOG_25              6225
#define IDS_LOG_26              6226
#define IDS_LOG_27              6227
#define IDS_LOG_28              6228
#define IDS_LOG_29              6229
#define IDS_LOG_30              6230
#define IDS_LOG_31              6231
#define IDS_LOG_32              6232
#define IDS_LOG_33              6233
#define IDS_LOG_34              6234
#define IDS_LOG_35              6235
#define IDS_LOG_36              6236
#define IDS_LOG_37              6237
#define IDS_LOG_38              6238
#define IDS_LOG_39              6239
#define IDS_LOG_40              6240
#define IDS_LOG_41              6241
#define IDS_LOG_42              6242
#define IDS_LOG_43              6243
#define IDS_LOG_44              6244
#define IDS_LOG_45              6245
#define IDS_LOG_46              6246
#define IDS_LOG_47              6247
#define IDS_LOG_48              6248
#define IDS_LOG_49              6249
#define IDS_LOG_50              6250
#define IDS_LOG_51              6251
#define IDS_LOG_52              6252
#define IDS_LOG_53              6253
#define IDS_LOG_54              6254
#define IDS_LOG_55              6255
#define IDS_LOG_56              6256
#define IDS_LOG_57              6257
#define IDS_LOG_58              6258
#define IDS_LOG_59              6259
#define IDS_LOG_60				6260
#define IDS_LOG_61				6261
#define IDS_LOG_62				6262
#define IDS_LOG_63				6263
#define IDS_LOG_64				6264
#define IDS_LOG_65				6265
#define IDS_LOG_66				6266
#define IDS_LOG_67				6267
#define IDS_LOG_68				6268
#define IDS_LOG_69				6269
#define IDS_LOG_70				6270
#define IDS_LOG_71				6271
#define IDS_LOG_72				6272
#define IDS_LOG_73				6273
#define IDS_LOG_74				6274
#define IDS_LOG_75				6275
#define IDS_LOG_76				6276
#define IDS_LOG_77				6277
#define IDS_LOG_78				6278
#define IDS_LOG_79				6279
#define IDS_LOG_80				6280
#define IDS_LOG_81				6281
#define IDS_LOG_82				6282
#define IDS_LOG_83				6283
#define IDS_LOG_84				6284
